Class: Bfwd::AddChargeRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/add_charge_request.rb

Overview

Request object for raising a charge against a subscription or invoice.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AddChargeRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 145

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.has_key?(:'taxAmount')
    self.tax_amount = attributes[:'taxAmount']
  else
    self.tax_amount = false
  end

  if attributes.has_key?(:'periodStart')
    self.period_start = attributes[:'periodStart']
  end

  if attributes.has_key?(:'periodEnd')
    self.period_end = attributes[:'periodEnd']
  end

  if attributes.has_key?(:'invoicingType')
    self.invoicing_type = attributes[:'invoicingType']
  end

  if attributes.has_key?(:'chargeType')
    self.charge_type = attributes[:'chargeType']
  end

  if attributes.has_key?(:'trial')
    self.trial = attributes[:'trial']
  else
    self.trial = false
  end

  if attributes.has_key?(:'remainingCreditBehaviour')
    self.remaining_credit_behaviour = attributes[:'remainingCreditBehaviour']
  end

  if attributes.has_key?(:'pricingComponent')
    self.pricing_component = attributes[:'pricingComponent']
  end

  if attributes.has_key?(:'pricingComponentValue')
    self.pricing_component_value = attributes[:'pricingComponentValue']
  end

  if attributes.has_key?(:'dryRun')
    self.dry_run = attributes[:'dryRun']
  else
    self.dry_run = false
  end

end

Instance Attribute Details

#amountObject

amount for which to charge. Used only for ad-hoc charges i.e charges not associated with any pricing component. Applicable if pricingComponent is NOT defined“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 45

def amount
  @amount
end

#charge_typeObject

class=\"label label-default\">Debit</span>","description":"Whether this charge represents an increase or decrease in invoice cost
<span class=\"label label-default\">Credit</span> &mdash; This results in a reduction to the invoice cost
<span class=\"label label-default\">Debit</span> &mdash; This will increase the invoice cost“,”verbs“:



60
61
62
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 60

def charge_type
  @charge_type
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 30

def created
  @created
end

#currencyObject

{ "description" : "Currency of the invoice specified by a three character ISO 4217 currency code.", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 42

def currency
  @currency
end

#descriptionObject

href="\"POST\",\"GET\"">description“:”“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 39

def description
  @description
end

#dry_runObject

described in the response:
<span class=\"label label-default\">true</span> &mdash; Are not actually performed; your subscription remains unchanged, no billing events run, and no invoices are executed.
<span class=\"label label-default\">false</span> &mdash; Are actually performed and committed.“,”verbs“:



75
76
77
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 75

def dry_run
  @dry_run
end

#idObject

of an existing charge to add to the invoice ","verbs“:



33
34
35
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 33

def id
  @id
end

#invoicing_typeObject

class=\"label label-default\">Aggregated</span>","description":"Applicable if adding a charge to the subscription.
<span class=\"label label-default\">Immediate</span> &mdash; Generate straight-away an invoice containing these charges.
<span class=\"label label-default\">Aggregated</span> &mdash; Add these charges to the next invoice &mdash; for example the invoice raised at the current period’s end.“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 57

def invoicing_type
  @invoicing_type
end

#nameObject

name given to the charge to help identify it.“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 36

def name
  @name
end

#period_endObject

of current period)","description":"(Applicable only if pricingComponent is defined)
End of the interval to which the charge applies. Used in pro-rata calculation“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 54

def period_end
  @period_end
end

#period_startObject

of the interval to which the charge applies. This can be used to apply a charge across partial or multiple periods. Pro-rating the price of pricingComponents purchased“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 51

def period_start
  @period_start
end

#pricing_componentObject

that this charge is for consumption of some quantity of this pricing component (whose name or ID can be provided).
If left blank:
The charge will be created as ‘ad-hoc’. That is: a monetary lump sum, associated with no pricing component“,”verbs“:



69
70
71
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 69

def pricing_component
  @pricing_component
end

#pricing_component_valueObject

value consumed of the pricing component which this charge concerns.Required if pricingComponent is defined“,”verbs“:



72
73
74
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 72

def pricing_component_value
  @pricing_component_value
end

#remaining_credit_behaviourObject

class=\"label label-default\">Rollover</span>","description":"Defines the behaviour applied to any outstanding credit resulting from the application of the charge.
<span class=\"label label-default\">Rollover</span> &mdash; Outstanding credit is returned to the accounts credit pool.
<span class=\"label label-default\">Discard</span> &mdash; Outstanding credit is lost.“,”verbs“:



66
67
68
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 66

def remaining_credit_behaviour
  @remaining_credit_behaviour
end

#tax_amountObject

if amount is specified and indicates whether or not to apply tax in addition to the value specified.
<span class=\"label label-default\">true</span> &mdash; Tax will be added on top of the nominal price specified in amount &mdash; in accordance with any taxation strategies you have defined.
<span class=\"label label-default\">false</span> &mdash; No tax will be applied on top of the price specified in amount.“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 48

def tax_amount
  @tax_amount
end

#trialObject

the charge is meant in the context of a trial.
<span class=\"label label-default\">false</span> &mdash; This is a non-trial charge, so funds will be sought from the customer.
<span class=\"label label-default\">true</span> &mdash; This is a trial charge, soThe charge can be considered ‘Paid’ without taking any funds from the customer.“,”verbs“:



63
64
65
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 63

def trial
  @trial
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 100

def self.attribute_map
  {
    :'created' => :'created',
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'currency' => :'currency',
    :'amount' => :'amount',
    :'tax_amount' => :'taxAmount',
    :'period_start' => :'periodStart',
    :'period_end' => :'periodEnd',
    :'invoicing_type' => :'invoicingType',
    :'charge_type' => :'chargeType',
    :'trial' => :'trial',
    :'remaining_credit_behaviour' => :'remainingCreditBehaviour',
    :'pricing_component' => :'pricingComponent',
    :'pricing_component_value' => :'pricingComponentValue',
    :'dry_run' => :'dryRun'
  }
end

.swagger_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 122

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'currency' => :'String',
    :'amount' => :'Float',
    :'tax_amount' => :'BOOLEAN',
    :'period_start' => :'DateTime',
    :'period_end' => :'DateTime',
    :'invoicing_type' => :'String',
    :'charge_type' => :'String',
    :'trial' => :'BOOLEAN',
    :'remaining_credit_behaviour' => :'String',
    :'pricing_component' => :'String',
    :'pricing_component_value' => :'Integer',
    :'dry_run' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 275

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      currency == o.currency &&
      amount == o.amount &&
      tax_amount == o.tax_amount &&
      period_start == o.period_start &&
      period_end == o.period_end &&
      invoicing_type == o.invoicing_type &&
      charge_type == o.charge_type &&
      trial == o.trial &&
      remaining_credit_behaviour == o.remaining_credit_behaviour &&
      pricing_component == o.pricing_component &&
      pricing_component_value == o.pricing_component_value &&
      dry_run == o.dry_run
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 332

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 398

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 311

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 298

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



304
305
306
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 304

def hash
  [created, id, name, description, currency, amount, tax_amount, period_start, period_end, invoicing_type, charge_type, trial, remaining_credit_behaviour, pricing_component, pricing_component_value, dry_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



225
226
227
228
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 225

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 378

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



384
385
386
387
388
389
390
391
392
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 384

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



372
373
374
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 372

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
# File 'lib/bf_ruby2/models/add_charge_request.rb', line 232

def valid?
  invoicing_type_validator = EnumAttributeValidator.new('String', ["Immediate", "Aggregated"])
  return false unless invoicing_type_validator.valid?(@invoicing_type)
  charge_type_validator = EnumAttributeValidator.new('String', ["Credit", "Debit"])
  return false unless charge_type_validator.valid?(@charge_type)
  return false if @remaining_credit_behaviour.nil?
  remaining_credit_behaviour_validator = EnumAttributeValidator.new('String', ["Rollover", "Discard"])
  return false unless remaining_credit_behaviour_validator.valid?(@remaining_credit_behaviour)
  return true
end