Class: Bfwd::AddChargesToAccountAPIRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/add_charges_to_account_api_request.rb

Overview

Request object for raising a charge against an account.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AddChargesToAccountAPIRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 115

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'purchaseOrder')
    self.purchase_order = attributes[:'purchaseOrder']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'paymentTerms')
    self.payment_terms = attributes[:'paymentTerms']
  end

  if attributes.has_key?(:'remainingCreditBehaviour')
    self.remaining_credit_behaviour = attributes[:'remainingCreditBehaviour']
  end

  if attributes.has_key?(:'invoiceState')
    self.invoice_state = attributes[:'invoiceState']
  end

  if attributes.has_key?(:'charges')
    if (value = attributes[:'charges']).is_a?(Array)
      self.charges = value
    end
  end

  if attributes.has_key?(:'dryRun')
    self.dry_run = attributes[:'dryRun']
  end

  if attributes.has_key?(:'voidOnFailure')
    self.void_on_failure = attributes[:'voidOnFailure']
  end

end

Instance Attribute Details

#chargesObject

charges which shall be added to the Account.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 51

def charges
  @charges
end

#currencyObject

of the charges raised, specified by a three-character ISO 4217 currency code.“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 39

def currency
  @currency
end

#descriptionObject

to apply to any Invoice immediately produced when adding charges“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 36

def description
  @description
end

#dry_runObject

the effects of adding charges to an Account, but do not actually persist any changes.“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 54

def dry_run
  @dry_run
end

#invoice_stateObject

the state of the resulting adhoc invoice if the invoicing type is Immediate“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 48

def invoice_state
  @invoice_state
end

#nameObject

name given to any Invoice immediately produced when adding charges.“,”verbs“:



30
31
32
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 30

def name
  @name
end

#payment_termsObject

the ‘payment terms’ for any Invoice generated as a result of this action. Number of days after the issued date that the invoice is due. Payment will be attempted regardless of the payment terms. Payment terms are all Net.“,”verbs“:



42
43
44
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 42

def payment_terms
  @payment_terms
end

#purchase_orderObject

order associated with any Invoice immediately produced when adding charges.“,”verbs“:



33
34
35
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 33

def purchase_order
  @purchase_order
end

#remaining_credit_behaviourObject

class=\"label label-default\">Rollover</span>","description":"Defines the behaviour applied to any outstanding credit resulting from the application of the charge.
<span class=\"label label-default\">Rollover</span> &mdash; Outstanding credit is returned to the accounts credit pool.
<span class=\"label label-default\">Discard</span> &mdash; Outstanding credit is lost.“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 45

def remaining_credit_behaviour
  @remaining_credit_behaviour
end

#void_on_failureObject

we have created an adhoc invoice and it has had an unsuccessful payment attempt, should we void it“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 57

def void_on_failure
  @void_on_failure
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 82

def self.attribute_map
  {
    :'name' => :'name',
    :'purchase_order' => :'purchaseOrder',
    :'description' => :'description',
    :'currency' => :'currency',
    :'payment_terms' => :'paymentTerms',
    :'remaining_credit_behaviour' => :'remainingCreditBehaviour',
    :'invoice_state' => :'invoiceState',
    :'charges' => :'charges',
    :'dry_run' => :'dryRun',
    :'void_on_failure' => :'voidOnFailure'
  }
end

.swagger_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 98

def self.swagger_types
  {
    :'name' => :'String',
    :'purchase_order' => :'String',
    :'description' => :'String',
    :'currency' => :'String',
    :'payment_terms' => :'Integer',
    :'remaining_credit_behaviour' => :'String',
    :'invoice_state' => :'String',
    :'charges' => :'Array<NestedChargeRequest>',
    :'dry_run' => :'BOOLEAN',
    :'void_on_failure' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      purchase_order == o.purchase_order &&
      description == o.description &&
      currency == o.currency &&
      payment_terms == o.payment_terms &&
      remaining_credit_behaviour == o.remaining_credit_behaviour &&
      invoice_state == o.invoice_state &&
      charges == o.charges &&
      dry_run == o.dry_run &&
      void_on_failure == o.void_on_failure
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 255

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 321

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 234

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 221

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



227
228
229
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 227

def hash
  [name, purchase_order, description, currency, payment_terms, remaining_credit_behaviour, invoice_state, charges, dry_run, void_on_failure].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



167
168
169
170
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 167

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 301

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



295
296
297
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 295

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
# File 'lib/bf_ruby2/models/add_charges_to_account_api_request.rb', line 174

def valid?
  remaining_credit_behaviour_validator = EnumAttributeValidator.new('String', ["Rollover", "Discard"])
  return false unless remaining_credit_behaviour_validator.valid?(@remaining_credit_behaviour)
  invoice_state_validator = EnumAttributeValidator.new('String', ["Unpaid", "Pending"])
  return false unless invoice_state_validator.valid?(@invoice_state)
  return true
end