Class: Bfwd::Address
- Inherits:
-
Object
- Object
- Bfwd::Address
- Defined in:
- lib/bf_ruby2/models/address.rb
Overview
Address
Instance Attribute Summary collapse
-
#address_line1 ⇒ Object
{ "description" : "", "verbs“: }.
-
#address_line2 ⇒ Object
{ "description" : "", "verbs“: }.
-
#address_line3 ⇒ Object
{ "description" : "", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#city ⇒ Object
{ "description" : "", "verbs“: }.
-
#country ⇒ Object
{ "description" : "", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#deleted ⇒ Object
{ "description" : "", "verbs“: }.
-
#id ⇒ Object
{ "description" : "", "verbs“: }.
-
#landline ⇒ Object
{ "description" : "Phone number", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "", "verbs":[] }.
-
#postcode ⇒ Object
{ "description" : "ZIP code or postcode.", "verbs“: }.
-
#primary_address ⇒ Object
{ "description" : "Is this the primary, default, address for the associated profile?", "verbs“: }.
-
#profile_id ⇒ Object
{ "description" : "", "verbs“: }.
-
#province ⇒ Object
{ "description" : "", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Address
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Address
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/bf_ruby2/models/address.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'profileID') self.profile_id = attributes[:'profileID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'addressLine1') self.address_line1 = attributes[:'addressLine1'] end if attributes.has_key?(:'addressLine2') self.address_line2 = attributes[:'addressLine2'] end if attributes.has_key?(:'addressLine3') self.address_line3 = attributes[:'addressLine3'] end if attributes.has_key?(:'city') self.city = attributes[:'city'] end if attributes.has_key?(:'province') self.province = attributes[:'province'] end if attributes.has_key?(:'country') self.country = attributes[:'country'] end if attributes.has_key?(:'postcode') self.postcode = attributes[:'postcode'] end if attributes.has_key?(:'landline') self.landline = attributes[:'landline'] end if attributes.has_key?(:'primaryAddress') self.primary_address = attributes[:'primaryAddress'] else self.primary_address = false end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end end |
Instance Attribute Details
#address_line1 ⇒ Object
{ "description" : "", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/address.rb', line 48 def address_line1 @address_line1 end |
#address_line2 ⇒ Object
{ "description" : "", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/address.rb', line 51 def address_line2 @address_line2 end |
#address_line3 ⇒ Object
{ "description" : "", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/address.rb', line 54 def address_line3 @address_line3 end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/address.rb', line 33 def changed_by @changed_by end |
#city ⇒ Object
{ "description" : "", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/address.rb', line 57 def city @city end |
#country ⇒ Object
{ "description" : "", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/address.rb', line 63 def country @country end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/address.rb', line 30 def created @created end |
#deleted ⇒ Object
{ "description" : "", "verbs“: }
75 76 77 |
# File 'lib/bf_ruby2/models/address.rb', line 75 def deleted @deleted end |
#id ⇒ Object
{ "description" : "", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/address.rb', line 39 def id @id end |
#landline ⇒ Object
{ "description" : "Phone number", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/address.rb', line 69 def landline @landline end |
#organization_id ⇒ Object
{ "description" : "", "verbs":[] }
45 46 47 |
# File 'lib/bf_ruby2/models/address.rb', line 45 def organization_id @organization_id end |
#postcode ⇒ Object
{ "description" : "ZIP code or postcode.", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/address.rb', line 66 def postcode @postcode end |
#primary_address ⇒ Object
{ "description" : "Is this the primary, default, address for the associated profile?", "verbs“: }
72 73 74 |
# File 'lib/bf_ruby2/models/address.rb', line 72 def primary_address @primary_address end |
#profile_id ⇒ Object
{ "description" : "", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/address.rb', line 42 def profile_id @profile_id end |
#province ⇒ Object
{ "description" : "", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/address.rb', line 60 def province @province end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/address.rb', line 36 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/bf_ruby2/models/address.rb', line 79 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'profile_id' => :'profileID', :'organization_id' => :'organizationID', :'address_line1' => :'addressLine1', :'address_line2' => :'addressLine2', :'address_line3' => :'addressLine3', :'city' => :'city', :'province' => :'province', :'country' => :'country', :'postcode' => :'postcode', :'landline' => :'landline', :'primary_address' => :'primaryAddress', :'deleted' => :'deleted' } end |
.swagger_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/bf_ruby2/models/address.rb', line 101 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'profile_id' => :'String', :'organization_id' => :'String', :'address_line1' => :'String', :'address_line2' => :'String', :'address_line3' => :'String', :'city' => :'String', :'province' => :'String', :'country' => :'String', :'postcode' => :'String', :'landline' => :'String', :'primary_address' => :'BOOLEAN', :'deleted' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/bf_ruby2/models/address.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && profile_id == o.profile_id && organization_id == o.organization_id && address_line1 == o.address_line1 && address_line2 == o.address_line2 && address_line3 == o.address_line3 && city == o.city && province == o.province && country == o.country && postcode == o.postcode && landline == o.landline && primary_address == o.primary_address && deleted == o.deleted end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/bf_ruby2/models/address.rb', line 277 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/bf_ruby2/models/address.rb', line 343 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/bf_ruby2/models/address.rb', line 256 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/bf_ruby2/models/address.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/bf_ruby2/models/address.rb', line 249 def hash [created, changed_by, updated, id, profile_id, organization_id, address_line1, address_line2, address_line3, city, province, country, postcode, landline, primary_address, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 |
# File 'lib/bf_ruby2/models/address.rb', line 202 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/bf_ruby2/models/address.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 |
# File 'lib/bf_ruby2/models/address.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/bf_ruby2/models/address.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 216 |
# File 'lib/bf_ruby2/models/address.rb', line 209 def valid? return false if @address_line1.nil? return false if @city.nil? return false if @province.nil? return false if @country.nil? return false if @postcode.nil? return true end |