Class: Bfwd::AggregatingComponent
- Inherits:
-
Object
- Object
- Bfwd::AggregatingComponent
- Defined in:
- lib/bf_ruby2/models/aggregating_component.rb
Overview
The aggregating component defines a component which should be re-priced upon invoice aggregation
Instance Attribute Summary collapse
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#deleted ⇒ Object
the AggregatingComponent has been retired.“,”verbs“:.
-
#id ⇒ Object
ID by which the AggregatingComponent can be looked up.“,”verbs“:.
-
#organization_id ⇒ Object
using your authentication credentials)","description":"ID of the BillForward Organization within which the requested pricing component should be created. If omitted: this will be auto-populated using your authentication credentials.“,”verbs“:.
-
#pricing_component_id ⇒ Object
of the pricing component to which this AggregatingComponent’s aggregation applies. The subscriber to the aggregating rate plan (which contains this AggregatingComponent), will consult its children at the end of each billing period, and collect from those children all charges whose pricing component matches this ID. Those charges’ quantities will be counted, and used when calculating the price of consuming this AggregatingComponent. The aggregating subscription then raises a discount charge — to account for the more favourable price tiering that emerges when aggregating.“,”verbs“:.
-
#pricing_component_name ⇒ Object
of the pricing component to which this AggregatingComponent’s aggregation applies. The subscriber to the aggregating rate plan (which contains this AggregatingComponent), will consult its children at the end of each billing period, and collect from those children all charges whose pricing component matches this ID. Those charges’ quantities will be counted, and used when calculating the price of consuming this AggregatingComponent. The aggregating subscription then raises a discount charge — to account for the more favourable price tiering that emerges when aggregating.“,”verbs“:.
-
#product_rate_plan_id ⇒ Object
of the rate plan upon which this AggregatingComponent is defined.“,”verbs“:.
-
#product_rate_plan_name ⇒ Object
of the rate plan upon which this AggregatingComponent is defined.“,”verbs“:.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AggregatingComponent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AggregatingComponent
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'productRatePlanID') self.product_rate_plan_id = attributes[:'productRatePlanID'] end if attributes.has_key?(:'productRatePlanName') self.product_rate_plan_name = attributes[:'productRatePlanName'] end if attributes.has_key?(:'pricingComponentID') self.pricing_component_id = attributes[:'pricingComponentID'] end if attributes.has_key?(:'pricingComponentName') self.pricing_component_name = attributes[:'pricingComponentName'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end end |
Instance Attribute Details
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 33 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 30 def created @created end |
#deleted ⇒ Object
the AggregatingComponent has been retired.“,”verbs“:
57 58 59 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 57 def deleted @deleted end |
#id ⇒ Object
ID by which the AggregatingComponent can be looked up.“,”verbs“:
39 40 41 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 39 def id @id end |
#organization_id ⇒ Object
using your authentication credentials)","description":"ID of the BillForward Organization within which the requested pricing component should be created. If omitted: this will be auto-populated using your authentication credentials.“,”verbs“:
42 43 44 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 42 def organization_id @organization_id end |
#pricing_component_id ⇒ Object
of the pricing component to which this AggregatingComponent’s aggregation applies. The subscriber to the aggregating rate plan (which contains this AggregatingComponent), will consult its children at the end of each billing period, and collect from those children all charges whose pricing component matches this ID. Those charges’ quantities will be counted, and used when calculating the price of consuming this AggregatingComponent. The aggregating subscription then raises a discount charge — to account for the more favourable price tiering that emerges when aggregating.“,”verbs“:
51 52 53 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 51 def pricing_component_id @pricing_component_id end |
#pricing_component_name ⇒ Object
of the pricing component to which this AggregatingComponent’s aggregation applies. The subscriber to the aggregating rate plan (which contains this AggregatingComponent), will consult its children at the end of each billing period, and collect from those children all charges whose pricing component matches this ID. Those charges’ quantities will be counted, and used when calculating the price of consuming this AggregatingComponent. The aggregating subscription then raises a discount charge — to account for the more favourable price tiering that emerges when aggregating.“,”verbs“:
54 55 56 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 54 def pricing_component_name @pricing_component_name end |
#product_rate_plan_id ⇒ Object
of the rate plan upon which this AggregatingComponent is defined.“,”verbs“:
45 46 47 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 45 def product_rate_plan_id @product_rate_plan_id end |
#product_rate_plan_name ⇒ Object
of the rate plan upon which this AggregatingComponent is defined.“,”verbs“:
48 49 50 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 48 def product_rate_plan_name @product_rate_plan_name end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 36 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 61 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'organization_id' => :'organizationID', :'product_rate_plan_id' => :'productRatePlanID', :'product_rate_plan_name' => :'productRatePlanName', :'pricing_component_id' => :'pricingComponentID', :'pricing_component_name' => :'pricingComponentName', :'deleted' => :'deleted' } end |
.swagger_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 77 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'organization_id' => :'String', :'product_rate_plan_id' => :'String', :'product_rate_plan_name' => :'String', :'pricing_component_id' => :'String', :'pricing_component_name' => :'String', :'deleted' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && organization_id == o.organization_id && product_rate_plan_id == o.product_rate_plan_id && product_rate_plan_name == o.product_rate_plan_name && pricing_component_id == o.pricing_component_id && pricing_component_name == o.pricing_component_name && deleted == o.deleted end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 212 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 278 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 191 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 184 def hash [created, changed_by, updated, id, organization_id, product_rate_plan_id, product_rate_plan_name, pricing_component_id, pricing_component_name, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 146 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
258 259 260 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 258 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
264 265 266 267 268 269 270 271 272 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 264 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
252 253 254 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 252 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 |
# File 'lib/bf_ruby2/models/aggregating_component.rb', line 153 def valid? return false if @pricing_component_id.nil? return false if @pricing_component_name.nil? return true end |