Class: Bfwd::AuditEntry
- Inherits:
-
Object
- Object
- Bfwd::AuditEntry
- Defined in:
- lib/bf_ruby2/models/audit_entry.rb
Overview
An entry from the audit-log, documenting the set of changes made to an entity during an insert or update.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#audit_action ⇒ Object
{ "description" : "update, insert", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who made the change.", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#entity ⇒ Object
{ "description" : "The entity type.", "verbs“: }.
-
#entity_id ⇒ Object
{ "description" : "ID of the entity.", "verbs“: }.
-
#field_changes ⇒ Object
{ "description" : "A description of the changes.", "verbs“: }.
-
#id ⇒ Object
{ "description" : "ID of the audit-entry.", "verbs“: }.
-
#new_entity ⇒ Object
Returns the value of attribute new_entity.
-
#organization_id ⇒ Object
{ "description" : "ID of the organization associated with the audit-entry.", "verbs“: }.
-
#state ⇒ Object
{ "description" : "The state of the audit entry.", "verbs“: }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuditEntry
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AuditEntry
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'entity') self.entity = attributes[:'entity'] end if attributes.has_key?(:'entityID') self.entity_id = attributes[:'entityID'] end if attributes.has_key?(:'auditAction') self.audit_action = attributes[:'auditAction'] end if attributes.has_key?(:'fieldChanges') if (value = attributes[:'fieldChanges']).is_a?(Array) self.field_changes = value end end if attributes.has_key?(:'newEntity') if (value = attributes[:'newEntity']).is_a?(Array) self.new_entity = value end end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'created') self.created = attributes[:'created'] end end |
Instance Attribute Details
#audit_action ⇒ Object
{ "description" : "update, insert", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 45 def audit_action @audit_action end |
#changed_by ⇒ Object
{ "description" : "ID of the user who made the change.", "verbs“: }
30 31 32 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 30 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
56 57 58 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 56 def created @created end |
#entity ⇒ Object
{ "description" : "The entity type.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 39 def entity @entity end |
#entity_id ⇒ Object
{ "description" : "ID of the entity.", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 42 def entity_id @entity_id end |
#field_changes ⇒ Object
{ "description" : "A description of the changes.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 48 def field_changes @field_changes end |
#id ⇒ Object
{ "description" : "ID of the audit-entry.", "verbs“: }
33 34 35 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 33 def id @id end |
#new_entity ⇒ Object
Returns the value of attribute new_entity.
50 51 52 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 50 def new_entity @new_entity end |
#organization_id ⇒ Object
{ "description" : "ID of the organization associated with the audit-entry.", "verbs“: }
36 37 38 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 36 def organization_id @organization_id end |
#state ⇒ Object
{ "description" : "The state of the audit entry.", "verbs“: }
53 54 55 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 53 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 81 def self.attribute_map { :'changed_by' => :'changedBy', :'id' => :'id', :'organization_id' => :'organizationID', :'entity' => :'entity', :'entity_id' => :'entityID', :'audit_action' => :'auditAction', :'field_changes' => :'fieldChanges', :'new_entity' => :'newEntity', :'state' => :'state', :'created' => :'created' } end |
.swagger_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 97 def self.swagger_types { :'changed_by' => :'String', :'id' => :'String', :'organization_id' => :'String', :'entity' => :'String', :'entity_id' => :'String', :'audit_action' => :'String', :'field_changes' => :'Array<String>', :'new_entity' => :'Array<String>', :'state' => :'String', :'created' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && changed_by == o.changed_by && id == o.id && organization_id == o.organization_id && entity == o.entity && entity_id == o.entity_id && audit_action == o.audit_action && field_changes == o.field_changes && new_entity == o.new_entity && state == o.state && created == o.created end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 277 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 343 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 256 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 249 def hash [changed_by, id, organization_id, entity, entity_id, audit_action, field_changes, new_entity, state, created].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 168 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
323 324 325 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 323 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
317 318 319 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 317 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/bf_ruby2/models/audit_entry.rb', line 175 def valid? return false if @changed_by.nil? return false if @id.nil? return false if @organization_id.nil? return false if @entity.nil? entity_validator = EnumAttributeValidator.new('String', ["Notification", "Organization", "OrganizationGateway", "Product", "User", "Subscription", "Profile", "ProductRatePlan", "Client", "Invoice", "PricingComponentValue", "Account", "PricingComponentValueChange", "PricingComponentTier", "PricingComponent", "PricingCalculation", "CouponDefinition", "CouponInstance", "CouponModifier", "CouponRule", "CouponBookDefinition", "CouponBook", "InvoiceLine", "Webhook", "SubscriptionCancellation", "NotificationSnapshot", "InvoicePayment", "InvoiceLinePayment", "Payment", "PaymentMethod", "PaymentMethodSubscriptionLink", "DunningLine", "CybersourceToken", "Card", "Alias", "PaypalSimplePaymentReconciliation", "FreePaymentReconciliation", "LocustworldPaymentReconciliation", "CouponInstanceExistingValue", "TaxLine", "TaxationStrategy", "TaxationLink", "Address", "AmendmentPriceNTime", "Authority", "UnitOfMeasure", "SearchResult", "Amendment", "AuditLog", "Password", "Username", "FixedTermDefinition", "FixedTerm", "Refund", "CreditNote", "Receipt", "AmendmentCompoundConstituent", "APIConfiguration", "StripeToken", "BraintreeToken", "BalancedToken", "PaypalToken", "AuthorizeNetToken", "SpreedlyToken", "GatewayRevenue", "AmendmentDiscardAmendment", "CancellationAmendment", "CompoundAmendment", "CompoundAmendmentConstituent", "FixedTermExpiryAmendment", "InvoiceNextExecutionAttemptAmendment", "PricingComponentValueAmendment", "BraintreeMerchantAccount", "WebhookSubscription", "Migration", "CassResult", "CassPaymentResult", "CassProductRatePlanResult", "CassChurnResult", "CassUpgradeResult", "SubscriptionCharge", "CassPaymentPProductResult", "ProductPaymentsArgs", "StripeACHToken", "UsageAmount", "UsageSession", "Usage", "UsagePeriod", "Period", "OfflinePayment", "CreditNotePayment", "CardVaultPayment", "FreePayment", "BraintreePayment", "BalancedPayment", "CybersourcePayment", "PaypalPayment", "PaypalSimplePayment", "LocustWorldPayment", "StripeOnlyPayment", "ProductPaymentsResult", "StripeACHPayment", "AuthorizeNetPayment", "CompoundUsageSession", "CompoundUsage", "UsageRoundingStrategies", "BillforwardManagedPaymentsResult", "PricingComponentValueMigrationChargeAmendmentMapping", "SubscriptionLTVResult", "AccountLTVResult", "ProductRatePlanPaymentsResult", "DebtsResult", "AccountPaymentsResult", "ComponentChange", "QuoteRequest", "Quote", "CouponCharge", "CouponInstanceInvoiceLink", "Coupon", "CouponDiscount", "CouponUniqueCodesRequest", "CouponUniqueCodesResponse", "GetCouponsResponse", "AddCouponCodeRequest", "AddCouponCodeResponse", "RemoveCouponFromSubscriptionRequest", "TokenizationPreAuth", "StripeTokenizationPreAuth", "BraintreeTokenizationPreAuth", "SpreedlyTokenizationPreAuth", "SagePayTokenizationPreAuth", "PayVisionTokenizationPreAuth", "TokenizationPreAuthRequest", "AuthCaptureRequest", "StripeACHBankAccountVerification", "PasswordReset", "PricingRequest", "AddTaxationStrategyRequest", "AddPaymentMethodRequest", "APIRequest", "SagePayToken", "SagePayNotificationRequest", "SagePayNotificationResponse", "SagePayOutstandingTransaction", "SagePayEnabledCardType", "TrustCommerceToken", "SagePayTransaction", "PricingComponentValueResponse", "MigrationResponse", "TimeResponse", "EntityTime", "Email", "AggregationLink", "BFPermission", "Role", "PermissionLink", "PayVisionToken", "PayVisionTransaction", "KashToken", "EmailProvider", "DataSynchronizationJob", "DataSynchronizationJobError", "DataSynchronizationConfiguration", "DataSynchronizationAppConfiguration", "AggregationChildrenResponse", "MetadataKeyValue", "Metadata", "AggregatingComponent", "PricingComponentMigrationValue", "InvoiceRecalculationAmendment", "IssueInvoiceAmendment", "EmailSubscription", "RevenueAttribution"]) return false unless entity_validator.valid?(@entity) return false if @entity_id.nil? return false if @audit_action.nil? audit_action_validator = EnumAttributeValidator.new('String', ["Accept", "Active", "AwaitingPayment", "AwaitingRefund", "Cancelled", "Completed", "Created", "Error", "Expiring", "Expired", "Failed", "Migrated", "NeedsAmendments", "Paid", "Pending", "Provisioned", "Refunded", "Reject", "Trial", "Unknown", "Unpaid", "Updated", "Voided", "PaymentFailed"]) return false unless audit_action_validator.valid?(@audit_action) return false if @field_changes.nil? return false if @new_entity.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["New", "Processed"]) return false unless state_validator.valid?(@state) return true end |