Class: Bfwd::BraintreeAuthCaptureRequest
- Inherits:
-
Object
- Object
- Bfwd::BraintreeAuthCaptureRequest
- Defined in:
- lib/bf_ruby2/models/braintree_auth_capture_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
of the BillForward Account with which you would like to associate the created payment method.
If omitted, BillForward will associate the created PaymentMethod with a newly-created Account, whose Profile details will be populated using billing information from the funding instrument.“,”verbs“:. -
#company_name ⇒ Object
name of the company of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#default_payment_method ⇒ Object
the PaymentMethod produced by this request should be elected as the ‘default’ payment method for the concerned BillForward Account. Whichever PaymentMethod is elected as an Account’s default payment method, will be consulted whenever payment is demanded of that Account (i.e. upon the execution of any of the Account’s invoices).“,”verbs“:.
-
#device_data ⇒ Object
when vaulting a PayPal payment method; otherwise optional)
A JSON string providing information about the device your customer used to fill out the card capture form. This information is inserted into your form by <a href=\"developers.braintreepayments.com/javascript+node/guides/advanced-fraud-tools/client-side\">braintree-data.js</a> — if and only if you use Braintree’s drop-in form integrations. You should ideally provide it if you have one (it aids with fraud detection), but it is only mandatory in the case of PayPal payment method vaulting.“,”verbs“:. -
#email ⇒ Object
email address of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#first_name ⇒ Object
first name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#gateway ⇒ Object
gateway with which your funding instrument has been vaulted.“,”verbs“:.
-
#last_name ⇒ Object
last name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#mobile ⇒ Object
mobile phone number of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#organization_id ⇒ Object
of the BillForward Organization within which the requested PaymentMethod should be created. If omitted, this will be auto-populated using your authentication credentials.“,”verbs“:.
-
#payment_method_nonce ⇒ Object
cryptographic nonce <a href=\"developers.braintreepayments.com/javascript+node/start/overview\">provided by Braintree’s client-side card capture SDK</a>, in response to your capturing a card into the Braintree vault. This nonce will be used by BillForward to find the tokenized card within the Braintree vault — precursory to linking a BillForward PaymentMethod to that tokenized card“,”verbs“:.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BraintreeAuthCaptureRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BraintreeAuthCaptureRequest
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 124 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'@type') self.type = attributes[:'@type'] end if attributes.has_key?(:'accountID') self.account_id = attributes[:'accountID'] end if attributes.has_key?(:'gateway') self.gateway = attributes[:'gateway'] end if attributes.has_key?(:'companyName') self.company_name = attributes[:'companyName'] end if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'firstName') self.first_name = attributes[:'firstName'] end if attributes.has_key?(:'lastName') self.last_name = attributes[:'lastName'] end if attributes.has_key?(:'mobile') self.mobile = attributes[:'mobile'] end if attributes.has_key?(:'defaultPaymentMethod') self.default_payment_method = attributes[:'defaultPaymentMethod'] else self.default_payment_method = false end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'paymentMethodNonce') self.payment_method_nonce = attributes[:'paymentMethodNonce'] end if attributes.has_key?(:'deviceData') self.device_data = attributes[:'deviceData'] end end |
Instance Attribute Details
#account_id ⇒ Object
of the BillForward Account with which you would like to associate the created payment method.
If omitted, BillForward will associate the created PaymentMethod with a newly-created Account, whose Profile details will be populated using billing information from the funding instrument.“,”verbs“:
32 33 34 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 32 def account_id @account_id end |
#company_name ⇒ Object
name of the company of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
38 39 40 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 38 def company_name @company_name end |
#default_payment_method ⇒ Object
the PaymentMethod produced by this request should be elected as the ‘default’ payment method for the concerned BillForward Account. Whichever PaymentMethod is elected as an Account’s default payment method, will be consulted whenever payment is demanded of that Account (i.e. upon the execution of any of the Account’s invoices).“,”verbs“:
53 54 55 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 53 def default_payment_method @default_payment_method end |
#device_data ⇒ Object
when vaulting a PayPal payment method; otherwise optional)
A JSON string providing information about the device your customer used to fill out the card capture form. This information is inserted into your form by <a href=\"developers.braintreepayments.com/javascript+node/guides/advanced-fraud-tools/client-side\">braintree-data.js</a> — if and only if you use Braintree’s drop-in form integrations. You should ideally provide it if you have one (it aids with fraud detection), but it is only mandatory in the case of PayPal payment method vaulting.“,”verbs“:
62 63 64 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 62 def device_data @device_data end |
#email ⇒ Object
email address of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
41 42 43 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 41 def email @email end |
#first_name ⇒ Object
first name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
44 45 46 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 44 def first_name @first_name end |
#gateway ⇒ Object
gateway with which your funding instrument has been vaulted.“,”verbs“:
35 36 37 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 35 def gateway @gateway end |
#last_name ⇒ Object
last name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
47 48 49 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 47 def last_name @last_name end |
#mobile ⇒ Object
mobile phone number of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
50 51 52 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 50 def mobile @mobile end |
#organization_id ⇒ Object
of the BillForward Organization within which the requested PaymentMethod should be created. If omitted, this will be auto-populated using your authentication credentials.“,”verbs“:
56 57 58 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 56 def organization_id @organization_id end |
#payment_method_nonce ⇒ Object
cryptographic nonce <a href=\"developers.braintreepayments.com/javascript+node/start/overview\">provided by Braintree’s client-side card capture SDK</a>, in response to your capturing a card into the Braintree vault. This nonce will be used by BillForward to find the tokenized card within the Braintree vault — precursory to linking a BillForward PaymentMethod to that tokenized card“,”verbs“:
59 60 61 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 59 def payment_method_nonce @payment_method_nonce end |
#type ⇒ Object
Returns the value of attribute type.
29 30 31 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 29 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 87 def self.attribute_map { :'type' => :'@type', :'account_id' => :'accountID', :'gateway' => :'gateway', :'company_name' => :'companyName', :'email' => :'email', :'first_name' => :'firstName', :'last_name' => :'lastName', :'mobile' => :'mobile', :'default_payment_method' => :'defaultPaymentMethod', :'organization_id' => :'organizationID', :'payment_method_nonce' => :'paymentMethodNonce', :'device_data' => :'deviceData' } end |
.swagger_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 105 def self.swagger_types { :'type' => :'String', :'account_id' => :'String', :'gateway' => :'String', :'company_name' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'mobile' => :'String', :'default_payment_method' => :'BOOLEAN', :'organization_id' => :'String', :'payment_method_nonce' => :'String', :'device_data' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 223 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && account_id == o.account_id && gateway == o.gateway && company_name == o.company_name && email == o.email && first_name == o.first_name && last_name == o.last_name && mobile == o.mobile && default_payment_method == o.default_payment_method && organization_id == o.organization_id && payment_method_nonce == o.payment_method_nonce && device_data == o.device_data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 276 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 342 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 255 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 248 def hash [type, account_id, gateway, company_name, email, first_name, last_name, mobile, default_payment_method, organization_id, payment_method_nonce, device_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 184 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
322 323 324 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 322 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
316 317 318 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 316 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 197 198 199 |
# File 'lib/bf_ruby2/models/braintree_auth_capture_request.rb', line 191 def valid? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["StripeAuthCaptureRequest"]) return false unless type_validator.valid?(@type) gateway_validator = EnumAttributeValidator.new('String', ["Balanced", "Braintree", "Cybersource", "Paypal", "Stripe", "AuthorizeNet", "Spreedly", "SagePay", "TrustCommerce", "Payvision", "Kash"]) return false unless gateway_validator.valid?(@gateway) return false if @payment_method_nonce.nil? return true end |