Class: Bfwd::Client
- Inherits:
-
Object
- Object
- Bfwd::Client
- Defined in:
- lib/bf_ruby2/models/client.rb
Overview
An oAuth2 client with which BillForward users may authenticate.
Instance Attribute Summary collapse
-
#access_token_validity_seconds ⇒ Object
{ "description" : "The amount of time in seconds that an access token for the client is valid.", "verbs“: }.
-
#authorities ⇒ Object
{ "description" : "Authorities associated with the client.", "verbs“: }.
-
#authorized_grant_types ⇒ Object
{ "description" : "Oauth2 Grant Types which may be used when authenticating with the client.", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#client_id ⇒ Object
{ "description" : "ID of the OAuth2 client.", "verbs“: }.
-
#client_secret ⇒ Object
{ "description" : "Unique Client Secret of the client. This is used as the OAuth2 Client secret", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#deleted ⇒ Object
{ "description" : "Indicates if a client has been retired. If a client has been retired it can still be retrieved using the appropriate flag on API requests.", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "Organization associated with the client.", "verbs“: }.
-
#refresh_token_validity_seconds ⇒ Object
{ "description" : "The amount of time in seconds that a refresh token for the client is valid.", "verbs“: }.
-
#registered_redirect_uris ⇒ Object
{ "description" : "Registered Redirect URIs associated with the client.", "verbs“: }.
-
#resource_ids ⇒ Object
{ "description" : "Resources associated with the client.", "verbs“: }.
-
#scope ⇒ Object
{ "description" : "Scopes associated with the client.", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Client
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Client
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/bf_ruby2/models/client.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'clientId') self.client_id = attributes[:'clientId'] end if attributes.has_key?(:'clientSecret') self.client_secret = attributes[:'clientSecret'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'scope') self.scope = attributes[:'scope'] end if attributes.has_key?(:'resourceIds') self.resource_ids = attributes[:'resourceIds'] end if attributes.has_key?(:'authorizedGrantTypes') self. = attributes[:'authorizedGrantTypes'] end if attributes.has_key?(:'registeredRedirectUris') self.registered_redirect_uris = attributes[:'registeredRedirectUris'] end if attributes.has_key?(:'authorities') self. = attributes[:'authorities'] end if attributes.has_key?(:'accessTokenValiditySeconds') self.access_token_validity_seconds = attributes[:'accessTokenValiditySeconds'] end if attributes.has_key?(:'refreshTokenValiditySeconds') self.refresh_token_validity_seconds = attributes[:'refreshTokenValiditySeconds'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end end |
Instance Attribute Details
#access_token_validity_seconds ⇒ Object
{ "description" : "The amount of time in seconds that an access token for the client is valid.", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/client.rb', line 63 def access_token_validity_seconds @access_token_validity_seconds end |
#authorities ⇒ Object
{ "description" : "Authorities associated with the client.", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/client.rb', line 60 def end |
#authorized_grant_types ⇒ Object
{ "description" : "Oauth2 Grant Types which may be used when authenticating with the client.", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/client.rb', line 54 def end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/client.rb', line 33 def changed_by @changed_by end |
#client_id ⇒ Object
{ "description" : "ID of the OAuth2 client.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/client.rb', line 39 def client_id @client_id end |
#client_secret ⇒ Object
{ "description" : "Unique Client Secret of the client. This is used as the OAuth2 Client secret", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/client.rb', line 42 def client_secret @client_secret end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/client.rb', line 30 def created @created end |
#deleted ⇒ Object
{ "description" : "Indicates if a client has been retired. If a client has been retired it can still be retrieved using the appropriate flag on API requests.", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/client.rb', line 69 def deleted @deleted end |
#organization_id ⇒ Object
{ "description" : "Organization associated with the client.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/client.rb', line 45 def organization_id @organization_id end |
#refresh_token_validity_seconds ⇒ Object
{ "description" : "The amount of time in seconds that a refresh token for the client is valid.", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/client.rb', line 66 def refresh_token_validity_seconds @refresh_token_validity_seconds end |
#registered_redirect_uris ⇒ Object
{ "description" : "Registered Redirect URIs associated with the client.", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/client.rb', line 57 def registered_redirect_uris @registered_redirect_uris end |
#resource_ids ⇒ Object
{ "description" : "Resources associated with the client.", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/client.rb', line 51 def resource_ids @resource_ids end |
#scope ⇒ Object
{ "description" : "Scopes associated with the client.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/client.rb', line 48 def scope @scope end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/client.rb', line 36 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/bf_ruby2/models/client.rb', line 73 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'client_id' => :'clientId', :'client_secret' => :'clientSecret', :'organization_id' => :'organizationID', :'scope' => :'scope', :'resource_ids' => :'resourceIds', :'authorized_grant_types' => :'authorizedGrantTypes', :'registered_redirect_uris' => :'registeredRedirectUris', :'authorities' => :'authorities', :'access_token_validity_seconds' => :'accessTokenValiditySeconds', :'refresh_token_validity_seconds' => :'refreshTokenValiditySeconds', :'deleted' => :'deleted' } end |
.swagger_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/bf_ruby2/models/client.rb', line 93 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'client_id' => :'String', :'client_secret' => :'String', :'organization_id' => :'String', :'scope' => :'String', :'resource_ids' => :'String', :'authorized_grant_types' => :'String', :'registered_redirect_uris' => :'String', :'authorities' => :'String', :'access_token_validity_seconds' => :'Integer', :'refresh_token_validity_seconds' => :'Integer', :'deleted' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/bf_ruby2/models/client.rb', line 205 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && client_id == o.client_id && client_secret == o.client_secret && organization_id == o.organization_id && scope == o.scope && resource_ids == o.resource_ids && == o. && registered_redirect_uris == o.registered_redirect_uris && == o. && access_token_validity_seconds == o.access_token_validity_seconds && refresh_token_validity_seconds == o.refresh_token_validity_seconds && deleted == o.deleted end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/bf_ruby2/models/client.rb', line 260 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/bf_ruby2/models/client.rb', line 326 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/bf_ruby2/models/client.rb', line 239 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/bf_ruby2/models/client.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/bf_ruby2/models/client.rb', line 232 def hash [created, changed_by, updated, client_id, client_secret, organization_id, scope, resource_ids, , registered_redirect_uris, , access_token_validity_seconds, refresh_token_validity_seconds, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 |
# File 'lib/bf_ruby2/models/client.rb', line 182 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
306 307 308 |
# File 'lib/bf_ruby2/models/client.rb', line 306 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 |
# File 'lib/bf_ruby2/models/client.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
300 301 302 |
# File 'lib/bf_ruby2/models/client.rb', line 300 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/bf_ruby2/models/client.rb', line 189 def valid? return false if @client_secret.nil? return false if @organization_id.nil? return false if @scope.nil? return false if @resource_ids.nil? return false if .nil? return false if @registered_redirect_uris.nil? return false if .nil? return false if @access_token_validity_seconds.nil? return false if @refresh_token_validity_seconds.nil? return false if @deleted.nil? return true end |