Class: Bfwd::CouponinstanceApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/couponinstance_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CouponinstanceApi

Returns a new instance of CouponinstanceApi.



30
31
32
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_coupon_instance(coupon_instance, opts = {}) ⇒ CouponInstancePagedMetadata

Create a coupon-instance. a new coupon","request":"createCouponInstanceRequest.html","response":"createCouponInstanceResponse.html"

Parameters:

  • coupon_instance

    The coupon-instance object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 39

def create_coupon_instance(coupon_instance, opts = {})
  data, _status_code, _headers = create_coupon_instance_with_http_info(coupon_instance, opts)
  return data
end

#create_coupon_instance_with_http_info(coupon_instance, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Create a coupon-instance. a new coupon&quot;,&quot;request&quot;:&quot;createCouponInstanceRequest.html&quot;,&quot;response&quot;:&quot;createCouponInstanceResponse.html&quot;

Parameters:

  • coupon_instance

    The coupon-instance object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 49

def create_coupon_instance_with_http_info(coupon_instance, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.create_coupon_instance ..."
  end
  # verify the required parameter 'coupon_instance' is set
  fail ArgumentError, "Missing the required parameter 'coupon_instance' when calling CouponinstanceApi.create_coupon_instance" if coupon_instance.nil?
  # resource path
  local_var_path = "/coupon-instances".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(coupon_instance)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#create_coupon_instance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_coupon_instance(coupon_instance_id, opts = {}) ⇒ CouponInstancePagedMetadata

Retire a coupon-instance, specified by the coupon-instance-ID parameter. a coupon","response":"deleteCouponInstanceByID.html"

Parameters:

  • coupon_instance_id

    ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



97
98
99
100
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 97

def delete_coupon_instance(coupon_instance_id, opts = {})
  data, _status_code, _headers = delete_coupon_instance_with_http_info(coupon_instance_id, opts)
  return data
end

#delete_coupon_instance_with_http_info(coupon_instance_id, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Retire a coupon-instance, specified by the coupon-instance-ID parameter. a coupon&quot;,&quot;response&quot;:&quot;deleteCouponInstanceByID.html&quot;

Parameters:

  • coupon_instance_id

    ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 108

def delete_coupon_instance_with_http_info(coupon_instance_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.delete_coupon_instance ..."
  end
  # verify the required parameter 'coupon_instance_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_instance_id' when calling CouponinstanceApi.delete_coupon_instance" if coupon_instance_id.nil?
  # resource path
  local_var_path = "/coupon-instances/{coupon-instance-ID}".sub('{format}','json').sub('{' + 'coupon-instance-ID' + '}', coupon_instance_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#delete_coupon_instance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_attachable_coupon_instances(attachableness, has_code, opts = {}) ⇒ CouponInstancePagedMetadata

Returns a collection of attachable coupon-instances. An attachable coupon-instance has at least one remaining use, and is not deleted. By default 10 values are returned. Records are returned in natural order. attachable coupons","response":"getCouponInstanceAllAttachable.html"

Parameters:

  • attachableness

    The attachableness of the coupon-instance.

  • has_code

    Whether the coupon-instances have coupon codes or not.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return. (default to 0)

  • :records (Integer)

    The maximum number of coupon-instances to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



162
163
164
165
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 162

def get_all_attachable_coupon_instances(attachableness, has_code, opts = {})
  data, _status_code, _headers = get_all_attachable_coupon_instances_with_http_info(attachableness, has_code, opts)
  return data
end

#get_all_attachable_coupon_instances_with_http_info(attachableness, has_code, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a collection of attachable coupon-instances. An attachable coupon-instance has at least one remaining use, and is not deleted. By default 10 values are returned. Records are returned in natural order. attachable coupons&quot;,&quot;response&quot;:&quot;getCouponInstanceAllAttachable.html&quot;

Parameters:

  • attachableness

    The attachableness of the coupon-instance.

  • has_code

    Whether the coupon-instances have coupon codes or not.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return.

  • :records (Integer)

    The maximum number of coupon-instances to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 178

def get_all_attachable_coupon_instances_with_http_info(attachableness, has_code, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_all_attachable_coupon_instances ..."
  end
  # verify the required parameter 'attachableness' is set
  fail ArgumentError, "Missing the required parameter 'attachableness' when calling CouponinstanceApi.get_all_attachable_coupon_instances" if attachableness.nil?
  # verify the required parameter 'has_code' is set
  fail ArgumentError, "Missing the required parameter 'has_code' when calling CouponinstanceApi.get_all_attachable_coupon_instances" if has_code.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-instances/attachable/{attachableness}/{has_code}".sub('{format}','json').sub('{' + 'attachableness' + '}', attachableness.to_s).sub('{' + 'has_code' + '}', has_code.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_all_attachable_coupon_instances\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_coupon_instances(opts = {}) ⇒ CouponInstancePagedMetadata

Returns a collection of coupon-instances. By default 10 values are returned. Records are returned in natural order. all coupons","response":"getCouponInstanceAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return. (default to 0)

  • :records (Integer)

    The maximum number of coupon-instances to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned. (default to true)

Returns:



240
241
242
243
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 240

def get_all_coupon_instances(opts = {})
  data, _status_code, _headers = get_all_coupon_instances_with_http_info(opts)
  return data
end

#get_all_coupon_instances_with_http_info(opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-instances. By default 10 values are returned. Records are returned in natural order. all coupons&quot;,&quot;response&quot;:&quot;getCouponInstanceAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return.

  • :records (Integer)

    The maximum number of coupon-instances to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned.

Returns:



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 255

def get_all_coupon_instances_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_all_coupon_instances ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-instances".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_all_coupon_instances\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_instance_by_coupon_code(coupon_code, opts = {}) ⇒ CouponInstancePagedMetadata

Returns a collection of coupon-instances, specified by coupon-code parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by coupon code","response":"getCouponInstanceByCouponCode.html"

Parameters:

  • coupon_code

    The string coupon-code of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return. (default to 0)

  • :records (Integer)

    The maximum number of coupon-instances to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned. (default to true)

Returns:



315
316
317
318
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 315

def get_coupon_instance_by_coupon_code(coupon_code, opts = {})
  data, _status_code, _headers = get_coupon_instance_by_coupon_code_with_http_info(coupon_code, opts)
  return data
end

#get_coupon_instance_by_coupon_code_with_http_info(coupon_code, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-instances, specified by coupon-code parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by coupon code&quot;,&quot;response&quot;:&quot;getCouponInstanceByCouponCode.html&quot;

Parameters:

  • coupon_code

    The string coupon-code of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return.

  • :records (Integer)

    The maximum number of coupon-instances to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned.

Returns:



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 331

def get_coupon_instance_by_coupon_code_with_http_info(coupon_code, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_coupon_instance_by_coupon_code ..."
  end
  # verify the required parameter 'coupon_code' is set
  fail ArgumentError, "Missing the required parameter 'coupon_code' when calling CouponinstanceApi.get_coupon_instance_by_coupon_code" if coupon_code.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-instances/coupon/{coupon-code}".sub('{format}','json').sub('{' + 'coupon-code' + '}', coupon_code.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_coupon_instance_by_coupon_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_instance_by_coupon_definition_id(coupon_definition_id, opts = {}) ⇒ CouponInstancePagedMetadata

Returns a collection of coupon-instances, specified by coupon-definition-ID parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by coupon definition","response":"getCouponInstanceByCouponDefinitionID.html"

Parameters:

  • coupon_definition_id

    The string coupon-definition-ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return. (default to 0)

  • :records (Integer)

    The maximum number of coupon-instances to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned. (default to true)

Returns:



393
394
395
396
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 393

def get_coupon_instance_by_coupon_definition_id(coupon_definition_id, opts = {})
  data, _status_code, _headers = get_coupon_instance_by_coupon_definition_id_with_http_info(coupon_definition_id, opts)
  return data
end

#get_coupon_instance_by_coupon_definition_id_with_http_info(coupon_definition_id, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-instances, specified by coupon-definition-ID parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by coupon definition&quot;,&quot;response&quot;:&quot;getCouponInstanceByCouponDefinitionID.html&quot;

Parameters:

  • coupon_definition_id

    The string coupon-definition-ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return.

  • :records (Integer)

    The maximum number of coupon-instances to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned.

Returns:



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 409

def get_coupon_instance_by_coupon_definition_id_with_http_info(coupon_definition_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_coupon_instance_by_coupon_definition_id ..."
  end
  # verify the required parameter 'coupon_definition_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_definition_id' when calling CouponinstanceApi.get_coupon_instance_by_coupon_definition_id" if coupon_definition_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-instances/coupon-definition/{coupon-definition-ID}".sub('{format}','json').sub('{' + 'coupon-definition-ID' + '}', coupon_definition_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_coupon_instance_by_coupon_definition_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_instance_by_id(coupon_instance_id, opts = {}) ⇒ CouponInstancePagedMetadata

Returns a single coupon-instance, specified by the coupon-instance-ID parameter. existing coupon","response":"getCouponInstanceByID.html"

Parameters:

  • coupon_instance_id

    ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



466
467
468
469
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 466

def get_coupon_instance_by_id(coupon_instance_id, opts = {})
  data, _status_code, _headers = get_coupon_instance_by_id_with_http_info(coupon_instance_id, opts)
  return data
end

#get_coupon_instance_by_id_with_http_info(coupon_instance_id, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a single coupon-instance, specified by the coupon-instance-ID parameter. existing coupon&quot;,&quot;response&quot;:&quot;getCouponInstanceByID.html&quot;

Parameters:

  • coupon_instance_id

    ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 477

def get_coupon_instance_by_id_with_http_info(coupon_instance_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_coupon_instance_by_id ..."
  end
  # verify the required parameter 'coupon_instance_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_instance_id' when calling CouponinstanceApi.get_coupon_instance_by_id" if coupon_instance_id.nil?
  # resource path
  local_var_path = "/coupon-instances/{coupon-instance-ID}".sub('{format}','json').sub('{' + 'coupon-instance-ID' + '}', coupon_instance_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_coupon_instance_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_instance_by_target_id(target_id, opts = {}) ⇒ CouponInstancePagedMetadata

Returns a collection of coupon-instances, specified by target-ID parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by target","response":"getCouponInstanceByTargetID.html"

Parameters:

  • target_id

    The string target-ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return. (default to 0)

  • :records (Integer)

    The maximum number of coupon-instances to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned. (default to true)

Returns:



531
532
533
534
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 531

def get_coupon_instance_by_target_id(target_id, opts = {})
  data, _status_code, _headers = get_coupon_instance_by_target_id_with_http_info(target_id, opts)
  return data
end

#get_coupon_instance_by_target_id_with_http_info(target_id, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-instances, specified by target-ID parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by target&quot;,&quot;response&quot;:&quot;getCouponInstanceByTargetID.html&quot;

Parameters:

  • target_id

    The string target-ID of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return.

  • :records (Integer)

    The maximum number of coupon-instances to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned.

Returns:



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 547

def get_coupon_instance_by_target_id_with_http_info(target_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_coupon_instance_by_target_id ..."
  end
  # verify the required parameter 'target_id' is set
  fail ArgumentError, "Missing the required parameter 'target_id' when calling CouponinstanceApi.get_coupon_instance_by_target_id" if target_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-instances/target/{target-ID}".sub('{format}','json').sub('{' + 'target-ID' + '}', target_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_coupon_instance_by_target_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_instance_by_target_type(target, opts = {}) ⇒ CouponInstancePagedMetadata

Returns a collection of coupon-instances, specified by target parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by target type","response":"getCouponInstanceByTarget.html"

Parameters:

  • target

    The string target of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return. (default to 0)

  • :records (Integer)

    The maximum number of coupon-instances to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned. (default to true)

Returns:



609
610
611
612
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 609

def get_coupon_instance_by_target_type(target, opts = {})
  data, _status_code, _headers = get_coupon_instance_by_target_type_with_http_info(target, opts)
  return data
end

#get_coupon_instance_by_target_type_with_http_info(target, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-instances, specified by target parameter. By default 10 coupon-instances are returned. Records are returned in natural order. by target type&quot;,&quot;response&quot;:&quot;getCouponInstanceByTarget.html&quot;

Parameters:

  • target

    The string target of the coupon-instance.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first coupon-instance to return.

  • :records (Integer)

    The maximum number of coupon-instances to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired coupon-instances should be returned.

Returns:



625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 625

def get_coupon_instance_by_target_type_with_http_info(target, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.get_coupon_instance_by_target_type ..."
  end
  # verify the required parameter 'target' is set
  fail ArgumentError, "Missing the required parameter 'target' when calling CouponinstanceApi.get_coupon_instance_by_target_type" if target.nil?
  # verify enum value
  unless ['none', 'subscription', 'account'].include?(target)
    fail ArgumentError, "invalid value for 'target', must be one of none, subscription, account"
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-instances/target-entity/{target}".sub('{format}','json').sub('{' + 'target' + '}', target.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#get_coupon_instance_by_target_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_coupon_instance(coupon_instance, opts = {}) ⇒ CouponInstancePagedMetadata

Update a coupon-instance. a coupon","request":"updateCouponInstanceRequest.html","response":"updateCouponInstanceResponse.html"

Parameters:

  • coupon_instance

    The coupon-instance object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



685
686
687
688
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 685

def update_coupon_instance(coupon_instance, opts = {})
  data, _status_code, _headers = update_coupon_instance_with_http_info(coupon_instance, opts)
  return data
end

#update_coupon_instance_with_http_info(coupon_instance, opts = {}) ⇒ Array<(CouponInstancePagedMetadata, Fixnum, Hash)>

Update a coupon-instance. a coupon&quot;,&quot;request&quot;:&quot;updateCouponInstanceRequest.html&quot;,&quot;response&quot;:&quot;updateCouponInstanceResponse.html&quot;

Parameters:

  • coupon_instance

    The coupon-instance object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
# File 'lib/bf_ruby2/api/couponinstance_api.rb', line 695

def update_coupon_instance_with_http_info(coupon_instance, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponinstanceApi.update_coupon_instance ..."
  end
  # verify the required parameter 'coupon_instance' is set
  fail ArgumentError, "Missing the required parameter 'coupon_instance' when calling CouponinstanceApi.update_coupon_instance" if coupon_instance.nil?
  # resource path
  local_var_path = "/coupon-instances".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(coupon_instance)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponInstancePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponinstanceApi#update_coupon_instance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end