Class: Bfwd::CreateAccountRequest
- Inherits:
-
Object
- Object
- Bfwd::CreateAccountRequest
- Defined in:
- lib/bf_ruby2/models/create_account_request.rb
Overview
CreateAccountRequest
Instance Attribute Summary collapse
-
#aggregating_product_rate_plan_id ⇒ Object
{ "description" : "If present, this will be the product rate plan to use when creating an aggregating subscription. An account level aggregating subscription will be created when the first subscription is created against the account.", "verbs":[] }.
-
#aggregating_subscription_id ⇒ Object
{ "description" : "The consistent ID of the account level aggregating subscription, if one exists.", "verbs":[] }.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#organization_id ⇒ Object
{ "description" : "Organization associated with the account.", "verbs":[] }.
-
#profile ⇒ Object
Returns the value of attribute profile.
-
#user_id ⇒ Object
{ "description" : "User associated with the account. If this is null, no user is currently assocaited with the account. A user is only set when an account is associated with a user account.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAccountRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAccountRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 72 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'profile') self.profile = attributes[:'profile'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'userID') self.user_id = attributes[:'userID'] end if attributes.has_key?(:'aggregatingProductRatePlanID') self.aggregating_product_rate_plan_id = attributes[:'aggregatingProductRatePlanID'] end if attributes.has_key?(:'aggregatingSubscriptionID') self.aggregating_subscription_id = attributes[:'aggregatingSubscriptionID'] end if attributes.has_key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#aggregating_product_rate_plan_id ⇒ Object
{ "description" : "If present, this will be the product rate plan to use when creating an aggregating subscription. An account level aggregating subscription will be created when the first subscription is created against the account.", "verbs":[] }
38 39 40 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 38 def aggregating_product_rate_plan_id @aggregating_product_rate_plan_id end |
#aggregating_subscription_id ⇒ Object
{ "description" : "The consistent ID of the account level aggregating subscription, if one exists.", "verbs":[] }
41 42 43 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 41 def aggregating_subscription_id @aggregating_subscription_id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
43 44 45 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 43 def end |
#organization_id ⇒ Object
{ "description" : "Organization associated with the account.", "verbs":[] }
32 33 34 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 32 def organization_id @organization_id end |
#profile ⇒ Object
Returns the value of attribute profile.
29 30 31 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 29 def profile @profile end |
#user_id ⇒ Object
{ "description" : "User associated with the account. If this is null, no user is currently assocaited with the account. A user is only set when an account is associated with a user account.", "verbs":[] }
35 36 37 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 35 def user_id @user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 47 def self.attribute_map { :'profile' => :'profile', :'organization_id' => :'organizationID', :'user_id' => :'userID', :'aggregating_product_rate_plan_id' => :'aggregatingProductRatePlanID', :'aggregating_subscription_id' => :'aggregatingSubscriptionID', :'metadata' => :'metadata' } end |
.swagger_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 59 def self.swagger_types { :'profile' => :'CreateAccountProfileRequest', :'organization_id' => :'String', :'user_id' => :'String', :'aggregating_product_rate_plan_id' => :'String', :'aggregating_subscription_id' => :'String', :'metadata' => :'DynamicMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 127 128 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 119 def ==(o) return true if self.equal?(o) self.class == o.class && profile == o.profile && organization_id == o.organization_id && user_id == o.user_id && aggregating_product_rate_plan_id == o.aggregating_product_rate_plan_id && aggregating_subscription_id == o.aggregating_subscription_id && == o. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 166 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 232 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 145 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
132 133 134 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 132 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 138 def hash [profile, organization_id, user_id, aggregating_product_rate_plan_id, aggregating_subscription_id, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 106 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
212 213 214 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 212 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
206 207 208 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 206 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 |
# File 'lib/bf_ruby2/models/create_account_request.rb', line 113 def valid? return true end |