Class: Bfwd::CreateSubscriptionChargeAmendment

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/create_subscription_charge_amendment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSubscriptionChargeAmendment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 170

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'@type')
    self.type = attributes[:'@type']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'amendmentType')
    self.amendment_type = attributes[:'amendmentType']
  end

  if attributes.has_key?(:'actioningTime')
    self.actioning_time = attributes[:'actioningTime']
  end

  if attributes.has_key?(:'actionedTime')
    self.actioned_time = attributes[:'actionedTime']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'deleted')
    self.deleted = attributes[:'deleted']
  else
    self.deleted = false
  end

  if attributes.has_key?(:'subscriptionChargeID')
    self.subscription_charge_id = attributes[:'subscriptionChargeID']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.has_key?(:'discount')
    self.discount = attributes[:'discount']
  end

  if attributes.has_key?(:'invoicingType')
    self.invoicing_type = attributes[:'invoicingType']
  end

  if attributes.has_key?(:'taxStatus')
    self.tax_status = attributes[:'taxStatus']
  end

  if attributes.has_key?(:'subscriptionCharge')
    self.subscription_charge = attributes[:'subscriptionCharge']
  end

  if attributes.has_key?(:'pricingComponentValueChange')
    self.pricing_component_value_change = attributes[:'pricingComponentValueChange']
  end

  if attributes.has_key?(:'pricingComponentID')
    self.pricing_component_id = attributes[:'pricingComponentID']
  end

end

Instance Attribute Details

#actioned_timeObject

{ "description" : "The time the amendment completed.", "verbs“: }



57
58
59
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 57

def actioned_time
  @actioned_time
end

#actioning_timeObject

{ "description" : "When the amendment will run", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 54

def actioning_time
  @actioning_time
end

#amendment_typeObject

{ "description" : "Type of amendment", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 51

def amendment_type
  @amendment_type
end

#amountObject

{ "description" : "Monetary value to charge in the same currency as the subscription.", "verbs“: }



72
73
74
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 72

def amount
  @amount
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 33

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 30

def created
  @created
end

#deletedObject

{ "description" : "Is the amendment deleted.", "verbs“: }



63
64
65
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 63

def deleted
  @deleted
end

#descriptionObject

{ "description" : ".", "verbs“: }



69
70
71
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 69

def description
  @description
end

#discountObject

{ "description" : "", "verbs":[] }



75
76
77
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 75

def discount
  @discount
end

#idObject

{ "description" : "", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 42

def id
  @id
end

#invoicing_typeObject

{ "description" : "<span class=\"label label-default\">Immediate</span> invoicing will result in an invoice being issued immediately for the charge. <span class=\"label label-default\">Aggregated</span> invoicing will generate a charge to be added to the next issued invoice, for example at the current billing period end.", "default" : "Aggregated", "verbs“: }



78
79
80
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 78

def invoicing_type
  @invoicing_type
end

#organization_idObject

{ "description" : "", "verbs“: }



45
46
47
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 45

def organization_id
  @organization_id
end

#pricing_component_idObject

{ "description" : "", "verbs":[] }



90
91
92
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 90

def pricing_component_id
  @pricing_component_id
end

#pricing_component_value_changeObject

{ "description" : "", "verbs":[] }



87
88
89
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 87

def pricing_component_value_change
  @pricing_component_value_change
end

#stateObject

Whether the subscription-amendment is: pending (to be actioned in the future), succeeded (actioning completed), failed (actioning was attempted but no effect was made) or discarded (the amendment had been cancelled before being actioned). Default: Pending



60
61
62
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 60

def state
  @state
end

#subscription_chargeObject

{ "description" : "", "verbs“: }



84
85
86
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 84

def subscription_charge
  @subscription_charge
end

#subscription_charge_idObject

{ "description" : "", "verbs“: }



66
67
68
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 66

def subscription_charge_id
  @subscription_charge_id
end

#subscription_idObject

{ "description" : "", "verbs“: }



48
49
50
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 48

def subscription_id
  @subscription_id
end

#tax_statusObject

{ "description" : "Whether the amount specified is <span class=\"label label-default\">inclusive</span> or <span class=\"label label-default\">exclusive</span> of tax", "default" : "inclusive", "verbs“: }



81
82
83
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 81

def tax_status
  @tax_status
end

#typeObject

{ "description" : "", "default" : "", "verbs“: }



39
40
41
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 39

def type
  @type
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 36

def updated
  @updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 115

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'type' => :'@type',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'subscription_id' => :'subscriptionID',
    :'amendment_type' => :'amendmentType',
    :'actioning_time' => :'actioningTime',
    :'actioned_time' => :'actionedTime',
    :'state' => :'state',
    :'deleted' => :'deleted',
    :'subscription_charge_id' => :'subscriptionChargeID',
    :'description' => :'description',
    :'amount' => :'amount',
    :'discount' => :'discount',
    :'invoicing_type' => :'invoicingType',
    :'tax_status' => :'taxStatus',
    :'subscription_charge' => :'subscriptionCharge',
    :'pricing_component_value_change' => :'pricingComponentValueChange',
    :'pricing_component_id' => :'pricingComponentID'
  }
end

.swagger_typesObject

Attribute type mapping.



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 142

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'type' => :'String',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'subscription_id' => :'String',
    :'amendment_type' => :'String',
    :'actioning_time' => :'DateTime',
    :'actioned_time' => :'DateTime',
    :'state' => :'String',
    :'deleted' => :'BOOLEAN',
    :'subscription_charge_id' => :'String',
    :'description' => :'String',
    :'amount' => :'Float',
    :'discount' => :'Float',
    :'invoicing_type' => :'String',
    :'tax_status' => :'String',
    :'subscription_charge' => :'SubscriptionCharge',
    :'pricing_component_value_change' => :'InsertableBillingEntity',
    :'pricing_component_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 347

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      type == o.type &&
      id == o.id &&
      organization_id == o.organization_id &&
      subscription_id == o.subscription_id &&
      amendment_type == o.amendment_type &&
      actioning_time == o.actioning_time &&
      actioned_time == o.actioned_time &&
      state == o.state &&
      deleted == o.deleted &&
      subscription_charge_id == o.subscription_charge_id &&
      description == o.description &&
      amount == o.amount &&
      discount == o.discount &&
      invoicing_type == o.invoicing_type &&
      tax_status == o.tax_status &&
      subscription_charge == o.subscription_charge &&
      pricing_component_value_change == o.pricing_component_value_change &&
      pricing_component_id == o.pricing_component_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 409

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



475
476
477
478
479
480
481
482
483
484
485
486
487
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 475

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 388

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


375
376
377
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 375

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



381
382
383
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 381

def hash
  [created, changed_by, updated, type, id, organization_id, subscription_id, amendment_type, actioning_time, actioned_time, state, deleted, subscription_charge_id, description, amount, discount, invoicing_type, tax_status, subscription_charge, pricing_component_value_change, pricing_component_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



266
267
268
269
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 266

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



455
456
457
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 455

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



461
462
463
464
465
466
467
468
469
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 461

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



449
450
451
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 449

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/bf_ruby2/models/create_subscription_charge_amendment.rb', line 273

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["InvoiceOutstandingChargesAmendment", "IssueInvoiceAmendment", "PricingComponentValueAmendment", "InvoiceRecalculationAmendment", "CancellationAmendment", "InvoiceNextExecutionAttemptAmendment", "FixedTermExpiryAmendment", "EndTrialAmendment", "ProductRatePlanMigrationAmendment", "AmendmentDiscardAmendment", "UpdateComponentValueAmendment", "ServiceEndAmendment", "ResumeSubscriptionAmendment", "CreateSubscriptionChargeAmendment", "TimerAmendment"])
  return false unless type_validator.valid?(@type)
  return false if @subscription_id.nil?
  return false if @amendment_type.nil?
  amendment_type_validator = EnumAttributeValidator.new('String', ["InvoiceNextExecutionAttempt", "Cancellation", "PricingComponentValue", "AmendmentDiscard", "Compound", "FixedTermExpiry", "InvoiceRecalculation", "EndTrial", "InvoiceOutstandingCharges", "IssueInvoice", "ProductRatePlanMigration", "UpdateComponentValue", "ServiceEnd", "ResumeSubscription", "CreateSubscriptionCharge", "Timer"])
  return false unless amendment_type_validator.valid?(@amendment_type)
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["Pending", "Succeeded", "Failed", "Discarded"])
  return false unless state_validator.valid?(@state)
  return false if @deleted.nil?
  return false if @amount.nil?
  return false if @invoicing_type.nil?
  invoicing_type_validator = EnumAttributeValidator.new('String', ["Immediate", "Aggregated"])
  return false unless invoicing_type_validator.valid?(@invoicing_type)
  return false if @tax_status.nil?
  tax_status_validator = EnumAttributeValidator.new('String', ["inclusive", "exclusive"])
  return false unless tax_status_validator.valid?(@tax_status)
  return true
end