Class: Bfwd::CreditnotesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/creditnotes_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CreditnotesApi

Returns a new instance of CreditnotesApi.



30
31
32
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_credit_note(credit_note, opts = {}) ⇒ CreditNotePagedMetadata

Create a credit note. a new credit note","request":"createCreditNoteRequest.html","response":"createCreditNoteResponse.html"

Parameters:

  • credit_note

    The credit note object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 39

def create_credit_note(credit_note, opts = {})
  data, _status_code, _headers = create_credit_note_with_http_info(credit_note, opts)
  return data
end

#create_credit_note_with_http_info(credit_note, opts = {}) ⇒ Array<(CreditNotePagedMetadata, Fixnum, Hash)>

Create a credit note. a new credit note&quot;,&quot;request&quot;:&quot;createCreditNoteRequest.html&quot;,&quot;response&quot;:&quot;createCreditNoteResponse.html&quot;

Parameters:

  • credit_note

    The credit note object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreditNotePagedMetadata, Fixnum, Hash)>)

    CreditNotePagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 49

def create_credit_note_with_http_info(credit_note, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CreditnotesApi.create_credit_note ..."
  end
  # verify the required parameter 'credit_note' is set
  fail ArgumentError, "Missing the required parameter 'credit_note' when calling CreditnotesApi.create_credit_note" if credit_note.nil?
  # resource path
  local_var_path = "/credit-notes".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(credit_note)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CreditNotePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CreditnotesApi#create_credit_note\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_credit_note_by_id(credit_note_id, opts = {}) ⇒ CreditNotePagedMetadata

Returns a single credit-note, specified by the ID parameter. an existing credit note","response":"getCreditNoteByID.html"

Parameters:

  • credit_note_id

    ID of the credit-note.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



97
98
99
100
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 97

def get_credit_note_by_id(credit_note_id, opts = {})
  data, _status_code, _headers = get_credit_note_by_id_with_http_info(credit_note_id, opts)
  return data
end

#get_credit_note_by_id_with_http_info(credit_note_id, opts = {}) ⇒ Array<(CreditNotePagedMetadata, Fixnum, Hash)>

Returns a single credit-note, specified by the ID parameter. an existing credit note&quot;,&quot;response&quot;:&quot;getCreditNoteByID.html&quot;

Parameters:

  • credit_note_id

    ID of the credit-note.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(CreditNotePagedMetadata, Fixnum, Hash)>)

    CreditNotePagedMetadata data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 108

def get_credit_note_by_id_with_http_info(credit_note_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CreditnotesApi.get_credit_note_by_id ..."
  end
  # verify the required parameter 'credit_note_id' is set
  fail ArgumentError, "Missing the required parameter 'credit_note_id' when calling CreditnotesApi.get_credit_note_by_id" if credit_note_id.nil?
  # resource path
  local_var_path = "/credit-notes/{credit-note-ID}".sub('{format}','json').sub('{' + 'credit-note-ID' + '}', credit_note_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CreditNotePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CreditnotesApi#get_credit_note_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_credit_note_for_account(account_id, opts = {}) ⇒ CreditNotePagedMetadata

Returns credit notes for an account. by account","response":"getCreditNotesByAccount.html"

Parameters:

  • account_id

    ID of the account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment to return. (default to 0)

  • :records (Integer)

    The maximum number of payments to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



161
162
163
164
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 161

def (, opts = {})
  data, _status_code, _headers = (, opts)
  return data
end

#get_credit_note_for_account_with_http_info(account_id, opts = {}) ⇒ Array<(CreditNotePagedMetadata, Fixnum, Hash)>

Returns credit notes for an account. by account&quot;,&quot;response&quot;:&quot;getCreditNotesByAccount.html&quot;

Parameters:

  • account_id

    ID of the account.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment to return.

  • :records (Integer)

    The maximum number of payments to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:

  • (Array<(CreditNotePagedMetadata, Fixnum, Hash)>)

    CreditNotePagedMetadata data, response status code and response headers



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 176

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CreditnotesApi.get_credit_note_for_account ..."
  end
  # verify the required parameter 'account_id' is set
  fail ArgumentError, "Missing the required parameter 'account_id' when calling CreditnotesApi.get_credit_note_for_account" if .nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/credit-notes/account/{account-ID}".sub('{format}','json').sub('{' + 'account-ID' + '}', .to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CreditNotePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CreditnotesApi#get_credit_note_for_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_credit_note_for_invoice(invoice_id, opts = {}) ⇒ CreditNotePagedMetadata

Returns credit notes for an invoice. by invoice","response":"getCreditNotesByInvoice.html"

Parameters:

  • invoice_id

    ID of the Invoice.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment to return. (default to 0)

  • :records (Integer)

    The maximum number of payments to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



236
237
238
239
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 236

def get_credit_note_for_invoice(invoice_id, opts = {})
  data, _status_code, _headers = get_credit_note_for_invoice_with_http_info(invoice_id, opts)
  return data
end

#get_credit_note_for_invoice_with_http_info(invoice_id, opts = {}) ⇒ Array<(CreditNotePagedMetadata, Fixnum, Hash)>

Returns credit notes for an invoice. by invoice&quot;,&quot;response&quot;:&quot;getCreditNotesByInvoice.html&quot;

Parameters:

  • invoice_id

    ID of the Invoice.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment to return.

  • :records (Integer)

    The maximum number of payments to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:

  • (Array<(CreditNotePagedMetadata, Fixnum, Hash)>)

    CreditNotePagedMetadata data, response status code and response headers



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 251

def get_credit_note_for_invoice_with_http_info(invoice_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CreditnotesApi.get_credit_note_for_invoice ..."
  end
  # verify the required parameter 'invoice_id' is set
  fail ArgumentError, "Missing the required parameter 'invoice_id' when calling CreditnotesApi.get_credit_note_for_invoice" if invoice_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/credit-notes/invoice/{invoice-ID}".sub('{format}','json').sub('{' + 'invoice-ID' + '}', invoice_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CreditNotePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CreditnotesApi#get_credit_note_for_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_credit_note_for_subscription(subscription_id, opts = {}) ⇒ CreditNotePagedMetadata

Returns credit notes for an subscription. by subscription","response":"getCreditNotesSubscription.html"

Parameters:

  • subscription_id

    ID of the subscription.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment to return. (default to 0)

  • :records (Integer)

    The maximum number of payments to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



311
312
313
314
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 311

def get_credit_note_for_subscription(subscription_id, opts = {})
  data, _status_code, _headers = get_credit_note_for_subscription_with_http_info(subscription_id, opts)
  return data
end

#get_credit_note_for_subscription_with_http_info(subscription_id, opts = {}) ⇒ Array<(CreditNotePagedMetadata, Fixnum, Hash)>

Returns credit notes for an subscription. by subscription&quot;,&quot;response&quot;:&quot;getCreditNotesSubscription.html&quot;

Parameters:

  • subscription_id

    ID of the subscription.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment to return.

  • :records (Integer)

    The maximum number of payments to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:

  • (Array<(CreditNotePagedMetadata, Fixnum, Hash)>)

    CreditNotePagedMetadata data, response status code and response headers



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 326

def get_credit_note_for_subscription_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CreditnotesApi.get_credit_note_for_subscription ..."
  end
  # verify the required parameter 'subscription_id' is set
  fail ArgumentError, "Missing the required parameter 'subscription_id' when calling CreditnotesApi.get_credit_note_for_subscription" if subscription_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/credit-notes/subscription/{subscription-ID}".sub('{format}','json').sub('{' + 'subscription-ID' + '}', subscription_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CreditNotePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CreditnotesApi#get_credit_note_for_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retire_credit_note(credit_note_id, organizations, opts = {}) ⇒ CreditNotePagedMetadata

Removes any remaining value from credit note remaining value from credit note","response":"deleteCreditNote.html"

Parameters:

  • credit_note_id

    ID of the credit-note.

  • organizations

    A list of organization-IDs used to restrict the scope of API calls.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



382
383
384
385
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 382

def retire_credit_note(credit_note_id, organizations, opts = {})
  data, _status_code, _headers = retire_credit_note_with_http_info(credit_note_id, organizations, opts)
  return data
end

#retire_credit_note_with_http_info(credit_note_id, organizations, opts = {}) ⇒ Array<(CreditNotePagedMetadata, Fixnum, Hash)>

Removes any remaining value from credit note remaining value from credit note&quot;,&quot;response&quot;:&quot;deleteCreditNote.html&quot;

Parameters:

  • credit_note_id

    ID of the credit-note.

  • organizations

    A list of organization-IDs used to restrict the scope of API calls.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreditNotePagedMetadata, Fixnum, Hash)>)

    CreditNotePagedMetadata data, response status code and response headers



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/bf_ruby2/api/creditnotes_api.rb', line 393

def retire_credit_note_with_http_info(credit_note_id, organizations, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CreditnotesApi.retire_credit_note ..."
  end
  # verify the required parameter 'credit_note_id' is set
  fail ArgumentError, "Missing the required parameter 'credit_note_id' when calling CreditnotesApi.retire_credit_note" if credit_note_id.nil?
  # verify the required parameter 'organizations' is set
  fail ArgumentError, "Missing the required parameter 'organizations' when calling CreditnotesApi.retire_credit_note" if organizations.nil?
  # resource path
  local_var_path = "/credit-notes/{credit-note-ID}".sub('{format}','json').sub('{' + 'credit-note-ID' + '}', credit_note_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(organizations, :multi)

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CreditNotePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CreditnotesApi#retire_credit_note\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end