Class: Bfwd::DataSynchronisationConfiguration
- Inherits:
-
Object
- Object
- Bfwd::DataSynchronisationConfiguration
- Defined in:
- lib/bf_ruby2/models/data_synchronisation_configuration.rb
Overview
Configuration used for synchronising BillForward data with some third-party platform’s dataset.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_token ⇒ Object
This is the token for the platform.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#deleted ⇒ Object
Is the sync job deleted.
-
#id ⇒ Object
ID of the Synchronization Configuration.
-
#instance_url ⇒ Object
This is the instance url for client’s salesforce instance.
-
#max_failed_retry ⇒ Object
This is maximum of the retry attempts when a synch is failed.
-
#organization_id ⇒ Object
Organization associated with Synchronization Configuration.
-
#platform ⇒ Object
This is the platform of the job.
-
#refresh_token ⇒ Object
This is the refresh token for the platform.
-
#synch_interval ⇒ Object
This is interval between each sync.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
-
#username ⇒ Object
This is the username for the platform.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DataSynchronisationConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DataSynchronisationConfiguration
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 130 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'username') self.username = attributes[:'username'] end if attributes.has_key?(:'accessToken') self.access_token = attributes[:'accessToken'] end if attributes.has_key?(:'refreshToken') self.refresh_token = attributes[:'refreshToken'] end if attributes.has_key?(:'instanceUrl') self.instance_url = attributes[:'instanceUrl'] end if attributes.has_key?(:'platform') self.platform = attributes[:'platform'] end if attributes.has_key?(:'maxFailedRetry') self.max_failed_retry = attributes[:'maxFailedRetry'] end if attributes.has_key?(:'synchInterval') self.synch_interval = attributes[:'synchInterval'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end end |
Instance Attribute Details
#access_token ⇒ Object
This is the token for the platform.
48 49 50 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 48 def access_token @access_token end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 33 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 30 def created @created end |
#deleted ⇒ Object
Is the sync job deleted.
66 67 68 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 66 def deleted @deleted end |
#id ⇒ Object
ID of the Synchronization Configuration.
39 40 41 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 39 def id @id end |
#instance_url ⇒ Object
This is the instance url for client’s salesforce instance.
54 55 56 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 54 def instance_url @instance_url end |
#max_failed_retry ⇒ Object
This is maximum of the retry attempts when a synch is failed.
60 61 62 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 60 def max_failed_retry @max_failed_retry end |
#organization_id ⇒ Object
Organization associated with Synchronization Configuration.
42 43 44 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 42 def organization_id @organization_id end |
#platform ⇒ Object
This is the platform of the job.
57 58 59 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 57 def platform @platform end |
#refresh_token ⇒ Object
This is the refresh token for the platform.
51 52 53 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 51 def refresh_token @refresh_token end |
#synch_interval ⇒ Object
This is interval between each sync.
63 64 65 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 63 def synch_interval @synch_interval end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 36 def updated @updated end |
#username ⇒ Object
This is the username for the platform.
45 46 47 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 45 def username @username end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 91 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'organization_id' => :'organizationID', :'username' => :'username', :'access_token' => :'accessToken', :'refresh_token' => :'refreshToken', :'instance_url' => :'instanceUrl', :'platform' => :'platform', :'max_failed_retry' => :'maxFailedRetry', :'synch_interval' => :'synchInterval', :'deleted' => :'deleted' } end |
.swagger_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 110 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'organization_id' => :'String', :'username' => :'String', :'access_token' => :'String', :'refresh_token' => :'String', :'instance_url' => :'String', :'platform' => :'String', :'max_failed_retry' => :'Integer', :'synch_interval' => :'Integer', :'deleted' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && organization_id == o.organization_id && username == o.username && access_token == o.access_token && refresh_token == o.refresh_token && instance_url == o.instance_url && platform == o.platform && max_failed_retry == o.max_failed_retry && synch_interval == o.synch_interval && deleted == o.deleted end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 280 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 346 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 259 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 252 def hash [created, changed_by, updated, id, organization_id, username, access_token, refresh_token, instance_url, platform, max_failed_retry, synch_interval, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
194 195 196 197 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 194 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
326 327 328 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 326 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
332 333 334 335 336 337 338 339 340 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 332 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 320 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/bf_ruby2/models/data_synchronisation_configuration.rb', line 201 def valid? return false if @organization_id.nil? return false if @username.nil? return false if @access_token.nil? return false if @refresh_token.nil? return false if @instance_url.nil? return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["Salesforce"]) return false unless platform_validator.valid?(@platform) return false if @deleted.nil? return true end |