Class: Bfwd::DunningLine

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/dunning_line.rb

Overview

A dunning-line specifies when the next execution attempt of an unpaid invoice should take place given the number of existing execution attempts.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DunningLine

Initializes the object



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/bf_ruby2/models/dunning_line.rb', line 120

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'attemptIx')
    self.attempt_ix = attributes[:'attemptIx']
  end

  if attributes.has_key?(:'minutesDelay')
    self.minutes_delay = attributes[:'minutesDelay']
  end

  if attributes.has_key?(:'gateway')
    self.gateway = attributes[:'gateway']
  end

  if attributes.has_key?(:'deleted')
    self.deleted = attributes[:'deleted']
  else
    self.deleted = false
  end

  if attributes.has_key?(:'organization')
    self.organization = attributes[:'organization']
  end

end

Instance Attribute Details

#attempt_ixObject

{ "description" : "The payment attempt this dunning line applies to, specified as a positive integer. Dunning lines are ZERO indexed.", "verbs“: }



48
49
50
# File 'lib/bf_ruby2/models/dunning_line.rb', line 48

def attempt_ix
  @attempt_ix
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/dunning_line.rb', line 33

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/dunning_line.rb', line 30

def created
  @created
end

#deletedObject

{ "description" : "Has the dunning-line been deleted?", "verbs“: }



57
58
59
# File 'lib/bf_ruby2/models/dunning_line.rb', line 57

def deleted
  @deleted
end

#gatewayObject

{ "description" : "The payment gateway to use for this payment attempt.", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/dunning_line.rb', line 54

def gateway
  @gateway
end

#idObject

{ "description" : "ID of the dunning-line.", "verbs“: }



39
40
41
# File 'lib/bf_ruby2/models/dunning_line.rb', line 39

def id
  @id
end

#minutes_delayObject

{ "description" : "The time before the next payment attempt in minutes.", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/dunning_line.rb', line 51

def minutes_delay
  @minutes_delay
end

#organizationObject

{ "description" : "organization associated with the dunning-line.", "verbs“: }



60
61
62
# File 'lib/bf_ruby2/models/dunning_line.rb', line 60

def organization
  @organization
end

#organization_idObject

{ "description" : "ID of the organization associated with the dunning-line.", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/dunning_line.rb', line 42

def organization_id
  @organization_id
end

#typeObject

{ "description" : "ID of the organization associated with the dunning-line.", "verbs“: }



45
46
47
# File 'lib/bf_ruby2/models/dunning_line.rb', line 45

def type
  @type
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/dunning_line.rb', line 36

def updated
  @updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/bf_ruby2/models/dunning_line.rb', line 85

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'type' => :'type',
    :'attempt_ix' => :'attemptIx',
    :'minutes_delay' => :'minutesDelay',
    :'gateway' => :'gateway',
    :'deleted' => :'deleted',
    :'organization' => :'organization'
  }
end

.swagger_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/bf_ruby2/models/dunning_line.rb', line 102

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'type' => :'String',
    :'attempt_ix' => :'Integer',
    :'minutes_delay' => :'Integer',
    :'gateway' => :'String',
    :'deleted' => :'BOOLEAN',
    :'organization' => :'Organization'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/bf_ruby2/models/dunning_line.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      id == o.id &&
      organization_id == o.organization_id &&
      type == o.type &&
      attempt_ix == o.attempt_ix &&
      minutes_delay == o.minutes_delay &&
      gateway == o.gateway &&
      deleted == o.deleted &&
      organization == o.organization
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/bf_ruby2/models/dunning_line.rb', line 272

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/bf_ruby2/models/dunning_line.rb', line 338

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/bf_ruby2/models/dunning_line.rb', line 251

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


238
239
240
# File 'lib/bf_ruby2/models/dunning_line.rb', line 238

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



244
245
246
# File 'lib/bf_ruby2/models/dunning_line.rb', line 244

def hash
  [created, changed_by, updated, id, organization_id, type, attempt_ix, minutes_delay, gateway, deleted, organization].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



176
177
178
179
# File 'lib/bf_ruby2/models/dunning_line.rb', line 176

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



318
319
320
# File 'lib/bf_ruby2/models/dunning_line.rb', line 318

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



324
325
326
327
328
329
330
331
332
# File 'lib/bf_ruby2/models/dunning_line.rb', line 324

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



312
313
314
# File 'lib/bf_ruby2/models/dunning_line.rb', line 312

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/bf_ruby2/models/dunning_line.rb', line 183

def valid?
  return false if @organization_id.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["Invoice", "Notification"])
  return false unless type_validator.valid?(@type)
  return false if @attempt_ix.nil?
  return false if @minutes_delay.nil?
  return false if @gateway.nil?
  gateway_validator = EnumAttributeValidator.new('String', ["cybersource_token", "card_vault", "paypal_simple", "locustworld", "free", "coupon", "credit_note", "stripe", "braintree", "balanced", "paypal", "billforward_test", "offline", "trial", "stripeACH", "authorizeNet", "spreedly", "sagePay", "trustCommerce", "payvision", "kash"])
  return false unless gateway_validator.valid?(@gateway)
  return false if @deleted.nil?
  return false if @organization.nil?
  return true
end