Class: Bfwd::Email

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/email.rb

Overview

Email.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Email

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/bf_ruby2/models/email.rb', line 204

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'accountID')
    self. = attributes[:'accountID']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'invoiceID')
    self.invoice_id = attributes[:'invoiceID']
  end

  if attributes.has_key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.has_key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.has_key?(:'cc')
    self.cc = attributes[:'cc']
  end

  if attributes.has_key?(:'bcc')
    self.bcc = attributes[:'bcc']
  end

  if attributes.has_key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.has_key?(:'html')
    self.html = attributes[:'html']
  end

  if attributes.has_key?(:'attachmentFilename')
    self.attachment_filename = attributes[:'attachmentFilename']
  end

  if attributes.has_key?(:'attachmentHtml')
    self.attachment_html = attributes[:'attachmentHtml']
  end

  if attributes.has_key?(:'plain')
    self.plain = attributes[:'plain']
  end

  if attributes.has_key?(:'sent')
    self.sent = attributes[:'sent']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'deleted')
    self.deleted = attributes[:'deleted']
  else
    self.deleted = false
  end

  if attributes.has_key?(:'headerURL')
    self.header_url = attributes[:'headerURL']
  end

  if attributes.has_key?(:'salutation')
    self.salutation = attributes[:'salutation']
  end

  if attributes.has_key?(:'paragraph1')
    self.paragraph1 = attributes[:'paragraph1']
  end

  if attributes.has_key?(:'paragraph2')
    self.paragraph2 = attributes[:'paragraph2']
  end

  if attributes.has_key?(:'footerInformation')
    self.footer_information = attributes[:'footerInformation']
  end

  if attributes.has_key?(:'signoff')
    self.signoff = attributes[:'signoff']
  end

  if attributes.has_key?(:'emaiSubscriptionType')
    self.emai_subscription_type = attributes[:'emaiSubscriptionType']
  end

  if attributes.has_key?(:'notificationID')
    self.notification_id = attributes[:'notificationID']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

end

Instance Attribute Details

#account_idObject

{ "description" : "", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/email.rb', line 42

def 
  @account_id
end

#attachment_filenameObject

{ "description" : "", "verbs“: }



69
70
71
# File 'lib/bf_ruby2/models/email.rb', line 69

def attachment_filename
  @attachment_filename
end

#attachment_htmlObject

{ "description" : "", "verbs“: }



72
73
74
# File 'lib/bf_ruby2/models/email.rb', line 72

def attachment_html
  @attachment_html
end

#bccObject

{ "description" : "", "verbs“: }



60
61
62
# File 'lib/bf_ruby2/models/email.rb', line 60

def bcc
  @bcc
end

#ccObject

{ "description" : "", "verbs“: }



57
58
59
# File 'lib/bf_ruby2/models/email.rb', line 57

def cc
  @cc
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/email.rb', line 33

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/email.rb', line 30

def created
  @created
end

#deletedObject

{ "description" : "", "verbs“: }



84
85
86
# File 'lib/bf_ruby2/models/email.rb', line 84

def deleted
  @deleted
end

#emai_subscription_typeObject

Returns the value of attribute emai_subscription_type.



104
105
106
# File 'lib/bf_ruby2/models/email.rb', line 104

def emai_subscription_type
  @emai_subscription_type
end

{ "description" : "", "verbs“: }



99
100
101
# File 'lib/bf_ruby2/models/email.rb', line 99

def footer_information
  @footer_information
end

#fromObject

{ "description" : "", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/email.rb', line 51

def from
  @from
end

#header_urlObject

{ "description" : "", "verbs“: }



87
88
89
# File 'lib/bf_ruby2/models/email.rb', line 87

def header_url
  @header_url
end

#htmlObject

{ "description" : "", "verbs“: }



66
67
68
# File 'lib/bf_ruby2/models/email.rb', line 66

def html
  @html
end

#idObject

{ "description" : "", "verbs“: }



39
40
41
# File 'lib/bf_ruby2/models/email.rb', line 39

def id
  @id
end

#invoice_idObject

{ "description" : "", "verbs“: }



48
49
50
# File 'lib/bf_ruby2/models/email.rb', line 48

def invoice_id
  @invoice_id
end

#notification_idObject

{ "description" : "", "verbs":[] }



107
108
109
# File 'lib/bf_ruby2/models/email.rb', line 107

def notification_id
  @notification_id
end

#organization_idObject

{ "description" : "", "verbs":[] }



110
111
112
# File 'lib/bf_ruby2/models/email.rb', line 110

def organization_id
  @organization_id
end

#paragraph1Object

{ "description" : "", "verbs“: }



93
94
95
# File 'lib/bf_ruby2/models/email.rb', line 93

def paragraph1
  @paragraph1
end

#paragraph2Object

{ "description" : "", "verbs“: }



96
97
98
# File 'lib/bf_ruby2/models/email.rb', line 96

def paragraph2
  @paragraph2
end

#plainObject

{ "description" : "", "verbs“: }



75
76
77
# File 'lib/bf_ruby2/models/email.rb', line 75

def plain
  @plain
end

#salutationObject

{ "description" : "", "verbs“: }



90
91
92
# File 'lib/bf_ruby2/models/email.rb', line 90

def salutation
  @salutation
end

#sentObject

{ "description" : "", "verbs“: }



78
79
80
# File 'lib/bf_ruby2/models/email.rb', line 78

def sent
  @sent
end

#signoffObject

{ "description" : "", "verbs“: }



102
103
104
# File 'lib/bf_ruby2/models/email.rb', line 102

def signoff
  @signoff
end

#stateObject

{ "description" : ".", "verbs“: }



81
82
83
# File 'lib/bf_ruby2/models/email.rb', line 81

def state
  @state
end

#subjectObject

{ "description" : "", "verbs“: }



63
64
65
# File 'lib/bf_ruby2/models/email.rb', line 63

def subject
  @subject
end

#subscription_idObject

{ "description" : "", "verbs“: }



45
46
47
# File 'lib/bf_ruby2/models/email.rb', line 45

def subscription_id
  @subscription_id
end

#toObject

{ "description" : "", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/email.rb', line 54

def to
  @to
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/email.rb', line 36

def updated
  @updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/bf_ruby2/models/email.rb', line 135

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'id' => :'id',
    :'account_id' => :'accountID',
    :'subscription_id' => :'subscriptionID',
    :'invoice_id' => :'invoiceID',
    :'from' => :'from',
    :'to' => :'to',
    :'cc' => :'cc',
    :'bcc' => :'bcc',
    :'subject' => :'subject',
    :'html' => :'html',
    :'attachment_filename' => :'attachmentFilename',
    :'attachment_html' => :'attachmentHtml',
    :'plain' => :'plain',
    :'sent' => :'sent',
    :'state' => :'state',
    :'deleted' => :'deleted',
    :'header_url' => :'headerURL',
    :'salutation' => :'salutation',
    :'paragraph1' => :'paragraph1',
    :'paragraph2' => :'paragraph2',
    :'footer_information' => :'footerInformation',
    :'signoff' => :'signoff',
    :'emai_subscription_type' => :'emaiSubscriptionType',
    :'notification_id' => :'notificationID',
    :'organization_id' => :'organizationID'
  }
end

.swagger_typesObject

Attribute type mapping.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/bf_ruby2/models/email.rb', line 169

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'id' => :'String',
    :'account_id' => :'String',
    :'subscription_id' => :'String',
    :'invoice_id' => :'String',
    :'from' => :'String',
    :'to' => :'String',
    :'cc' => :'String',
    :'bcc' => :'String',
    :'subject' => :'String',
    :'html' => :'String',
    :'attachment_filename' => :'String',
    :'attachment_html' => :'String',
    :'plain' => :'String',
    :'sent' => :'DateTime',
    :'state' => :'String',
    :'deleted' => :'BOOLEAN',
    :'header_url' => :'String',
    :'salutation' => :'String',
    :'paragraph1' => :'String',
    :'paragraph2' => :'String',
    :'footer_information' => :'String',
    :'signoff' => :'String',
    :'emai_subscription_type' => :'String',
    :'notification_id' => :'String',
    :'organization_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/bf_ruby2/models/email.rb', line 367

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      id == o.id &&
       == o. &&
      subscription_id == o.subscription_id &&
      invoice_id == o.invoice_id &&
      from == o.from &&
      to == o.to &&
      cc == o.cc &&
      bcc == o.bcc &&
      subject == o.subject &&
      html == o.html &&
      attachment_filename == o.attachment_filename &&
      attachment_html == o.attachment_html &&
      plain == o.plain &&
      sent == o.sent &&
      state == o.state &&
      deleted == o.deleted &&
      header_url == o.header_url &&
      salutation == o.salutation &&
      paragraph1 == o.paragraph1 &&
      paragraph2 == o.paragraph2 &&
      footer_information == o.footer_information &&
      signoff == o.signoff &&
      emai_subscription_type == o.emai_subscription_type &&
      notification_id == o.notification_id &&
      organization_id == o.organization_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/bf_ruby2/models/email.rb', line 436

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/bf_ruby2/models/email.rb', line 502

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/bf_ruby2/models/email.rb', line 415

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


402
403
404
# File 'lib/bf_ruby2/models/email.rb', line 402

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



408
409
410
# File 'lib/bf_ruby2/models/email.rb', line 408

def hash
  [created, changed_by, updated, id, , subscription_id, invoice_id, from, to, cc, bcc, subject, html, attachment_filename, attachment_html, plain, sent, state, deleted, header_url, salutation, paragraph1, paragraph2, footer_information, signoff, emai_subscription_type, notification_id, organization_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



328
329
330
331
# File 'lib/bf_ruby2/models/email.rb', line 328

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



482
483
484
# File 'lib/bf_ruby2/models/email.rb', line 482

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



488
489
490
491
492
493
494
495
496
# File 'lib/bf_ruby2/models/email.rb', line 488

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



476
477
478
# File 'lib/bf_ruby2/models/email.rb', line 476

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



335
336
337
338
339
340
341
342
343
# File 'lib/bf_ruby2/models/email.rb', line 335

def valid?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["Pending", "Unsent", "Sent"])
  return false unless state_validator.valid?(@state)
  emai_subscription_type_validator = EnumAttributeValidator.new('String', ["FailedPayment", "InvoicePaid", "SubscriptionCancellation", "SubscriptionCancelled", "SubscriptionPlanMigrated", "SubscriptionPlanMigrating", "CardExpired", "CardExpiring"])
  return false unless emai_subscription_type_validator.valid?(@emai_subscription_type)
  return false if @organization_id.nil?
  return true
end