Class: Bfwd::EmailSubscription

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/email_subscription.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailSubscription

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/bf_ruby2/models/email_subscription.rb', line 122

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.has_key?(:'bcc')
    self.bcc = attributes[:'bcc']
  end

  if attributes.has_key?(:'cc')
    self.cc = attributes[:'cc']
  end

  if attributes.has_key?(:'subjectTemplate')
    self.subject_template = attributes[:'subjectTemplate']
  end

  if attributes.has_key?(:'sendToCustomer')
    self.send_to_customer = attributes[:'sendToCustomer']
  else
    self.send_to_customer = false
  end

  if attributes.has_key?(:'attachInvoice')
    self.attach_invoice = attributes[:'attachInvoice']
  else
    self.attach_invoice = false
  end

end

Instance Attribute Details

#attach_invoiceObject

Returns the value of attribute attach_invoice.



58
59
60
# File 'lib/bf_ruby2/models/email_subscription.rb', line 58

def attach_invoice
  @attach_invoice
end

#bccObject

Returns the value of attribute bcc.



50
51
52
# File 'lib/bf_ruby2/models/email_subscription.rb', line 50

def bcc
  @bcc
end

#ccObject

Returns the value of attribute cc.



52
53
54
# File 'lib/bf_ruby2/models/email_subscription.rb', line 52

def cc
  @cc
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/email_subscription.rb', line 33

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/email_subscription.rb', line 30

def created
  @created
end

#fromObject

Returns the value of attribute from.



48
49
50
# File 'lib/bf_ruby2/models/email_subscription.rb', line 48

def from
  @from
end

#idObject

{ "description" : "ID of the email provider.", "verbs“: }



39
40
41
# File 'lib/bf_ruby2/models/email_subscription.rb', line 39

def id
  @id
end

#organization_idObject

{ "description" : "ID of the organization associated with the email provider.", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/email_subscription.rb', line 42

def organization_id
  @organization_id
end

#send_to_customerObject

Returns the value of attribute send_to_customer.



56
57
58
# File 'lib/bf_ruby2/models/email_subscription.rb', line 56

def send_to_customer
  @send_to_customer
end

#stateObject

Returns the value of attribute state.



46
47
48
# File 'lib/bf_ruby2/models/email_subscription.rb', line 46

def state
  @state
end

#subject_templateObject

Returns the value of attribute subject_template.



54
55
56
# File 'lib/bf_ruby2/models/email_subscription.rb', line 54

def subject_template
  @subject_template
end

#typeObject

Returns the value of attribute type.



44
45
46
# File 'lib/bf_ruby2/models/email_subscription.rb', line 44

def type
  @type
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/email_subscription.rb', line 36

def updated
  @updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/bf_ruby2/models/email_subscription.rb', line 83

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'type' => :'type',
    :'state' => :'state',
    :'from' => :'from',
    :'bcc' => :'bcc',
    :'cc' => :'cc',
    :'subject_template' => :'subjectTemplate',
    :'send_to_customer' => :'sendToCustomer',
    :'attach_invoice' => :'attachInvoice'
  }
end

.swagger_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/bf_ruby2/models/email_subscription.rb', line 102

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'type' => :'String',
    :'state' => :'String',
    :'from' => :'String',
    :'bcc' => :'String',
    :'cc' => :'String',
    :'subject_template' => :'String',
    :'send_to_customer' => :'BOOLEAN',
    :'attach_invoice' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/bf_ruby2/models/email_subscription.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      id == o.id &&
      organization_id == o.organization_id &&
      type == o.type &&
      state == o.state &&
      from == o.from &&
      bcc == o.bcc &&
      cc == o.cc &&
      subject_template == o.subject_template &&
      send_to_customer == o.send_to_customer &&
      attach_invoice == o.attach_invoice
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/bf_ruby2/models/email_subscription.rb', line 282

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/bf_ruby2/models/email_subscription.rb', line 348

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/bf_ruby2/models/email_subscription.rb', line 261

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/bf_ruby2/models/email_subscription.rb', line 248

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



254
255
256
# File 'lib/bf_ruby2/models/email_subscription.rb', line 254

def hash
  [created, changed_by, updated, id, organization_id, type, state, from, bcc, cc, subject_template, send_to_customer, attach_invoice].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



188
189
190
191
# File 'lib/bf_ruby2/models/email_subscription.rb', line 188

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
# File 'lib/bf_ruby2/models/email_subscription.rb', line 328

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
# File 'lib/bf_ruby2/models/email_subscription.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



322
323
324
# File 'lib/bf_ruby2/models/email_subscription.rb', line 322

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
199
200
201
202
203
204
# File 'lib/bf_ruby2/models/email_subscription.rb', line 195

def valid?
  return false if @organization_id.nil?
  type_validator = EnumAttributeValidator.new('String', ["FailedPayment", "InvoicePaid", "SubscriptionCancellation", "SubscriptionCancelled", "SubscriptionPlanMigrated", "SubscriptionPlanMigrating", "CardExpired", "CardExpiring"])
  return false unless type_validator.valid?(@type)
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["Active", "Disabled"])
  return false unless state_validator.valid?(@state)
  return false if @from.nil?
  return true
end