Class: Bfwd::FixedTerm
- Inherits:
-
Object
- Object
- Bfwd::FixedTerm
- Defined in:
- lib/bf_ruby2/models/fixed_term.rb
Overview
FixedTerm
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#compound_uplift ⇒ Object
{ "description" : "compoundUplift", "verbs“: }The proportional INCREASE in price applied every time the fixed terms recur.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#deleted ⇒ Object
{ "description" : "Is the fixedTerm deleted.", "verbs“: }.
-
#expiry_behaviour ⇒ Object
fixedTermExpiryBehaviour.
-
#expiry_time ⇒ Object
expiry_time.
-
#fixed_term_definition ⇒ Object
Returns the value of attribute fixed_term_definition.
-
#fixed_term_definition_id ⇒ Object
{ "description" : "fixedTermDefinitionID", "verbs“: }.
-
#fixed_term_number ⇒ Object
{ "description" : "The number of sequential fixed terms previous to this one for the subscription (i.e. zero indexed ‘fixedTermCount’).", "verbs“: }.
-
#id ⇒ Object
id.
-
#organization_id ⇒ Object
{ "description" : "The ID of the organization associated with the amendment.", "verbs“: }.
-
#periods ⇒ Object
{ "description" : "The number of billing periods that this fixed term lasts for.", "verbs“: }.
-
#product_rate_plan_as_of_time ⇒ Object
productRatePlanAsOfTime.
-
#start_time ⇒ Object
start_time.
-
#state ⇒ Object
state.
-
#subscription_id ⇒ Object
{ "description" : "subscriptionID", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FixedTerm
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FixedTerm
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 149 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'subscriptionID') self.subscription_id = attributes[:'subscriptionID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'fixedTermDefinitionID') self.fixed_term_definition_id = attributes[:'fixedTermDefinitionID'] end if attributes.has_key?(:'fixedTermDefinition') self.fixed_term_definition = attributes[:'fixedTermDefinition'] end if attributes.has_key?(:'expiryBehaviour') self.expiry_behaviour = attributes[:'expiryBehaviour'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'productRatePlanAsOfTime') self.product_rate_plan_as_of_time = attributes[:'productRatePlanAsOfTime'] end if attributes.has_key?(:'compoundUplift') self.compound_uplift = attributes[:'compoundUplift'] end if attributes.has_key?(:'startTime') self.start_time = attributes[:'startTime'] end if attributes.has_key?(:'expiryTime') self.expiry_time = attributes[:'expiryTime'] end if attributes.has_key?(:'periods') self.periods = attributes[:'periods'] end if attributes.has_key?(:'fixedTermNumber') self.fixed_term_number = attributes[:'fixedTermNumber'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end end |
Instance Attribute Details
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 33 def changed_by @changed_by end |
#compound_uplift ⇒ Object
{ "description" : "compoundUplift", "verbs“: }The proportional INCREASE in price applied every time the fixed terms recur. e.g. 0.03 is a 3% increase. -0.5 is a 50% decrease. 3 is a 300% increase
62 63 64 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 62 def compound_uplift @compound_uplift end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 30 def created @created end |
#deleted ⇒ Object
{ "description" : "Is the fixedTerm deleted.", "verbs“: }
77 78 79 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 77 def deleted @deleted end |
#expiry_behaviour ⇒ Object
fixedTermExpiryBehaviour
53 54 55 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 53 def expiry_behaviour @expiry_behaviour end |
#expiry_time ⇒ Object
expiry_time
68 69 70 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 68 def expiry_time @expiry_time end |
#fixed_term_definition ⇒ Object
Returns the value of attribute fixed_term_definition.
50 51 52 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 50 def fixed_term_definition @fixed_term_definition end |
#fixed_term_definition_id ⇒ Object
{ "description" : "fixedTermDefinitionID", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 48 def fixed_term_definition_id @fixed_term_definition_id end |
#fixed_term_number ⇒ Object
{ "description" : "The number of sequential fixed terms previous to this one for the subscription (i.e. zero indexed ‘fixedTermCount’).", "verbs“: }
74 75 76 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 74 def fixed_term_number @fixed_term_number end |
#id ⇒ Object
id
39 40 41 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 39 def id @id end |
#organization_id ⇒ Object
{ "description" : "The ID of the organization associated with the amendment.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 45 def organization_id @organization_id end |
#periods ⇒ Object
{ "description" : "The number of billing periods that this fixed term lasts for.", "verbs“: }
71 72 73 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 71 def periods @periods end |
#product_rate_plan_as_of_time ⇒ Object
productRatePlanAsOfTime
59 60 61 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 59 def product_rate_plan_as_of_time @product_rate_plan_as_of_time end |
#start_time ⇒ Object
start_time
65 66 67 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 65 def start_time @start_time end |
#state ⇒ Object
state
56 57 58 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 56 def state @state end |
#subscription_id ⇒ Object
{ "description" : "subscriptionID", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 42 def subscription_id @subscription_id end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 36 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 102 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'subscription_id' => :'subscriptionID', :'organization_id' => :'organizationID', :'fixed_term_definition_id' => :'fixedTermDefinitionID', :'fixed_term_definition' => :'fixedTermDefinition', :'expiry_behaviour' => :'expiryBehaviour', :'state' => :'state', :'product_rate_plan_as_of_time' => :'productRatePlanAsOfTime', :'compound_uplift' => :'compoundUplift', :'start_time' => :'startTime', :'expiry_time' => :'expiryTime', :'periods' => :'periods', :'fixed_term_number' => :'fixedTermNumber', :'deleted' => :'deleted' } end |
.swagger_types ⇒ Object
Attribute type mapping.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 125 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'subscription_id' => :'String', :'organization_id' => :'String', :'fixed_term_definition_id' => :'String', :'fixed_term_definition' => :'MutableBillingEntity', :'expiry_behaviour' => :'String', :'state' => :'String', :'product_rate_plan_as_of_time' => :'DateTime', :'compound_uplift' => :'Float', :'start_time' => :'DateTime', :'expiry_time' => :'DateTime', :'periods' => :'Integer', :'fixed_term_number' => :'Integer', :'deleted' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 279 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && subscription_id == o.subscription_id && organization_id == o.organization_id && fixed_term_definition_id == o.fixed_term_definition_id && fixed_term_definition == o.fixed_term_definition && expiry_behaviour == o.expiry_behaviour && state == o.state && product_rate_plan_as_of_time == o.product_rate_plan_as_of_time && compound_uplift == o.compound_uplift && start_time == o.start_time && expiry_time == o.expiry_time && periods == o.periods && fixed_term_number == o.fixed_term_number && deleted == o.deleted end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 337 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 403 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 316 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
303 304 305 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 303 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
309 310 311 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 309 def hash [created, changed_by, updated, id, subscription_id, organization_id, fixed_term_definition_id, fixed_term_definition, expiry_behaviour, state, product_rate_plan_as_of_time, compound_uplift, start_time, expiry_time, periods, fixed_term_number, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 229 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
383 384 385 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 383 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
389 390 391 392 393 394 395 396 397 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 389 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
377 378 379 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 377 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/bf_ruby2/models/fixed_term.rb', line 236 def valid? return false if @subscription_id.nil? return false if @organization_id.nil? return false if @fixed_term_definition_id.nil? return false if @fixed_term_definition.nil? return false if @expiry_behaviour.nil? expiry_behaviour_validator = EnumAttributeValidator.new('String', ["ExpireSubscription", "EvergreenSubscription", "RecurUplift", "RecurLatestPricing"]) return false unless expiry_behaviour_validator.valid?(@expiry_behaviour) return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["NeedsAmendments", "Active", "Expired"]) return false unless state_validator.valid?(@state) return false if @product_rate_plan_as_of_time.nil? return false if @compound_uplift.nil? return false if @start_time.nil? return false if @expiry_time.nil? return false if @periods.nil? return false if @fixed_term_number.nil? return false if @deleted.nil? return true end |