Class: Bfwd::InvoiceLinePayment

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/invoice_line_payment.rb

Overview

An InvoiceLinePayment specifies the amount of a particular invoice payment used to pay part of — or the entirety of — the outstanding balance of the associated invoice line.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InvoiceLinePayment

Initializes the object



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 210

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'periodStart')
    self.period_start = attributes[:'periodStart']
  end

  if attributes.has_key?(:'periodEnd')
    self.period_end = attributes[:'periodEnd']
  end

  if attributes.has_key?(:'paymentReceived')
    self.payment_received = attributes[:'paymentReceived']
  end

  if attributes.has_key?(:'refundReceived')
    self.refund_received = attributes[:'refundReceived']
  end

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'paymentID')
    self.payment_id = attributes[:'paymentID']
  end

  if attributes.has_key?(:'gatewayOriginalPaymentReference')
    self.gateway_original_payment_reference = attributes[:'gatewayOriginalPaymentReference']
  end

  if attributes.has_key?(:'gatewayRefundPaymentReference')
    self.gateway_refund_payment_reference = attributes[:'gatewayRefundPaymentReference']
  end

  if attributes.has_key?(:'aggregatedInvoiceID')
    self.aggregated_invoice_id = attributes[:'aggregatedInvoiceID']
  end

  if attributes.has_key?(:'aggregatedInvoiceLineID')
    self.aggregated_invoice_line_id = attributes[:'aggregatedInvoiceLineID']
  end

  if attributes.has_key?(:'invoicePaymentID')
    self.invoice_payment_id = attributes[:'invoicePaymentID']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'gateway')
    self.gateway = attributes[:'gateway']
  end

  if attributes.has_key?(:'nominalAmount')
    self.nominal_amount = attributes[:'nominalAmount']
  end

  if attributes.has_key?(:'actualAmount')
    self.actual_amount = attributes[:'actualAmount']
  end

  if attributes.has_key?(:'refundedAmount')
    self.refunded_amount = attributes[:'refundedAmount']
  end

  if attributes.has_key?(:'pricingComponentID')
    self.pricing_component_id = attributes[:'pricingComponentID']
  end

  if attributes.has_key?(:'pricingComponentName')
    self.pricing_component_name = attributes[:'pricingComponentName']
  end

  if attributes.has_key?(:'productRatePlanID')
    self.product_rate_plan_id = attributes[:'productRatePlanID']
  end

  if attributes.has_key?(:'productRatePlanName')
    self.product_rate_plan_name = attributes[:'productRatePlanName']
  end

  if attributes.has_key?(:'productRatePlanNamePublic')
    self.product_rate_plan_name_public = attributes[:'productRatePlanNamePublic']
  end

  if attributes.has_key?(:'productID')
    self.product_id = attributes[:'productID']
  end

  if attributes.has_key?(:'productName')
    self.product_name = attributes[:'productName']
  end

  if attributes.has_key?(:'productNamePublic')
    self.product_name_public = attributes[:'productNamePublic']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'accountID')
    self. = attributes[:'accountID']
  end

end

Instance Attribute Details

#account_idObject

of the Account with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



114
115
116
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 114

def 
  @account_id
end

#actual_amountObject

amount paid — through real money — toward this invoice line.“,”verbs“:



81
82
83
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 81

def actual_amount
  @actual_amount
end

#aggregated_invoice_idObject

of the invoice to which this InvoiceLinePayment’s invoice line belongs.“,”verbs“:



63
64
65
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 63

def aggregated_invoice_id
  @aggregated_invoice_id
end

#aggregated_invoice_line_idObject

of the invoice line toward which this InvoiceLinePayment contributes payment.“,”verbs“:



66
67
68
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 66

def aggregated_invoice_line_id
  @aggregated_invoice_line_id
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



45
46
47
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 45

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



42
43
44
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 42

def created
  @created
end

#currencyObject

currency of the payment — specified by a three-character ISO 4217 currency code.“,”verbs“:



72
73
74
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 72

def currency
  @currency
end

#gatewayObject

gateway through which the payment was made.“,”verbs“:



75
76
77
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 75

def gateway
  @gateway
end

#gateway_original_payment_referenceObject

with which the original payment transaction can be looked up in its gateway.“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 57

def gateway_original_payment_reference
  @gateway_original_payment_reference
end

#gateway_refund_payment_referenceObject

with which the refund transaction for the payment can be looked up in its gateway.“,”verbs“:



60
61
62
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 60

def gateway_refund_payment_reference
  @gateway_refund_payment_reference
end

#idObject



48
49
50
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 48

def id
  @id
end

#invoice_payment_idObject

of the InvoicePayment with which this InvoiceLinePayment is associated.“,”verbs“:



69
70
71
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 69

def invoice_payment_id
  @invoice_payment_id
end

#nominal_amountObject

amount paid — through credit or otherwise — toward this invoice line.“,”verbs“:



78
79
80
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 78

def nominal_amount
  @nominal_amount
end

#organization_idObject

of the organization associated with the InvoiceLinePayment.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 51

def organization_id
  @organization_id
end

#payment_idObject

of the Payment used upon this InvoiceLinePayment’s invoice line.“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 54

def payment_id
  @payment_id
end

#payment_receivedObject

date when the associated payment was received.“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 36

def payment_received
  @payment_received
end

#period_endObject

of the charge with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



33
34
35
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 33

def period_end
  @period_end
end

#period_startObject

of the charge with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



30
31
32
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 30

def period_start
  @period_start
end

#pricing_component_idObject

of the PricingComponent with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



87
88
89
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 87

def pricing_component_id
  @pricing_component_id
end

#pricing_component_nameObject

of the PricingComponent with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



90
91
92
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 90

def pricing_component_name
  @pricing_component_name
end

#product_idObject

of the Product with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



102
103
104
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 102

def product_id
  @product_id
end

#product_nameObject

name of the Product with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



105
106
107
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 105

def product_name
  @product_name
end

#product_name_publicObject

name of the Product with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



108
109
110
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 108

def product_name_public
  @product_name_public
end

#product_rate_plan_idObject

of the ProductRatePlan with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



93
94
95
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 93

def product_rate_plan_id
  @product_rate_plan_id
end

#product_rate_plan_nameObject

name of the ProductRatePlan with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



96
97
98
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 96

def product_rate_plan_name
  @product_rate_plan_name
end

#product_rate_plan_name_publicObject

name of the ProductRatePlan with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



99
100
101
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 99

def product_rate_plan_name_public
  @product_rate_plan_name_public
end

#refund_receivedObject

date when the associated payment was refunded.“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 39

def refund_received
  @refund_received
end

#refunded_amountObject

monetary amount refunded toward this invoice line.“,”verbs“:



84
85
86
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 84

def refunded_amount
  @refunded_amount
end

#subscription_idObject

of the Subscription with which this InvoiceLinePayment’s invoice line is associated.“,”verbs“:



111
112
113
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 111

def subscription_id
  @subscription_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 139

def self.attribute_map
  {
    :'period_start' => :'periodStart',
    :'period_end' => :'periodEnd',
    :'payment_received' => :'paymentReceived',
    :'refund_received' => :'refundReceived',
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'payment_id' => :'paymentID',
    :'gateway_original_payment_reference' => :'gatewayOriginalPaymentReference',
    :'gateway_refund_payment_reference' => :'gatewayRefundPaymentReference',
    :'aggregated_invoice_id' => :'aggregatedInvoiceID',
    :'aggregated_invoice_line_id' => :'aggregatedInvoiceLineID',
    :'invoice_payment_id' => :'invoicePaymentID',
    :'currency' => :'currency',
    :'gateway' => :'gateway',
    :'nominal_amount' => :'nominalAmount',
    :'actual_amount' => :'actualAmount',
    :'refunded_amount' => :'refundedAmount',
    :'pricing_component_id' => :'pricingComponentID',
    :'pricing_component_name' => :'pricingComponentName',
    :'product_rate_plan_id' => :'productRatePlanID',
    :'product_rate_plan_name' => :'productRatePlanName',
    :'product_rate_plan_name_public' => :'productRatePlanNamePublic',
    :'product_id' => :'productID',
    :'product_name' => :'productName',
    :'product_name_public' => :'productNamePublic',
    :'subscription_id' => :'subscriptionID',
    :'account_id' => :'accountID'
  }
end

.swagger_typesObject

Attribute type mapping.



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 174

def self.swagger_types
  {
    :'period_start' => :'DateTime',
    :'period_end' => :'DateTime',
    :'payment_received' => :'DateTime',
    :'refund_received' => :'DateTime',
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'payment_id' => :'String',
    :'gateway_original_payment_reference' => :'String',
    :'gateway_refund_payment_reference' => :'String',
    :'aggregated_invoice_id' => :'String',
    :'aggregated_invoice_line_id' => :'String',
    :'invoice_payment_id' => :'String',
    :'currency' => :'String',
    :'gateway' => :'String',
    :'nominal_amount' => :'Float',
    :'actual_amount' => :'Float',
    :'refunded_amount' => :'Float',
    :'pricing_component_id' => :'String',
    :'pricing_component_name' => :'String',
    :'product_rate_plan_id' => :'String',
    :'product_rate_plan_name' => :'String',
    :'product_rate_plan_name_public' => :'String',
    :'product_id' => :'String',
    :'product_name' => :'String',
    :'product_name_public' => :'String',
    :'subscription_id' => :'String',
    :'account_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 387

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      period_start == o.period_start &&
      period_end == o.period_end &&
      payment_received == o.payment_received &&
      refund_received == o.refund_received &&
      created == o.created &&
      changed_by == o.changed_by &&
      id == o.id &&
      organization_id == o.organization_id &&
      payment_id == o.payment_id &&
      gateway_original_payment_reference == o.gateway_original_payment_reference &&
      gateway_refund_payment_reference == o.gateway_refund_payment_reference &&
      aggregated_invoice_id == o.aggregated_invoice_id &&
      aggregated_invoice_line_id == o.aggregated_invoice_line_id &&
      invoice_payment_id == o.invoice_payment_id &&
      currency == o.currency &&
      gateway == o.gateway &&
      nominal_amount == o.nominal_amount &&
      actual_amount == o.actual_amount &&
      refunded_amount == o.refunded_amount &&
      pricing_component_id == o.pricing_component_id &&
      pricing_component_name == o.pricing_component_name &&
      product_rate_plan_id == o.product_rate_plan_id &&
      product_rate_plan_name == o.product_rate_plan_name &&
      product_rate_plan_name_public == o.product_rate_plan_name_public &&
      product_id == o.product_id &&
      product_name == o.product_name &&
      product_name_public == o.product_name_public &&
      subscription_id == o.subscription_id &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 457

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 523

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 436

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


423
424
425
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 423

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



429
430
431
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 429

def hash
  [period_start, period_end, payment_received, refund_received, created, changed_by, id, organization_id, payment_id, gateway_original_payment_reference, gateway_refund_payment_reference, aggregated_invoice_id, aggregated_invoice_line_id, invoice_payment_id, currency, gateway, nominal_amount, actual_amount, refunded_amount, pricing_component_id, pricing_component_name, product_rate_plan_id, product_rate_plan_name, product_rate_plan_name_public, product_id, product_name, product_name_public, subscription_id, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



336
337
338
339
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 336

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



503
504
505
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 503

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



509
510
511
512
513
514
515
516
517
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 509

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



497
498
499
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 497

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/bf_ruby2/models/invoice_line_payment.rb', line 343

def valid?
  return false if @period_start.nil?
  return false if @period_end.nil?
  return false if @payment_received.nil?
  return false if @refund_received.nil?
  return false if @organization_id.nil?
  return false if @payment_id.nil?
  return false if @gateway_original_payment_reference.nil?
  return false if @gateway_refund_payment_reference.nil?
  return false if @aggregated_invoice_id.nil?
  return false if @aggregated_invoice_line_id.nil?
  return false if @invoice_payment_id.nil?
  return false if @currency.nil?
  return false if @gateway.nil?
  gateway_validator = EnumAttributeValidator.new('String', ["cybersource_token", "card_vault", "paypal_simple", "locustworld", "free", "coupon", "credit_note", "stripe", "braintree", "balanced", "paypal", "billforward_test", "offline", "trial", "stripeACH", "authorizeNet", "spreedly", "sagePay", "trustCommerce", "payvision", "kash"])
  return false unless gateway_validator.valid?(@gateway)
  return false if @nominal_amount.nil?
  return false if @actual_amount.nil?
  return false if @refunded_amount.nil?
  return false if @pricing_component_id.nil?
  return false if @pricing_component_name.nil?
  return false if @product_rate_plan_id.nil?
  return false if @product_rate_plan_name.nil?
  return false if @product_rate_plan_name_public.nil?
  return false if @product_id.nil?
  return false if @product_name.nil?
  return false if @product_name_public.nil?
  return false if @subscription_id.nil?
  return false if @account_id.nil?
  return true
end