Class: Bfwd::InvoiceRecalculationAmendment

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/invoice_recalculation_amendment.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InvoiceRecalculationAmendment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 145

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'@type')
    self.type = attributes[:'@type']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'amendmentType')
    self.amendment_type = attributes[:'amendmentType']
  end

  if attributes.has_key?(:'actioningTime')
    self.actioning_time = attributes[:'actioningTime']
  end

  if attributes.has_key?(:'actionedTime')
    self.actioned_time = attributes[:'actionedTime']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'deleted')
    self.deleted = attributes[:'deleted']
  else
    self.deleted = false
  end

  if attributes.has_key?(:'invoiceID')
    self.invoice_id = attributes[:'invoiceID']
  end

  if attributes.has_key?(:'recalculationBehaviour')
    self.recalculation_behaviour = attributes[:'recalculationBehaviour']
  end

  if attributes.has_key?(:'newInvoiceState')
    self.new_invoice_state = attributes[:'newInvoiceState']
  end

  if attributes.has_key?(:'includeInvoicedChargesOnly')
    self.include_invoiced_charges_only = attributes[:'includeInvoicedChargesOnly']
  else
    self.include_invoiced_charges_only = false
  end

end

Instance Attribute Details

#actioned_timeObject

{ "description" : "The time the amendment completed.", "verbs“: }



57
58
59
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 57

def actioned_time
  @actioned_time
end

#actioning_timeObject

{ "description" : "When the amendment will run", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 54

def actioning_time
  @actioning_time
end

#amendment_typeObject

{ "description" : "Type of amendment", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 51

def amendment_type
  @amendment_type
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 33

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 30

def created
  @created
end

#deletedObject

{ "description" : "Is the amendment deleted.", "verbs“: }



63
64
65
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 63

def deleted
  @deleted
end

#idObject

{ "description" : "", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 42

def id
  @id
end

#include_invoiced_charges_onlyObject

{ "description" : "Only include charges which are already linked to the invoice being recalculated", "default" : "Pending", "verbs“: }



75
76
77
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 75

def include_invoiced_charges_only
  @include_invoiced_charges_only
end

#invoice_idObject

{ "description" : "Identifier of the invoice to recalcaulte", "verbs“: }



66
67
68
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 66

def invoice_id
  @invoice_id
end

#new_invoice_stateObject

{ "description" : "State of invoice once recalculated", "default" : "Pending", "verbs“: }



72
73
74
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 72

def new_invoice_state
  @new_invoice_state
end

#organization_idObject

{ "description" : "", "verbs“: }



45
46
47
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 45

def organization_id
  @organization_id
end

#recalculation_behaviourObject

{ "description" : "The recalculation behaviour of the invoice", "default" : "RecalculateAsLatestSubscriptionVersion", "verbs“: }



69
70
71
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 69

def recalculation_behaviour
  @recalculation_behaviour
end

#stateObject

Whether the subscription-amendment is: pending (to be actioned in the future), succeeded (actioning completed), failed (actioning was attempted but no effect was made) or discarded (the amendment had been cancelled before being actioned). Default: Pending



60
61
62
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 60

def state
  @state
end

#subscription_idObject

{ "description" : "", "verbs“: }



48
49
50
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 48

def subscription_id
  @subscription_id
end

#typeObject

{ "description" : "", "default" : "", "verbs“: }



39
40
41
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 39

def type
  @type
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 36

def updated
  @updated
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 100

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'type' => :'@type',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'subscription_id' => :'subscriptionID',
    :'amendment_type' => :'amendmentType',
    :'actioning_time' => :'actioningTime',
    :'actioned_time' => :'actionedTime',
    :'state' => :'state',
    :'deleted' => :'deleted',
    :'invoice_id' => :'invoiceID',
    :'recalculation_behaviour' => :'recalculationBehaviour',
    :'new_invoice_state' => :'newInvoiceState',
    :'include_invoiced_charges_only' => :'includeInvoicedChargesOnly'
  }
end

.swagger_typesObject

Attribute type mapping.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 122

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'type' => :'String',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'subscription_id' => :'String',
    :'amendment_type' => :'String',
    :'actioning_time' => :'DateTime',
    :'actioned_time' => :'DateTime',
    :'state' => :'String',
    :'deleted' => :'BOOLEAN',
    :'invoice_id' => :'String',
    :'recalculation_behaviour' => :'String',
    :'new_invoice_state' => :'String',
    :'include_invoiced_charges_only' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 305

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      type == o.type &&
      id == o.id &&
      organization_id == o.organization_id &&
      subscription_id == o.subscription_id &&
      amendment_type == o.amendment_type &&
      actioning_time == o.actioning_time &&
      actioned_time == o.actioned_time &&
      state == o.state &&
      deleted == o.deleted &&
      invoice_id == o.invoice_id &&
      recalculation_behaviour == o.recalculation_behaviour &&
      new_invoice_state == o.new_invoice_state &&
      include_invoiced_charges_only == o.include_invoiced_charges_only
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 362

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 428

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 341

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


328
329
330
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 328

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



334
335
336
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 334

def hash
  [created, changed_by, updated, type, id, organization_id, subscription_id, amendment_type, actioning_time, actioned_time, state, deleted, invoice_id, recalculation_behaviour, new_invoice_state, include_invoiced_charges_only].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



223
224
225
226
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 223

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 408

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



414
415
416
417
418
419
420
421
422
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 414

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



402
403
404
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 402

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/bf_ruby2/models/invoice_recalculation_amendment.rb', line 230

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["InvoiceOutstandingChargesAmendment", "IssueInvoiceAmendment", "PricingComponentValueAmendment", "InvoiceRecalculationAmendment", "CancellationAmendment", "InvoiceNextExecutionAttemptAmendment", "FixedTermExpiryAmendment", "EndTrialAmendment", "ProductRatePlanMigrationAmendment", "AmendmentDiscardAmendment", "UpdateComponentValueAmendment", "ServiceEndAmendment", "ResumeSubscriptionAmendment", "CreateSubscriptionChargeAmendment", "TimerAmendment"])
  return false unless type_validator.valid?(@type)
  return false if @subscription_id.nil?
  return false if @amendment_type.nil?
  amendment_type_validator = EnumAttributeValidator.new('String', ["InvoiceNextExecutionAttempt", "Cancellation", "PricingComponentValue", "AmendmentDiscard", "Compound", "FixedTermExpiry", "InvoiceRecalculation", "EndTrial", "InvoiceOutstandingCharges", "IssueInvoice", "ProductRatePlanMigration", "UpdateComponentValue", "ServiceEnd", "ResumeSubscription", "CreateSubscriptionCharge", "Timer"])
  return false unless amendment_type_validator.valid?(@amendment_type)
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["Pending", "Succeeded", "Failed", "Discarded"])
  return false unless state_validator.valid?(@state)
  return false if @deleted.nil?
  return false if @invoice_id.nil?
  return false if @recalculation_behaviour.nil?
  recalculation_behaviour_validator = EnumAttributeValidator.new('String', ["RecalculateAsLatestSubscriptionVersion", "RecalculateAsCurrentSubscriptionVersion"])
  return false unless recalculation_behaviour_validator.valid?(@recalculation_behaviour)
  return false if @new_invoice_state.nil?
  new_invoice_state_validator = EnumAttributeValidator.new('String', ["Paid", "Unpaid", "Pending", "Voided"])
  return false unless new_invoice_state_validator.valid?(@new_invoice_state)
  return false if @include_invoiced_charges_only.nil?
  return true
end