Class: Bfwd::InvoiceRecalculationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/invoice_recalculation_request.rb

Overview

Request object for recalculating an invoice.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InvoiceRecalculationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 90

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'recalculationBehaviour')
    self.recalculation_behaviour = attributes[:'recalculationBehaviour']
  end

  if attributes.has_key?(:'newState')
    self.new_state = attributes[:'newState']
  end

  if attributes.has_key?(:'onlyInvoiceAssociatedCharges')
    self.only_invoice_associated_charges = attributes[:'onlyInvoiceAssociatedCharges']
  else
    self.only_invoice_associated_charges = false
  end

  if attributes.has_key?(:'dryRun')
    self.dry_run = attributes[:'dryRun']
  else
    self.dry_run = false
  end

end

Instance Attribute Details

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 30

def created
  @created
end

#dry_runObject

the invoice but do not store or attempt payment“,”verbs“:



42
43
44
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 42

def dry_run
  @dry_run
end

#new_stateObject

of the invoice once recalculated“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 36

def new_state
  @new_state
end

#only_invoice_associated_chargesObject

include charges which are already associated with the invoice. For example the subscription may have pending charges which can be added to the invoice on recalculation by setting this value to false. Note settings this value to true may cause new invoice line itemsto the invoice“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 39

def only_invoice_associated_charges
  @only_invoice_associated_charges
end

#recalculation_behaviourObject

plan change a subscription may have outstanding invoices.If the value of the invoice needs to be changed it can either be calculated via the new or old plan. <span class=\"label label-default\">RecalculateAsLatestSubscriptionVersion</span> calculates as the original plan and <span class=\"label label-default\">RecalculateAsCurrentSubscriptionVersion</span> as the new plan“verbs”:



33
34
35
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 33

def recalculation_behaviour
  @recalculation_behaviour
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 67

def self.attribute_map
  {
    :'created' => :'created',
    :'recalculation_behaviour' => :'recalculationBehaviour',
    :'new_state' => :'newState',
    :'only_invoice_associated_charges' => :'onlyInvoiceAssociatedCharges',
    :'dry_run' => :'dryRun'
  }
end

.swagger_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 78

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'recalculation_behaviour' => :'String',
    :'new_state' => :'String',
    :'only_invoice_associated_charges' => :'BOOLEAN',
    :'dry_run' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      recalculation_behaviour == o.recalculation_behaviour &&
      new_state == o.new_state &&
      only_invoice_associated_charges == o.only_invoice_associated_charges &&
      dry_run == o.dry_run
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 211

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 277

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 190

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 177

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



183
184
185
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 183

def hash
  [created, recalculation_behaviour, new_state, only_invoice_associated_charges, dry_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



124
125
126
127
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 124

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 257

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



251
252
253
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 251

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
138
139
140
141
# File 'lib/bf_ruby2/models/invoice_recalculation_request.rb', line 131

def valid?
  return false if @recalculation_behaviour.nil?
  recalculation_behaviour_validator = EnumAttributeValidator.new('String', ["RecalculateAsLatestSubscriptionVersion", "RecalculateAsCurrentSubscriptionVersion"])
  return false unless recalculation_behaviour_validator.valid?(@recalculation_behaviour)
  return false if @new_state.nil?
  new_state_validator = EnumAttributeValidator.new('String', ["Paid", "Unpaid", "Pending", "Voided"])
  return false unless new_state_validator.valid?(@new_state)
  return false if @only_invoice_associated_charges.nil?
  return false if @dry_run.nil?
  return true
end