Class: Bfwd::MigrationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/migration_request.rb

Overview

Request object for producing migrating a subscription.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MigrationRequest

Initializes the object



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/bf_ruby2/models/migration_request.rb', line 110

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'nextSubscriptionName')
    self.next_subscription_name = attributes[:'nextSubscriptionName']
  end

  if attributes.has_key?(:'nextSubscriptionDescription')
    self.next_subscription_description = attributes[:'nextSubscriptionDescription']
  end

  if attributes.has_key?(:'product')
    self.product = attributes[:'product']
  end

  if attributes.has_key?(:'productRatePlan')
    self.product_rate_plan = attributes[:'productRatePlan']
  end

  if attributes.has_key?(:'invoicingType')
    self.invoicing_type = attributes[:'invoicingType']
  end

  if attributes.has_key?(:'mappings')
    if (value = attributes[:'mappings']).is_a?(Array)
      self.mappings = value
    end
  end

  if attributes.has_key?(:'pricingBehaviour')
    self.pricing_behaviour = attributes[:'pricingBehaviour']
  end

  if attributes.has_key?(:'dryRun')
    self.dry_run = attributes[:'dryRun']
  else
    self.dry_run = false
  end

end

Instance Attribute Details

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/migration_request.rb', line 30

def created
  @created
end

#dry_runObject

the effects of migration but do not actually perform a migration.“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/migration_request.rb', line 54

def dry_run
  @dry_run
end

#invoicing_typeObject

class=\"label label-default\">Aggregated</span>","description":"The strategy for how to raise invoices for charges caused by this migration.
<span class=\"label label-default\">Immediate</span> &mdash; Generate straight-away an invoice containing these charges.
<span class=\"label label-default\">Aggregated</span> &mdash; Add these charges to the next invoice which is generated naturally &mdash; i.e. the invoice raised at the current period’s end.“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/migration_request.rb', line 45

def invoicing_type
  @invoicing_type
end

#mappingsObject

of pricing components and quantities thereof to be consumed in the new rate plan.“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/migration_request.rb', line 48

def mappings
  @mappings
end

#next_subscription_descriptionObject

to which the subscription will change upon successful migration.“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/migration_request.rb', line 36

def next_subscription_description
  @next_subscription_description
end

#next_subscription_nameObject

to which the subscription will change upon successful migration.“,”verbs“:



33
34
35
# File 'lib/bf_ruby2/models/migration_request.rb', line 33

def next_subscription_name
  @next_subscription_name
end

#pricing_behaviourObject

behaviour defines how migration charges are calculated.
<span class=\"label label-default\">DifferenceProRated</span> &mdash; Calculate the difference between in-advance charges of the existing and new rate-plan, then pro-rate based on time remaining.
<span class=\"label label-default\">None</span> &mdash; Set the migration charge as zero cost.
<span class=\"label label-default\">Full</span> &mdash; Set the costs as the total of the new rate-plan’s in-advance charges.
<span class=\"label label-default\">Difference</span> &mdash; The same calculation as in <span class=\"label label-default\">DifferenceProRated</span>, but with no pro-ration applied.
<span class=\"label label-default\">ProRated</span> &mdash; When moving to a rate-plan of the same duration: Pro-rates the in-advance charges of the new rate-plan.
When moving to a rate-plan of a different duration: A credit-note will be issued for the price of any remaining time on the existing plan’s billing period.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/migration_request.rb', line 51

def pricing_behaviour
  @pricing_behaviour
end

#productObject

product to which the subscription will be migrated.“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/migration_request.rb', line 39

def product
  @product
end

#product_rate_planObject

rate plan (of some product) to which the subscription will be migrated.“,”verbs“:



42
43
44
# File 'lib/bf_ruby2/models/migration_request.rb', line 42

def product_rate_plan
  @product_rate_plan
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/bf_ruby2/models/migration_request.rb', line 79

def self.attribute_map
  {
    :'created' => :'created',
    :'next_subscription_name' => :'nextSubscriptionName',
    :'next_subscription_description' => :'nextSubscriptionDescription',
    :'product' => :'product',
    :'product_rate_plan' => :'productRatePlan',
    :'invoicing_type' => :'invoicingType',
    :'mappings' => :'mappings',
    :'pricing_behaviour' => :'pricingBehaviour',
    :'dry_run' => :'dryRun'
  }
end

.swagger_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/bf_ruby2/models/migration_request.rb', line 94

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'next_subscription_name' => :'String',
    :'next_subscription_description' => :'String',
    :'product' => :'String',
    :'product_rate_plan' => :'String',
    :'invoicing_type' => :'String',
    :'mappings' => :'Array<PricingComponentMigrationValue>',
    :'pricing_behaviour' => :'String',
    :'dry_run' => :'BOOLEAN'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/bf_ruby2/models/migration_request.rb', line 200

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      next_subscription_name == o.next_subscription_name &&
      next_subscription_description == o.next_subscription_description &&
      product == o.product &&
      product_rate_plan == o.product_rate_plan &&
      invoicing_type == o.invoicing_type &&
      mappings == o.mappings &&
      pricing_behaviour == o.pricing_behaviour &&
      dry_run == o.dry_run
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/bf_ruby2/models/migration_request.rb', line 250

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/bf_ruby2/models/migration_request.rb', line 316

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/bf_ruby2/models/migration_request.rb', line 229

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


216
217
218
# File 'lib/bf_ruby2/models/migration_request.rb', line 216

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



222
223
224
# File 'lib/bf_ruby2/models/migration_request.rb', line 222

def hash
  [created, next_subscription_name, next_subscription_description, product, product_rate_plan, invoicing_type, mappings, pricing_behaviour, dry_run].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



160
161
162
163
# File 'lib/bf_ruby2/models/migration_request.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



296
297
298
# File 'lib/bf_ruby2/models/migration_request.rb', line 296

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
# File 'lib/bf_ruby2/models/migration_request.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



290
291
292
# File 'lib/bf_ruby2/models/migration_request.rb', line 290

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



167
168
169
170
171
172
173
174
175
176
# File 'lib/bf_ruby2/models/migration_request.rb', line 167

def valid?
  return false if @product_rate_plan.nil?
  return false if @invoicing_type.nil?
  invoicing_type_validator = EnumAttributeValidator.new('String', ["Immediate", "Aggregated"])
  return false unless invoicing_type_validator.valid?(@invoicing_type)
  return false if @pricing_behaviour.nil?
  pricing_behaviour_validator = EnumAttributeValidator.new('String', ["None", "Full", "Difference", "DifferenceProRated", "ProRated"])
  return false unless pricing_behaviour_validator.valid?(@pricing_behaviour)
  return true
end