Class: Bfwd::NestedChargeRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/nested_charge_request.rb

Overview

Partial request, which – when accompanied by additional context – describes some request concerning charges.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ NestedChargeRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 125

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.has_key?(:'taxAmount')
    self.tax_amount = attributes[:'taxAmount']
  end

  if attributes.has_key?(:'periodStart')
    self.period_start = attributes[:'periodStart']
  end

  if attributes.has_key?(:'periodEnd')
    self.period_end = attributes[:'periodEnd']
  end

  if attributes.has_key?(:'chargeType')
    self.charge_type = attributes[:'chargeType']
  end

  if attributes.has_key?(:'trial')
    self.trial = attributes[:'trial']
  end

  if attributes.has_key?(:'product')
    self.product = attributes[:'product']
  end

  if attributes.has_key?(:'productRatePlan')
    self.product_rate_plan = attributes[:'productRatePlan']
  end

  if attributes.has_key?(:'pricingComponent')
    self.pricing_component = attributes[:'pricingComponent']
  end

  if attributes.has_key?(:'pricingComponentValue')
    self.pricing_component_value = attributes[:'pricingComponentValue']
  end

end

Instance Attribute Details

#amountObject

amount for which to charge. Used only for ad-hoc charges i.e charges not associated with any pricing component. Applicable if pricingComponent is NOT defined“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 36

def amount
  @amount
end

#charge_typeObject

class=\"label label-default\">Debit</span>","description":"Whether this charge represents an increase or decrease in invoice cost
<span class=\"label label-default\">Credit</span> &mdash; This results in a reduction to the invoice cost
<span class=\"label label-default\">Debit</span> &mdash; This will increase the invoice cost“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 48

def charge_type
  @charge_type
end

#descriptionObject

href="\"POST\",\"GET\"">description“:”“,”verbs“:



33
34
35
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 33

def description
  @description
end

#nameObject

name given to the charge to help identify it.“,”verbs“:



30
31
32
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 30

def name
  @name
end

#period_endObject

of current period)","description":"(Applicable only if pricingComponent is defined)
End of the interval to which the charge applies. Used in pro-rata calculation“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 45

def period_end
  @period_end
end

#period_startObject

of the interval to which the charge applies. This can be used to apply a charge across partial or multiple periods. Pro-rating the price of pricingComponents purchased“,”verbs“:



42
43
44
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 42

def period_start
  @period_start
end

#pricing_componentObject

that this charge is for consumption of some quantity of this pricing component (whose name or ID can be provided).
If left blank:
The charge will be created as ‘ad-hoc’. That is: a monetary lump sum, associated with no pricing component“,”verbs“:



60
61
62
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 60

def pricing_component
  @pricing_component
end

#pricing_component_valueObject

if pricingComponent is defined]. The value consumed of the pricing component which this charge concerns.“,”verbs“:



63
64
65
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 63

def pricing_component_value
  @pricing_component_value
end

#productObject

only if the productRatePlan field is populated with a name (as opposed to an ID)]. The ID or name of the product rate plan to which the referenced rate plan belongs.“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 54

def product
  @product
end

#product_rate_planObject

only if the pricingComponent field is populated with a name (as opposed to an ID)]. The ID or name of the rate plan to which the referenced PricingComponent belongs.“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 57

def product_rate_plan
  @product_rate_plan
end

#tax_amountObject

if amount is specified and indicates whether or not to apply tax in addition to the value specified.
<span class=\"label label-default\">true</span> &mdash; Tax will be added on top of the nominal price specified in amount &mdash; in accordance with any taxation strategies you have defined.
<span class=\"label label-default\">false</span> &mdash; No tax will be applied on top of the price specified in amount.“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 39

def tax_amount
  @tax_amount
end

#trialObject

the charge is meant in the context of a trial.
<span class=\"label label-default\">false</span> &mdash; This is a non-trial charge, so funds will be sought from the customer.
<span class=\"label label-default\">true</span> &mdash; This is a trial charge, soThe charge can be considered ‘Paid’ without taking any funds from the customer.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 51

def trial
  @trial
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 88

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'amount' => :'amount',
    :'tax_amount' => :'taxAmount',
    :'period_start' => :'periodStart',
    :'period_end' => :'periodEnd',
    :'charge_type' => :'chargeType',
    :'trial' => :'trial',
    :'product' => :'product',
    :'product_rate_plan' => :'productRatePlan',
    :'pricing_component' => :'pricingComponent',
    :'pricing_component_value' => :'pricingComponentValue'
  }
end

.swagger_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 106

def self.swagger_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'amount' => :'Float',
    :'tax_amount' => :'BOOLEAN',
    :'period_start' => :'DateTime',
    :'period_end' => :'DateTime',
    :'charge_type' => :'String',
    :'trial' => :'BOOLEAN',
    :'product' => :'String',
    :'product_rate_plan' => :'String',
    :'pricing_component' => :'String',
    :'pricing_component_value' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      amount == o.amount &&
      tax_amount == o.tax_amount &&
      period_start == o.period_start &&
      period_end == o.period_end &&
      charge_type == o.charge_type &&
      trial == o.trial &&
      product == o.product &&
      product_rate_plan == o.product_rate_plan &&
      pricing_component == o.pricing_component &&
      pricing_component_value == o.pricing_component_value
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 261

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 327

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 240

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 227

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



233
234
235
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 233

def hash
  [name, description, amount, tax_amount, period_start, period_end, charge_type, trial, product, product_rate_plan, pricing_component, pricing_component_value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



183
184
185
186
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 307

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



301
302
303
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 301

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
# File 'lib/bf_ruby2/models/nested_charge_request.rb', line 190

def valid?
  charge_type_validator = EnumAttributeValidator.new('String', ["Credit", "Debit"])
  return false unless charge_type_validator.valid?(@charge_type)
  return true
end