Class: Bfwd::Organization
- Inherits:
-
Object
- Object
- Bfwd::Organization
- Defined in:
- lib/bf_ruby2/models/organization.rb
Overview
Organization within which all your BillForward interactions are scoped.
Instance Attribute Summary collapse
-
#_alias ⇒ Object
Returns the value of attribute _alias.
-
#api_configurations ⇒ Object
{ "description" : "Stores the organizations 3rd party API keys which may be used by the system for payment gateway integration etc.", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#clients ⇒ Object
{ "description" : "The OAuth2 clients associated with the organization. In most cases an organization would not have any clients associated with their account. In the case of an APP developer, a clients would exist per an application they have developed. To further understand clients please see the client, OAuth2 API and APP development documentation.", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#customer_code ⇒ Object
{ "description" : "A shortcode for the organization. This is used as a short reference code for use when referring to the organization, by default this is set to the organizations name.", "verbs“: }.
-
#deleted ⇒ Object
{ "description" : "Indicates if an organization has been retired. If an organization has been retired it can still be retrieved using the appropriate flag on API requests.", "verbs“: }.
-
#dunning_lines ⇒ Object
{ "description" : "The dunning-lines associated with the organization. Dunning lines are used as re-try logic for invoices to attempt to reconcile the payment.", "verbs“: }.
-
#id ⇒ Object
{ "description" : "ID of the organization.", "verbs“: }.
-
#name ⇒ Object
{ "description" : "The name of the organization.", "verbs“: }.
-
#organization_gateways ⇒ Object
{ "description" : "The card-vault gateways associated with the organization.", "verbs“: }.
-
#taxation_strategies ⇒ Object
{ "description" : "The taxation-strategies associated with the organization. Taxation-strategies may be linked to product-rate-plans to specify how their tax should be calculated.", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
-
#webhooks ⇒ Object
{ "description" : "The WebHooks associated with the organization. These are the end-points where notifications are sent. WebHooks are added, updated and removed from the organization. Thus to add a WebHook, the webhook must be defined on this property of the organization and then the organization updated. To update a WebHook the same procedure must be followed, first retrieving the organization followed by updating the appropriate WebHook, finally the organization is updated.", "verbs“: }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Organization
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Organization
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/bf_ruby2/models/organization.rb', line 113 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'customerCode') self.customer_code = attributes[:'customerCode'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end if attributes.has_key?(:'webhooks') if (value = attributes[:'webhooks']).is_a?(Array) self.webhooks = value end end if attributes.has_key?(:'alias') if (value = attributes[:'alias']).is_a?(Array) self._alias = value end end if attributes.has_key?(:'clients') if (value = attributes[:'clients']).is_a?(Array) self.clients = value end end if attributes.has_key?(:'dunningLines') if (value = attributes[:'dunningLines']).is_a?(Array) self.dunning_lines = value end end if attributes.has_key?(:'taxationStrategies') if (value = attributes[:'taxationStrategies']).is_a?(Array) self.taxation_strategies = value end end if attributes.has_key?(:'organizationGateways') if (value = attributes[:'organizationGateways']).is_a?(Array) self.organization_gateways = value end end if attributes.has_key?(:'apiConfigurations') if (value = attributes[:'apiConfigurations']).is_a?(Array) self.api_configurations = value end end end |
Instance Attribute Details
#_alias ⇒ Object
Returns the value of attribute _alias.
53 54 55 |
# File 'lib/bf_ruby2/models/organization.rb', line 53 def _alias @_alias end |
#api_configurations ⇒ Object
{ "description" : "Stores the organizations 3rd party API keys which may be used by the system for payment gateway integration etc.", "verbs“: }
68 69 70 |
# File 'lib/bf_ruby2/models/organization.rb', line 68 def api_configurations @api_configurations end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/organization.rb', line 33 def changed_by @changed_by end |
#clients ⇒ Object
{ "description" : "The OAuth2 clients associated with the organization. In most cases an organization would not have any clients associated with their account. In the case of an APP developer, a clients would exist per an application they have developed. To further understand clients please see the client, OAuth2 API and APP development documentation.", "verbs“: }
56 57 58 |
# File 'lib/bf_ruby2/models/organization.rb', line 56 def clients @clients end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/organization.rb', line 30 def created @created end |
#customer_code ⇒ Object
{ "description" : "A shortcode for the organization. This is used as a short reference code for use when referring to the organization, by default this is set to the organizations name.", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/organization.rb', line 42 def customer_code @customer_code end |
#deleted ⇒ Object
{ "description" : "Indicates if an organization has been retired. If an organization has been retired it can still be retrieved using the appropriate flag on API requests.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/organization.rb', line 48 def deleted @deleted end |
#dunning_lines ⇒ Object
{ "description" : "The dunning-lines associated with the organization. Dunning lines are used as re-try logic for invoices to attempt to reconcile the payment.", "verbs“: }
59 60 61 |
# File 'lib/bf_ruby2/models/organization.rb', line 59 def dunning_lines @dunning_lines end |
#id ⇒ Object
{ "description" : "ID of the organization.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/organization.rb', line 39 def id @id end |
#name ⇒ Object
{ "description" : "The name of the organization.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/organization.rb', line 45 def name @name end |
#organization_gateways ⇒ Object
{ "description" : "The card-vault gateways associated with the organization.", "verbs“: }
65 66 67 |
# File 'lib/bf_ruby2/models/organization.rb', line 65 def organization_gateways @organization_gateways end |
#taxation_strategies ⇒ Object
{ "description" : "The taxation-strategies associated with the organization. Taxation-strategies may be linked to product-rate-plans to specify how their tax should be calculated.", "verbs“: }
62 63 64 |
# File 'lib/bf_ruby2/models/organization.rb', line 62 def taxation_strategies @taxation_strategies end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/organization.rb', line 36 def updated @updated end |
#webhooks ⇒ Object
{ "description" : "The WebHooks associated with the organization. These are the end-points where notifications are sent. WebHooks are added, updated and removed from the organization. Thus to add a WebHook, the webhook must be defined on this property of the organization and then the organization updated. To update a WebHook the same procedure must be followed, first retrieving the organization followed by updating the appropriate WebHook, finally the organization is updated.", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/organization.rb', line 51 def webhooks @webhooks end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/models/organization.rb', line 72 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'customer_code' => :'customerCode', :'name' => :'name', :'deleted' => :'deleted', :'webhooks' => :'webhooks', :'_alias' => :'alias', :'clients' => :'clients', :'dunning_lines' => :'dunningLines', :'taxation_strategies' => :'taxationStrategies', :'organization_gateways' => :'organizationGateways', :'api_configurations' => :'apiConfigurations' } end |
.swagger_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/bf_ruby2/models/organization.rb', line 92 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'customer_code' => :'String', :'name' => :'String', :'deleted' => :'BOOLEAN', :'webhooks' => :'Array<MutableBillingEntity>', :'_alias' => :'Array<ModelAlias>', :'clients' => :'Array<Client>', :'dunning_lines' => :'Array<DunningLine>', :'taxation_strategies' => :'Array<MutableBillingEntity>', :'organization_gateways' => :'Array<MutableBillingEntity>', :'api_configurations' => :'Array<MutableBillingEntity>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/bf_ruby2/models/organization.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && customer_code == o.customer_code && name == o.name && deleted == o.deleted && webhooks == o.webhooks && _alias == o._alias && clients == o.clients && dunning_lines == o.dunning_lines && taxation_strategies == o.taxation_strategies && organization_gateways == o.organization_gateways && api_configurations == o.api_configurations end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/bf_ruby2/models/organization.rb', line 267 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/bf_ruby2/models/organization.rb', line 333 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/bf_ruby2/models/organization.rb', line 246 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/bf_ruby2/models/organization.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/bf_ruby2/models/organization.rb', line 239 def hash [created, changed_by, updated, id, customer_code, name, deleted, webhooks, _alias, clients, dunning_lines, taxation_strategies, organization_gateways, api_configurations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 |
# File 'lib/bf_ruby2/models/organization.rb', line 195 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
313 314 315 |
# File 'lib/bf_ruby2/models/organization.rb', line 313 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
319 320 321 322 323 324 325 326 327 |
# File 'lib/bf_ruby2/models/organization.rb', line 319 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
307 308 309 |
# File 'lib/bf_ruby2/models/organization.rb', line 307 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 |
# File 'lib/bf_ruby2/models/organization.rb', line 202 def valid? return false if @customer_code.nil? return false if @name.nil? return false if @deleted.nil? return false if @webhooks.nil? return true end |