Class: Bfwd::PricingcomponentvaluechangesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PricingcomponentvaluechangesApi

Returns a new instance of PricingcomponentvaluechangesApi.



30
31
32
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_pricing_component_value_change(pricing_component_value_change, opts = {}) ⇒ PricingComponentValueChangePagedMetadata

Create a pricing-component-value-change. Bfwd::PricingcomponentvaluechangesApi."nickname":"Create","request":"createPricingComponentValueChangeRequest.html","response":"createPricingComponentValueChangeResponse"nickname":"Create","request":"createPricingComponentValueChangeRequest.html","response":"createPricingComponentValueChangeResponse.html"

Parameters:

  • pricing_component_value_change

    The pricing-component-value-change object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 39

def create_pricing_component_value_change(pricing_component_value_change, opts = {})
  data, _status_code, _headers = create_pricing_component_value_change_with_http_info(pricing_component_value_change, opts)
  return data
end

#create_pricing_component_value_change_with_http_info(pricing_component_value_change, opts = {}) ⇒ Array<(PricingComponentValueChangePagedMetadata, Fixnum, Hash)>

Create a pricing-component-value-change. Bfwd::PricingcomponentvaluechangesApi.&quot;nickname&quot;:&quot;Create&quot;,&quot;request&quot;:&quot;createPricingComponentValueChangeRequest.html&quot;,&quot;response&quot;:&quot;createPricingComponentValueChangeResponse&quot;nickname&quot;:&quot;Create&quot;,&quot;request&quot;:&quot;createPricingComponentValueChangeRequest.html&quot;,&quot;response&quot;:&quot;createPricingComponentValueChangeResponse.html&quot;

Parameters:

  • pricing_component_value_change

    The pricing-component-value-change object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 49

def create_pricing_component_value_change_with_http_info(pricing_component_value_change, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluechangesApi.create_pricing_component_value_change ..."
  end
  # verify the required parameter 'pricing_component_value_change' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_value_change' when calling PricingcomponentvaluechangesApi.create_pricing_component_value_change" if pricing_component_value_change.nil?
  # resource path
  local_var_path = "/pricing-component-value-changes".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component_value_change)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValueChangePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluechangesApi#create_pricing_component_value_change\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_pricing_component_value_changes(opts = {}) ⇒ PricingComponentValueChangePagedMetadata

Returns a collection of pricing-component-value-changes. By default 10 values are returned. Records are returned in natural order. All","response":"getPricingComponentValueChangeAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



100
101
102
103
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 100

def get_all_pricing_component_value_changes(opts = {})
  data, _status_code, _headers = get_all_pricing_component_value_changes_with_http_info(opts)
  return data
end

#get_all_pricing_component_value_changes_with_http_info(opts = {}) ⇒ Array<(PricingComponentValueChangePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-value-changes. By default 10 values are returned. Records are returned in natural order. All&quot;,&quot;response&quot;:&quot;getPricingComponentValueChangeAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return.

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 114

def get_all_pricing_component_value_changes_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluechangesApi.get_all_pricing_component_value_changes ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-value-changes".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValueChangePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluechangesApi#get_all_pricing_component_value_changes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_value_change(id, opts = {}) ⇒ PricingComponentValueChangePagedMetadata

Returns a single pricing-component-value-changes, specified by the ID parameter. by id","response":"getPricingComponentValueChangeByID.html"

Parameters:

  • id

    The string ID of the pricing-component-value-change.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



168
169
170
171
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 168

def get_pricing_component_value_change(id, opts = {})
  data, _status_code, _headers = get_pricing_component_value_change_with_http_info(id, opts)
  return data
end

#get_pricing_component_value_change_by_component_id(pricing_component_id, opts = {}) ⇒ PricingComponentValueChangePagedMetadata

Returns a collection of pricing-component-value-changes, specified by the pricing-component-value-ID parameter. By default 10 values are returned. Records are returned in natural order. by Component-ID","response":"getPricingComponentValueChangeByID.html"

Parameters:

  • pricing_component_id

    The string ID of the pricing-component-value.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



232
233
234
235
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 232

def get_pricing_component_value_change_by_component_id(pricing_component_id, opts = {})
  data, _status_code, _headers = get_pricing_component_value_change_by_component_id_with_http_info(pricing_component_id, opts)
  return data
end

#get_pricing_component_value_change_by_component_id_with_http_info(pricing_component_id, opts = {}) ⇒ Array<(PricingComponentValueChangePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-value-changes, specified by the pricing-component-value-ID parameter. By default 10 values are returned. Records are returned in natural order. by Component-ID&quot;,&quot;response&quot;:&quot;getPricingComponentValueChangeByID.html&quot;

Parameters:

  • pricing_component_id

    The string ID of the pricing-component-value.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return.

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 247

def get_pricing_component_value_change_by_component_id_with_http_info(pricing_component_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluechangesApi.get_pricing_component_value_change_by_component_id ..."
  end
  # verify the required parameter 'pricing_component_id' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_id' when calling PricingcomponentvaluechangesApi.get_pricing_component_value_change_by_component_id" if pricing_component_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-value-changes/component-ID/{pricing-component-ID}".sub('{format}','json').sub('{' + 'pricing-component-ID' + '}', pricing_component_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValueChangePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluechangesApi#get_pricing_component_value_change_by_component_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_value_change_by_invoice_id(invoice_id, opts = {}) ⇒ PricingComponentValueChangePagedMetadata

Returns a collection of pricing-component-value-changes, specified by the invoice-ID parameter. By default 10 values are returned. Records are returned in natural order. by Invoice-ID","response":"getPricingComponentValueChangeByInvoiceID.html"

Parameters:

  • invoice_id

    The string invoice-ID of the pricing-component-value-change.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



307
308
309
310
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 307

def get_pricing_component_value_change_by_invoice_id(invoice_id, opts = {})
  data, _status_code, _headers = get_pricing_component_value_change_by_invoice_id_with_http_info(invoice_id, opts)
  return data
end

#get_pricing_component_value_change_by_invoice_id_with_http_info(invoice_id, opts = {}) ⇒ Array<(PricingComponentValueChangePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-value-changes, specified by the invoice-ID parameter. By default 10 values are returned. Records are returned in natural order. by Invoice-ID&quot;,&quot;response&quot;:&quot;getPricingComponentValueChangeByInvoiceID.html&quot;

Parameters:

  • invoice_id

    The string invoice-ID of the pricing-component-value-change.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return.

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 322

def get_pricing_component_value_change_by_invoice_id_with_http_info(invoice_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluechangesApi.get_pricing_component_value_change_by_invoice_id ..."
  end
  # verify the required parameter 'invoice_id' is set
  fail ArgumentError, "Missing the required parameter 'invoice_id' when calling PricingcomponentvaluechangesApi.get_pricing_component_value_change_by_invoice_id" if invoice_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-value-changes/invoice/{invoice-ID}".sub('{format}','json').sub('{' + 'invoice-ID' + '}', invoice_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValueChangePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluechangesApi#get_pricing_component_value_change_by_invoice_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_value_change_by_subscription_id(subscription_id, opts = {}) ⇒ PricingComponentValueChangePagedMetadata

Returns a collection of pricing-component-value-changes, specified by the subscription-ID parameter. By default 10 values are returned. Records are returned in natural order. by Subscription-ID","response":"getPricingComponentValueChangeBySubscriptionID.html"

Parameters:

  • subscription_id

    ID of the subscription.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



382
383
384
385
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 382

def get_pricing_component_value_change_by_subscription_id(subscription_id, opts = {})
  data, _status_code, _headers = get_pricing_component_value_change_by_subscription_id_with_http_info(subscription_id, opts)
  return data
end

#get_pricing_component_value_change_by_subscription_id_with_http_info(subscription_id, opts = {}) ⇒ Array<(PricingComponentValueChangePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-value-changes, specified by the subscription-ID parameter. By default 10 values are returned. Records are returned in natural order. by Subscription-ID&quot;,&quot;response&quot;:&quot;getPricingComponentValueChangeBySubscriptionID.html&quot;

Parameters:

  • subscription_id

    ID of the subscription.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value-change to return.

  • :records (Integer)

    The maximum number of pricing-component-value-changes to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 397

def get_pricing_component_value_change_by_subscription_id_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluechangesApi.get_pricing_component_value_change_by_subscription_id ..."
  end
  # verify the required parameter 'subscription_id' is set
  fail ArgumentError, "Missing the required parameter 'subscription_id' when calling PricingcomponentvaluechangesApi.get_pricing_component_value_change_by_subscription_id" if subscription_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-value-changes/subscription/{subscription-ID}".sub('{format}','json').sub('{' + 'subscription-ID' + '}', subscription_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValueChangePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluechangesApi#get_pricing_component_value_change_by_subscription_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_value_change_with_http_info(id, opts = {}) ⇒ Array<(PricingComponentValueChangePagedMetadata, Fixnum, Hash)>

Returns a single pricing-component-value-changes, specified by the ID parameter. by id&quot;,&quot;response&quot;:&quot;getPricingComponentValueChangeByID.html&quot;

Parameters:

  • id

    The string ID of the pricing-component-value-change.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/bf_ruby2/api/pricingcomponentvaluechanges_api.rb', line 179

def get_pricing_component_value_change_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluechangesApi.get_pricing_component_value_change ..."
  end
  # verify the required parameter 'id' is set
  fail ArgumentError, "Missing the required parameter 'id' when calling PricingcomponentvaluechangesApi.get_pricing_component_value_change" if id.nil?
  # resource path
  local_var_path = "/pricing-component-value-changes/{ID}".sub('{format}','json').sub('{' + 'ID' + '}', id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValueChangePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluechangesApi#get_pricing_component_value_change\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end