Class: Bfwd::Profile
- Inherits:
-
Object
- Object
- Bfwd::Profile
- Defined in:
- lib/bf_ruby2/models/profile.rb
Overview
Profile
Instance Attribute Summary collapse
-
#account_id ⇒ Object
{ "description" : "", "verbs“: }.
-
#additional_information ⇒ Object
{ "description" : "Any additional information", "verbs“: }.
-
#addresses ⇒ Object
{ "description" : "Address associated with the profile", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#company_name ⇒ Object
{ "description" : "", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#dob ⇒ Object
{ "description" : "Date of birth in YYYY-MM-DD format", "verbs“: }.
-
#email ⇒ Object
{ "description" : "E-mail address", "verbs“: }.
-
#fax ⇒ Object
{ "description" : "Fax number", "verbs“: }.
-
#first_name ⇒ Object
{ "description" : "", "verbs“: }.
-
#id ⇒ Object
{ "description" : "ID of the profile.", "verbs“: }.
-
#landline ⇒ Object
{ "description" : "Home telephone number", "verbs“: }.
-
#last_name ⇒ Object
{ "description" : "", "verbs“: }.
-
#logo_url ⇒ Object
{ "description" : "", "verbs“: }.
-
#mobile ⇒ Object
{ "description" : "Mobile telephone number", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "", "verbs":[] }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
-
#vat_number ⇒ Object
{ "description" : "VAT number", "verbs“: }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Profile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Profile
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/bf_ruby2/models/profile.rb', line 134 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'accountID') self.account_id = attributes[:'accountID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'firstName') self.first_name = attributes[:'firstName'] end if attributes.has_key?(:'lastName') self.last_name = attributes[:'lastName'] end if attributes.has_key?(:'companyName') self.company_name = attributes[:'companyName'] end if attributes.has_key?(:'logoURL') self.logo_url = attributes[:'logoURL'] end if attributes.has_key?(:'addresses') if (value = attributes[:'addresses']).is_a?(Array) self.addresses = value end end if attributes.has_key?(:'mobile') self.mobile = attributes[:'mobile'] end if attributes.has_key?(:'landline') self.landline = attributes[:'landline'] end if attributes.has_key?(:'fax') self.fax = attributes[:'fax'] end if attributes.has_key?(:'dob') self.dob = attributes[:'dob'] end if attributes.has_key?(:'vatNumber') self.vat_number = attributes[:'vatNumber'] end if attributes.has_key?(:'additionalInformation') self.additional_information = attributes[:'additionalInformation'] end end |
Instance Attribute Details
#account_id ⇒ Object
{ "description" : "", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/profile.rb', line 42 def account_id @account_id end |
#additional_information ⇒ Object
{ "description" : "Any additional information", "verbs“: }
81 82 83 |
# File 'lib/bf_ruby2/models/profile.rb', line 81 def additional_information @additional_information end |
#addresses ⇒ Object
{ "description" : "Address associated with the profile", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/profile.rb', line 63 def addresses @addresses end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/profile.rb', line 33 def changed_by @changed_by end |
#company_name ⇒ Object
{ "description" : "", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/profile.rb', line 57 def company_name @company_name end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/profile.rb', line 30 def created @created end |
#dob ⇒ Object
{ "description" : "Date of birth in YYYY-MM-DD format", "verbs“: }
75 76 77 |
# File 'lib/bf_ruby2/models/profile.rb', line 75 def dob @dob end |
#email ⇒ Object
{ "description" : "E-mail address", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/profile.rb', line 48 def email @email end |
#fax ⇒ Object
{ "description" : "Fax number", "verbs“: }
72 73 74 |
# File 'lib/bf_ruby2/models/profile.rb', line 72 def fax @fax end |
#first_name ⇒ Object
{ "description" : "", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/profile.rb', line 51 def first_name @first_name end |
#id ⇒ Object
{ "description" : "ID of the profile.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/profile.rb', line 39 def id @id end |
#landline ⇒ Object
{ "description" : "Home telephone number", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/profile.rb', line 69 def landline @landline end |
#last_name ⇒ Object
{ "description" : "", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/profile.rb', line 54 def last_name @last_name end |
#logo_url ⇒ Object
{ "description" : "", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/profile.rb', line 60 def logo_url @logo_url end |
#mobile ⇒ Object
{ "description" : "Mobile telephone number", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/profile.rb', line 66 def mobile @mobile end |
#organization_id ⇒ Object
{ "description" : "", "verbs":[] }
45 46 47 |
# File 'lib/bf_ruby2/models/profile.rb', line 45 def organization_id @organization_id end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/profile.rb', line 36 def updated @updated end |
#vat_number ⇒ Object
{ "description" : "VAT number", "verbs“: }
78 79 80 |
# File 'lib/bf_ruby2/models/profile.rb', line 78 def vat_number @vat_number end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/bf_ruby2/models/profile.rb', line 85 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'account_id' => :'accountID', :'organization_id' => :'organizationID', :'email' => :'email', :'first_name' => :'firstName', :'last_name' => :'lastName', :'company_name' => :'companyName', :'logo_url' => :'logoURL', :'addresses' => :'addresses', :'mobile' => :'mobile', :'landline' => :'landline', :'fax' => :'fax', :'dob' => :'dob', :'vat_number' => :'vatNumber', :'additional_information' => :'additionalInformation' } end |
.swagger_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/bf_ruby2/models/profile.rb', line 109 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'account_id' => :'String', :'organization_id' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'company_name' => :'String', :'logo_url' => :'String', :'addresses' => :'Array<Address>', :'mobile' => :'String', :'landline' => :'String', :'fax' => :'String', :'dob' => :'DateTime', :'vat_number' => :'String', :'additional_information' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/bf_ruby2/models/profile.rb', line 237 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && account_id == o.account_id && organization_id == o.organization_id && email == o.email && first_name == o.first_name && last_name == o.last_name && company_name == o.company_name && logo_url == o.logo_url && addresses == o.addresses && mobile == o.mobile && landline == o.landline && fax == o.fax && dob == o.dob && vat_number == o.vat_number && additional_information == o.additional_information end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/bf_ruby2/models/profile.rb', line 296 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/bf_ruby2/models/profile.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/bf_ruby2/models/profile.rb', line 275 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
262 263 264 |
# File 'lib/bf_ruby2/models/profile.rb', line 262 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
268 269 270 |
# File 'lib/bf_ruby2/models/profile.rb', line 268 def hash [created, changed_by, updated, id, account_id, organization_id, email, first_name, last_name, company_name, logo_url, addresses, mobile, landline, fax, dob, vat_number, additional_information].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
218 219 220 221 |
# File 'lib/bf_ruby2/models/profile.rb', line 218 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
342 343 344 |
# File 'lib/bf_ruby2/models/profile.rb', line 342 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 |
# File 'lib/bf_ruby2/models/profile.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
336 337 338 |
# File 'lib/bf_ruby2/models/profile.rb', line 336 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
225 226 227 228 229 230 231 232 233 |
# File 'lib/bf_ruby2/models/profile.rb', line 225 def valid? return false if @id.nil? return false if @account_id.nil? return false if @organization_id.nil? return false if @email.nil? return false if @first_name.nil? return false if @last_name.nil? return true end |