Class: Bfwd::QuoteRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/quote_request.rb

Overview

Entity for requesting a price quote.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ QuoteRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/bf_ruby2/models/quote_request.rb', line 150

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'product')
    self.product = attributes[:'product']
  end

  if attributes.has_key?(:'productRatePlan')
    self.product_rate_plan = attributes[:'productRatePlan']
  end

  if attributes.has_key?(:'accountID')
    self. = attributes[:'accountID']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'subscriptionVersionID')
    self.subscription_version_id = attributes[:'subscriptionVersionID']
  end

  if attributes.has_key?(:'quoteFor')
    self.quote_for = attributes[:'quoteFor']
  end

  if attributes.has_key?(:'prorated')
    self.prorated = attributes[:'prorated']
  else
    self.prorated = false
  end

  if attributes.has_key?(:'free')
    self.free = attributes[:'free']
  else
    self.free = false
  end

  if attributes.has_key?(:'includeAppliedCoupons')
    self.include_applied_coupons = attributes[:'includeAppliedCoupons']
  else
    self.include_applied_coupons = false
  end

  if attributes.has_key?(:'periodStart')
    self.period_start = attributes[:'periodStart']
  end

  if attributes.has_key?(:'periodEnd')
    self.period_end = attributes[:'periodEnd']
  end

  if attributes.has_key?(:'remainingCreditBehaviour')
    self.remaining_credit_behaviour = attributes[:'remainingCreditBehaviour']
  end

  if attributes.has_key?(:'quantities')
    if (value = attributes[:'quantities']).is_a?(Array)
      self.quantities = value
    end
  end

  if attributes.has_key?(:'couponCodes')
    if (value = attributes[:'couponCodes']).is_a?(Array)
      self.coupon_codes = value
    end
  end

  if attributes.has_key?(:'pricingBehaviour')
    self.pricing_behaviour = attributes[:'pricingBehaviour']
  end

end

Instance Attribute Details

#account_idObject

of the account for which a price quote is requested.“,”verbs“:



42
43
44
# File 'lib/bf_ruby2/models/quote_request.rb', line 42

def 
  @account_id
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/quote_request.rb', line 33

def changed_by
  @changed_by
end

#coupon_codesObject

list of coupon codes to consider in calculating the quote.“,”verbs“:



75
76
77
# File 'lib/bf_ruby2/models/quote_request.rb', line 75

def coupon_codes
  @coupon_codes
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/quote_request.rb', line 30

def created
  @created
end

#freeObject

or not to present a waived final price in the quote.“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/quote_request.rb', line 57

def free
  @free
end

#include_applied_couponsObject

or not to include coupons which have already been applied to the subscription.“,”verbs“:



60
61
62
# File 'lib/bf_ruby2/models/quote_request.rb', line 60

def include_applied_coupons
  @include_applied_coupons
end

#period_endObject

of current period)","description":"The time-ending of the interval with which the quote is concerned. This can be used to request a quote across partial or multiple periods — potentially pro-rating its price.“,”verbs“:



66
67
68
# File 'lib/bf_ruby2/models/quote_request.rb', line 66

def period_end
  @period_end
end

#period_startObject

time-beginning of the interval with which the quote is concerned. This can be used to request a quote across partial or multiple periods — potentially pro-rating its price.“,”verbs“:



63
64
65
# File 'lib/bf_ruby2/models/quote_request.rb', line 63

def period_start
  @period_start
end

#pricing_behaviourObject

{ "description" : "Pricing behaviour defines how migration charges are calculated. <span class=\"label label-default\">DifferenceProRated</span> calculates the difference between in-advance charges of the existing and new rate-plan, then pro-rates based on time remaining. <span class=\"label label-default\">None</span> sets the migration charge as zero cost. <span class=\"label label-default\">Full</span> sets the costs as the total of the new rate-plans in-advance charges. <span class=\"label label-default\">Difference</span> is the same calculation as <span class=\"label label-default\">DifferenceProRated</span> but no pro-ration is applied. <span class=\"label label-default\">ProRated</span> differs depending on two cases; when moving to a rate-plan of the same duration it pro-rates the in-advance charges of the new rate-plan. If the duration is different, a credit-note will be issued any remaining time on the existing plans billing period.", "default" : "DifferenceProRated", "verbs“: }



78
79
80
# File 'lib/bf_ruby2/models/quote_request.rb', line 78

def pricing_behaviour
  @pricing_behaviour
end

#productObject

product for which a price quote is requested.“,”verbs“:



36
37
38
# File 'lib/bf_ruby2/models/quote_request.rb', line 36

def product
  @product
end

#product_rate_planObject

rate plan (of some product) for which a price quote is requested.“,”verbs“:



39
40
41
# File 'lib/bf_ruby2/models/quote_request.rb', line 39

def product_rate_plan
  @product_rate_plan
end

#proratedObject

or not to pro-rate the price (if the quote concerns a time interval containing a partial period).“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/quote_request.rb', line 54

def prorated
  @prorated
end

#quantitiesObject

list of pricing components (and their values) to consider in calculating the quote.“,”verbs“:



72
73
74
# File 'lib/bf_ruby2/models/quote_request.rb', line 72

def quantities
  @quantities
end

#quote_forObject

scenario with which the quote is concerned.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/quote_request.rb', line 51

def quote_for
  @quote_for
end

#remaining_credit_behaviourObject

class=\"label label-default\">Rollover</span>","description":"Defines the behaviour applied to any outstanding credit resulting from the application of the charge..
<span class=\"label label-default\">Rollover</span> &mdash; Outstanding credit is returned to the accounts credit pool.
<span class=\"label label-default\">Discard</span> &mdash; Outstanding credit is lost.“,”verbs“:



69
70
71
# File 'lib/bf_ruby2/models/quote_request.rb', line 69

def remaining_credit_behaviour
  @remaining_credit_behaviour
end

#subscription_idObject

of the subscription for which a price quote is requested.“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/quote_request.rb', line 45

def subscription_id
  @subscription_id
end

#subscription_version_idObject

ID of the subscription for which a price quote is requested.“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/quote_request.rb', line 48

def subscription_version_id
  @subscription_version_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/bf_ruby2/models/quote_request.rb', line 103

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'product' => :'product',
    :'product_rate_plan' => :'productRatePlan',
    :'account_id' => :'accountID',
    :'subscription_id' => :'subscriptionID',
    :'subscription_version_id' => :'subscriptionVersionID',
    :'quote_for' => :'quoteFor',
    :'prorated' => :'prorated',
    :'free' => :'free',
    :'include_applied_coupons' => :'includeAppliedCoupons',
    :'period_start' => :'periodStart',
    :'period_end' => :'periodEnd',
    :'remaining_credit_behaviour' => :'remainingCreditBehaviour',
    :'quantities' => :'quantities',
    :'coupon_codes' => :'couponCodes',
    :'pricing_behaviour' => :'pricingBehaviour'
  }
end

.swagger_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/bf_ruby2/models/quote_request.rb', line 126

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'product' => :'String',
    :'product_rate_plan' => :'String',
    :'account_id' => :'String',
    :'subscription_id' => :'String',
    :'subscription_version_id' => :'String',
    :'quote_for' => :'String',
    :'prorated' => :'BOOLEAN',
    :'free' => :'BOOLEAN',
    :'include_applied_coupons' => :'BOOLEAN',
    :'period_start' => :'DateTime',
    :'period_end' => :'DateTime',
    :'remaining_credit_behaviour' => :'String',
    :'quantities' => :'Array<QuoteRequestValue>',
    :'coupon_codes' => :'Array<String>',
    :'pricing_behaviour' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/bf_ruby2/models/quote_request.rb', line 291

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      product == o.product &&
      product_rate_plan == o.product_rate_plan &&
       == o. &&
      subscription_id == o.subscription_id &&
      subscription_version_id == o.subscription_version_id &&
      quote_for == o.quote_for &&
      prorated == o.prorated &&
      free == o.free &&
      include_applied_coupons == o.include_applied_coupons &&
      period_start == o.period_start &&
      period_end == o.period_end &&
      remaining_credit_behaviour == o.remaining_credit_behaviour &&
      quantities == o.quantities &&
      coupon_codes == o.coupon_codes &&
      pricing_behaviour == o.pricing_behaviour
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/bf_ruby2/models/quote_request.rb', line 349

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/bf_ruby2/models/quote_request.rb', line 415

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/bf_ruby2/models/quote_request.rb', line 328

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


315
316
317
# File 'lib/bf_ruby2/models/quote_request.rb', line 315

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



321
322
323
# File 'lib/bf_ruby2/models/quote_request.rb', line 321

def hash
  [created, changed_by, product, product_rate_plan, , subscription_id, subscription_version_id, quote_for, prorated, free, include_applied_coupons, period_start, period_end, remaining_credit_behaviour, quantities, coupon_codes, pricing_behaviour].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



238
239
240
241
# File 'lib/bf_ruby2/models/quote_request.rb', line 238

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



395
396
397
# File 'lib/bf_ruby2/models/quote_request.rb', line 395

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
404
405
406
407
408
409
# File 'lib/bf_ruby2/models/quote_request.rb', line 401

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



389
390
391
# File 'lib/bf_ruby2/models/quote_request.rb', line 389

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/bf_ruby2/models/quote_request.rb', line 245

def valid?
  return false if @product_rate_plan.nil?
  quote_for_validator = EnumAttributeValidator.new('String', ["InitialPeriod", "RecurringPeriod", "Upgrade", "Migration"])
  return false unless quote_for_validator.valid?(@quote_for)
  return false if @period_end.nil?
  return false if @remaining_credit_behaviour.nil?
  remaining_credit_behaviour_validator = EnumAttributeValidator.new('String', ["Rollover", "Discard"])
  return false unless remaining_credit_behaviour_validator.valid?(@remaining_credit_behaviour)
  return false if @pricing_behaviour.nil?
  pricing_behaviour_validator = EnumAttributeValidator.new('String', ["None", "Full", "Difference", "DifferenceProRated", "ProRated"])
  return false unless pricing_behaviour_validator.valid?(@pricing_behaviour)
  return true
end