Class: Bfwd::SubscriptionCharge

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/subscription_charge.rb

Overview

Represents a monetary amount — or quantity consumed — attributed to some invoice or subscription.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionCharge

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 190

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'crmID')
    self.crm_id = attributes[:'crmID']
  end

  if attributes.has_key?(:'accountID')
    self. = attributes[:'accountID']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'subscriptionVersionID')
    self.subscription_version_id = attributes[:'subscriptionVersionID']
  end

  if attributes.has_key?(:'invoiceID')
    self.invoice_id = attributes[:'invoiceID']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.has_key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.has_key?(:'amountExcludingTax')
    self.amount_excluding_tax = attributes[:'amountExcludingTax']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'periodStart')
    self.period_start = attributes[:'periodStart']
  end

  if attributes.has_key?(:'periodEnd')
    self.period_end = attributes[:'periodEnd']
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'invoicingType')
    self.invoicing_type = attributes[:'invoicingType']
  end

  if attributes.has_key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.has_key?(:'chargeType')
    self.charge_type = attributes[:'chargeType']
  end

  if attributes.has_key?(:'calculation')
    self.calculation = attributes[:'calculation']
  end

  if attributes.has_key?(:'remainingCreditBehaviour')
    self.remaining_credit_behaviour = attributes[:'remainingCreditBehaviour']
  end

  if attributes.has_key?(:'trial')
    self.trial = attributes[:'trial']
  else
    self.trial = false
  end

  if attributes.has_key?(:'versionID')
    self.version_id = attributes[:'versionID']
  end

  if attributes.has_key?(:'versionNumber')
    self.version_number = attributes[:'versionNumber']
  end

end

Instance Attribute Details

#account_idObject

of the account owning the subscription for which the charge was generated.“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 45

def 
  @account_id
end

#amountObject

amount of the charge — including any tax applied to the final amount.“,”verbs“:



63
64
65
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 63

def amount
  @amount
end

#amount_excluding_taxObject

amount of the charge — excluding any tax applied to the final amount.“,”verbs“:



66
67
68
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 66

def amount_excluding_tax
  @amount_excluding_tax
end

#calculationObject

string)","description":"A human-readable explanation of how the value of the charge was calculated.“,”verbs“:



90
91
92
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 90

def calculation
  @calculation
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 33

def changed_by
  @changed_by
end

#charge_typeObject

class=\"label label-default\">Debit</span>","description":"Whether this charge represents money given to or taken from the customer.
<span class=\"label label-default\">Credit</span> &mdash; This is a charge for money given to the customer.
<span class=\"label label-default\">Debit</span> &mdash; This is a charge for money taken from the customer.“,”verbs“:



87
88
89
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 87

def charge_type
  @charge_type
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



30
31
32
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 30

def created
  @created
end

#crm_idObject



42
43
44
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 42

def crm_id
  @crm_id
end

#currencyObject

{ "description" : "Currency of the invoice specified by a three character ISO 4217 currency code.", "verbs“: }



69
70
71
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 69

def currency
  @currency
end

#descriptionObject



60
61
62
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 60

def description
  @description
end

#idObject



39
40
41
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 39

def id
  @id
end

#invoice_idObject

of the invoice to which this charge applies (if the charge targets a specific invoice).“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 54

def invoice_id
  @invoice_id
end

#invoicing_typeObject

class=\"label label-default\">Aggregated</span>","description":"The strategy for how this charge will raise invoices.
<span class=\"label label-default\">Immediate</span> &mdash; Generate straight-away an invoice containing this charge.
<span class=\"label label-default\">Aggregated</span> &mdash; Add this charge to the next invoice which is generated naturally &mdash; i.e. the invoice raised at the current period’s end.“,”verbs“:



81
82
83
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 81

def invoicing_type
  @invoicing_type
end

#nameObject

name given to the charge to help identify it.“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 57

def name
  @name
end

#period_endObject

of current period)","description":"The time-ending of the interval to which the charge applies. This can be used to apply a charge across partial or multiple periods,to pro-rate its price.“,”verbs“:



75
76
77
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 75

def period_end
  @period_end
end

#period_startObject

time-beginning of the interval to which the charge applies. This can be used to apply a charge across partial or multiple periods,to pro-rate its price.“,”verbs“:



72
73
74
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 72

def period_start
  @period_start
end

#remaining_credit_behaviourObject

class=\"label label-default\">Rollover</span>","description":"Defines the behaviour applied to any outstanding credit resulting from the application of the charge..
<span class=\"label label-default\">Rollover</span> &mdash; Outstanding credit is returned to the accounts credit pool.
<span class=\"label label-default\">Discard</span> &mdash; Outstanding credit is lost.“,”verbs“:



93
94
95
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 93

def remaining_credit_behaviour
  @remaining_credit_behaviour
end

#stateObject

class=\"label label-default\">Pending</span>","description":"The current state of the charge.“,”verbs“:



84
85
86
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 84

def state
  @state
end

#subscription_idObject

of the subscription for which the charge was generated.“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 48

def subscription_id
  @subscription_id
end

#subscription_version_idObject

ID of the subscription for which the charge was generated.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 51

def subscription_version_id
  @subscription_version_id
end

#trialObject

only if any of [pricingComponentName, pricingComponentID] are defined)
Whether the charge was created for a subscription whilst in a trial period.
<span class=\"label label-default\">false</span> &mdash; This is a non-trial charge, so funds will be sought from the customer.
<span class=\"label label-default\">true</span> &mdash; This is a trial charge, soThe charge can be considered ‘Paid’ without taking any funds from the customer.“,”verbs“:



96
97
98
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 96

def trial
  @trial
end

#typeObject

type describing the nature of the charge.“,”verbs“:



78
79
80
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 78

def type
  @type
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 36

def updated
  @updated
end

#version_idObject

version ID of the charge.“,”verbs“:



99
100
101
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 99

def version_id
  @version_id
end

#version_numberObject

version number of the charge. The first version of a charge is version number 1.“,”verbs“:



102
103
104
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 102

def version_number
  @version_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 127

def self.attribute_map
  {
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'id' => :'id',
    :'crm_id' => :'crmID',
    :'account_id' => :'accountID',
    :'subscription_id' => :'subscriptionID',
    :'subscription_version_id' => :'subscriptionVersionID',
    :'invoice_id' => :'invoiceID',
    :'name' => :'name',
    :'description' => :'description',
    :'amount' => :'amount',
    :'amount_excluding_tax' => :'amountExcludingTax',
    :'currency' => :'currency',
    :'period_start' => :'periodStart',
    :'period_end' => :'periodEnd',
    :'type' => :'type',
    :'invoicing_type' => :'invoicingType',
    :'state' => :'state',
    :'charge_type' => :'chargeType',
    :'calculation' => :'calculation',
    :'remaining_credit_behaviour' => :'remainingCreditBehaviour',
    :'trial' => :'trial',
    :'version_id' => :'versionID',
    :'version_number' => :'versionNumber'
  }
end

.swagger_typesObject

Attribute type mapping.



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 158

def self.swagger_types
  {
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'id' => :'String',
    :'crm_id' => :'String',
    :'account_id' => :'String',
    :'subscription_id' => :'String',
    :'subscription_version_id' => :'String',
    :'invoice_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'amount' => :'Float',
    :'amount_excluding_tax' => :'Float',
    :'currency' => :'String',
    :'period_start' => :'DateTime',
    :'period_end' => :'DateTime',
    :'type' => :'String',
    :'invoicing_type' => :'String',
    :'state' => :'String',
    :'charge_type' => :'String',
    :'calculation' => :'String',
    :'remaining_credit_behaviour' => :'String',
    :'trial' => :'BOOLEAN',
    :'version_id' => :'String',
    :'version_number' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 381

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      id == o.id &&
      crm_id == o.crm_id &&
       == o. &&
      subscription_id == o.subscription_id &&
      subscription_version_id == o.subscription_version_id &&
      invoice_id == o.invoice_id &&
      name == o.name &&
      description == o.description &&
      amount == o.amount &&
      amount_excluding_tax == o.amount_excluding_tax &&
      currency == o.currency &&
      period_start == o.period_start &&
      period_end == o.period_end &&
      type == o.type &&
      invoicing_type == o.invoicing_type &&
      state == o.state &&
      charge_type == o.charge_type &&
      calculation == o.calculation &&
      remaining_credit_behaviour == o.remaining_credit_behaviour &&
      trial == o.trial &&
      version_id == o.version_id &&
      version_number == o.version_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 447

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = Bfwd.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 513

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 426

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


413
414
415
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 413

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



419
420
421
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 419

def hash
  [created, changed_by, updated, id, crm_id, , subscription_id, subscription_version_id, invoice_id, name, description, amount, amount_excluding_tax, currency, period_start, period_end, type, invoicing_type, state, charge_type, calculation, remaining_credit_behaviour, trial, version_id, version_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



302
303
304
305
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 302

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



493
494
495
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 493

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



499
500
501
502
503
504
505
506
507
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 499

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



487
488
489
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 487

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/bf_ruby2/models/subscription_charge.rb', line 309

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["Setup", "Upgrade", "Manual", "ProductRatePlanMigration", "Arrears", "Advance", "Coupon", "Usage", "PricingComponent"])
  return false unless type_validator.valid?(@type)
  return false if @invoicing_type.nil?
  invoicing_type_validator = EnumAttributeValidator.new('String', ["Immediate", "Aggregated"])
  return false unless invoicing_type_validator.valid?(@invoicing_type)
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["Voided", "Pending", "AwaitingPayment", "Paid", "Failed"])
  return false unless state_validator.valid?(@state)
  return false if @charge_type.nil?
  charge_type_validator = EnumAttributeValidator.new('String', ["Credit", "Debit"])
  return false unless charge_type_validator.valid?(@charge_type)
  return false if @remaining_credit_behaviour.nil?
  remaining_credit_behaviour_validator = EnumAttributeValidator.new('String', ["Rollover", "Discard"])
  return false unless remaining_credit_behaviour_validator.valid?(@remaining_credit_behaviour)
  return false if @version_number.nil?
  return true
end