Class: Bfwd::TimeRequest
- Inherits:
-
Object
- Object
- Bfwd::TimeRequest
- Defined in:
- lib/bf_ruby2/models/time_request.rb
Overview
Request object for advancing a subscription’s flow through time.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#advance_inclusively ⇒ Object
advancing onto an instant in time:
<span class=\"label label-default\">true</span> — Action the events scheduled for your destination time. Amendments scheduled at your destined time will be actioned during this time travel. Advancing to a period boundary will promote your subscription to the period on the future side of that boundary.
<span class=\"label label-default\">false</span> — Do not action events scheduled for your destination time. Amendments scheduled at your destined time will not be actioned during this time travel. Advancing to a period boundary will result in your subscription’s remaining within the period on the past side of that boundary.“,”verbs“:. -
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#dry_run ⇒ Object
described in the response:
<span class=\"label label-default\">true</span> — Are not actually performed; your subscription remains unchanged, no billing events run, and no invoices are executed.
<span class=\"label label-default\">false</span> — Are actually performed and committed.“,”verbs“:. -
#execution_strategy ⇒ Object
class=\"label label-default\">SingleAttempt</span>","description":"What strategy to use when executing any invoices raised as time advances:
<span class=\"label label-default\">SingleAttempt</span> — Execute any invoice just once.
<span class=\"label label-default\">FollowDunning</span> — Apply the existing dunning strategy when executing invoices.
<span class=\"label label-default\">None</span>: Do not execute invoices.“,”verbs“:. -
#freeze_on_completion ⇒ Object
the subscription is advanced through time:
<span class=\"label label-default\">true</span> — Freeze the subscription.
<span class=\"label label-default\">false</span> — Do not freeze the subscription.“,”verbs“:. -
#handle_amendments ⇒ Object
time scrubs forward:
<span class=\"label label-default\">true</span> — Run any amendments that were scheduled to action.
<span class=\"label label-default\">false</span> — Do not run any amendments that were scheduled to action.“,”verbs“:. -
#periods ⇒ Object
one of [
periods,to])
The number of period boundaries up to which the subscription should advance. A 1-value advances the subscription to the end of its current service period. Higher values advance the subscription to subsequent period boundaries.“verbs”:. -
#skip_intermediate_periods ⇒ Object
time scrubs forward:
<span class=\"label label-default\">true</span> — Raise no invoice upon advancing over a period boundary.
<span class=\"label label-default\">false</span> — Raise invoices for any period that is entered.“,”verbs“:. -
#to ⇒ Object
one of [
periods,to])
The time up until which the subscription should be fast-forwarded.“,”verbs“:.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TimeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TimeRequest
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/bf_ruby2/models/time_request.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'periods') self.periods = attributes[:'periods'] end if attributes.has_key?(:'to') self.to = attributes[:'to'] end if attributes.has_key?(:'dryRun') self.dry_run = attributes[:'dryRun'] else self.dry_run = false end if attributes.has_key?(:'skipIntermediatePeriods') self.skip_intermediate_periods = attributes[:'skipIntermediatePeriods'] else self.skip_intermediate_periods = false end if attributes.has_key?(:'handleAmendments') self.handle_amendments = attributes[:'handleAmendments'] else self.handle_amendments = false end if attributes.has_key?(:'executionStrategy') self.execution_strategy = attributes[:'executionStrategy'] end if attributes.has_key?(:'freezeOnCompletion') self.freeze_on_completion = attributes[:'freezeOnCompletion'] else self.freeze_on_completion = false end if attributes.has_key?(:'advanceInclusively') self.advance_inclusively = attributes[:'advanceInclusively'] else self.advance_inclusively = false end end |
Instance Attribute Details
#advance_inclusively ⇒ Object
advancing onto an instant in time:
<span class=\"label label-default\">true</span> — Action the events scheduled for your destination time. Amendments scheduled at your destined time will be actioned during this time travel. Advancing to a period boundary will promote your subscription to the period on the future side of that boundary.
<span class=\"label label-default\">false</span> — Do not action events scheduled for your destination time. Amendments scheduled at your destined time will not be actioned during this time travel. Advancing to a period boundary will result in your subscription’s remaining within the period on the past side of that boundary.“,”verbs“:
54 55 56 |
# File 'lib/bf_ruby2/models/time_request.rb', line 54 def advance_inclusively @advance_inclusively end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/time_request.rb', line 30 def created @created end |
#dry_run ⇒ Object
described in the response:
<span class=\"label label-default\">true</span> — Are not actually performed; your subscription remains unchanged, no billing events run, and no invoices are executed.
<span class=\"label label-default\">false</span> — Are actually performed and committed.“,”verbs“:
39 40 41 |
# File 'lib/bf_ruby2/models/time_request.rb', line 39 def dry_run @dry_run end |
#execution_strategy ⇒ Object
class=\"label label-default\">SingleAttempt</span>","description":"What strategy to use when executing any invoices raised as time advances:
<span class=\"label label-default\">SingleAttempt</span> — Execute any invoice just once.
<span class=\"label label-default\">FollowDunning</span> — Apply the existing dunning strategy when executing invoices.
<span class=\"label label-default\">None</span>: Do not execute invoices.“,”verbs“:
48 49 50 |
# File 'lib/bf_ruby2/models/time_request.rb', line 48 def execution_strategy @execution_strategy end |
#freeze_on_completion ⇒ Object
the subscription is advanced through time:
<span class=\"label label-default\">true</span> — Freeze the subscription.
<span class=\"label label-default\">false</span> — Do not freeze the subscription.“,”verbs“:
51 52 53 |
# File 'lib/bf_ruby2/models/time_request.rb', line 51 def freeze_on_completion @freeze_on_completion end |
#handle_amendments ⇒ Object
time scrubs forward:
<span class=\"label label-default\">true</span> — Run any amendments that were scheduled to action.
<span class=\"label label-default\">false</span> — Do not run any amendments that were scheduled to action.“,”verbs“:
45 46 47 |
# File 'lib/bf_ruby2/models/time_request.rb', line 45 def handle_amendments @handle_amendments end |
#periods ⇒ Object
one of [periods, to])
The number of period boundaries up to which the subscription should advance. A 1-value advances the subscription to the end of its current service period. Higher values advance the subscription to subsequent period boundaries.“verbs”:
33 34 35 |
# File 'lib/bf_ruby2/models/time_request.rb', line 33 def periods @periods end |
#skip_intermediate_periods ⇒ Object
time scrubs forward:
<span class=\"label label-default\">true</span> — Raise no invoice upon advancing over a period boundary.
<span class=\"label label-default\">false</span> — Raise invoices for any period that is entered.“,”verbs“:
42 43 44 |
# File 'lib/bf_ruby2/models/time_request.rb', line 42 def skip_intermediate_periods @skip_intermediate_periods end |
#to ⇒ Object
one of [periods, to])
The time up until which the subscription should be fast-forwarded.“,”verbs“:
36 37 38 |
# File 'lib/bf_ruby2/models/time_request.rb', line 36 def to @to end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/bf_ruby2/models/time_request.rb', line 79 def self.attribute_map { :'created' => :'created', :'periods' => :'periods', :'to' => :'to', :'dry_run' => :'dryRun', :'skip_intermediate_periods' => :'skipIntermediatePeriods', :'handle_amendments' => :'handleAmendments', :'execution_strategy' => :'executionStrategy', :'freeze_on_completion' => :'freezeOnCompletion', :'advance_inclusively' => :'advanceInclusively' } end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/bf_ruby2/models/time_request.rb', line 94 def self.swagger_types { :'created' => :'DateTime', :'periods' => :'Integer', :'to' => :'DateTime', :'dry_run' => :'BOOLEAN', :'skip_intermediate_periods' => :'BOOLEAN', :'handle_amendments' => :'BOOLEAN', :'execution_strategy' => :'String', :'freeze_on_completion' => :'BOOLEAN', :'advance_inclusively' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/bf_ruby2/models/time_request.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && periods == o.periods && to == o.to && dry_run == o.dry_run && skip_intermediate_periods == o.skip_intermediate_periods && handle_amendments == o.handle_amendments && execution_strategy == o.execution_strategy && freeze_on_completion == o.freeze_on_completion && advance_inclusively == o.advance_inclusively end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/bf_ruby2/models/time_request.rb', line 241 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/bf_ruby2/models/time_request.rb', line 307 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/bf_ruby2/models/time_request.rb', line 220 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/bf_ruby2/models/time_request.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/bf_ruby2/models/time_request.rb', line 213 def hash [created, periods, to, dry_run, skip_intermediate_periods, handle_amendments, execution_strategy, freeze_on_completion, advance_inclusively].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 |
# File 'lib/bf_ruby2/models/time_request.rb', line 166 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
287 288 289 |
# File 'lib/bf_ruby2/models/time_request.rb', line 287 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 |
# File 'lib/bf_ruby2/models/time_request.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
281 282 283 |
# File 'lib/bf_ruby2/models/time_request.rb', line 281 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 |
# File 'lib/bf_ruby2/models/time_request.rb', line 173 def valid? execution_strategy_validator = EnumAttributeValidator.new('String', ["SingleAttempt", "FollowDunning", "None"]) return false unless execution_strategy_validator.valid?(@execution_strategy) return true end |