Class: Bfwd::UpdateSubscriptionRequest
- Inherits:
-
Object
- Object
- Bfwd::UpdateSubscriptionRequest
- Defined in:
- lib/bf_ruby2/models/update_subscription_request.rb
Overview
Entity for requesting that a subscription be updated.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_end ⇒ Object
only be changed if subscription is still in Provisioned state] ISO 8601 UTC DateTime (e.g. 2015-06-16T11:58:41Z) describing the date at which the subscription should finish its first service period.“,”verbs“:.
-
#aggregate_all_subscriptions_on_account ⇒ Object
this subscription should become an ‘aggregating subscription’, collecting charges (starting now) from all other subscriptions (current and future) belonging to this BillForward Account.“,”verbs“:.
-
#description ⇒ Object
description to assign to the updated subscription. This is primarily for your benefit — for example, you could write here the mechanism through which you obtained this customer. (e.g. ‘Customer obtained through Lazy Wednesdays promotion’).“,”verbs“:.
-
#failed_payment_behaviour ⇒ Object
action that should be taken, should an invoice for some subscription to this rate plan remain unpaid despite the dunning period’s being exceeded.
<span class=\"label label-default\">CancelSubscription</span> — Demotes the subscription to theFailedstate as soon as the dunning period is exceeded.
<span class=\"label label-default\">None</span> — The subscription is allowed to continue in theAwaitingPaymentstate indefinitely even if the dunning period is exceeded.For slow payment cycles — or when manual invoice remediation is common — <span class=\"label label-default\">None</span> is recommended.
In a heavily-automated SaaS environment, automatic cancellation via <span class=\"label label-default\">CancelSubscription</span> is recommended.“,”verbs“:. -
#id ⇒ Object
of the Subscription you wish to update.“,”verbs“:.
-
#name ⇒ Object
name to assign to the updated subscription. This is primarily for your benefit — for example, to enable you to identify subscriptions at a glance in the BillForward web interface (e.g. ‘Customer 1425, [email protected], Premium membership’).“,”verbs“:.
-
#parent_id ⇒ Object
of a parent subscription which will collect the charges raised by this subscription. The parent becomes responsible for paying those charges.“,”verbs“:.
-
#start ⇒ Object
only be changed if subscription is still in Provisioned state] ISO 8601 UTC DateTime (e.g. 2015-06-16T11:58:41Z) describing the date at which the subscription should enter its first service period.“,”verbs“:.
-
#state ⇒ Object
only be changed if subscription is still in Provisioned state] The state into which you wish to move the updated subscription.
<span class=\"label label-default\">AwaitingPayment</span> — The subscription is activated. Afterstarttime is surpassed, it will begin service and raise its first invoice.“,”verbs“:.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSubscriptionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSubscriptionRequest
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 110 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'start') self.start = attributes[:'start'] end if attributes.has_key?(:'end') self._end = attributes[:'end'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'parentID') self.parent_id = attributes[:'parentID'] end if attributes.has_key?(:'aggregateAllSubscriptionsOnAccount') self.aggregate_all_subscriptions_on_account = attributes[:'aggregateAllSubscriptionsOnAccount'] else self.aggregate_all_subscriptions_on_account = false end if attributes.has_key?(:'failedPaymentBehaviour') self.failed_payment_behaviour = attributes[:'failedPaymentBehaviour'] end end |
Instance Attribute Details
#_end ⇒ Object
only be changed if subscription is still in Provisioned state] ISO 8601 UTC DateTime (e.g. 2015-06-16T11:58:41Z) describing the date at which the subscription should finish its first service period.“,”verbs“:
42 43 44 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 42 def _end @_end end |
#aggregate_all_subscriptions_on_account ⇒ Object
this subscription should become an ‘aggregating subscription’, collecting charges (starting now) from all other subscriptions (current and future) belonging to this BillForward Account.“,”verbs“:
51 52 53 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 51 def aggregate_all_subscriptions_on_account @aggregate_all_subscriptions_on_account end |
#description ⇒ Object
description to assign to the updated subscription. This is primarily for your benefit — for example, you could write here the mechanism through which you obtained this customer. (e.g. ‘Customer obtained through Lazy Wednesdays promotion’).“,”verbs“:
36 37 38 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 36 def description @description end |
#failed_payment_behaviour ⇒ Object
action that should be taken, should an invoice for some subscription to this rate plan remain unpaid despite the dunning period’s being exceeded.
<span class=\"label label-default\">CancelSubscription</span> — Demotes the subscription to the Failed state as soon as the dunning period is exceeded.
<span class=\"label label-default\">None</span> — The subscription is allowed to continue in the AwaitingPayment state indefinitely even if the dunning period is exceeded.For slow payment cycles — or when manual invoice remediation is common — <span class=\"label label-default\">None</span> is recommended.
In a heavily-automated SaaS environment, automatic cancellation via <span class=\"label label-default\">CancelSubscription</span> is recommended.“,”verbs“:
54 55 56 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 54 def failed_payment_behaviour @failed_payment_behaviour end |
#id ⇒ Object
of the Subscription you wish to update.“,”verbs“:
30 31 32 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 30 def id @id end |
#name ⇒ Object
name to assign to the updated subscription. This is primarily for your benefit — for example, to enable you to identify subscriptions at a glance in the BillForward web interface (e.g. ‘Customer 1425, [email protected], Premium membership’).“,”verbs“:
33 34 35 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 33 def name @name end |
#parent_id ⇒ Object
of a parent subscription which will collect the charges raised by this subscription. The parent becomes responsible for paying those charges.“,”verbs“:
48 49 50 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 48 def parent_id @parent_id end |
#start ⇒ Object
only be changed if subscription is still in Provisioned state] ISO 8601 UTC DateTime (e.g. 2015-06-16T11:58:41Z) describing the date at which the subscription should enter its first service period.“,”verbs“:
39 40 41 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 39 def start @start end |
#state ⇒ Object
only be changed if subscription is still in Provisioned state] The state into which you wish to move the updated subscription.
<span class=\"label label-default\">AwaitingPayment</span> — The subscription is activated. After start time is surpassed, it will begin service and raise its first invoice.“,”verbs“:
45 46 47 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 45 def state @state end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 79 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'start' => :'start', :'_end' => :'end', :'state' => :'state', :'parent_id' => :'parentID', :'aggregate_all_subscriptions_on_account' => :'aggregateAllSubscriptionsOnAccount', :'failed_payment_behaviour' => :'failedPaymentBehaviour' } end |
.swagger_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 94 def self.swagger_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'start' => :'DateTime', :'_end' => :'DateTime', :'state' => :'String', :'parent_id' => :'String', :'aggregate_all_subscriptions_on_account' => :'BOOLEAN', :'failed_payment_behaviour' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && start == o.start && _end == o._end && state == o.state && parent_id == o.parent_id && aggregate_all_subscriptions_on_account == o.aggregate_all_subscriptions_on_account && failed_payment_behaviour == o.failed_payment_behaviour end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 246 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 312 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 225 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 218 def hash [id, name, description, start, _end, state, parent_id, aggregate_all_subscriptions_on_account, failed_payment_behaviour].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 158 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
292 293 294 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 292 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
298 299 300 301 302 303 304 305 306 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 298 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
286 287 288 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 286 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 |
# File 'lib/bf_ruby2/models/update_subscription_request.rb', line 165 def valid? return false if @id.nil? state_validator = EnumAttributeValidator.new('String', ["Trial", "Provisioned", "Paid", "AwaitingPayment", "Cancelled", "Failed", "Expired"]) return false unless state_validator.valid?(@state) failed_payment_behaviour_validator = EnumAttributeValidator.new('String', ["CancelSubscription", "None"]) return false unless failed_payment_behaviour_validator.valid?(@failed_payment_behaviour) return true end |