Class: Bfwd::UsageSession
- Inherits:
-
Object
- Object
- Bfwd::UsageSession
- Defined in:
- lib/bf_ruby2/models/usage_session.rb
Overview
A session of usage
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#description ⇒ Object
{ "description" : "A description provided by the user, to record details about this session.", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "Organization associated with this session.", "verbs“: }.
-
#pricing_component_id ⇒ Object
{ "description" : "ID of the pricing-component to which this usage session applies", "verbs“: }.
-
#pricing_component_name ⇒ Object
{ "description" : "Name of the pricing-component to which this usage session applies", "verbs“: }.
-
#session_id ⇒ Object
{ "description" : "A (not guaranteed unique) identifier for this session, provided by the user. This, when combined with the subscription ID and unit of measure, uniquely identify a session.", "verbs“: }.
-
#sessionix ⇒ Object
{ "description" : "The current incarnation of the session. Initially 0, this number increments every time the session is ‘cut’ without ending. For example, a cut is taken of a session if it outlasts the end date of the billing period it started in. The session reincarnates with an incremented sessionix, in the next billing period (that is, if some period indeed follows the current one).", "verbs“: }.
-
#start ⇒ Object
{ "description" : "The start date of this session, UTC DateTime", "verbs“: }.
-
#state ⇒ Object
{ "description" : "The type of usage measured within this billing period. Options are ‘", "verbs“: }Active’, Which refers to a session that is currently running ‘Historic’, Which refers to a session that has terminated.
-
#stop ⇒ Object
{ "description" : "The end date of this session, UTC DateTime", "verbs“: }.
-
#subscription_id ⇒ Object
{ "description" : "ID of the subscription to which this session pertains.", "verbs“: }.
-
#uduration ⇒ Object
{ "description" : "The amount of time that elapsed (in milliseconds?) during this session. Initially 0. Presently updated only when a cut is taken of the session (for example if the session or billnig period ends).", "verbs“: }.
-
#uom ⇒ Object
{ "description" : "Unit-of-measure to which this usage session applies", "verbs“: }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UsageSession
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UsageSession
Initializes the object
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 135 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'subscriptionID') self.subscription_id = attributes[:'subscriptionID'] end if attributes.has_key?(:'sessionID') self.session_id = attributes[:'sessionID'] end if attributes.has_key?(:'pricingComponentID') self.pricing_component_id = attributes[:'pricingComponentID'] end if attributes.has_key?(:'pricingComponentName') self.pricing_component_name = attributes[:'pricingComponentName'] end if attributes.has_key?(:'uom') self.uom = attributes[:'uom'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'sessionix') self.sessionix = attributes[:'sessionix'] end if attributes.has_key?(:'start') self.start = attributes[:'start'] end if attributes.has_key?(:'stop') self.stop = attributes[:'stop'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'uduration') self.uduration = attributes[:'uduration'] end end |
Instance Attribute Details
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 33 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 30 def created @created end |
#description ⇒ Object
{ "description" : "A description provided by the user, to record details about this session.", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 54 def description @description end |
#organization_id ⇒ Object
{ "description" : "Organization associated with this session.", "verbs“: }
36 37 38 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 36 def organization_id @organization_id end |
#pricing_component_id ⇒ Object
{ "description" : "ID of the pricing-component to which this usage session applies", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 45 def pricing_component_id @pricing_component_id end |
#pricing_component_name ⇒ Object
{ "description" : "Name of the pricing-component to which this usage session applies", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 48 def pricing_component_name @pricing_component_name end |
#session_id ⇒ Object
{ "description" : "A (not guaranteed unique) identifier for this session, provided by the user. This, when combined with the subscription ID and unit of measure, uniquely identify a session.", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 42 def session_id @session_id end |
#sessionix ⇒ Object
{ "description" : "The current incarnation of the session. Initially 0, this number increments every time the session is ‘cut’ without ending. For example, a cut is taken of a session if it outlasts the end date of the billing period it started in. The session reincarnates with an incremented sessionix, in the next billing period (that is, if some period indeed follows the current one).", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 57 def sessionix @sessionix end |
#start ⇒ Object
{ "description" : "The start date of this session, UTC DateTime", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 60 def start @start end |
#state ⇒ Object
{ "description" : "The type of usage measured within this billing period. Options are ‘", "verbs“: }Active’, Which refers to a session that is currently running ‘Historic’, Which refers to a session that has terminated.
66 67 68 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 66 def state @state end |
#stop ⇒ Object
{ "description" : "The end date of this session, UTC DateTime", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 63 def stop @stop end |
#subscription_id ⇒ Object
{ "description" : "ID of the subscription to which this session pertains.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 39 def subscription_id @subscription_id end |
#uduration ⇒ Object
{ "description" : "The amount of time that elapsed (in milliseconds?) during this session. Initially 0. Presently updated only when a cut is taken of the session (for example if the session or billnig period ends).", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 69 def uduration @uduration end |
#uom ⇒ Object
{ "description" : "Unit-of-measure to which this usage session applies", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 51 def uom @uom end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 94 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'organization_id' => :'organizationID', :'subscription_id' => :'subscriptionID', :'session_id' => :'sessionID', :'pricing_component_id' => :'pricingComponentID', :'pricing_component_name' => :'pricingComponentName', :'uom' => :'uom', :'description' => :'description', :'sessionix' => :'sessionix', :'start' => :'start', :'stop' => :'stop', :'state' => :'state', :'uduration' => :'uduration' } end |
.swagger_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 114 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'organization_id' => :'String', :'subscription_id' => :'String', :'session_id' => :'String', :'pricing_component_id' => :'String', :'pricing_component_name' => :'String', :'uom' => :'String', :'description' => :'String', :'sessionix' => :'Integer', :'start' => :'DateTime', :'stop' => :'DateTime', :'state' => :'String', :'uduration' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && organization_id == o.organization_id && subscription_id == o.subscription_id && session_id == o.session_id && pricing_component_id == o.pricing_component_id && pricing_component_name == o.pricing_component_name && uom == o.uom && description == o.description && sessionix == o.sessionix && start == o.start && stop == o.stop && state == o.state && uduration == o.uduration end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 286 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 352 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 265 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
252 253 254 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 252 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
258 259 260 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 258 def hash [created, changed_by, organization_id, subscription_id, session_id, pricing_component_id, pricing_component_name, uom, description, sessionix, start, stop, state, uduration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 201 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
332 333 334 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 332 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
326 327 328 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 326 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 216 217 |
# File 'lib/bf_ruby2/models/usage_session.rb', line 208 def valid? return false if @subscription_id.nil? return false if @session_id.nil? return false if @pricing_component_id.nil? return false if @pricing_component_name.nil? return false if @uom.nil? state_validator = EnumAttributeValidator.new('String', ["Active", "Historic"]) return false unless state_validator.valid?(@state) return true end |