Class: BillForward::AuditlogsApi
- Inherits:
-
Object
- Object
- BillForward::AuditlogsApi
- Defined in:
- lib/bf_ruby2/api/auditlogs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_all_audit_entries(opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of all audit-log objects.
-
#get_all_audit_entries_with_http_info(opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of all audit-log objects.
-
#get_audit_entries_by_created_date(lower_threshold, upper_threshold, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of audit-log objects with created times within the period specified by the lower-threshold and upper-threshold parameters.
-
#get_audit_entries_by_created_date_with_http_info(lower_threshold, upper_threshold, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of audit-log objects with created times within the period specified by the lower-threshold and upper-threshold parameters.
-
#get_audit_entry_by_entity_id(entity_id, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of audit-log entries, specified by the entity-ID parameter.
-
#get_audit_entry_by_entity_id_with_http_info(entity_id, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of audit-log entries, specified by the entity-ID parameter.
-
#get_audit_entry_by_entity_type(entity_type, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of audit-log entries, specified by the entity-type parameter.
-
#get_audit_entry_by_entity_type_with_http_info(entity_type, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of audit-log entries, specified by the entity-type parameter.
-
#get_audit_entry_by_id(audit_id, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a single audit-log entry, specified by the audit-ID parameter.
-
#get_audit_entry_by_id_with_http_info(audit_id, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a single audit-log entry, specified by the audit-ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ AuditlogsApi
constructor
A new instance of AuditlogsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuditlogsApi
Returns a new instance of AuditlogsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#get_all_audit_entries(opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of all audit-log objects. By default 10 values are returned. Records are returned in natural order. all","response":"getAuditAll.html"
44 45 46 47 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 44 def get_all_audit_entries(opts = {}) data, _status_code, _headers = get_all_audit_entries_with_http_info(opts) return data end |
#get_all_audit_entries_with_http_info(opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of all audit-log objects. By default 10 values are returned. Records are returned in natural order. all","response":"getAuditAll.html"
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 59 def get_all_audit_entries_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditlogsApi.get_all_audit_entries ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/audit-logs".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditEntryPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditlogsApi#get_all_audit_entries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audit_entries_by_created_date(lower_threshold, upper_threshold, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of audit-log objects with created times within the period specified by the lower-threshold and upper-threshold parameters. By default 10 values are returned. Records are returned in natural order. by created time","response":"getAuditByCreated.html"
120 121 122 123 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 120 def get_audit_entries_by_created_date(lower_threshold, upper_threshold, opts = {}) data, _status_code, _headers = get_audit_entries_by_created_date_with_http_info(lower_threshold, upper_threshold, opts) return data end |
#get_audit_entries_by_created_date_with_http_info(lower_threshold, upper_threshold, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of audit-log objects with created times within the period specified by the lower-threshold and upper-threshold parameters. By default 10 values are returned. Records are returned in natural order. by created time","response":"getAuditByCreated.html"
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 137 def get_audit_entries_by_created_date_with_http_info(lower_threshold, upper_threshold, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditlogsApi.get_audit_entries_by_created_date ..." end # verify the required parameter 'lower_threshold' is set fail ArgumentError, "Missing the required parameter 'lower_threshold' when calling AuditlogsApi.get_audit_entries_by_created_date" if lower_threshold.nil? # verify the required parameter 'upper_threshold' is set fail ArgumentError, "Missing the required parameter 'upper_threshold' when calling AuditlogsApi.get_audit_entries_by_created_date" if upper_threshold.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/audit-logs/created/{lower-threshold}/{upper-threshold}".sub('{format}','json').sub('{' + 'lower-threshold' + '}', lower_threshold.to_s).sub('{' + 'upper-threshold' + '}', upper_threshold.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditEntryPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditlogsApi#get_audit_entries_by_created_date\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audit_entry_by_entity_id(entity_id, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of audit-log entries, specified by the entity-ID parameter. By default 10 values are returned. Records are returned in natural order. by entity-ID","response":"getAuditByEntityID.html"
201 202 203 204 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 201 def get_audit_entry_by_entity_id(entity_id, opts = {}) data, _status_code, _headers = get_audit_entry_by_entity_id_with_http_info(entity_id, opts) return data end |
#get_audit_entry_by_entity_id_with_http_info(entity_id, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of audit-log entries, specified by the entity-ID parameter. By default 10 values are returned. Records are returned in natural order. by entity-ID","response":"getAuditByEntityID.html"
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 217 def get_audit_entry_by_entity_id_with_http_info(entity_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditlogsApi.get_audit_entry_by_entity_id ..." end # verify the required parameter 'entity_id' is set fail ArgumentError, "Missing the required parameter 'entity_id' when calling AuditlogsApi.get_audit_entry_by_entity_id" if entity_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/audit-logs/entity/{entity-ID}".sub('{format}','json').sub('{' + 'entity-ID' + '}', entity_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditEntryPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditlogsApi#get_audit_entry_by_entity_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audit_entry_by_entity_type(entity_type, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a collection of audit-log entries, specified by the entity-type parameter. By default 10 values are returned. Records are returned in natural order. by entity type","response":"getAuditByEntityType.html"
279 280 281 282 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 279 def get_audit_entry_by_entity_type(entity_type, opts = {}) data, _status_code, _headers = get_audit_entry_by_entity_type_with_http_info(entity_type, opts) return data end |
#get_audit_entry_by_entity_type_with_http_info(entity_type, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a collection of audit-log entries, specified by the entity-type parameter. By default 10 values are returned. Records are returned in natural order. by entity type","response":"getAuditByEntityType.html"
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 295 def get_audit_entry_by_entity_type_with_http_info(entity_type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditlogsApi.get_audit_entry_by_entity_type ..." end # verify the required parameter 'entity_type' is set fail ArgumentError, "Missing the required parameter 'entity_type' when calling AuditlogsApi.get_audit_entry_by_entity_type" if entity_type.nil? # verify enum value unless ['Notification', 'Organization', 'OrganizationGateway', 'Product', 'User', 'Subscription', 'Profile', 'ProductRatePlan', 'Client', 'Invoice', 'PricingComponentValue', 'Account', 'PricingComponentValueChange', 'PricingComponentTier', 'PricingComponent', 'PricingCalculation', 'CouponDefinition', 'CouponInstance', 'CouponModifier', 'CouponRule', 'CouponBookDefinition', 'CouponBook', 'InvoiceLine', 'Webhook', 'SubscriptionCancellation', 'NotificationSnapshot', 'InvoicePayment', 'InvoiceLinePayment', 'Payment', 'PaymentMethod', 'PaymentMethodSubscriptionLink', 'DunningLine', 'CybersourceToken', 'Card', 'Alias', 'PaypalSimplePaymentReconciliation', 'FreePaymentReconciliation', 'LocustworldPaymentReconciliation', 'CouponInstanceExistingValue', 'TaxLine', 'TaxationStrategy', 'TaxationLink', 'Address', 'AmendmentPriceNTime', 'Authority', 'UnitOfMeasure', 'SearchResult', 'Amendment', 'AuditLog', 'Password', 'Username', 'FixedTermDefinition', 'FixedTerm', 'Refund', 'CreditNote', 'Receipt', 'AmendmentCompoundConstituent', 'APIConfiguration', 'StripeToken', 'BraintreeToken', 'BalancedToken', 'PaypalToken', 'AuthorizeNetToken', 'SpreedlyToken', 'GatewayRevenue', 'AmendmentDiscardAmendment', 'CancellationAmendment', 'CompoundAmendment', 'CompoundAmendmentConstituent', 'FixedTermExpiryAmendment', 'InvoiceNextExecutionAttemptAmendment', 'PricingComponentValueAmendment', 'BraintreeMerchantAccount', 'WebhookSubscription', 'Migration', 'CassResult', 'CassPaymentResult', 'CassProductRatePlanResult', 'CassChurnResult', 'CassUpgradeResult', 'SubscriptionCharge', 'CassPaymentPProductResult', 'ProductPaymentsArgs', 'StripeACHToken', 'UsageAmount', 'UsageSession', 'Usage', 'UsagePeriod', 'Period', 'OfflinePayment', 'CreditNotePayment', 'CardVaultPayment', 'FreePayment', 'BraintreePayment', 'BalancedPayment', 'CybersourcePayment', 'PaypalPayment', 'PaypalSimplePayment', 'LocustWorldPayment', 'StripeOnlyPayment', 'ProductPaymentsResult', 'StripeACHPayment', 'AuthorizeNetPayment', 'CompoundUsageSession', 'CompoundUsage', 'UsageRoundingStrategies', 'BillforwardManagedPaymentsResult', 'PricingComponentValueMigrationChargeAmendmentMapping', 'SubscriptionLTVResult', 'AccountLTVResult', 'ProductRatePlanPaymentsResult', 'DebtsResult', 'AccountPaymentsResult', 'ComponentChange', 'QuoteRequest', 'Quote', 'CouponCharge', 'CouponInstanceInvoiceLink', 'Coupon', 'CouponDiscount', 'CouponUniqueCodesRequest', 'CouponUniqueCodesResponse', 'GetCouponsResponse', 'AddCouponCodeRequest', 'AddCouponCodeResponse', 'RemoveCouponFromSubscriptionRequest', 'TokenizationPreAuth', 'StripeTokenizationPreAuth', 'BraintreeTokenizationPreAuth', 'SpreedlyTokenizationPreAuth', 'SagePayTokenizationPreAuth', 'PayVisionTokenizationPreAuth', 'TokenizationPreAuthRequest', 'AuthCaptureRequest', 'StripeACHBankAccountVerification', 'PasswordReset', 'PricingRequest', 'AddTaxationStrategyRequest', 'AddPaymentMethodRequest', 'APIRequest', 'SagePayToken', 'SagePayNotificationRequest', 'SagePayNotificationResponse', 'SagePayOutstandingTransaction', 'SagePayEnabledCardType', 'TrustCommerceToken', 'SagePayTransaction', 'PricingComponentValueResponse', 'MigrationResponse', 'TimeResponse', 'EntityTime', 'Email', 'AggregationLink', 'BFPermission', 'Role', 'PermissionLink', 'PayVisionToken', 'PayVisionTransaction', 'KashToken', 'EmailProvider', 'DataSynchronizationJob', 'DataSynchronizationJobError', 'DataSynchronizationConfiguration', 'DataSynchronizationAppConfiguration', 'AggregationChildrenResponse', 'MetadataKeyValue', 'Metadata', 'AggregatingComponent', 'PricingComponentMigrationValue', 'InvoiceRecalculationAmendment', 'IssueInvoiceAmendment', 'EmailSubscription', 'RevenueAttribution'].include?(entity_type) fail ArgumentError, "invalid value for 'entity_type', must be one of Notification, Organization, OrganizationGateway, Product, User, Subscription, Profile, ProductRatePlan, Client, Invoice, PricingComponentValue, Account, PricingComponentValueChange, PricingComponentTier, PricingComponent, PricingCalculation, CouponDefinition, CouponInstance, CouponModifier, CouponRule, CouponBookDefinition, CouponBook, InvoiceLine, Webhook, SubscriptionCancellation, NotificationSnapshot, InvoicePayment, InvoiceLinePayment, Payment, PaymentMethod, PaymentMethodSubscriptionLink, DunningLine, CybersourceToken, Card, Alias, PaypalSimplePaymentReconciliation, FreePaymentReconciliation, LocustworldPaymentReconciliation, CouponInstanceExistingValue, TaxLine, TaxationStrategy, TaxationLink, Address, AmendmentPriceNTime, Authority, UnitOfMeasure, SearchResult, Amendment, AuditLog, Password, Username, FixedTermDefinition, FixedTerm, Refund, CreditNote, Receipt, AmendmentCompoundConstituent, APIConfiguration, StripeToken, BraintreeToken, BalancedToken, PaypalToken, AuthorizeNetToken, SpreedlyToken, GatewayRevenue, AmendmentDiscardAmendment, CancellationAmendment, CompoundAmendment, CompoundAmendmentConstituent, FixedTermExpiryAmendment, InvoiceNextExecutionAttemptAmendment, PricingComponentValueAmendment, BraintreeMerchantAccount, WebhookSubscription, Migration, CassResult, CassPaymentResult, CassProductRatePlanResult, CassChurnResult, CassUpgradeResult, SubscriptionCharge, CassPaymentPProductResult, ProductPaymentsArgs, StripeACHToken, UsageAmount, UsageSession, Usage, UsagePeriod, Period, OfflinePayment, CreditNotePayment, CardVaultPayment, FreePayment, BraintreePayment, BalancedPayment, CybersourcePayment, PaypalPayment, PaypalSimplePayment, LocustWorldPayment, StripeOnlyPayment, ProductPaymentsResult, StripeACHPayment, AuthorizeNetPayment, CompoundUsageSession, CompoundUsage, UsageRoundingStrategies, BillforwardManagedPaymentsResult, PricingComponentValueMigrationChargeAmendmentMapping, SubscriptionLTVResult, AccountLTVResult, ProductRatePlanPaymentsResult, DebtsResult, AccountPaymentsResult, ComponentChange, QuoteRequest, Quote, CouponCharge, CouponInstanceInvoiceLink, Coupon, CouponDiscount, CouponUniqueCodesRequest, CouponUniqueCodesResponse, GetCouponsResponse, AddCouponCodeRequest, AddCouponCodeResponse, RemoveCouponFromSubscriptionRequest, TokenizationPreAuth, StripeTokenizationPreAuth, BraintreeTokenizationPreAuth, SpreedlyTokenizationPreAuth, SagePayTokenizationPreAuth, PayVisionTokenizationPreAuth, TokenizationPreAuthRequest, AuthCaptureRequest, StripeACHBankAccountVerification, PasswordReset, PricingRequest, AddTaxationStrategyRequest, AddPaymentMethodRequest, APIRequest, SagePayToken, SagePayNotificationRequest, SagePayNotificationResponse, SagePayOutstandingTransaction, SagePayEnabledCardType, TrustCommerceToken, SagePayTransaction, PricingComponentValueResponse, MigrationResponse, TimeResponse, EntityTime, Email, AggregationLink, BFPermission, Role, PermissionLink, PayVisionToken, PayVisionTransaction, KashToken, EmailProvider, DataSynchronizationJob, DataSynchronizationJobError, DataSynchronizationConfiguration, DataSynchronizationAppConfiguration, AggregationChildrenResponse, MetadataKeyValue, Metadata, AggregatingComponent, PricingComponentMigrationValue, InvoiceRecalculationAmendment, IssueInvoiceAmendment, EmailSubscription, RevenueAttribution" end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/audit-logs/entity-type/{entity-type}".sub('{format}','json').sub('{' + 'entity-type' + '}', entity_type.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditEntryPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditlogsApi#get_audit_entry_by_entity_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audit_entry_by_id(audit_id, opts = {}) ⇒ AuditEntryPagedMetadata
Returns a single audit-log entry, specified by the audit-ID parameter. by id","response":"getAuditByID.html"
356 357 358 359 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 356 def get_audit_entry_by_id(audit_id, opts = {}) data, _status_code, _headers = get_audit_entry_by_id_with_http_info(audit_id, opts) return data end |
#get_audit_entry_by_id_with_http_info(audit_id, opts = {}) ⇒ Array<(AuditEntryPagedMetadata, Fixnum, Hash)>
Returns a single audit-log entry, specified by the audit-ID parameter. by id","response":"getAuditByID.html"
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/bf_ruby2/api/auditlogs_api.rb', line 367 def get_audit_entry_by_id_with_http_info(audit_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AuditlogsApi.get_audit_entry_by_id ..." end # verify the required parameter 'audit_id' is set fail ArgumentError, "Missing the required parameter 'audit_id' when calling AuditlogsApi.get_audit_entry_by_id" if audit_id.nil? # resource path local_var_path = "/audit-logs/{audit-ID}".sub('{format}','json').sub('{' + 'audit-ID' + '}', audit_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'AuditEntryPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditlogsApi#get_audit_entry_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |