Class: BillForward::CancelSubscriptionRequest
- Inherits:
-
Object
- Object
- BillForward::CancelSubscriptionRequest
- Defined in:
- lib/bf_ruby2/models/cancel_subscription_request.rb
Overview
CancelSubscriptionRequest
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#cancel_children ⇒ Object
Returns the value of attribute cancel_children.
-
#cancel_empty_parent ⇒ Object
Returns the value of attribute cancel_empty_parent.
-
#cancellation_credit ⇒ Object
Specifies whether the service will end immediately on cancellation or if it will continue until the end of the current period.
-
#service_end ⇒ Object
Returns the value of attribute service_end.
-
#source ⇒ Object
Returns the value of attribute source.
-
#state ⇒ Object
Returns the value of attribute state.
-
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CancelSubscriptionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CancelSubscriptionRequest
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 94 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'subscriptionID') self.subscription_id = attributes[:'subscriptionID'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'source') self.source = attributes[:'source'] end if attributes.has_key?(:'serviceEnd') self.service_end = attributes[:'serviceEnd'] end if attributes.has_key?(:'cancellationCredit') self.cancellation_credit = attributes[:'cancellationCredit'] end if attributes.has_key?(:'cancelChildren') self.cancel_children = attributes[:'cancelChildren'] end if attributes.has_key?(:'cancelEmptyParent') self.cancel_empty_parent = attributes[:'cancelEmptyParent'] end end |
Instance Attribute Details
#cancel_children ⇒ Object
Returns the value of attribute cancel_children.
40 41 42 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 40 def cancel_children @cancel_children end |
#cancel_empty_parent ⇒ Object
Returns the value of attribute cancel_empty_parent.
42 43 44 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 42 def cancel_empty_parent @cancel_empty_parent end |
#cancellation_credit ⇒ Object
Specifies whether the service will end immediately on cancellation or if it will continue until the end of the current period. Default: AtPeriodEnd
38 39 40 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 38 def cancellation_credit @cancellation_credit end |
#service_end ⇒ Object
Returns the value of attribute service_end.
35 36 37 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 35 def service_end @service_end end |
#source ⇒ Object
Returns the value of attribute source.
33 34 35 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 33 def source @source end |
#state ⇒ Object
Returns the value of attribute state.
31 32 33 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 31 def state @state end |
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
29 30 31 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 29 def subscription_id @subscription_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 67 def self.attribute_map { :'subscription_id' => :'subscriptionID', :'state' => :'state', :'source' => :'source', :'service_end' => :'serviceEnd', :'cancellation_credit' => :'cancellationCredit', :'cancel_children' => :'cancelChildren', :'cancel_empty_parent' => :'cancelEmptyParent' } end |
.swagger_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 80 def self.swagger_types { :'subscription_id' => :'String', :'state' => :'String', :'source' => :'String', :'service_end' => :'String', :'cancellation_credit' => :'String', :'cancel_children' => :'BOOLEAN', :'cancel_empty_parent' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && subscription_id == o.subscription_id && state == o.state && source == o.source && service_end == o.service_end && cancellation_credit == o.cancellation_credit && cancel_children == o.cancel_children && cancel_empty_parent == o.cancel_empty_parent end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 219 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 285 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 198 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 191 def hash [subscription_id, state, source, service_end, cancellation_credit, cancel_children, cancel_empty_parent].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 132 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
265 266 267 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 265 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 259 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 143 144 145 146 147 |
# File 'lib/bf_ruby2/models/cancel_subscription_request.rb', line 139 def valid? return false if @subscription_id.nil? return false if @source.nil? service_end_validator = EnumAttributeValidator.new('String', ["Immediate", "AtPeriodEnd"]) return false unless service_end_validator.valid?(@service_end) cancellation_credit_validator = EnumAttributeValidator.new('String', ["Credit", "None"]) return false unless cancellation_credit_validator.valid?(@cancellation_credit) return true end |