Class: BillForward::ChargesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/charges_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ChargesApi

Returns a new instance of ChargesApi.



30
31
32
# File 'lib/bf_ruby2/api/charges_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/charges_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#batch_recalculate_subscription_charge(request, opts = {}) ⇒ RecalculateChargeBatchResponsePagedMetadata

Recalculate a batch of charges. re-calculate charges","request":"batchRecalculateChargeRequest.html","response":"batchRecalculateChargeResponse.html"

Parameters:

  • request

    The batch charge request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/charges_api.rb', line 39

def batch_recalculate_subscription_charge(request, opts = {})
  data, _status_code, _headers = batch_recalculate_subscription_charge_with_http_info(request, opts)
  return data
end

#batch_recalculate_subscription_charge_with_http_info(request, opts = {}) ⇒ Array<(RecalculateChargeBatchResponsePagedMetadata, Fixnum, Hash)>

Recalculate a batch of charges. re-calculate charges&quot;,&quot;request&quot;:&quot;batchRecalculateChargeRequest.html&quot;,&quot;response&quot;:&quot;batchRecalculateChargeResponse.html&quot;

Parameters:

  • request

    The batch charge request.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/charges_api.rb', line 49

def batch_recalculate_subscription_charge_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.batch_recalculate_subscription_charge ..."
  end
  # verify the required parameter 'request' is set
  fail ArgumentError, "Missing the required parameter 'request' when calling ChargesApi.batch_recalculate_subscription_charge" if request.nil?
  # resource path
  local_var_path = "/charges/recalculate".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RecalculateChargeBatchResponsePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#batch_recalculate_subscription_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_subscription_charges(opts = {}) ⇒ SubscriptionChargePagedMetadata

Retrieves a collection of all charges. By default 10 values are returned. Records are returned in natural order. all charges","response":"getChargeAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return. (default to 0)

  • :records (Integer)

    The maximum number of subscriptions to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/charges_api.rb', line 101

def get_all_subscription_charges(opts = {})
  data, _status_code, _headers = get_all_subscription_charges_with_http_info(opts)
  return data
end

#get_all_subscription_charges_with_http_info(opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Retrieves a collection of all charges. By default 10 values are returned. Records are returned in natural order. all charges&quot;,&quot;response&quot;:&quot;getChargeAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return.

  • :records (Integer)

    The maximum number of subscriptions to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/charges_api.rb', line 116

def get_all_subscription_charges_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.get_all_subscription_charges ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/charges".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#get_all_subscription_charges\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_subscription_charge_by_account_id(account_id, opts = {}) ⇒ SubscriptionChargePagedMetadata

Retrieves a collection of charges, specified by the account-ID parameter. By default 10 values are returned. Records are returned in natural order. by account","response":"getChargeByAccount.html"

Parameters:

  • account_id

    The string ID of the account

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return. (default to 0)

  • :records (Integer)

    The maximum number of subscriptions to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



176
177
178
179
# File 'lib/bf_ruby2/api/charges_api.rb', line 176

def (, opts = {})
  data, _status_code, _headers = (, opts)
  return data
end

#get_subscription_charge_by_account_id_with_http_info(account_id, opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Retrieves a collection of charges, specified by the account-ID parameter. By default 10 values are returned. Records are returned in natural order. by account&quot;,&quot;response&quot;:&quot;getChargeByAccount.html&quot;

Parameters:

  • account_id

    The string ID of the account

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return.

  • :records (Integer)

    The maximum number of subscriptions to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/bf_ruby2/api/charges_api.rb', line 192

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.get_subscription_charge_by_account_id ..."
  end
  # verify the required parameter 'account_id' is set
  fail ArgumentError, "Missing the required parameter 'account_id' when calling ChargesApi.get_subscription_charge_by_account_id" if .nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/charges/account/{account-ID}".sub('{format}','json').sub('{' + 'account-ID' + '}', .to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#get_subscription_charge_by_account_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_subscription_charge_by_id(charge_id, opts = {}) ⇒ SubscriptionChargePagedMetadata

Retrieves a single charge, specified by the charge-id parameter. a charge","response":"getChargeByID.html"

Parameters:

  • charge_id

    The unique string-ID of the subscription.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return. (default to 0)

  • :records (Integer)

    The maximum number of subscriptions to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



254
255
256
257
# File 'lib/bf_ruby2/api/charges_api.rb', line 254

def get_subscription_charge_by_id(charge_id, opts = {})
  data, _status_code, _headers = get_subscription_charge_by_id_with_http_info(charge_id, opts)
  return data
end

#get_subscription_charge_by_id_with_http_info(charge_id, opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Retrieves a single charge, specified by the charge-id parameter. a charge&quot;,&quot;response&quot;:&quot;getChargeByID.html&quot;

Parameters:

  • charge_id

    The unique string-ID of the subscription.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return.

  • :records (Integer)

    The maximum number of subscriptions to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/bf_ruby2/api/charges_api.rb', line 270

def get_subscription_charge_by_id_with_http_info(charge_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.get_subscription_charge_by_id ..."
  end
  # verify the required parameter 'charge_id' is set
  fail ArgumentError, "Missing the required parameter 'charge_id' when calling ChargesApi.get_subscription_charge_by_id" if charge_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/charges/{charge-id}".sub('{format}','json').sub('{' + 'charge-id' + '}', charge_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#get_subscription_charge_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_subscription_charge_by_state(state, opts = {}) ⇒ SubscriptionChargePagedMetadata

Retrieves a collection of charges, specified by the state parameter. By default 10 values are returned. Records are returned in natural order. by state","response":"getChargeByState.html"

Parameters:

  • state

    The current state of the charge

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return. (default to 0)

  • :records (Integer)

    The maximum number of subscriptions to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



332
333
334
335
# File 'lib/bf_ruby2/api/charges_api.rb', line 332

def get_subscription_charge_by_state(state, opts = {})
  data, _status_code, _headers = get_subscription_charge_by_state_with_http_info(state, opts)
  return data
end

#get_subscription_charge_by_state_with_http_info(state, opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Retrieves a collection of charges, specified by the state parameter. By default 10 values are returned. Records are returned in natural order. by state&quot;,&quot;response&quot;:&quot;getChargeByState.html&quot;

Parameters:

  • state

    The current state of the charge

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return.

  • :records (Integer)

    The maximum number of subscriptions to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/bf_ruby2/api/charges_api.rb', line 348

def get_subscription_charge_by_state_with_http_info(state, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.get_subscription_charge_by_state ..."
  end
  # verify the required parameter 'state' is set
  fail ArgumentError, "Missing the required parameter 'state' when calling ChargesApi.get_subscription_charge_by_state" if state.nil?
  # verify enum value
  unless ['Voided', 'Pending', 'AwaitingPayment', 'Paid', 'Failed'].include?(state)
    fail ArgumentError, "invalid value for 'state', must be one of Voided, Pending, AwaitingPayment, Paid, Failed"
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/charges/state/{state}".sub('{format}','json').sub('{' + 'state' + '}', state.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#get_subscription_charge_by_state\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_subscription_charge_by_version_id(version_id, opts = {}) ⇒ SubscriptionChargePagedMetadata

Retrieves a single charge, specified by the version-ID parameter. by version","response":"getChargeByVersionID.html"

Parameters:

  • version_id

    The version-ID of the charge.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



409
410
411
412
# File 'lib/bf_ruby2/api/charges_api.rb', line 409

def get_subscription_charge_by_version_id(version_id, opts = {})
  data, _status_code, _headers = get_subscription_charge_by_version_id_with_http_info(version_id, opts)
  return data
end

#get_subscription_charge_by_version_id_with_http_info(version_id, opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Retrieves a single charge, specified by the version-ID parameter. by version&quot;,&quot;response&quot;:&quot;getChargeByVersionID.html&quot;

Parameters:

  • version_id

    The version-ID of the charge.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/bf_ruby2/api/charges_api.rb', line 420

def get_subscription_charge_by_version_id_with_http_info(version_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.get_subscription_charge_by_version_id ..."
  end
  # verify the required parameter 'version_id' is set
  fail ArgumentError, "Missing the required parameter 'version_id' when calling ChargesApi.get_subscription_charge_by_version_id" if version_id.nil?
  # resource path
  local_var_path = "/charges/version/{version-ID}".sub('{format}','json').sub('{' + 'version-ID' + '}', version_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#get_subscription_charge_by_version_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#recalculate_subscription_charge(charge_id, charge, opts = {}) ⇒ SubscriptionChargePagedMetadata

Recalculate a charge. a charge","request":"recalculateChargeRequest.html","response":"recalculateChargeResponse.html"

Parameters:

  • charge_id

    Unique id of the charge.

  • charge

    The charge to be re-calculated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



469
470
471
472
# File 'lib/bf_ruby2/api/charges_api.rb', line 469

def recalculate_subscription_charge(charge_id, charge, opts = {})
  data, _status_code, _headers = recalculate_subscription_charge_with_http_info(charge_id, charge, opts)
  return data
end

#recalculate_subscription_charge_with_http_info(charge_id, charge, opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Recalculate a charge. a charge&quot;,&quot;request&quot;:&quot;recalculateChargeRequest.html&quot;,&quot;response&quot;:&quot;recalculateChargeResponse.html&quot;

Parameters:

  • charge_id

    Unique id of the charge.

  • charge

    The charge to be re-calculated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/bf_ruby2/api/charges_api.rb', line 480

def recalculate_subscription_charge_with_http_info(charge_id, charge, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.recalculate_subscription_charge ..."
  end
  # verify the required parameter 'charge_id' is set
  fail ArgumentError, "Missing the required parameter 'charge_id' when calling ChargesApi.recalculate_subscription_charge" if charge_id.nil?
  # verify the required parameter 'charge' is set
  fail ArgumentError, "Missing the required parameter 'charge' when calling ChargesApi.recalculate_subscription_charge" if charge.nil?
  # resource path
  local_var_path = "/charges/{charge-ID}/recalculate".sub('{format}','json').sub('{' + 'charge-ID' + '}', charge_id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(charge)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#recalculate_subscription_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#void_subscription_charge(charge_id, opts = {}) ⇒ SubscriptionChargePagedMetadata

Void the charge with the specified charge-ID. charge","response":"deleteCharge.html"

Parameters:

  • charge_id

    Unique id of the charge.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



530
531
532
533
# File 'lib/bf_ruby2/api/charges_api.rb', line 530

def void_subscription_charge(charge_id, opts = {})
  data, _status_code, _headers = void_subscription_charge_with_http_info(charge_id, opts)
  return data
end

#void_subscription_charge_with_http_info(charge_id, opts = {}) ⇒ Array<(SubscriptionChargePagedMetadata, Fixnum, Hash)>

Void the charge with the specified charge-ID. charge&quot;,&quot;response&quot;:&quot;deleteCharge.html&quot;

Parameters:

  • charge_id

    Unique id of the charge.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/bf_ruby2/api/charges_api.rb', line 541

def void_subscription_charge_with_http_info(charge_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: ChargesApi.void_subscription_charge ..."
  end
  # verify the required parameter 'charge_id' is set
  fail ArgumentError, "Missing the required parameter 'charge_id' when calling ChargesApi.void_subscription_charge" if charge_id.nil?
  # resource path
  local_var_path = "/charges/{charge-id}".sub('{format}','json').sub('{' + 'charge-id' + '}', charge_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'SubscriptionChargePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ChargesApi#void_subscription_charge\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end