Class: BillForward::ConfigurationsApi
- Inherits:
-
Object
- Object
- BillForward::ConfigurationsApi
- Defined in:
- lib/bf_ruby2/api/configurations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_api_configuration(configuration, opts = {}) ⇒ APIConfigurationPagedMetadata
Create a configuration.
-
#create_api_configuration_with_http_info(configuration, opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Create a configuration.
-
#get_all_api_configurations(opts = {}) ⇒ APIConfigurationPagedMetadata
Returns a collection of configurations.
-
#get_all_api_configurations_with_http_info(opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection of configurations.
-
#get_api_configurations_by_type(configuration_type, opts = {}) ⇒ APIConfigurationPagedMetadata
Returns a single configuration, specified by the type parameter.
-
#get_api_configurations_by_type_with_http_info(configuration_type, opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Returns a single configuration, specified by the type parameter.
-
#initialize(api_client = ApiClient.default) ⇒ ConfigurationsApi
constructor
A new instance of ConfigurationsApi.
-
#update_api_configuration(configuration, opts = {}) ⇒ APIConfigurationPagedMetadata
Update a configuration.
-
#update_api_configuration_with_http_info(configuration, opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Update a configuration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConfigurationsApi
Returns a new instance of ConfigurationsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_api_configuration(configuration, opts = {}) ⇒ APIConfigurationPagedMetadata
Create a configuration. a new configuration","request":"createConfigurationRequest.html","response":"createConfigurationResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 39 def create_api_configuration(configuration, opts = {}) data, _status_code, _headers = create_api_configuration_with_http_info(configuration, opts) return data end |
#create_api_configuration_with_http_info(configuration, opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Create a configuration. a new configuration","request":"createConfigurationRequest.html","response":"createConfigurationResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 49 def create_api_configuration_with_http_info(configuration, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConfigurationsApi.create_api_configuration ..." end # verify the required parameter 'configuration' is set fail ArgumentError, "Missing the required parameter 'configuration' when calling ConfigurationsApi.create_api_configuration" if configuration.nil? # resource path local_var_path = "/configurations".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(configuration) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'APIConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigurationsApi#create_api_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_api_configurations(opts = {}) ⇒ APIConfigurationPagedMetadata
Returns a collection of configurations. By default 10 values are returned. Records are returned in natural order. all configurations","response":"getConfigurationsAll.html"
100 101 102 103 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 100 def get_all_api_configurations(opts = {}) data, _status_code, _headers = get_all_api_configurations_with_http_info(opts) return data end |
#get_all_api_configurations_with_http_info(opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection of configurations. By default 10 values are returned. Records are returned in natural order. all configurations","response":"getConfigurationsAll.html"
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 114 def get_all_api_configurations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConfigurationsApi.get_all_api_configurations ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/configurations".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'APIConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigurationsApi#get_all_api_configurations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_api_configurations_by_type(configuration_type, opts = {}) ⇒ APIConfigurationPagedMetadata
Returns a single configuration, specified by the type parameter. by payment gateway","response":"getConfigurationByType.html"
172 173 174 175 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 172 def get_api_configurations_by_type(configuration_type, opts = {}) data, _status_code, _headers = get_api_configurations_by_type_with_http_info(configuration_type, opts) return data end |
#get_api_configurations_by_type_with_http_info(configuration_type, opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Returns a single configuration, specified by the type parameter. by payment gateway","response":"getConfigurationByType.html"
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 187 def get_api_configurations_by_type_with_http_info(configuration_type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConfigurationsApi.get_api_configurations_by_type ..." end # verify the required parameter 'configuration_type' is set fail ArgumentError, "Missing the required parameter 'configuration_type' when calling ConfigurationsApi.get_api_configurations_by_type" if configuration_type.nil? # verify enum value unless ['Balanced', 'Braintree', 'Cybersource', 'Paypal', 'Stripe', 'AuthorizeNet', 'Spreedly', 'SagePay', 'TrustCommerce', 'Payvision', 'Kash'].include?(configuration_type) fail ArgumentError, "invalid value for 'configuration_type', must be one of Balanced, Braintree, Cybersource, Paypal, Stripe, AuthorizeNet, Spreedly, SagePay, TrustCommerce, Payvision, Kash" end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/configurations/type/{configuration-type}".sub('{format}','json').sub('{' + 'configuration-type' + '}', configuration_type.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'APIConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigurationsApi#get_api_configurations_by_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_api_configuration(configuration, opts = {}) ⇒ APIConfigurationPagedMetadata
Update a configuration. a configuration","request":"updateConfigurationRequest.html","response":"updateConfigurationResponse.html"
246 247 248 249 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 246 def update_api_configuration(configuration, opts = {}) data, _status_code, _headers = update_api_configuration_with_http_info(configuration, opts) return data end |
#update_api_configuration_with_http_info(configuration, opts = {}) ⇒ Array<(APIConfigurationPagedMetadata, Fixnum, Hash)>
Update a configuration. a configuration","request":"updateConfigurationRequest.html","response":"updateConfigurationResponse.html"
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/bf_ruby2/api/configurations_api.rb', line 256 def update_api_configuration_with_http_info(configuration, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ConfigurationsApi.update_api_configuration ..." end # verify the required parameter 'configuration' is set fail ArgumentError, "Missing the required parameter 'configuration' when calling ConfigurationsApi.update_api_configuration" if configuration.nil? # resource path local_var_path = "/configurations".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(configuration) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'APIConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigurationsApi#update_api_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |