Class: BillForward::CouponBook
- Inherits:
-
Object
- Object
- BillForward::CouponBook
- Defined in:
- lib/bf_ruby2/models/coupon_book.rb
Overview
A coupon-book.
Instance Attribute Summary collapse
-
#book_code ⇒ Object
{ "description" : "The book code for the coupon-book. This is used to create coupon-instances which are associated with subscriptions.", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#cost ⇒ Object
{ "description" : "The cost of the coupon-book. Can be used to keep track of coupon-book sales.", "verbs“: }.
-
#coupon_book_definition_id ⇒ Object
{ "description" : "ID of the coupon-book-definition associated with the coupon-book.", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#crm_id ⇒ Object
{ "description" : "CRM ID of the product-rate-plan.", "verbs“: }.
-
#deleted ⇒ Object
{ "description" : "Has the coupon book been deleted?", "verbs“: }.
-
#id ⇒ Object
{ "description" : "ID of the coupon-book.", "verbs“: }.
-
#max_remaining_coupons ⇒ Object
{ "description" : "The original number of available coupon-instances that the coupon-book can hold.", "verbs“: }.
-
#maximum_coupon_uses ⇒ Object
{ "description" : "The maximum number of uses each coupon-instance created from this coupon-book can have.", "verbs“: }.
-
#name ⇒ Object
{ "description" : "The human readable name of the coupon-book.", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "Organization associated with the the coupon-book.", "verbs“: }.
-
#remaining_coupons ⇒ Object
{ "description" : "The number of available coupon-instances left in the coupon-book.", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CouponBook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CouponBook
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 114 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'bookCode') self.book_code = attributes[:'bookCode'] end if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'crmID') self.crm_id = attributes[:'crmID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'couponBookDefinitionID') self.coupon_book_definition_id = attributes[:'couponBookDefinitionID'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'cost') self.cost = attributes[:'cost'] end if attributes.has_key?(:'remainingCoupons') self.remaining_coupons = attributes[:'remainingCoupons'] end if attributes.has_key?(:'maxRemainingCoupons') self.max_remaining_coupons = attributes[:'maxRemainingCoupons'] end if attributes.has_key?(:'maximumCouponUses') self.maximum_coupon_uses = attributes[:'maximumCouponUses'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end end |
Instance Attribute Details
#book_code ⇒ Object
{ "description" : "The book code for the coupon-book. This is used to create coupon-instances which are associated with subscriptions.", "verbs“: }
30 31 32 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 30 def book_code @book_code end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 36 def changed_by @changed_by end |
#cost ⇒ Object
{ "description" : "The cost of the coupon-book. Can be used to keep track of coupon-book sales.", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 57 def cost @cost end |
#coupon_book_definition_id ⇒ Object
{ "description" : "ID of the coupon-book-definition associated with the coupon-book.", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 51 def coupon_book_definition_id @coupon_book_definition_id end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 33 def created @created end |
#crm_id ⇒ Object
{ "description" : "CRM ID of the product-rate-plan.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 45 def crm_id @crm_id end |
#deleted ⇒ Object
{ "description" : "Has the coupon book been deleted?", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 69 def deleted @deleted end |
#id ⇒ Object
{ "description" : "ID of the coupon-book.", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 42 def id @id end |
#max_remaining_coupons ⇒ Object
{ "description" : "The original number of available coupon-instances that the coupon-book can hold.", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 63 def max_remaining_coupons @max_remaining_coupons end |
#maximum_coupon_uses ⇒ Object
{ "description" : "The maximum number of uses each coupon-instance created from this coupon-book can have.", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 66 def maximum_coupon_uses @maximum_coupon_uses end |
#name ⇒ Object
{ "description" : "The human readable name of the coupon-book.", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 54 def name @name end |
#organization_id ⇒ Object
{ "description" : "Organization associated with the the coupon-book.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 48 def organization_id @organization_id end |
#remaining_coupons ⇒ Object
{ "description" : "The number of available coupon-instances left in the coupon-book.", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 60 def remaining_coupons @remaining_coupons end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
39 40 41 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 39 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 73 def self.attribute_map { :'book_code' => :'bookCode', :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'crm_id' => :'crmID', :'organization_id' => :'organizationID', :'coupon_book_definition_id' => :'couponBookDefinitionID', :'name' => :'name', :'cost' => :'cost', :'remaining_coupons' => :'remainingCoupons', :'max_remaining_coupons' => :'maxRemainingCoupons', :'maximum_coupon_uses' => :'maximumCouponUses', :'deleted' => :'deleted' } end |
.swagger_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 93 def self.swagger_types { :'book_code' => :'String', :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'crm_id' => :'String', :'organization_id' => :'String', :'coupon_book_definition_id' => :'String', :'name' => :'String', :'cost' => :'Float', :'remaining_coupons' => :'Integer', :'max_remaining_coupons' => :'Integer', :'maximum_coupon_uses' => :'Integer', :'deleted' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 205 def ==(o) return true if self.equal?(o) self.class == o.class && book_code == o.book_code && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && crm_id == o.crm_id && organization_id == o.organization_id && coupon_book_definition_id == o.coupon_book_definition_id && name == o.name && cost == o.cost && remaining_coupons == o.remaining_coupons && max_remaining_coupons == o.max_remaining_coupons && maximum_coupon_uses == o.maximum_coupon_uses && deleted == o.deleted end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 260 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 326 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 239 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 232 def hash [book_code, created, changed_by, updated, id, crm_id, organization_id, coupon_book_definition_id, name, cost, remaining_coupons, max_remaining_coupons, maximum_coupon_uses, deleted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 182 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
306 307 308 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 306 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
300 301 302 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 300 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/bf_ruby2/models/coupon_book.rb', line 189 def valid? return false if @id.nil? return false if @crm_id.nil? return false if @organization_id.nil? return false if @coupon_book_definition_id.nil? return false if @name.nil? return false if @cost.nil? return false if @remaining_coupons.nil? return false if @max_remaining_coupons.nil? return false if @maximum_coupon_uses.nil? return false if @deleted.nil? return true end |