Class: BillForward::CouponDefinition
- Inherits:
-
Object
- Object
- BillForward::CouponDefinition
- Defined in:
- lib/bf_ruby2/models/coupon_definition.rb
Overview
A coupon-definition.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#crm_id ⇒ Object
{ "description" : "CRM ID of the product-rate-plan.", "verbs“: }.
-
#currency ⇒ Object
{ "description" : "The currency of the coupon-definition specified by a three character ISO 4217 currency code.", "verbs“: }.
-
#customer_code ⇒ Object
{ "description" : "The customerCode associated with the organization.", "verbs“: }.
-
#definition_valid_from ⇒ Object
{ "description" : "The UTC DateTime that the coupon-definition is valid from.", "verbs“: }.
-
#definition_valid_till ⇒ Object
{ "description" : "The UTC DateTime that the coupon-definition is valid until.", "verbs“: }.
-
#description ⇒ Object
{ "description" : "The human readable description of the coupon-definition.", "verbs“: }.
-
#fixed_end_date ⇒ Object
{ "description" : "The UTC DateTime specifying the fixed end date of the coupon-definition.", "verbs“: }.
-
#id ⇒ Object
{ "description" : "ID of the coupon-definition.", "verbs“: }.
-
#instance_duration ⇒ Object
{ "description" : "instanceDuration", "verbs“: }.
-
#instance_duration_period ⇒ Object
{ "description" : "instanceDurationPeriod", "verbs“: }.
-
#modifiers ⇒ Object
{ "description" : "The collection of coupon-modifiers associated with the coupon-definition.", "verbs“: }.
-
#name ⇒ Object
{ "description" : "The human readable name of the coupon-definition.", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "ID of the organization associated with the coupon-definition.", "verbs“: }.
-
#rules ⇒ Object
{ "description" : "The collection of coupon-rules associated with the coupon-definition.", "verbs“: }.
-
#state ⇒ Object
{ "description" : "The current state of the coupon-definition.", "verbs“: }.
-
#target ⇒ Object
{ "description" : "The target of the coupon-definition. Currently coupon-definitions can only target products.", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CouponDefinition
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CouponDefinition
Initializes the object
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 160 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'crmID') self.crm_id = attributes[:'crmID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'customerCode') self.customer_code = attributes[:'customerCode'] end if attributes.has_key?(:'target') self.target = attributes[:'target'] end if attributes.has_key?(:'currency') self.currency = attributes[:'currency'] end if attributes.has_key?(:'definitionValidFrom') self.definition_valid_from = attributes[:'definitionValidFrom'] end if attributes.has_key?(:'definitionValidTill') self.definition_valid_till = attributes[:'definitionValidTill'] end if attributes.has_key?(:'instanceDurationPeriod') self.instance_duration_period = attributes[:'instanceDurationPeriod'] end if attributes.has_key?(:'instanceDuration') self.instance_duration = attributes[:'instanceDuration'] end if attributes.has_key?(:'fixedEndDate') self.fixed_end_date = attributes[:'fixedEndDate'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end if attributes.has_key?(:'modifiers') if (value = attributes[:'modifiers']).is_a?(Array) self.modifiers = value end end if attributes.has_key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end end end |
Instance Attribute Details
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 33 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 30 def created @created end |
#crm_id ⇒ Object
{ "description" : "CRM ID of the product-rate-plan.", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 42 def crm_id @crm_id end |
#currency ⇒ Object
{ "description" : "The currency of the coupon-definition specified by a three character ISO 4217 currency code.", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 60 def currency @currency end |
#customer_code ⇒ Object
{ "description" : "The customerCode associated with the organization.", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 54 def customer_code @customer_code end |
#definition_valid_from ⇒ Object
{ "description" : "The UTC DateTime that the coupon-definition is valid from.", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 63 def definition_valid_from @definition_valid_from end |
#definition_valid_till ⇒ Object
{ "description" : "The UTC DateTime that the coupon-definition is valid until.", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 66 def definition_valid_till @definition_valid_till end |
#description ⇒ Object
{ "description" : "The human readable description of the coupon-definition.", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 51 def description @description end |
#fixed_end_date ⇒ Object
{ "description" : "The UTC DateTime specifying the fixed end date of the coupon-definition.", "verbs“: }
75 76 77 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 75 def fixed_end_date @fixed_end_date end |
#id ⇒ Object
{ "description" : "ID of the coupon-definition.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 39 def id @id end |
#instance_duration ⇒ Object
{ "description" : "instanceDuration", "verbs“: }
72 73 74 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 72 def instance_duration @instance_duration end |
#instance_duration_period ⇒ Object
{ "description" : "instanceDurationPeriod", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 69 def instance_duration_period @instance_duration_period end |
#modifiers ⇒ Object
{ "description" : "The collection of coupon-modifiers associated with the coupon-definition.", "verbs“: }
81 82 83 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 81 def modifiers @modifiers end |
#name ⇒ Object
{ "description" : "The human readable name of the coupon-definition.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 48 def name @name end |
#organization_id ⇒ Object
{ "description" : "ID of the organization associated with the coupon-definition.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 45 def organization_id @organization_id end |
#rules ⇒ Object
{ "description" : "The collection of coupon-rules associated with the coupon-definition.", "verbs“: }
84 85 86 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 84 def rules @rules end |
#state ⇒ Object
{ "description" : "The current state of the coupon-definition.", "verbs“: }
78 79 80 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 78 def state @state end |
#target ⇒ Object
{ "description" : "The target of the coupon-definition. Currently coupon-definitions can only target products.", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 57 def target @target end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 36 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 109 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'crm_id' => :'crmID', :'organization_id' => :'organizationID', :'name' => :'name', :'description' => :'description', :'customer_code' => :'customerCode', :'target' => :'target', :'currency' => :'currency', :'definition_valid_from' => :'definitionValidFrom', :'definition_valid_till' => :'definitionValidTill', :'instance_duration_period' => :'instanceDurationPeriod', :'instance_duration' => :'instanceDuration', :'fixed_end_date' => :'fixedEndDate', :'state' => :'state', :'modifiers' => :'modifiers', :'rules' => :'rules' } end |
.swagger_types ⇒ Object
Attribute type mapping.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 134 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'crm_id' => :'String', :'organization_id' => :'String', :'name' => :'String', :'description' => :'String', :'customer_code' => :'String', :'target' => :'String', :'currency' => :'String', :'definition_valid_from' => :'DateTime', :'definition_valid_till' => :'DateTime', :'instance_duration_period' => :'String', :'instance_duration' => :'Integer', :'fixed_end_date' => :'DateTime', :'state' => :'String', :'modifiers' => :'Array<CouponModifierBase>', :'rules' => :'Array<CouponRule>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 312 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && crm_id == o.crm_id && organization_id == o.organization_id && name == o.name && description == o.description && customer_code == o.customer_code && target == o.target && currency == o.currency && definition_valid_from == o.definition_valid_from && definition_valid_till == o.definition_valid_till && instance_duration_period == o.instance_duration_period && instance_duration == o.instance_duration && fixed_end_date == o.fixed_end_date && state == o.state && modifiers == o.modifiers && rules == o.rules end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 372 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 438 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 351 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
338 339 340 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 338 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
344 345 346 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 344 def hash [created, changed_by, updated, id, crm_id, organization_id, name, description, customer_code, target, currency, definition_valid_from, definition_valid_till, instance_duration_period, instance_duration, fixed_end_date, state, modifiers, rules].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
250 251 252 253 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 250 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
418 419 420 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 418 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
424 425 426 427 428 429 430 431 432 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 424 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
412 413 414 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 412 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/bf_ruby2/models/coupon_definition.rb', line 257 def valid? return false if @crm_id.nil? return false if @organization_id.nil? return false if @name.nil? return false if @description.nil? return false if @customer_code.nil? return false if @target.nil? target_validator = EnumAttributeValidator.new('String', ["product", "account"]) return false unless target_validator.valid?(@target) return false if @currency.nil? return false if @definition_valid_from.nil? return false if @instance_duration_period.nil? instance_duration_period_validator = EnumAttributeValidator.new('String', ["minutes", "hours", "days", "months", "years", "periods"]) return false unless instance_duration_period_validator.valid?(@instance_duration_period) return false if @instance_duration.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["development", "production", "deleted"]) return false unless state_validator.valid?(@state) return false if @modifiers.nil? return false if @rules.nil? return true end |