Class: BillForward::CouponInstance

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/coupon_instance.rb

Overview

A coupon-instance.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CouponInstance

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 160

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'targetID')
    self.target_id = attributes[:'targetID']
  end

  if attributes.has_key?(:'couponCode')
    self.coupon_code = attributes[:'couponCode']
  end

  if attributes.has_key?(:'dateInitialised')
    self.date_initialised = attributes[:'dateInitialised']
  end

  if attributes.has_key?(:'validTill')
    self.valid_till = attributes[:'validTill']
  end

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'crmID')
    self.crm_id = attributes[:'crmID']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'bookID')
    self.book_id = attributes[:'bookID']
  end

  if attributes.has_key?(:'couponDefinitionID')
    self.coupon_definition_id = attributes[:'couponDefinitionID']
  end

  if attributes.has_key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.has_key?(:'periodsValidFor')
    self.periods_valid_for = attributes[:'periodsValidFor']
  end

  if attributes.has_key?(:'totalPeriods')
    self.total_periods = attributes[:'totalPeriods']
  end

  if attributes.has_key?(:'remainingUses')
    self.remaining_uses = attributes[:'remainingUses']
  end

  if attributes.has_key?(:'instanceDiscountValue')
    self.instance_discount_value = attributes[:'instanceDiscountValue']
  end

  if attributes.has_key?(:'maxRemainingUses')
    self.max_remaining_uses = attributes[:'maxRemainingUses']
  end

  if attributes.has_key?(:'couponInstanceExistingValues')
    if (value = attributes[:'couponInstanceExistingValues']).is_a?(Array)
      self.coupon_instance_existing_values = value
    end
  end

end

Instance Attribute Details

#book_idObject

{ "description" : "ID of the coupon-book associated with the coupon-instance.", "verbs“: }



60
61
62
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 60

def book_id
  @book_id
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



45
46
47
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 45

def changed_by
  @changed_by
end

#coupon_codeObject

{ "description" : "Code for the coupon. This code can be used to apply coupon-instances to subscriptions or accounts.", "verbs“: }



33
34
35
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 33

def coupon_code
  @coupon_code
end

#coupon_definition_idObject

{ "description" : "ID of the coupon-definition associated with the coupon-instance.", "verbs“: }



63
64
65
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 63

def coupon_definition_id
  @coupon_definition_id
end

#coupon_instance_existing_valuesObject

{ "description" : "The collection of coupon-instance-existing-value objects associated with the coupon-instance.", "verbs“: }



84
85
86
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 84

def coupon_instance_existing_values
  @coupon_instance_existing_values
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



42
43
44
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 42

def created
  @created
end

#crm_idObject

{ "description" : "CRM ID of the product-rate-plan.", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 54

def crm_id
  @crm_id
end

#date_initialisedObject

{ "description" : "The UTC DateTime the coupon was initialised.", "verbs“: }



36
37
38
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 36

def date_initialised
  @date_initialised
end

#idObject

{ "description" : "ID of the coupon-instance.", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 51

def id
  @id
end

#instance_discount_valueObject

{ "description" : "(Optional) The value to be used for dynamic price calculation, if the coupon definition has an ‘instance’ or ‘instance_percent’ coupon modifier. If it is not set, the effect amount of the coupon modifier will be used.", "verbs“: }



78
79
80
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 78

def instance_discount_value
  @instance_discount_value
end

#max_remaining_usesObject

{ "description" : "The number of remaining uses the coupon-instance had upon initialisation.", "verbs“: }



81
82
83
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 81

def max_remaining_uses
  @max_remaining_uses
end

#organization_idObject

{ "description" : "Organization associated with the", "verbs“: }



57
58
59
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 57

def organization_id
  @organization_id
end

#periods_valid_forObject

{ "description" : "Number of subscription periods the coupon is valid for. Unused.", "verbs“: }



69
70
71
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 69

def periods_valid_for
  @periods_valid_for
end

#remaining_usesObject

{ "description" : "The number of remaining uses the coupon-instance has left.", "verbs“: }



75
76
77
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 75

def remaining_uses
  @remaining_uses
end

#targetObject

{ "description" : "Ttype of the target for the coupon-instance. Used in combination with the targetID.", "verbs“: }



66
67
68
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 66

def target
  @target
end

#target_idObject

{ "description" : "Target ID of the coupon-instance. If the target is subscription, this is the subscription’s ID. If the target is account, this is the account’s ID.", "verbs“: }



30
31
32
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 30

def target_id
  @target_id
end

#total_periodsObject

{ "description" : "Unused.", "verbs“: }



72
73
74
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 72

def total_periods
  @total_periods
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



48
49
50
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 48

def updated
  @updated
end

#valid_tillObject

{ "description" : "The UTC DateTime the coupon-instance is valid until.", "verbs“: }



39
40
41
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 39

def valid_till
  @valid_till
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 109

def self.attribute_map
  {
    :'target_id' => :'targetID',
    :'coupon_code' => :'couponCode',
    :'date_initialised' => :'dateInitialised',
    :'valid_till' => :'validTill',
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'id' => :'id',
    :'crm_id' => :'crmID',
    :'organization_id' => :'organizationID',
    :'book_id' => :'bookID',
    :'coupon_definition_id' => :'couponDefinitionID',
    :'target' => :'target',
    :'periods_valid_for' => :'periodsValidFor',
    :'total_periods' => :'totalPeriods',
    :'remaining_uses' => :'remainingUses',
    :'instance_discount_value' => :'instanceDiscountValue',
    :'max_remaining_uses' => :'maxRemainingUses',
    :'coupon_instance_existing_values' => :'couponInstanceExistingValues'
  }
end

.swagger_typesObject

Attribute type mapping.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 134

def self.swagger_types
  {
    :'target_id' => :'String',
    :'coupon_code' => :'String',
    :'date_initialised' => :'DateTime',
    :'valid_till' => :'DateTime',
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'id' => :'String',
    :'crm_id' => :'String',
    :'organization_id' => :'String',
    :'book_id' => :'String',
    :'coupon_definition_id' => :'String',
    :'target' => :'String',
    :'periods_valid_for' => :'Integer',
    :'total_periods' => :'Integer',
    :'remaining_uses' => :'Integer',
    :'instance_discount_value' => :'Float',
    :'max_remaining_uses' => :'Integer',
    :'coupon_instance_existing_values' => :'Array<CouponInstanceExistingValue>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 284

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      target_id == o.target_id &&
      coupon_code == o.coupon_code &&
      date_initialised == o.date_initialised &&
      valid_till == o.valid_till &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      id == o.id &&
      crm_id == o.crm_id &&
      organization_id == o.organization_id &&
      book_id == o.book_id &&
      coupon_definition_id == o.coupon_definition_id &&
      target == o.target &&
      periods_valid_for == o.periods_valid_for &&
      total_periods == o.total_periods &&
      remaining_uses == o.remaining_uses &&
      instance_discount_value == o.instance_discount_value &&
      max_remaining_uses == o.max_remaining_uses &&
      coupon_instance_existing_values == o.coupon_instance_existing_values
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 344

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = BillForward.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 410

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 323

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 310

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



316
317
318
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 316

def hash
  [target_id, coupon_code, date_initialised, valid_till, created, changed_by, updated, id, crm_id, organization_id, book_id, coupon_definition_id, target, periods_valid_for, total_periods, remaining_uses, instance_discount_value, max_remaining_uses, coupon_instance_existing_values].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



248
249
250
251
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 248

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



390
391
392
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 390

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



396
397
398
399
400
401
402
403
404
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 396

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



384
385
386
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 384

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/bf_ruby2/models/coupon_instance.rb', line 255

def valid?
  return false if @date_initialised.nil?
  return false if @crm_id.nil?
  return false if @organization_id.nil?
  return false if @book_id.nil?
  return false if @coupon_definition_id.nil?
  return false if @target.nil?
  target_validator = EnumAttributeValidator.new('String', ["none", "subscription", "account"])
  return false unless target_validator.valid?(@target)
  return false if @periods_valid_for.nil?
  return false if @total_periods.nil?
  return false if @remaining_uses.nil?
  return false if @max_remaining_uses.nil?
  return false if @coupon_instance_existing_values.nil?
  return true
end