Class: BillForward::CouponRule

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/coupon_rule.rb

Overview

A coupon-rule.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CouponRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 150

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'parentRuleID')
    self.parent_rule_id = attributes[:'parentRuleID']
  end

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'couponDefinitionID')
    self.coupon_definition_id = attributes[:'couponDefinitionID']
  end

  if attributes.has_key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.has_key?(:'polarity')
    self.polarity = attributes[:'polarity']
  end

  if attributes.has_key?(:'verb')
    self.verb = attributes[:'verb']
  end

  if attributes.has_key?(:'preposition')
    self.preposition = attributes[:'preposition']
  end

  if attributes.has_key?(:'parameter')
    self.parameter = attributes[:'parameter']
  end

  if attributes.has_key?(:'object')
    self.object = attributes[:'object']
  end

  if attributes.has_key?(:'ruleValidationStrategy')
    self.rule_validation_strategy = attributes[:'ruleValidationStrategy']
  end

  if attributes.has_key?(:'specifier')
    self.specifier = attributes[:'specifier']
  end

  if attributes.has_key?(:'deleted')
    self.deleted = attributes[:'deleted']
  else
    self.deleted = false
  end

  if attributes.has_key?(:'childRules')
    if (value = attributes[:'childRules']).is_a?(Array)
      self.child_rules = value
    end
  end

end

Instance Attribute Details

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 36

def changed_by
  @changed_by
end

#child_rulesObject

{ "description" : "The collection of child coupon-rules associated with the coupon-rule.", "verbs“: }



78
79
80
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 78

def child_rules
  @child_rules
end

#coupon_definition_idObject

{ "description" : "ID of the coupon-definition associated with the coupon-rule.", "verbs“: }



48
49
50
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 48

def coupon_definition_id
  @coupon_definition_id
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



33
34
35
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 33

def created
  @created
end

#deletedObject

{ "description" : "Has the coupon-modifier been deleted.", "verbs“: }



75
76
77
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 75

def deleted
  @deleted
end

#idObject

{ "description" : "ID of the coupon-rule.", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 42

def id
  @id
end

#objectObject

{ "description" : "The property of the subject of the coupon-rule. e.g. When the subject is ‘subscription’ and the object is ‘product-ID’, the coupon-rule will observe the product-ID for that subscription.", "verbs“: }



66
67
68
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 66

def object
  @object
end

#organization_idObject

{ "description" : "ID of the organization associated with the coupon-rule.", "verbs“: }



45
46
47
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 45

def organization_id
  @organization_id
end

#parameterObject

{ "description" : "The parameter for the coupon-rule. This specifies the ID or the quantity for the object of the subject.", "verbs“: }



63
64
65
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 63

def parameter
  @parameter
end

#parent_rule_idObject

{ "description" : "ID of the parent of this coupon-rule.", "verbs“: }



30
31
32
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 30

def parent_rule_id
  @parent_rule_id
end

#polarityObject

{ "description" : "Specifies whether the rule’s result will affect the application of the coupon-instance positively or negatively.", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 54

def polarity
  @polarity
end

#prepositionObject

{ "description" : "This is the comparison operator of the coupon-rule’s parameter and the subject’s object.", "verbs“: }



60
61
62
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 60

def preposition
  @preposition
end

#rule_validation_strategyObject

{ "description" : "The rule-validation-strategy object associated with the coupon-rule.", "verbs“: }



69
70
71
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 69

def rule_validation_strategy
  @rule_validation_strategy
end

#specifierObject

{ "description" : "When the subject is subscription, the specifier is used to define which unit of measure the coupon rule will operate on. When the subject is user, the specifier defines which property of the user’s account it will operate on.", "verbs“: }



72
73
74
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 72

def specifier
  @specifier
end

#subjectObject

{ "description" : "The subject of the coupon-rule. The coupon-rule can operate on either the user or subscription that the coupon-instance is associated with.", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 51

def subject
  @subject
end

#updatedObject

{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }



39
40
41
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 39

def updated
  @updated
end

#verbObject

{ "description" : "The verb of the coupon-rule. coupon-rules can check whether the user or subscription has a certain property.", "verbs“: }



57
58
59
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 57

def verb
  @verb
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 103

def self.attribute_map
  {
    :'parent_rule_id' => :'parentRuleID',
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'updated' => :'updated',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'coupon_definition_id' => :'couponDefinitionID',
    :'subject' => :'subject',
    :'polarity' => :'polarity',
    :'verb' => :'verb',
    :'preposition' => :'preposition',
    :'parameter' => :'parameter',
    :'object' => :'object',
    :'rule_validation_strategy' => :'ruleValidationStrategy',
    :'specifier' => :'specifier',
    :'deleted' => :'deleted',
    :'child_rules' => :'childRules'
  }
end

.swagger_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 126

def self.swagger_types
  {
    :'parent_rule_id' => :'String',
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'updated' => :'DateTime',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'coupon_definition_id' => :'String',
    :'subject' => :'String',
    :'polarity' => :'String',
    :'verb' => :'String',
    :'preposition' => :'String',
    :'parameter' => :'String',
    :'object' => :'String',
    :'rule_validation_strategy' => :'String',
    :'specifier' => :'String',
    :'deleted' => :'BOOLEAN',
    :'child_rules' => :'Array<CouponRule>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 330

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      parent_rule_id == o.parent_rule_id &&
      created == o.created &&
      changed_by == o.changed_by &&
      updated == o.updated &&
      id == o.id &&
      organization_id == o.organization_id &&
      coupon_definition_id == o.coupon_definition_id &&
      subject == o.subject &&
      polarity == o.polarity &&
      verb == o.verb &&
      preposition == o.preposition &&
      parameter == o.parameter &&
      object == o.object &&
      rule_validation_strategy == o.rule_validation_strategy &&
      specifier == o.specifier &&
      deleted == o.deleted &&
      child_rules == o.child_rules
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 388

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = BillForward.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 454

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 367

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


354
355
356
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 354

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



360
361
362
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 360

def hash
  [parent_rule_id, created, changed_by, updated, id, organization_id, coupon_definition_id, subject, polarity, verb, preposition, parameter, object, rule_validation_strategy, specifier, deleted, child_rules].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



232
233
234
235
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 232

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



434
435
436
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 434

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



440
441
442
443
444
445
446
447
448
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 440

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



428
429
430
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 428

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/bf_ruby2/models/coupon_rule.rb', line 239

def valid?
  return false if @parent_rule_id.nil?
  return false if @organization_id.nil?
  return false if @coupon_definition_id.nil?
  return false if @subject.nil?
  subject_validator = EnumAttributeValidator.new('String', ["user", "current_subscription", "child_rules"])
  return false unless subject_validator.valid?(@subject)
  return false if @polarity.nil?
  polarity_validator = EnumAttributeValidator.new('String', ["does", "does_not"])
  return false unless polarity_validator.valid?(@polarity)
  return false if @verb.nil?
  verb_validator = EnumAttributeValidator.new('String', ["have"])
  return false unless verb_validator.valid?(@verb)
  return false if @preposition.nil?
  preposition_validator = EnumAttributeValidator.new('String', ["less_than", "less_than_or_equal_to", "greater_than", "greater_than_or_equal_to", "equal_to"])
  return false unless preposition_validator.valid?(@preposition)
  return false if @parameter.nil?
  return false if @object.nil?
  object_validator = EnumAttributeValidator.new('String', ["subscription", "unit_of_measure", "satisfaction", "product_rate_plan_id", "product_id"])
  return false unless object_validator.valid?(@object)
  return false if @rule_validation_strategy.nil?
  rule_validation_strategy_validator = EnumAttributeValidator.new('String', ["only_at_initialisation", "while_recurring_or_initialisation", "only_while_recurring"])
  return false unless rule_validation_strategy_validator.valid?(@rule_validation_strategy)
  return false if @specifier.nil?
  return false if @deleted.nil?
  return false if @child_rules.nil?
  return true
end