Class: BillForward::CoupondefinitionApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/coupondefinition_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CoupondefinitionApi

Returns a new instance of CoupondefinitionApi.



30
31
32
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_coupon_definition(coupon_definition, opts = {}) ⇒ CouponDefinitionPagedMetadata

Create a coupon-definition. a new definition","request":"createCouponDefinitionRequest.html","response":"createCouponDefinitionResponse.html"

Parameters:

  • coupon_definition

    The coupon-definiton object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 39

def create_coupon_definition(coupon_definition, opts = {})
  data, _status_code, _headers = create_coupon_definition_with_http_info(coupon_definition, opts)
  return data
end

#create_coupon_definition_with_http_info(coupon_definition, opts = {}) ⇒ Array<(CouponDefinitionPagedMetadata, Fixnum, Hash)>

Create a coupon-definition. a new definition&quot;,&quot;request&quot;:&quot;createCouponDefinitionRequest.html&quot;,&quot;response&quot;:&quot;createCouponDefinitionResponse.html&quot;

Parameters:

  • coupon_definition

    The coupon-definiton object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 49

def create_coupon_definition_with_http_info(coupon_definition, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CoupondefinitionApi.create_coupon_definition ..."
  end
  # verify the required parameter 'coupon_definition' is set
  fail ArgumentError, "Missing the required parameter 'coupon_definition' when calling CoupondefinitionApi.create_coupon_definition" if coupon_definition.nil?
  # resource path
  local_var_path = "/coupon-definitions".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(coupon_definition)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponDefinitionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CoupondefinitionApi#create_coupon_definition\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_coupon_definition(coupon_definition_id, opts = {}) ⇒ CouponDefinitionPagedMetadata

Retire a coupon-definition, specified by the coupon-definition-ID parameter. a definition","response":"deleteCouponDefinitionByID.html"

Parameters:

  • coupon_definition_id

    ID of the coupon-definition.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



97
98
99
100
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 97

def delete_coupon_definition(coupon_definition_id, opts = {})
  data, _status_code, _headers = delete_coupon_definition_with_http_info(coupon_definition_id, opts)
  return data
end

#delete_coupon_definition_with_http_info(coupon_definition_id, opts = {}) ⇒ Array<(CouponDefinitionPagedMetadata, Fixnum, Hash)>

Retire a coupon-definition, specified by the coupon-definition-ID parameter. a definition&quot;,&quot;response&quot;:&quot;deleteCouponDefinitionByID.html&quot;

Parameters:

  • coupon_definition_id

    ID of the coupon-definition.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 108

def delete_coupon_definition_with_http_info(coupon_definition_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CoupondefinitionApi.delete_coupon_definition ..."
  end
  # verify the required parameter 'coupon_definition_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_definition_id' when calling CoupondefinitionApi.delete_coupon_definition" if coupon_definition_id.nil?
  # resource path
  local_var_path = "/coupon-definitions/{coupon-definition-ID}".sub('{format}','json').sub('{' + 'coupon-definition-ID' + '}', coupon_definition_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponDefinitionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CoupondefinitionApi#delete_coupon_definition\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_coupon_definitions(opts = {}) ⇒ CouponDefinitionPagedMetadata

Returns a collection of coupon-definitions. By default 10 values are returned. Records are returned in natural order. all coupon definitions","response":"getCouponDefinitionAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first product-rate-plan to return. (default to 0)

  • :records (Integer)

    The maximum number of product-rate-plans to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired coupon-definitions should be returned. (default to true)

Returns:



161
162
163
164
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 161

def get_all_coupon_definitions(opts = {})
  data, _status_code, _headers = get_all_coupon_definitions_with_http_info(opts)
  return data
end

#get_all_coupon_definitions_with_http_info(opts = {}) ⇒ Array<(CouponDefinitionPagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-definitions. By default 10 values are returned. Records are returned in natural order. all coupon definitions&quot;,&quot;response&quot;:&quot;getCouponDefinitionAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first product-rate-plan to return.

  • :records (Integer)

    The maximum number of product-rate-plans to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired coupon-definitions should be returned.

Returns:



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 176

def get_all_coupon_definitions_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CoupondefinitionApi.get_all_coupon_definitions ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-definitions".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponDefinitionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CoupondefinitionApi#get_all_coupon_definitions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_definition_by_id(coupon_definition_id, opts = {}) ⇒ CouponDefinitionPagedMetadata

Returns a single coupon-definition, specified by the coupon-definition-ID parameter. existing coupon definition","response":"getCouponDefinitionByID.html"

Parameters:

  • coupon_definition_id

    ID of the coupon-definition.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



231
232
233
234
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 231

def get_coupon_definition_by_id(coupon_definition_id, opts = {})
  data, _status_code, _headers = get_coupon_definition_by_id_with_http_info(coupon_definition_id, opts)
  return data
end

#get_coupon_definition_by_id_with_http_info(coupon_definition_id, opts = {}) ⇒ Array<(CouponDefinitionPagedMetadata, Fixnum, Hash)>

Returns a single coupon-definition, specified by the coupon-definition-ID parameter. existing coupon definition&quot;,&quot;response&quot;:&quot;getCouponDefinitionByID.html&quot;

Parameters:

  • coupon_definition_id

    ID of the coupon-definition.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 242

def get_coupon_definition_by_id_with_http_info(coupon_definition_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CoupondefinitionApi.get_coupon_definition_by_id ..."
  end
  # verify the required parameter 'coupon_definition_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_definition_id' when calling CoupondefinitionApi.get_coupon_definition_by_id" if coupon_definition_id.nil?
  # resource path
  local_var_path = "/coupon-definitions/{coupon-definition-ID}".sub('{format}','json').sub('{' + 'coupon-definition-ID' + '}', coupon_definition_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponDefinitionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CoupondefinitionApi#get_coupon_definition_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_coupon_definition(coupon_definition, opts = {}) ⇒ CouponDefinitionPagedMetadata

Update a coupon-definition. a definition","request":"updateCouponDefinitionRequest.html","response":"updateCouponDefinitionResponse.html"

Parameters:

  • coupon_definition

    The coupon-definition object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



290
291
292
293
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 290

def update_coupon_definition(coupon_definition, opts = {})
  data, _status_code, _headers = update_coupon_definition_with_http_info(coupon_definition, opts)
  return data
end

#update_coupon_definition_with_http_info(coupon_definition, opts = {}) ⇒ Array<(CouponDefinitionPagedMetadata, Fixnum, Hash)>

Update a coupon-definition. a definition&quot;,&quot;request&quot;:&quot;updateCouponDefinitionRequest.html&quot;,&quot;response&quot;:&quot;updateCouponDefinitionResponse.html&quot;

Parameters:

  • coupon_definition

    The coupon-definition object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/bf_ruby2/api/coupondefinition_api.rb', line 300

def update_coupon_definition_with_http_info(coupon_definition, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CoupondefinitionApi.update_coupon_definition ..."
  end
  # verify the required parameter 'coupon_definition' is set
  fail ArgumentError, "Missing the required parameter 'coupon_definition' when calling CoupondefinitionApi.update_coupon_definition" if coupon_definition.nil?
  # resource path
  local_var_path = "/coupon-definitions".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(coupon_definition)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponDefinitionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CoupondefinitionApi#update_coupon_definition\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end