Class: BillForward::CouponruleApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/couponrule_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CouponruleApi

Returns a new instance of CouponruleApi.



30
31
32
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_coupon_rule(coupon_rule, opts = {}) ⇒ CouponRulePagedMetadata

Create a coupon-rule. {"nickname":"Create a new rule", "request" : "createCouponRuleRequest.html" ,"response" : "createCouponRuleResponse.html" }

Parameters:

  • coupon_rule

    The coupon-rule object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 39

def create_coupon_rule(coupon_rule, opts = {})
  data, _status_code, _headers = create_coupon_rule_with_http_info(coupon_rule, opts)
  return data
end

#create_coupon_rule_with_http_info(coupon_rule, opts = {}) ⇒ Array<(CouponRulePagedMetadata, Fixnum, Hash)>

Create a coupon-rule. {&quot;nickname&quot;:&quot;Create a new rule&quot;, &quot;request&quot; : &quot;createCouponRuleRequest.html&quot; ,&quot;response&quot; : &quot;createCouponRuleResponse.html&quot; }

Parameters:

  • coupon_rule

    The coupon-rule object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CouponRulePagedMetadata, Fixnum, Hash)>)

    CouponRulePagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 49

def create_coupon_rule_with_http_info(coupon_rule, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponruleApi.create_coupon_rule ..."
  end
  # verify the required parameter 'coupon_rule' is set
  fail ArgumentError, "Missing the required parameter 'coupon_rule' when calling CouponruleApi.create_coupon_rule" if coupon_rule.nil?
  # resource path
  local_var_path = "/coupon-rules".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(coupon_rule)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponRulePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponruleApi#create_coupon_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_coupon_rule(coupon_rule_id, opts = {}) ⇒ CouponRulePagedMetadata

Retire a coupon-rule, specified by the coupon-rule-ID parameter. a rule","response" : "deleteCouponRuleByID.html"

Parameters:

  • coupon_rule_id

    ID of the coupon-rule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



97
98
99
100
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 97

def delete_coupon_rule(coupon_rule_id, opts = {})
  data, _status_code, _headers = delete_coupon_rule_with_http_info(coupon_rule_id, opts)
  return data
end

#delete_coupon_rule_with_http_info(coupon_rule_id, opts = {}) ⇒ Array<(CouponRulePagedMetadata, Fixnum, Hash)>

Retire a coupon-rule, specified by the coupon-rule-ID parameter. a rule&quot;,&quot;response&quot; : &quot;deleteCouponRuleByID.html&quot;

Parameters:

  • coupon_rule_id

    ID of the coupon-rule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(CouponRulePagedMetadata, Fixnum, Hash)>)

    CouponRulePagedMetadata data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 108

def delete_coupon_rule_with_http_info(coupon_rule_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponruleApi.delete_coupon_rule ..."
  end
  # verify the required parameter 'coupon_rule_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_rule_id' when calling CouponruleApi.delete_coupon_rule" if coupon_rule_id.nil?
  # resource path
  local_var_path = "/coupon-rules/{coupon-rule-ID}".sub('{format}','json').sub('{' + 'coupon-rule-ID' + '}', coupon_rule_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponRulePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponruleApi#delete_coupon_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_coupon_rules(opts = {}) ⇒ CouponRulePagedMetadata

Returns a collection of coupon-rules. By default 10 values are returned. Records are returned in natural order. all rules","response" : "getCouponRuleAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first product-rate-plan to return. (default to 0)

  • :records (Integer)

    The maximum number of product-rate-plans to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



160
161
162
163
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 160

def get_all_coupon_rules(opts = {})
  data, _status_code, _headers = get_all_coupon_rules_with_http_info(opts)
  return data
end

#get_all_coupon_rules_with_http_info(opts = {}) ⇒ Array<(CouponRulePagedMetadata, Fixnum, Hash)>

Returns a collection of coupon-rules. By default 10 values are returned. Records are returned in natural order. all rules&quot;,&quot;response&quot; : &quot;getCouponRuleAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first product-rate-plan to return.

  • :records (Integer)

    The maximum number of product-rate-plans to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:

  • (Array<(CouponRulePagedMetadata, Fixnum, Hash)>)

    CouponRulePagedMetadata data, response status code and response headers



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 174

def get_all_coupon_rules_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponruleApi.get_all_coupon_rules ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/coupon-rules".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponRulePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponruleApi#get_all_coupon_rules\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_rule_by_coupon_definition_id(coupon_definition_id, opts = {}) ⇒ CouponRulePagedMetadata

Returns a single coupon-definition, specified by the coupon-definition-ID parameter. by coupon definition","response" : "getCouponRuleByCouponDefinitionID.html"

Parameters:

  • coupon_definition_id

    ID of the coupon-definition.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



228
229
230
231
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 228

def get_coupon_rule_by_coupon_definition_id(coupon_definition_id, opts = {})
  data, _status_code, _headers = get_coupon_rule_by_coupon_definition_id_with_http_info(coupon_definition_id, opts)
  return data
end

#get_coupon_rule_by_coupon_definition_id_with_http_info(coupon_definition_id, opts = {}) ⇒ Array<(CouponRulePagedMetadata, Fixnum, Hash)>

Returns a single coupon-definition, specified by the coupon-definition-ID parameter. by coupon definition&quot;,&quot;response&quot; : &quot;getCouponRuleByCouponDefinitionID.html&quot;

Parameters:

  • coupon_definition_id

    ID of the coupon-definition.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(CouponRulePagedMetadata, Fixnum, Hash)>)

    CouponRulePagedMetadata data, response status code and response headers



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 239

def get_coupon_rule_by_coupon_definition_id_with_http_info(coupon_definition_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponruleApi.get_coupon_rule_by_coupon_definition_id ..."
  end
  # verify the required parameter 'coupon_definition_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_definition_id' when calling CouponruleApi.get_coupon_rule_by_coupon_definition_id" if coupon_definition_id.nil?
  # resource path
  local_var_path = "/coupon-rules/coupon-definition/{coupon-definition-ID}".sub('{format}','json').sub('{' + 'coupon-definition-ID' + '}', coupon_definition_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponRulePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponruleApi#get_coupon_rule_by_coupon_definition_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_rule_by_id(coupon_rule_id, opts = {}) ⇒ CouponRulePagedMetadata

Returns a single coupon-rule, specified by the coupon-rule-ID parameter. an existing rule","response" : "getCouponRuleByID.html"

Parameters:

  • coupon_rule_id

    ID of the coupon-rule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



288
289
290
291
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 288

def get_coupon_rule_by_id(coupon_rule_id, opts = {})
  data, _status_code, _headers = get_coupon_rule_by_id_with_http_info(coupon_rule_id, opts)
  return data
end

#get_coupon_rule_by_id_with_http_info(coupon_rule_id, opts = {}) ⇒ Array<(CouponRulePagedMetadata, Fixnum, Hash)>

Returns a single coupon-rule, specified by the coupon-rule-ID parameter. an existing rule&quot;,&quot;response&quot; : &quot;getCouponRuleByID.html&quot;

Parameters:

  • coupon_rule_id

    ID of the coupon-rule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(CouponRulePagedMetadata, Fixnum, Hash)>)

    CouponRulePagedMetadata data, response status code and response headers



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/bf_ruby2/api/couponrule_api.rb', line 299

def get_coupon_rule_by_id_with_http_info(coupon_rule_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: CouponruleApi.get_coupon_rule_by_id ..."
  end
  # verify the required parameter 'coupon_rule_id' is set
  fail ArgumentError, "Missing the required parameter 'coupon_rule_id' when calling CouponruleApi.get_coupon_rule_by_id" if coupon_rule_id.nil?
  # resource path
  local_var_path = "/coupon-rules/{coupon-rule-ID}".sub('{format}','json').sub('{' + 'coupon-rule-ID' + '}', coupon_rule_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'CouponRulePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CouponruleApi#get_coupon_rule_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end