Class: BillForward::DunninglinesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/dunninglines_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DunninglinesApi

Returns a new instance of DunninglinesApi.



30
31
32
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_dunning_line(dunning_line, opts = {}) ⇒ DunningLinePagedMetadata

Create a dunning-line. a new dunning line","request":"createDunningLineRequest.html","response":"createDunningLineResponse.html"

Parameters:

  • dunning_line

    The Dunning-Line object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 39

def create_dunning_line(dunning_line, opts = {})
  data, _status_code, _headers = create_dunning_line_with_http_info(dunning_line, opts)
  return data
end

#create_dunning_line_with_http_info(dunning_line, opts = {}) ⇒ Array<(DunningLinePagedMetadata, Fixnum, Hash)>

Create a dunning-line. a new dunning line&quot;,&quot;request&quot;:&quot;createDunningLineRequest.html&quot;,&quot;response&quot;:&quot;createDunningLineResponse.html&quot;

Parameters:

  • dunning_line

    The Dunning-Line object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DunningLinePagedMetadata, Fixnum, Hash)>)

    DunningLinePagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 49

def create_dunning_line_with_http_info(dunning_line, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: DunninglinesApi.create_dunning_line ..."
  end
  # verify the required parameter 'dunning_line' is set
  fail ArgumentError, "Missing the required parameter 'dunning_line' when calling DunninglinesApi.create_dunning_line" if dunning_line.nil?
  # resource path
  local_var_path = "/dunning-lines".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(dunning_line)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'DunningLinePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DunninglinesApi#create_dunning_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_dunning_lines(opts = {}) ⇒ DunningLinePagedMetadata

Returns a collection of all dunning-lines. By default 10 values are returned. Records are returned in natural order. all dunning lines","response":"getDunningLineByID.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first invoice to return. (default to 0)

  • :records (Integer)

    The maximum number of invoices to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 101

def get_all_dunning_lines(opts = {})
  data, _status_code, _headers = get_all_dunning_lines_with_http_info(opts)
  return data
end

#get_all_dunning_lines_with_http_info(opts = {}) ⇒ Array<(DunningLinePagedMetadata, Fixnum, Hash)>

Returns a collection of all dunning-lines. By default 10 values are returned. Records are returned in natural order. all dunning lines&quot;,&quot;response&quot;:&quot;getDunningLineByID.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first invoice to return.

  • :records (Integer)

    The maximum number of invoices to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(DunningLinePagedMetadata, Fixnum, Hash)>)

    DunningLinePagedMetadata data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 116

def get_all_dunning_lines_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: DunninglinesApi.get_all_dunning_lines ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/dunning-lines".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'DunningLinePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DunninglinesApi#get_all_dunning_lines\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_dunning_line_by_attempt_index(index, opts = {}) ⇒ DunningLinePagedMetadata

Returns a collection of dunning-lines specified by the index parameter. By default 10 values are returned. Records are returned in natural order. by attempt","response":"getDunningLineByID.html"

Parameters:

  • index

    The attempt index of the dunning-line.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first invoice to return. (default to 0)

  • :records (Integer)

    The maximum number of invoices to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



176
177
178
179
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 176

def get_dunning_line_by_attempt_index(index, opts = {})
  data, _status_code, _headers = get_dunning_line_by_attempt_index_with_http_info(index, opts)
  return data
end

#get_dunning_line_by_attempt_index_with_http_info(index, opts = {}) ⇒ Array<(DunningLinePagedMetadata, Fixnum, Hash)>

Returns a collection of dunning-lines specified by the index parameter. By default 10 values are returned. Records are returned in natural order. by attempt&quot;,&quot;response&quot;:&quot;getDunningLineByID.html&quot;

Parameters:

  • index

    The attempt index of the dunning-line.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first invoice to return.

  • :records (Integer)

    The maximum number of invoices to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(DunningLinePagedMetadata, Fixnum, Hash)>)

    DunningLinePagedMetadata data, response status code and response headers



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 192

def get_dunning_line_by_attempt_index_with_http_info(index, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: DunninglinesApi.get_dunning_line_by_attempt_index ..."
  end
  # verify the required parameter 'index' is set
  fail ArgumentError, "Missing the required parameter 'index' when calling DunninglinesApi.get_dunning_line_by_attempt_index" if index.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/dunning-lines/attempt-index/{index}".sub('{format}','json').sub('{' + 'index' + '}', index.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'DunningLinePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DunninglinesApi#get_dunning_line_by_attempt_index\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_dunning_line_by_id(dunning_line_id, opts = {}) ⇒ DunningLinePagedMetadata

Returns a single dunning-line, specified by the dunning-line-ID parameter. an existing dunning line","response":"getDunningLineByID.html"

Parameters:

  • dunning_line_id

    ID of the dunning-line.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



249
250
251
252
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 249

def get_dunning_line_by_id(dunning_line_id, opts = {})
  data, _status_code, _headers = get_dunning_line_by_id_with_http_info(dunning_line_id, opts)
  return data
end

#get_dunning_line_by_id_with_http_info(dunning_line_id, opts = {}) ⇒ Array<(DunningLinePagedMetadata, Fixnum, Hash)>

Returns a single dunning-line, specified by the dunning-line-ID parameter. an existing dunning line&quot;,&quot;response&quot;:&quot;getDunningLineByID.html&quot;

Parameters:

  • dunning_line_id

    ID of the dunning-line.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(DunningLinePagedMetadata, Fixnum, Hash)>)

    DunningLinePagedMetadata data, response status code and response headers



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 260

def get_dunning_line_by_id_with_http_info(dunning_line_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: DunninglinesApi.get_dunning_line_by_id ..."
  end
  # verify the required parameter 'dunning_line_id' is set
  fail ArgumentError, "Missing the required parameter 'dunning_line_id' when calling DunninglinesApi.get_dunning_line_by_id" if dunning_line_id.nil?
  # resource path
  local_var_path = "/dunning-lines/{dunning-line-ID}".sub('{format}','json').sub('{' + 'dunning-line-ID' + '}', dunning_line_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8', 'text/xml']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'DunningLinePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DunninglinesApi#get_dunning_line_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retire_dunning_line(dunning_line_id, organizations, opts = {}) ⇒ DunningLinePagedMetadata

Retires the specified dunning-line. a dunning line","response":"deleteDunningLine.html"

Parameters:

  • dunning_line_id

    ID of the dunning-line.

  • organizations

    A list of organization-IDs used to restrict the scope of API calls.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



309
310
311
312
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 309

def retire_dunning_line(dunning_line_id, organizations, opts = {})
  data, _status_code, _headers = retire_dunning_line_with_http_info(dunning_line_id, organizations, opts)
  return data
end

#retire_dunning_line_with_http_info(dunning_line_id, organizations, opts = {}) ⇒ Array<(DunningLinePagedMetadata, Fixnum, Hash)>

Retires the specified dunning-line. a dunning line&quot;,&quot;response&quot;:&quot;deleteDunningLine.html&quot;

Parameters:

  • dunning_line_id

    ID of the dunning-line.

  • organizations

    A list of organization-IDs used to restrict the scope of API calls.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DunningLinePagedMetadata, Fixnum, Hash)>)

    DunningLinePagedMetadata data, response status code and response headers



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 320

def retire_dunning_line_with_http_info(dunning_line_id, organizations, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: DunninglinesApi.retire_dunning_line ..."
  end
  # verify the required parameter 'dunning_line_id' is set
  fail ArgumentError, "Missing the required parameter 'dunning_line_id' when calling DunninglinesApi.retire_dunning_line" if dunning_line_id.nil?
  # verify the required parameter 'organizations' is set
  fail ArgumentError, "Missing the required parameter 'organizations' when calling DunninglinesApi.retire_dunning_line" if organizations.nil?
  # resource path
  local_var_path = "/dunning-lines/{dunning-line-ID}".sub('{format}','json').sub('{' + 'dunning-line-ID' + '}', dunning_line_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(organizations, :multi)

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'DunningLinePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DunninglinesApi#retire_dunning_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_dunning_line(dunning_line, opts = {}) ⇒ DunningLinePagedMetadata

Update a dunning-line. a dunning line","request":"updateDunningLineRequest.html","response":"updateDunningLineResponse.html"

Parameters:

  • dunning_line

    The Dunning-Line object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



370
371
372
373
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 370

def update_dunning_line(dunning_line, opts = {})
  data, _status_code, _headers = update_dunning_line_with_http_info(dunning_line, opts)
  return data
end

#update_dunning_line_with_http_info(dunning_line, opts = {}) ⇒ Array<(DunningLinePagedMetadata, Fixnum, Hash)>

Update a dunning-line. a dunning line&quot;,&quot;request&quot;:&quot;updateDunningLineRequest.html&quot;,&quot;response&quot;:&quot;updateDunningLineResponse.html&quot;

Parameters:

  • dunning_line

    The Dunning-Line object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DunningLinePagedMetadata, Fixnum, Hash)>)

    DunningLinePagedMetadata data, response status code and response headers



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/bf_ruby2/api/dunninglines_api.rb', line 380

def update_dunning_line_with_http_info(dunning_line, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: DunninglinesApi.update_dunning_line ..."
  end
  # verify the required parameter 'dunning_line' is set
  fail ArgumentError, "Missing the required parameter 'dunning_line' when calling DunninglinesApi.update_dunning_line" if dunning_line.nil?
  # resource path
  local_var_path = "/dunning-lines".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(dunning_line)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'DunningLinePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DunninglinesApi#update_dunning_line\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end