Class: BillForward::PaymentmethodsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/paymentmethods_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PaymentmethodsApi

Returns a new instance of PaymentmethodsApi.



30
31
32
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_payment_method(payment_method, opts = {}) ⇒ PaymentMethodPagedMetadata

Create a payment-method. a new payment method","request":"createPaymentMethodRequest.html","response":"createPaymentMethodResponse.html"

Parameters:

  • payment_method

    The payment-method object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 39

def create_payment_method(payment_method, opts = {})
  data, _status_code, _headers = create_payment_method_with_http_info(payment_method, opts)
  return data
end

#create_payment_method_with_http_info(payment_method, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Create a payment-method. a new payment method&quot;,&quot;request&quot;:&quot;createPaymentMethodRequest.html&quot;,&quot;response&quot;:&quot;createPaymentMethodResponse.html&quot;

Parameters:

  • payment_method

    The payment-method object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 49

def create_payment_method_with_http_info(payment_method, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.create_payment_method ..."
  end
  # verify the required parameter 'payment_method' is set
  fail ArgumentError, "Missing the required parameter 'payment_method' when calling PaymentmethodsApi.create_payment_method" if payment_method.nil?
  # resource path
  local_var_path = "/payment-methods".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(payment_method)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#create_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_payment_method(payment_method_id, opts = {}) ⇒ PaymentMethodPagedMetadata

Deletes the payment-method specified by the payment-method-ID parameter. payment method","response":"deletePaymentMethod.html"

Parameters:

  • payment_method_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



97
98
99
100
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 97

def delete_payment_method(payment_method_id, opts = {})
  data, _status_code, _headers = delete_payment_method_with_http_info(payment_method_id, opts)
  return data
end

#delete_payment_method_with_http_info(payment_method_id, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Deletes the payment-method specified by the payment-method-ID parameter. payment method&quot;,&quot;response&quot;:&quot;deletePaymentMethod.html&quot;

Parameters:

  • payment_method_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 108

def delete_payment_method_with_http_info(payment_method_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.delete_payment_method ..."
  end
  # verify the required parameter 'payment_method_id' is set
  fail ArgumentError, "Missing the required parameter 'payment_method_id' when calling PaymentmethodsApi.delete_payment_method" if payment_method_id.nil?
  # resource path
  local_var_path = "/payment-methods/{payment-method-ID}".sub('{format}','json').sub('{' + 'payment-method-ID' + '}', payment_method_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#delete_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_payment_methods(opts = {}) ⇒ PaymentMethodPagedMetadata

Returns a collection of all payment-methods. By default 10 values are returned. Records are returned in natural order. all payment methods","response":"getPaymentMethodAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment-method to return. (default to 0)

  • :records (Integer)

    The maximum number of payment-methods to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



161
162
163
164
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 161

def get_all_payment_methods(opts = {})
  data, _status_code, _headers = get_all_payment_methods_with_http_info(opts)
  return data
end

#get_all_payment_methods_with_http_info(opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Returns a collection of all payment-methods. By default 10 values are returned. Records are returned in natural order. all payment methods&quot;,&quot;response&quot;:&quot;getPaymentMethodAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment-method to return.

  • :records (Integer)

    The maximum number of payment-methods to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 176

def get_all_payment_methods_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.get_all_payment_methods ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/payment-methods".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#get_all_payment_methods\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_payment_method_by_account_id(account_id, opts = {}) ⇒ PaymentMethodPagedMetadata

Returns a collection of payment-methods, specified by the account-ID parameter. By default 10 values are returned. Records are returned in natural order. by account","response":"getPaymentMethodByAccount.html"

Parameters:

  • account_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment-method to return. (default to 0)

  • :records (Integer)

    The maximum number of payment-methods to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

  • :default_only (BOOLEAN)

    Whether only the defualt payment method should be returned. (default to false)

Returns:



237
238
239
240
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 237

def (, opts = {})
  data, _status_code, _headers = (, opts)
  return data
end

#get_payment_method_by_account_id_with_http_info(account_id, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Returns a collection of payment-methods, specified by the account-ID parameter. By default 10 values are returned. Records are returned in natural order. by account&quot;,&quot;response&quot;:&quot;getPaymentMethodByAccount.html&quot;

Parameters:

  • account_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment-method to return.

  • :records (Integer)

    The maximum number of payment-methods to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

  • :default_only (BOOLEAN)

    Whether only the defualt payment method should be returned.

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 254

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.get_payment_method_by_account_id ..."
  end
  # verify the required parameter 'account_id' is set
  fail ArgumentError, "Missing the required parameter 'account_id' when calling PaymentmethodsApi.get_payment_method_by_account_id" if .nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/payment-methods/account/{account-ID}".sub('{format}','json').sub('{' + 'account-ID' + '}', .to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?
  query_params[:'default_only'] = opts[:'default_only'] if !opts[:'default_only'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#get_payment_method_by_account_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_payment_method_by_id(payment_method_id, opts = {}) ⇒ PaymentMethodPagedMetadata

Returns a single payment-method, specified by the payment-method-ID parameter. existing payment method","response":"getPaymentMethodByID.html"

Parameters:

  • payment_method_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



312
313
314
315
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 312

def get_payment_method_by_id(payment_method_id, opts = {})
  data, _status_code, _headers = get_payment_method_by_id_with_http_info(payment_method_id, opts)
  return data
end

#get_payment_method_by_id_with_http_info(payment_method_id, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Returns a single payment-method, specified by the payment-method-ID parameter. existing payment method&quot;,&quot;response&quot;:&quot;getPaymentMethodByID.html&quot;

Parameters:

  • payment_method_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 323

def get_payment_method_by_id_with_http_info(payment_method_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.get_payment_method_by_id ..."
  end
  # verify the required parameter 'payment_method_id' is set
  fail ArgumentError, "Missing the required parameter 'payment_method_id' when calling PaymentmethodsApi.get_payment_method_by_id" if payment_method_id.nil?
  # resource path
  local_var_path = "/payment-methods/{payment-method-ID}".sub('{format}','json').sub('{' + 'payment-method-ID' + '}', payment_method_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#get_payment_method_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Returns a single payment-method, specified by the linkID parameter. by subscription link","response":"getPaymentMethodByLinkID.html"

Parameters:

  • link_id

    The link-id of the payment-method.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



372
373
374
375
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 372

def get_payment_method_by_link_id(link_id, opts = {})
  data, _status_code, _headers = get_payment_method_by_link_id_with_http_info(link_id, opts)
  return data
end

Returns a single payment-method, specified by the linkID parameter. by subscription link&quot;,&quot;response&quot;:&quot;getPaymentMethodByLinkID.html&quot;

Parameters:

  • link_id

    The link-id of the payment-method.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 383

def get_payment_method_by_link_id_with_http_info(link_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.get_payment_method_by_link_id ..."
  end
  # verify the required parameter 'link_id' is set
  fail ArgumentError, "Missing the required parameter 'link_id' when calling PaymentmethodsApi.get_payment_method_by_link_id" if link_id.nil?
  # resource path
  local_var_path = "/payment-methods/link-id/{linkID}".sub('{format}','json').sub('{' + 'linkID' + '}', link_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#get_payment_method_by_link_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_payment_method_by_payment_gateway(gateway, opts = {}) ⇒ PaymentMethodPagedMetadata

Returns a collection of payment-methods, specified by the gateway parameter. By default 10 values are returned. Records are returned in natural order. by gateway","response":"getPaymentMethodByGateway.html"

Parameters:

  • gateway

    The payment-method gateway which generated the payment-method.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment-method to return. (default to 0)

  • :records (Integer)

    The maximum number of payment-methods to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to id)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



437
438
439
440
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 437

def get_payment_method_by_payment_gateway(gateway, opts = {})
  data, _status_code, _headers = get_payment_method_by_payment_gateway_with_http_info(gateway, opts)
  return data
end

#get_payment_method_by_payment_gateway_with_http_info(gateway, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Returns a collection of payment-methods, specified by the gateway parameter. By default 10 values are returned. Records are returned in natural order. by gateway&quot;,&quot;response&quot;:&quot;getPaymentMethodByGateway.html&quot;

Parameters:

  • gateway

    The payment-method gateway which generated the payment-method.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first payment-method to return.

  • :records (Integer)

    The maximum number of payment-methods to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 453

def get_payment_method_by_payment_gateway_with_http_info(gateway, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.get_payment_method_by_payment_gateway ..."
  end
  # verify the required parameter 'gateway' is set
  fail ArgumentError, "Missing the required parameter 'gateway' when calling PaymentmethodsApi.get_payment_method_by_payment_gateway" if gateway.nil?
  # verify enum value
  unless ['cybersource_token', 'card_vault', 'paypal_simple', 'locustworld', 'free', 'coupon', 'credit_note', 'stripe', 'braintree', 'balanced', 'paypal', 'billforward_test', 'offline', 'trial', 'stripeACH', 'authorizeNet', 'spreedly', 'sagePay', 'trustCommerce', 'payvision', 'kash'].include?(gateway)
    fail ArgumentError, "invalid value for 'gateway', must be one of cybersource_token, card_vault, paypal_simple, locustworld, free, coupon, credit_note, stripe, braintree, balanced, paypal, billforward_test, offline, trial, stripeACH, authorizeNet, spreedly, sagePay, trustCommerce, payvision, kash"
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/payment-methods/gateway/{gateway}".sub('{format}','json').sub('{' + 'gateway' + '}', gateway.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#get_payment_method_by_payment_gateway\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_payment_method(payment_method, opts = {}) ⇒ PaymentMethodPagedMetadata

Update a payment-method. a payment-method","request":"updatePaymentMethodRequest.html","response":"updatePaymentMethodResponse.html"

Parameters:

  • payment_method

    The payment-method object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



513
514
515
516
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 513

def update_payment_method(payment_method, opts = {})
  data, _status_code, _headers = update_payment_method_with_http_info(payment_method, opts)
  return data
end

#update_payment_method_with_http_info(payment_method, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>

Update a payment-method. a payment-method&quot;,&quot;request&quot;:&quot;updatePaymentMethodRequest.html&quot;,&quot;response&quot;:&quot;updatePaymentMethodResponse.html&quot;

Parameters:

  • payment_method

    The payment-method object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>)

    PaymentMethodPagedMetadata data, response status code and response headers



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
# File 'lib/bf_ruby2/api/paymentmethods_api.rb', line 523

def update_payment_method_with_http_info(payment_method, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PaymentmethodsApi.update_payment_method ..."
  end
  # verify the required parameter 'payment_method' is set
  fail ArgumentError, "Missing the required parameter 'payment_method' when calling PaymentmethodsApi.update_payment_method" if payment_method.nil?
  # resource path
  local_var_path = "/payment-methods".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(payment_method)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PaymentMethodPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PaymentmethodsApi#update_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end