Class: BillForward::PermissionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/permissions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PermissionsApi

Returns a new instance of PermissionsApi.



30
31
32
# File 'lib/bf_ruby2/api/permissions_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/permissions_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_permission(permission_request, opts = {}) ⇒ BFPermissionPagedMetadata

Create a new permission. a new permission","request":"createPermissionRequest.html","response":"createPermissionResponse.html"

Parameters:

  • permission_request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/permissions_api.rb', line 39

def create_permission(permission_request, opts = {})
  data, _status_code, _headers = create_permission_with_http_info(permission_request, opts)
  return data
end

#create_permission_with_http_info(permission_request, opts = {}) ⇒ Array<(BFPermissionPagedMetadata, Fixnum, Hash)>

Create a new permission. a new permission&quot;,&quot;request&quot;:&quot;createPermissionRequest.html&quot;,&quot;response&quot;:&quot;createPermissionResponse.html&quot;

Parameters:

  • permission_request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BFPermissionPagedMetadata, Fixnum, Hash)>)

    BFPermissionPagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/permissions_api.rb', line 49

def create_permission_with_http_info(permission_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PermissionsApi.create_permission ..."
  end
  # verify the required parameter 'permission_request' is set
  fail ArgumentError, "Missing the required parameter 'permission_request' when calling PermissionsApi.create_permission" if permission_request.nil?
  # resource path
  local_var_path = "/permissions".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(permission_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BFPermissionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PermissionsApi#create_permission\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_permissions(opts = {}) ⇒ BFPermissionPagedMetadata

Retrieves a collection of all permissions. By default 10 values are returned. Records are returned in natural order. all permissions","response":"getPermissionAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return. (default to 0)

  • :records (Integer)

    The maximum number of subscriptions to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/permissions_api.rb', line 101

def get_all_permissions(opts = {})
  data, _status_code, _headers = get_all_permissions_with_http_info(opts)
  return data
end

#get_all_permissions_with_http_info(opts = {}) ⇒ Array<(BFPermissionPagedMetadata, Fixnum, Hash)>

Retrieves a collection of all permissions. By default 10 values are returned. Records are returned in natural order. all permissions&quot;,&quot;response&quot;:&quot;getPermissionAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first subscription to return.

  • :records (Integer)

    The maximum number of subscriptions to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:

  • (Array<(BFPermissionPagedMetadata, Fixnum, Hash)>)

    BFPermissionPagedMetadata data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/permissions_api.rb', line 116

def get_all_permissions_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PermissionsApi.get_all_permissions ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/permissions".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BFPermissionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PermissionsApi#get_all_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_available_actions_for_resource(resource, opts = {}) ⇒ PermissionActionEntityPagedMetadata

Retrieves all the available actions for the specified resource. available actions","response":"getAvailableActions.html"

Parameters:

  • resource
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



171
172
173
174
# File 'lib/bf_ruby2/api/permissions_api.rb', line 171

def get_available_actions_for_resource(resource, opts = {})
  data, _status_code, _headers = get_available_actions_for_resource_with_http_info(resource, opts)
  return data
end

#get_available_actions_for_resource_with_http_info(resource, opts = {}) ⇒ Array<(PermissionActionEntityPagedMetadata, Fixnum, Hash)>

Retrieves all the available actions for the specified resource. available actions&quot;,&quot;response&quot;:&quot;getAvailableActions.html&quot;

Parameters:

  • resource
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/bf_ruby2/api/permissions_api.rb', line 182

def get_available_actions_for_resource_with_http_info(resource, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PermissionsApi.get_available_actions_for_resource ..."
  end
  # verify the required parameter 'resource' is set
  fail ArgumentError, "Missing the required parameter 'resource' when calling PermissionsApi.get_available_actions_for_resource" if resource.nil?
  # verify enum value
  unless ['All', 'Account', 'Address', 'Amendment', 'Analytics', 'Audit', 'BFAdmin', 'BFJS', 'Charge', 'Client', 'Configuration', 'CouponBook', 'CouponBookDefinition', 'CouponDefinition', 'CouponInstance', 'CouponModifier', 'CouponRule', 'Coupon', 'Credit', 'CybersourceToken', 'Dunning', 'Email', 'FixedTerm', 'Gateway', 'Invoice', 'Notification', 'Organization', 'Password', 'PaymentMethod', 'Payment', 'Permission', 'PricingComponent', 'PricingComponentTier', 'PricingComponentValueChange', 'PricingComponentValue', 'ProductRatePlan', 'Product', 'ProductResources', 'Profile', 'Quote', 'Receipt', 'Refund', 'Salesforce', 'Search', 'Subscription', 'Tax', 'UnitOfMeasure', 'Usage', 'Username', 'User', 'UserResources', 'Webhook'].include?(resource)
    fail ArgumentError, "invalid value for 'resource', must be one of All, Account, Address, Amendment, Analytics, Audit, BFAdmin, BFJS, Charge, Client, Configuration, CouponBook, CouponBookDefinition, CouponDefinition, CouponInstance, CouponModifier, CouponRule, Coupon, Credit, CybersourceToken, Dunning, Email, FixedTerm, Gateway, Invoice, Notification, Organization, Password, PaymentMethod, Payment, Permission, PricingComponent, PricingComponentTier, PricingComponentValueChange, PricingComponentValue, ProductRatePlan, Product, ProductResources, Profile, Quote, Receipt, Refund, Salesforce, Search, Subscription, Tax, UnitOfMeasure, Usage, Username, User, UserResources, Webhook"
  end
  # resource path
  local_var_path = "/permissions/resources/{resource}".sub('{format}','json').sub('{' + 'resource' + '}', resource.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PermissionActionEntityPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PermissionsApi#get_available_actions_for_resource\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_available_resources(opts = {}) ⇒ PermissionResourceEntityPagedMetadata

Retrieves all available resource. available resources","response":"getAvailableResources.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



234
235
236
237
# File 'lib/bf_ruby2/api/permissions_api.rb', line 234

def get_available_resources(opts = {})
  data, _status_code, _headers = get_available_resources_with_http_info(opts)
  return data
end

#get_available_resources_with_http_info(opts = {}) ⇒ Array<(PermissionResourceEntityPagedMetadata, Fixnum, Hash)>

Retrieves all available resource. available resources&quot;,&quot;response&quot;:&quot;getAvailableResources.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/bf_ruby2/api/permissions_api.rb', line 244

def get_available_resources_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PermissionsApi.get_available_resources ..."
  end
  # resource path
  local_var_path = "/permissions/resources".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PermissionResourceEntityPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PermissionsApi#get_available_resources\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_permission_by_id(permission_id, opts = {}) ⇒ BFPermissionPagedMetadata

Retrieves a single permission, specified by the ID parameter. a permission","response":"getPermissionByID.html"

Parameters:

  • permission_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



292
293
294
295
# File 'lib/bf_ruby2/api/permissions_api.rb', line 292

def get_permission_by_id(permission_id, opts = {})
  data, _status_code, _headers = get_permission_by_id_with_http_info(permission_id, opts)
  return data
end

#get_permission_by_id_with_http_info(permission_id, opts = {}) ⇒ Array<(BFPermissionPagedMetadata, Fixnum, Hash)>

Retrieves a single permission, specified by the ID parameter. a permission&quot;,&quot;response&quot;:&quot;getPermissionByID.html&quot;

Parameters:

  • permission_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:

  • (Array<(BFPermissionPagedMetadata, Fixnum, Hash)>)

    BFPermissionPagedMetadata data, response status code and response headers



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/bf_ruby2/api/permissions_api.rb', line 304

def get_permission_by_id_with_http_info(permission_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PermissionsApi.get_permission_by_id ..."
  end
  # verify the required parameter 'permission_id' is set
  fail ArgumentError, "Missing the required parameter 'permission_id' when calling PermissionsApi.get_permission_by_id" if permission_id.nil?
  # resource path
  local_var_path = "/permissions/{permission-ID}".sub('{format}','json').sub('{' + 'permission-ID' + '}', permission_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BFPermissionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PermissionsApi#get_permission_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#revoke_permission(permission_id, opts = {}) ⇒ BFPermissionPagedMetadata

Revokes a permission permission","response":"revokePermission.html","request":"revokePErmissionRequest.html"

Parameters:

  • permission_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



354
355
356
357
# File 'lib/bf_ruby2/api/permissions_api.rb', line 354

def revoke_permission(permission_id, opts = {})
  data, _status_code, _headers = revoke_permission_with_http_info(permission_id, opts)
  return data
end

#revoke_permission_with_http_info(permission_id, opts = {}) ⇒ Array<(BFPermissionPagedMetadata, Fixnum, Hash)>

Revokes a permission permission&quot;,&quot;response&quot;:&quot;revokePermission.html&quot;,&quot;request&quot;:&quot;revokePErmissionRequest.html&quot;

Parameters:

  • permission_id
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(BFPermissionPagedMetadata, Fixnum, Hash)>)

    BFPermissionPagedMetadata data, response status code and response headers



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/bf_ruby2/api/permissions_api.rb', line 365

def revoke_permission_with_http_info(permission_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PermissionsApi.revoke_permission ..."
  end
  # verify the required parameter 'permission_id' is set
  fail ArgumentError, "Missing the required parameter 'permission_id' when calling PermissionsApi.revoke_permission" if permission_id.nil?
  # resource path
  local_var_path = "/permissions/{permission-ID}".sub('{format}','json').sub('{' + 'permission-ID' + '}', permission_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BFPermissionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PermissionsApi#revoke_permission\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end