Class: BillForward::PricingComponentTier

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/pricing_component_tier.rb

Overview

PricingComponentTier

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PricingComponentTier

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 125

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'lowerThreshold')
    self.lower_threshold = attributes[:'lowerThreshold']
  end

  if attributes.has_key?(:'upperThreshold')
    self.upper_threshold = attributes[:'upperThreshold']
  end

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'crmID')
    self.crm_id = attributes[:'crmID']
  end

  if attributes.has_key?(:'pricingComponentVersionID')
    self.pricing_component_version_id = attributes[:'pricingComponentVersionID']
  end

  if attributes.has_key?(:'pricingComponentID')
    self.pricing_component_id = attributes[:'pricingComponentID']
  end

  if attributes.has_key?(:'productRatePlanID')
    self.product_rate_plan_id = attributes[:'productRatePlanID']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'pricingType')
    self.pricing_type = attributes[:'pricingType']
  end

  if attributes.has_key?(:'price')
    self.price = attributes[:'price']
  end

end

Instance Attribute Details

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



39
40
41
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 39

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 36

def created
  @created
end

#crm_idObject

{ "description" : "", "verbs“: }



45
46
47
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 45

def crm_id
  @crm_id
end

#idObject

{ "description" : "", "verbs“: }



42
43
44
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 42

def id
  @id
end

#lower_thresholdObject

{ "description" : "The lower threshold of the tier.", "verbs“: }



30
31
32
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 30

def lower_threshold
  @lower_threshold
end

#organization_idObject

{ "description" : "Organization associated with the pricing-component-tier.", "verbs":[] }



57
58
59
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 57

def organization_id
  @organization_id
end

#priceObject

{ "description" : "Cost associated with tier. When the pricingType is fixed this is the total value. When pricingType is unit, this is the cost of each unit. ", "verbs“: }



63
64
65
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 63

def price
  @price
end

#pricing_component_idObject

{ "description" : "ID of the pricing-component associated with the pricing-component-tier.", "verbs“: }



51
52
53
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 51

def pricing_component_id
  @pricing_component_id
end

#pricing_component_version_idObject

{ "description" : "Version ID of the associated pricing-component", "verbs“: }



48
49
50
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 48

def pricing_component_version_id
  @pricing_component_version_id
end

#pricing_typeObject

{ "description" : "Pricing calculation used to price items in this pricing tier. Unit pricing means every distinct value is used in the calculation. Fixed means that the total price of the tier is fixed regardless of the purchased amount.", "verbs“: }



60
61
62
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 60

def pricing_type
  @pricing_type
end

#product_rate_plan_idObject

{ "description" : "ID of the product-rate-plan associated with the pricing-component-tier.", "verbs“: }



54
55
56
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 54

def product_rate_plan_id
  @product_rate_plan_id
end

#upper_thresholdObject

{ "default" : "∞", "description" : "The upper threshold of the tier. If this is left null the tier will be infinite", "verbs“: }



33
34
35
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 33

def upper_threshold
  @upper_threshold
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 88

def self.attribute_map
  {
    :'lower_threshold' => :'lowerThreshold',
    :'upper_threshold' => :'upperThreshold',
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'id' => :'id',
    :'crm_id' => :'crmID',
    :'pricing_component_version_id' => :'pricingComponentVersionID',
    :'pricing_component_id' => :'pricingComponentID',
    :'product_rate_plan_id' => :'productRatePlanID',
    :'organization_id' => :'organizationID',
    :'pricing_type' => :'pricingType',
    :'price' => :'price'
  }
end

.swagger_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 106

def self.swagger_types
  {
    :'lower_threshold' => :'Integer',
    :'upper_threshold' => :'Integer',
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'id' => :'String',
    :'crm_id' => :'String',
    :'pricing_component_version_id' => :'String',
    :'pricing_component_id' => :'String',
    :'product_rate_plan_id' => :'String',
    :'organization_id' => :'String',
    :'pricing_type' => :'String',
    :'price' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      lower_threshold == o.lower_threshold &&
      upper_threshold == o.upper_threshold &&
      created == o.created &&
      changed_by == o.changed_by &&
      id == o.id &&
      crm_id == o.crm_id &&
      pricing_component_version_id == o.pricing_component_version_id &&
      pricing_component_id == o.pricing_component_id &&
      product_rate_plan_id == o.product_rate_plan_id &&
      organization_id == o.organization_id &&
      pricing_type == o.pricing_type &&
      price == o.price
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 264

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = BillForward.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 330

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 243

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 230

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



236
237
238
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 236

def hash
  [lower_threshold, upper_threshold, created, changed_by, id, crm_id, pricing_component_version_id, pricing_component_id, product_rate_plan_id, organization_id, pricing_type, price].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



183
184
185
186
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



310
311
312
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 310

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
319
320
321
322
323
324
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 316

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



304
305
306
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 304

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
# File 'lib/bf_ruby2/models/pricing_component_tier.rb', line 190

def valid?
  return false if @pricing_component_version_id.nil?
  return false if @pricing_type.nil?
  pricing_type_validator = EnumAttributeValidator.new('String', ["unit", "fixed"])
  return false unless pricing_type_validator.valid?(@pricing_type)
  return false if @price.nil?
  return true
end