Class: BillForward::PricingcalculatorApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/pricingcalculator_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PricingcalculatorApi



30
31
32
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#get_amendment_cost(ammendment_price_request, opts = {}) ⇒ AmendmentPriceNTimePagedMetadata

Calculates the price of a subscription’s upgrading/downgrading to a new pricing component value. { \“nickname\” : \“Calculate upgrade price\”, \“request\” : \“AmendmentPriceRequest.html\” ,\“response\” : \“AmendmentPriceNTime.html\” }



39
40
41
42
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 39

def get_amendment_cost(ammendment_price_request, opts = {})
  data, _status_code, _headers = get_amendment_cost_with_http_info(ammendment_price_request, opts)
  return data
end

#get_amendment_cost_with_http_info(ammendment_price_request, opts = {}) ⇒ Array<(AmendmentPriceNTimePagedMetadata, Fixnum, Hash)>

Calculates the price of a subscription&#39;s upgrading/downgrading to a new pricing component value. { \&quot;nickname\&quot; : \&quot;Calculate upgrade price\&quot;, \&quot;request\&quot; : \&quot;AmendmentPriceRequest.html\&quot; ,\&quot;response\&quot; : \&quot;AmendmentPriceNTime.html\&quot; }



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 49

def get_amendment_cost_with_http_info(ammendment_price_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcalculatorApi.get_amendment_cost ..."
  end
  # verify the required parameter 'ammendment_price_request' is set
  fail ArgumentError, "Missing the required parameter 'ammendment_price_request' when calling PricingcalculatorApi.get_amendment_cost" if ammendment_price_request.nil?
  # resource path
  local_var_path = "/pricing-calculator/amendment-cost".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(ammendment_price_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'AmendmentPriceNTimePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcalculatorApi#get_amendment_cost\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_coupon_instance_initialisation_cost(coupon_instance_initialisation_request, opts = {}) ⇒ PriceCalculationPagedMetadata

Calculates the price of a subscription to a rate plan, at specified values of pricing component values, and with the specified coupon applied. { \“nickname\” : \“Calculate price with a coupon\”,\“request\” : \“PriceRequestWithCoupon.html\” ,\“response\” : \“PriceCalculationWithCoupon.html\” }



96
97
98
99
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 96

def get_coupon_instance_initialisation_cost(coupon_instance_initialisation_request, opts = {})
  data, _status_code, _headers = get_coupon_instance_initialisation_cost_with_http_info(coupon_instance_initialisation_request, opts)
  return data
end

#get_coupon_instance_initialisation_cost_with_http_info(coupon_instance_initialisation_request, opts = {}) ⇒ Array<(PriceCalculationPagedMetadata, Fixnum, Hash)>

Calculates the price of a subscription to a rate plan, at specified values of pricing component values, and with the specified coupon applied. { \&quot;nickname\&quot; : \&quot;Calculate price with a coupon\&quot;,\&quot;request\&quot; : \&quot;PriceRequestWithCoupon.html\&quot; ,\&quot;response\&quot; : \&quot;PriceCalculationWithCoupon.html\&quot; }



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 106

def get_coupon_instance_initialisation_cost_with_http_info(coupon_instance_initialisation_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcalculatorApi.get_coupon_instance_initialisation_cost ..."
  end
  # verify the required parameter 'coupon_instance_initialisation_request' is set
  fail ArgumentError, "Missing the required parameter 'coupon_instance_initialisation_request' when calling PricingcalculatorApi.get_coupon_instance_initialisation_cost" if coupon_instance_initialisation_request.nil?
  # resource path
  local_var_path = "/pricing-calculator/coupon-instance/initialisation".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(coupon_instance_initialisation_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PriceCalculationPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcalculatorApi#get_coupon_instance_initialisation_cost\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_product_rate_plan_costs(price_request, opts = {}) ⇒ PriceCalculationPagedMetadata

Calculates the price of a subscription to a rate plan, at specified values of pricing component values. { \“nickname\” : \“Calculate price\”, \“request\” : \“PriceRequest.html\” ,\“response\” : \“PriceCalculation.html\” }



153
154
155
156
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 153

def get_product_rate_plan_costs(price_request, opts = {})
  data, _status_code, _headers = get_product_rate_plan_costs_with_http_info(price_request, opts)
  return data
end

#get_product_rate_plan_costs_with_http_info(price_request, opts = {}) ⇒ Array<(PriceCalculationPagedMetadata, Fixnum, Hash)>

Calculates the price of a subscription to a rate plan, at specified values of pricing component values. { \&quot;nickname\&quot; : \&quot;Calculate price\&quot;, \&quot;request\&quot; : \&quot;PriceRequest.html\&quot; ,\&quot;response\&quot; : \&quot;PriceCalculation.html\&quot; }



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/bf_ruby2/api/pricingcalculator_api.rb', line 163

def get_product_rate_plan_costs_with_http_info(price_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcalculatorApi.get_product_rate_plan_costs ..."
  end
  # verify the required parameter 'price_request' is set
  fail ArgumentError, "Missing the required parameter 'price_request' when calling PricingcalculatorApi.get_product_rate_plan_costs" if price_request.nil?
  # resource path
  local_var_path = "/pricing-calculator/product-rate-plan".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(price_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PriceCalculationPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcalculatorApi#get_product_rate_plan_costs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end