Class: BillForward::PricingcomponentsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/pricingcomponents_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PricingcomponentsApi

Returns a new instance of PricingcomponentsApi.



30
31
32
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_pricing_component(pricing_component, opts = {}) ⇒ PricingComponentPagedMetadata

Create a pricing-component. a new pricing-component","request":"createPricingComponentRequest.html","response":"createPricingComponentResponse.html"

Parameters:

  • pricing_component

    The pricing-component object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 39

def create_pricing_component(pricing_component, opts = {})
  data, _status_code, _headers = create_pricing_component_with_http_info(pricing_component, opts)
  return data
end

#create_pricing_component_with_http_info(pricing_component, opts = {}) ⇒ Array<(PricingComponentPagedMetadata, Fixnum, Hash)>

Create a pricing-component. a new pricing-component&quot;,&quot;request&quot;:&quot;createPricingComponentRequest.html&quot;,&quot;response&quot;:&quot;createPricingComponentResponse.html&quot;

Parameters:

  • pricing_component

    The pricing-component object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 49

def create_pricing_component_with_http_info(pricing_component, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentsApi.create_pricing_component ..."
  end
  # verify the required parameter 'pricing_component' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component' when calling PricingcomponentsApi.create_pricing_component" if pricing_component.nil?
  # resource path
  local_var_path = "/pricing-components".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentsApi#create_pricing_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_pricing_components(opts = {}) ⇒ PricingComponentPagedMetadata

Returns a collection of pricing-components. By default 10 values are returned. Records are returned in natural order. all pricing-components","response":"getPricingComponentsAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-components to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 101

def get_all_pricing_components(opts = {})
  data, _status_code, _headers = get_all_pricing_components_with_http_info(opts)
  return data
end

#get_all_pricing_components_with_http_info(opts = {}) ⇒ Array<(PricingComponentPagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-components. By default 10 values are returned. Records are returned in natural order. all pricing-components&quot;,&quot;response&quot;:&quot;getPricingComponentsAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component to return.

  • :records (Integer)

    The maximum number of pricing-components to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 116

def get_all_pricing_components_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentsApi.get_all_pricing_components ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-components".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentsApi#get_all_pricing_components\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component(pricing_component_id, opts = {}) ⇒ PricingComponentPagedMetadata

Returns a collection of pricing-components, specified by the pricing-component-ID parameter. By default 10 values are returned. Records are returned in natural order. an existing pricing-component","response":"getPricingComponentsByID.html"

Parameters:

  • pricing_component_id

    The string ID of the pricing-component.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-components to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



176
177
178
179
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 176

def get_pricing_component(pricing_component_id, opts = {})
  data, _status_code, _headers = get_pricing_component_with_http_info(pricing_component_id, opts)
  return data
end

#get_pricing_component_by_product_rate_plan_id(product_rate_plan_id, opts = {}) ⇒ PricingComponentPagedMetadata

Returns a collection of pricing-components, specified by the product-rate-plan-ID parameter. By default 10 values are returned. Records are returned in natural order. by rate-plan","response":"getPricingComponentsByPRP.html"

Parameters:

  • product_rate_plan_id

    The string product-rate-plan-ID of the pricing-component.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-components to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



254
255
256
257
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 254

def get_pricing_component_by_product_rate_plan_id(product_rate_plan_id, opts = {})
  data, _status_code, _headers = get_pricing_component_by_product_rate_plan_id_with_http_info(product_rate_plan_id, opts)
  return data
end

#get_pricing_component_by_product_rate_plan_id_with_http_info(product_rate_plan_id, opts = {}) ⇒ Array<(PricingComponentPagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-components, specified by the product-rate-plan-ID parameter. By default 10 values are returned. Records are returned in natural order. by rate-plan&quot;,&quot;response&quot;:&quot;getPricingComponentsByPRP.html&quot;

Parameters:

  • product_rate_plan_id

    The string product-rate-plan-ID of the pricing-component.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component to return.

  • :records (Integer)

    The maximum number of pricing-components to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 270

def get_pricing_component_by_product_rate_plan_id_with_http_info(product_rate_plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentsApi.get_pricing_component_by_product_rate_plan_id ..."
  end
  # verify the required parameter 'product_rate_plan_id' is set
  fail ArgumentError, "Missing the required parameter 'product_rate_plan_id' when calling PricingcomponentsApi.get_pricing_component_by_product_rate_plan_id" if product_rate_plan_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-components/product-rate-plan/{product-rate-plan-ID}".sub('{format}','json').sub('{' + 'product-rate-plan-ID' + '}', product_rate_plan_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentsApi#get_pricing_component_by_product_rate_plan_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_with_http_info(pricing_component_id, opts = {}) ⇒ Array<(PricingComponentPagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-components, specified by the pricing-component-ID parameter. By default 10 values are returned. Records are returned in natural order. an existing pricing-component&quot;,&quot;response&quot;:&quot;getPricingComponentsByID.html&quot;

Parameters:

  • pricing_component_id

    The string ID of the pricing-component.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component to return.

  • :records (Integer)

    The maximum number of pricing-components to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 192

def get_pricing_component_with_http_info(pricing_component_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentsApi.get_pricing_component ..."
  end
  # verify the required parameter 'pricing_component_id' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_id' when calling PricingcomponentsApi.get_pricing_component" if pricing_component_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-components/{pricing-component-ID}".sub('{format}','json').sub('{' + 'pricing-component-ID' + '}', pricing_component_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentsApi#get_pricing_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retire_pricing_component(pricing_component_id, opts = {}) ⇒ PricingComponentPagedMetadata

Retires the pricing-component specified by the pricing-component-ID parameter. a pricing-component"

Parameters:

  • pricing_component_id

    The string ID of the pricing-component.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization IDs used to restrict the scope of API calls.

Returns:



327
328
329
330
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 327

def retire_pricing_component(pricing_component_id, opts = {})
  data, _status_code, _headers = retire_pricing_component_with_http_info(pricing_component_id, opts)
  return data
end

#retire_pricing_component_with_http_info(pricing_component_id, opts = {}) ⇒ Array<(PricingComponentPagedMetadata, Fixnum, Hash)>

Retires the pricing-component specified by the pricing-component-ID parameter. a pricing-component&quot;

Parameters:

  • pricing_component_id

    The string ID of the pricing-component.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization IDs used to restrict the scope of API calls.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 338

def retire_pricing_component_with_http_info(pricing_component_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentsApi.retire_pricing_component ..."
  end
  # verify the required parameter 'pricing_component_id' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_id' when calling PricingcomponentsApi.retire_pricing_component" if pricing_component_id.nil?
  # resource path
  local_var_path = "/pricing-components/{pricing-component-ID}".sub('{format}','json').sub('{' + 'pricing-component-ID' + '}', pricing_component_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentsApi#retire_pricing_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_pricing_component(pricing_component, opts = {}) ⇒ PricingComponentPagedMetadata

Update a pricing-component. a pricing-component","request":"updatePricingComponentRequest.html","response":"updatePricingComponentResponse.html"

Parameters:

  • pricing_component

    The pricing-component object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



386
387
388
389
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 386

def update_pricing_component(pricing_component, opts = {})
  data, _status_code, _headers = update_pricing_component_with_http_info(pricing_component, opts)
  return data
end

#update_pricing_component_with_http_info(pricing_component, opts = {}) ⇒ Array<(PricingComponentPagedMetadata, Fixnum, Hash)>

Update a pricing-component. a pricing-component&quot;,&quot;request&quot;:&quot;updatePricingComponentRequest.html&quot;,&quot;response&quot;:&quot;updatePricingComponentResponse.html&quot;

Parameters:

  • pricing_component

    The pricing-component object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/bf_ruby2/api/pricingcomponents_api.rb', line 396

def update_pricing_component_with_http_info(pricing_component, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentsApi.update_pricing_component ..."
  end
  # verify the required parameter 'pricing_component' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component' when calling PricingcomponentsApi.update_pricing_component" if pricing_component.nil?
  # resource path
  local_var_path = "/pricing-components".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentsApi#update_pricing_component\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end