Class: BillForward::PricingcomponenttiersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/pricingcomponenttiers_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PricingcomponenttiersApi

Returns a new instance of PricingcomponenttiersApi.



30
31
32
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_pricing_component_tier(pricing_component_tier, opts = {}) ⇒ PricingComponentTierPagedMetadata

Create a new tier","request":"createPricingComponentTierRequest.html","response":"createPricingComponentTierResponse.html"

Parameters:

  • pricing_component_tier

    The pricing-component-tier object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 39

def create_pricing_component_tier(pricing_component_tier, opts = {})
  data, _status_code, _headers = create_pricing_component_tier_with_http_info(pricing_component_tier, opts)
  return data
end

#create_pricing_component_tier_with_http_info(pricing_component_tier, opts = {}) ⇒ Array<(PricingComponentTierPagedMetadata, Fixnum, Hash)>

Create a new tier&quot;,&quot;request&quot;:&quot;createPricingComponentTierRequest.html&quot;,&quot;response&quot;:&quot;createPricingComponentTierResponse.html&quot;

Parameters:

  • pricing_component_tier

    The pricing-component-tier object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 49

def create_pricing_component_tier_with_http_info(pricing_component_tier, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponenttiersApi.create_pricing_component_tier ..."
  end
  # verify the required parameter 'pricing_component_tier' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_tier' when calling PricingcomponenttiersApi.create_pricing_component_tier" if pricing_component_tier.nil?
  # resource path
  local_var_path = "/pricing-component-tiers".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component_tier)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentTierPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponenttiersApi#create_pricing_component_tier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_pricing_component_tiers(opts = {}) ⇒ PricingComponentTierPagedMetadata

Returns a collection of pricing-component-tier-tiers. By default 10 values are returned. Records are returned in natural order. all tiers","response":"getPricingComponentTiersAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-tier-tier to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-tier-tiers to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



100
101
102
103
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 100

def get_all_pricing_component_tiers(opts = {})
  data, _status_code, _headers = get_all_pricing_component_tiers_with_http_info(opts)
  return data
end

#get_all_pricing_component_tiers_with_http_info(opts = {}) ⇒ Array<(PricingComponentTierPagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-tier-tiers. By default 10 values are returned. Records are returned in natural order. all tiers&quot;,&quot;response&quot;:&quot;getPricingComponentTiersAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-tier-tier to return.

  • :records (Integer)

    The maximum number of pricing-component-tier-tiers to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 114

def get_all_pricing_component_tiers_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponenttiersApi.get_all_pricing_component_tiers ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-tiers".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentTierPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponenttiersApi#get_all_pricing_component_tiers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_tier(pricing_component_tier_id, opts = {}) ⇒ PricingComponentTierPagedMetadata

Returns a collection of pricing-component-tier-tiers, specified by the pricing-component-tier-ID parameter. By default 10 values are returned. Records are returned in natural order. an existing tier","response":"getPricingComponentTiersByID.html"

Parameters:

  • pricing_component_tier_id

    The string ID of the pricing-component-tier-tier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-tier-tier to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-tier-tiers to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



172
173
174
175
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 172

def get_pricing_component_tier(pricing_component_tier_id, opts = {})
  data, _status_code, _headers = get_pricing_component_tier_with_http_info(pricing_component_tier_id, opts)
  return data
end

#get_pricing_component_tier_by_product_rate_plan_id(product_rate_plan_id, opts = {}) ⇒ PricingComponentTierPagedMetadata

Returns a collection of pricing-component-tier-tiers, specified by the product-rate-plan-ID parameter. By default 10 values are returned. Records are returned in natural order. by rate-plan","response":"getPricingComponentTiersByPRP.html"

Parameters:

  • product_rate_plan_id

    The string product-rate-plan-ID of the pricing-component-tier-tier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-tier-tier to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-tier-tiers to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



247
248
249
250
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 247

def get_pricing_component_tier_by_product_rate_plan_id(product_rate_plan_id, opts = {})
  data, _status_code, _headers = get_pricing_component_tier_by_product_rate_plan_id_with_http_info(product_rate_plan_id, opts)
  return data
end

#get_pricing_component_tier_by_product_rate_plan_id_with_http_info(product_rate_plan_id, opts = {}) ⇒ Array<(PricingComponentTierPagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-tier-tiers, specified by the product-rate-plan-ID parameter. By default 10 values are returned. Records are returned in natural order. by rate-plan&quot;,&quot;response&quot;:&quot;getPricingComponentTiersByPRP.html&quot;

Parameters:

  • product_rate_plan_id

    The string product-rate-plan-ID of the pricing-component-tier-tier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-tier-tier to return.

  • :records (Integer)

    The maximum number of pricing-component-tier-tiers to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 262

def get_pricing_component_tier_by_product_rate_plan_id_with_http_info(product_rate_plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponenttiersApi.get_pricing_component_tier_by_product_rate_plan_id ..."
  end
  # verify the required parameter 'product_rate_plan_id' is set
  fail ArgumentError, "Missing the required parameter 'product_rate_plan_id' when calling PricingcomponenttiersApi.get_pricing_component_tier_by_product_rate_plan_id" if product_rate_plan_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-tiers/product-rate-plan/{product-rate-plan-ID}".sub('{format}','json').sub('{' + 'product-rate-plan-ID' + '}', product_rate_plan_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentTierPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponenttiersApi#get_pricing_component_tier_by_product_rate_plan_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_tier_with_http_info(pricing_component_tier_id, opts = {}) ⇒ Array<(PricingComponentTierPagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-tier-tiers, specified by the pricing-component-tier-ID parameter. By default 10 values are returned. Records are returned in natural order. an existing tier&quot;,&quot;response&quot;:&quot;getPricingComponentTiersByID.html&quot;

Parameters:

  • pricing_component_tier_id

    The string ID of the pricing-component-tier-tier.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-tier-tier to return.

  • :records (Integer)

    The maximum number of pricing-component-tier-tiers to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 187

def get_pricing_component_tier_with_http_info(pricing_component_tier_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponenttiersApi.get_pricing_component_tier ..."
  end
  # verify the required parameter 'pricing_component_tier_id' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_tier_id' when calling PricingcomponenttiersApi.get_pricing_component_tier" if pricing_component_tier_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-tiers/{pricing-component-tier-ID}".sub('{format}','json').sub('{' + 'pricing-component-tier-ID' + '}', pricing_component_tier_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentTierPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponenttiersApi#get_pricing_component_tier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_pricing_component_tier(pricing_component_tier, opts = {}) ⇒ PricingComponentTierPagedMetadata

Update. a tier","request":"updatePricingComponentTierRequest.html","response":"updatePricingComponentTierResponse.html"

Parameters:

  • pricing_component_tier

    The pricing-component-tier object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



317
318
319
320
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 317

def update_pricing_component_tier(pricing_component_tier, opts = {})
  data, _status_code, _headers = update_pricing_component_tier_with_http_info(pricing_component_tier, opts)
  return data
end

#update_pricing_component_tier_with_http_info(pricing_component_tier, opts = {}) ⇒ Array<(PricingComponentTierPagedMetadata, Fixnum, Hash)>

Update. a tier&quot;,&quot;request&quot;:&quot;updatePricingComponentTierRequest.html&quot;,&quot;response&quot;:&quot;updatePricingComponentTierResponse.html&quot;

Parameters:

  • pricing_component_tier

    The pricing-component-tier object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/bf_ruby2/api/pricingcomponenttiers_api.rb', line 327

def update_pricing_component_tier_with_http_info(pricing_component_tier, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponenttiersApi.update_pricing_component_tier ..."
  end
  # verify the required parameter 'pricing_component_tier' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_tier' when calling PricingcomponenttiersApi.update_pricing_component_tier" if pricing_component_tier.nil?
  # resource path
  local_var_path = "/pricing-component-tiers".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component_tier)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentTierPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponenttiersApi#update_pricing_component_tier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end