Class: BillForward::PricingcomponentvaluesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/pricingcomponentvalues_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PricingcomponentvaluesApi

Returns a new instance of PricingcomponentvaluesApi.



30
31
32
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_pricing_component_value(pricing_component_value, opts = {}) ⇒ PricingComponentValuePagedMetadata

Create a pricing-component-value. a new value","request":"createPricingComponentValueRequest.html","response":"createPricingComponentValueResponse.html"

Parameters:

  • pricing_component_value

    The pricing-component-value object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 39

def create_pricing_component_value(pricing_component_value, opts = {})
  data, _status_code, _headers = create_pricing_component_value_with_http_info(pricing_component_value, opts)
  return data
end

#create_pricing_component_value_with_http_info(pricing_component_value, opts = {}) ⇒ Array<(PricingComponentValuePagedMetadata, Fixnum, Hash)>

Create a pricing-component-value. a new value&quot;,&quot;request&quot;:&quot;createPricingComponentValueRequest.html&quot;,&quot;response&quot;:&quot;createPricingComponentValueResponse.html&quot;

Parameters:

  • pricing_component_value

    The pricing-component-value object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 49

def create_pricing_component_value_with_http_info(pricing_component_value, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluesApi.create_pricing_component_value ..."
  end
  # verify the required parameter 'pricing_component_value' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_value' when calling PricingcomponentvaluesApi.create_pricing_component_value" if pricing_component_value.nil?
  # resource path
  local_var_path = "/pricing-component-values".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component_value)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValuePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluesApi#create_pricing_component_value\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_pricing_component_values(opts = {}) ⇒ PricingComponentValuePagedMetadata

Returns a collection of pricing-component-values.By default 10 values are returned. Records are returned in natural order. all values","response":"getPricingComponentValueAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-values to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 101

def get_all_pricing_component_values(opts = {})
  data, _status_code, _headers = get_all_pricing_component_values_with_http_info(opts)
  return data
end

#get_all_pricing_component_values_with_http_info(opts = {}) ⇒ Array<(PricingComponentValuePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-values.By default 10 values are returned. Records are returned in natural order. all values&quot;,&quot;response&quot;:&quot;getPricingComponentValueAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value to return.

  • :records (Integer)

    The maximum number of pricing-component-values to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 116

def get_all_pricing_component_values_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluesApi.get_all_pricing_component_values ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-values".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValuePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluesApi#get_all_pricing_component_values\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_value(pricing_component_id, opts = {}) ⇒ PricingComponentValuePagedMetadata

Returns a collection of pricing-component-values, specified by the pricing-component-ID parameter.By default 10 values are returned. Records are returned in natural order. existing values","response":"getPricingComponentValueByID.html"

Parameters:

  • pricing_component_id

    The string ID of the pricing-component-value.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-values to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



176
177
178
179
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 176

def get_pricing_component_value(pricing_component_id, opts = {})
  data, _status_code, _headers = get_pricing_component_value_with_http_info(pricing_component_id, opts)
  return data
end

#get_pricing_component_value_by_subscription_id(subscription_id, opts = {}) ⇒ PricingComponentValuePagedMetadata

Returns a collection of pricing-component-values, specified by the subscription-ID parameter.By default 10 values are returned. Records are returned in natural order. by subscription","response":"getPricingComponentValueBySubscriptionID.html"

Parameters:

  • subscription_id

    The string subscription-ID of the pricing-component-value.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value to return. (default to 0)

  • :records (Integer)

    The maximum number of pricing-component-values to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



254
255
256
257
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 254

def get_pricing_component_value_by_subscription_id(subscription_id, opts = {})
  data, _status_code, _headers = get_pricing_component_value_by_subscription_id_with_http_info(subscription_id, opts)
  return data
end

#get_pricing_component_value_by_subscription_id_with_http_info(subscription_id, opts = {}) ⇒ Array<(PricingComponentValuePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-values, specified by the subscription-ID parameter.By default 10 values are returned. Records are returned in natural order. by subscription&quot;,&quot;response&quot;:&quot;getPricingComponentValueBySubscriptionID.html&quot;

Parameters:

  • subscription_id

    The string subscription-ID of the pricing-component-value.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value to return.

  • :records (Integer)

    The maximum number of pricing-component-values to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 270

def get_pricing_component_value_by_subscription_id_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluesApi.get_pricing_component_value_by_subscription_id ..."
  end
  # verify the required parameter 'subscription_id' is set
  fail ArgumentError, "Missing the required parameter 'subscription_id' when calling PricingcomponentvaluesApi.get_pricing_component_value_by_subscription_id" if subscription_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-values/subscription/{subscription-ID}".sub('{format}','json').sub('{' + 'subscription-ID' + '}', subscription_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValuePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluesApi#get_pricing_component_value_by_subscription_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_pricing_component_value_with_http_info(pricing_component_id, opts = {}) ⇒ Array<(PricingComponentValuePagedMetadata, Fixnum, Hash)>

Returns a collection of pricing-component-values, specified by the pricing-component-ID parameter.By default 10 values are returned. Records are returned in natural order. existing values&quot;,&quot;response&quot;:&quot;getPricingComponentValueByID.html&quot;

Parameters:

  • pricing_component_id

    The string ID of the pricing-component-value.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first pricing-component-value to return.

  • :records (Integer)

    The maximum number of pricing-component-values to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 192

def get_pricing_component_value_with_http_info(pricing_component_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluesApi.get_pricing_component_value ..."
  end
  # verify the required parameter 'pricing_component_id' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_id' when calling PricingcomponentvaluesApi.get_pricing_component_value" if pricing_component_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/pricing-component-values/{pricing-component-ID}".sub('{format}','json').sub('{' + 'pricing-component-ID' + '}', pricing_component_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValuePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluesApi#get_pricing_component_value\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_pricing_component_value(pricing_component_value, opts = {}) ⇒ PricingComponentValuePagedMetadata

Update a pricing-component-value. a value","request":"updatePricingComponentValueRequest.html","response":"updatePricingComponentValueResponse.html"

Parameters:

  • pricing_component_value

    The pricing-component-value object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



326
327
328
329
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 326

def update_pricing_component_value(pricing_component_value, opts = {})
  data, _status_code, _headers = update_pricing_component_value_with_http_info(pricing_component_value, opts)
  return data
end

#update_pricing_component_value_with_http_info(pricing_component_value, opts = {}) ⇒ Array<(PricingComponentValuePagedMetadata, Fixnum, Hash)>

Update a pricing-component-value. a value&quot;,&quot;request&quot;:&quot;updatePricingComponentValueRequest.html&quot;,&quot;response&quot;:&quot;updatePricingComponentValueResponse.html&quot;

Parameters:

  • pricing_component_value

    The pricing-component-value object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/bf_ruby2/api/pricingcomponentvalues_api.rb', line 336

def update_pricing_component_value_with_http_info(pricing_component_value, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: PricingcomponentvaluesApi.update_pricing_component_value ..."
  end
  # verify the required parameter 'pricing_component_value' is set
  fail ArgumentError, "Missing the required parameter 'pricing_component_value' when calling PricingcomponentvaluesApi.update_pricing_component_value" if pricing_component_value.nil?
  # resource path
  local_var_path = "/pricing-component-values".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(pricing_component_value)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'PricingComponentValuePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PricingcomponentvaluesApi#update_pricing_component_value\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end