Class: BillForward::RecalculateChargeBatchRequest
- Inherits:
-
Object
- Object
- BillForward::RecalculateChargeBatchRequest
- Defined in:
- lib/bf_ruby2/models/recalculate_charge_batch_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
- #charges ⇒ Object
-
#dry_run ⇒ Object
described in the response:
<span class=\"label label-default\">true</span> — Are not actually performed; your subscription remains unchanged, no billing events run, and no invoices are executed.
<span class=\"label label-default\">false</span> — Are actually performed and committed.“,”verbs“:. -
#invoice_state ⇒ Object
(invoice is raised in its default initial state),"description":"The new state recalculated invoices should be created as. ","verbs“:.
-
#organization_id ⇒ Object
using your authentication credentials) ID of the organization actioning this request.","description":"ID of the BillForward Organization within which the requested pricing component should be created. If omitted: this will be auto-populated using your authentication credentials.“,”verbs“:.
-
#recalculate_invoices ⇒ Object
{ "description" : "Whether the invoice of any charge to be recalculated should also be recalculated.", "verbs“: }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecalculateChargeBatchRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RecalculateChargeBatchRequest
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 90 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'charges') if (value = attributes[:'charges']).is_a?(Array) self.charges = value end end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'dryRun') self.dry_run = attributes[:'dryRun'] else self.dry_run = false end if attributes.has_key?(:'recalculateInvoices') self.recalculate_invoices = attributes[:'recalculateInvoices'] else self.recalculate_invoices = true end if attributes.has_key?(:'invoiceState') self.invoice_state = attributes[:'invoiceState'] end end |
Instance Attribute Details
#charges ⇒ Object
30 31 32 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 30 def charges @charges end |
#dry_run ⇒ Object
described in the response:
<span class=\"label label-default\">true</span> — Are not actually performed; your subscription remains unchanged, no billing events run, and no invoices are executed.
<span class=\"label label-default\">false</span> — Are actually performed and committed.“,”verbs“:
36 37 38 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 36 def dry_run @dry_run end |
#invoice_state ⇒ Object
(invoice is raised in its default initial state),"description":"The new state recalculated invoices should be created as. ","verbs“:
42 43 44 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 42 def invoice_state @invoice_state end |
#organization_id ⇒ Object
using your authentication credentials) ID of the organization actioning this request.","description":"ID of the BillForward Organization within which the requested pricing component should be created. If omitted: this will be auto-populated using your authentication credentials.“,”verbs“:
33 34 35 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 33 def organization_id @organization_id end |
#recalculate_invoices ⇒ Object
{ "description" : "Whether the invoice of any charge to be recalculated should also be recalculated.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 39 def recalculate_invoices @recalculate_invoices end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 67 def self.attribute_map { :'charges' => :'charges', :'organization_id' => :'organizationID', :'dry_run' => :'dryRun', :'recalculate_invoices' => :'recalculateInvoices', :'invoice_state' => :'invoiceState' } end |
.swagger_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 78 def self.swagger_types { :'charges' => :'Array<SingleRecalculateChargeRequest>', :'organization_id' => :'String', :'dry_run' => :'BOOLEAN', :'recalculate_invoices' => :'BOOLEAN', :'invoice_state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
151 152 153 154 155 156 157 158 159 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 151 def ==(o) return true if self.equal?(o) self.class == o.class && charges == o.charges && organization_id == o.organization_id && dry_run == o.dry_run && recalculate_invoices == o.recalculate_invoices && invoice_state == o.invoice_state end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 197 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 263 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 176 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
163 164 165 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 163 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 169 def hash [charges, organization_id, dry_run, recalculate_invoices, invoice_state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 126 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
243 244 245 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 243 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
237 238 239 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 237 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 137 |
# File 'lib/bf_ruby2/models/recalculate_charge_batch_request.rb', line 133 def valid? invoice_state_validator = EnumAttributeValidator.new('String', ["Paid", "Unpaid", "Pending", "Voided"]) return false unless invoice_state_validator.valid?(@invoice_state) return true end |