Class: BillForward::RefundsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/refunds_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RefundsApi

Returns a new instance of RefundsApi.



30
31
32
# File 'lib/bf_ruby2/api/refunds_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/refunds_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_refund(refund, opts = {}) ⇒ RefundPagedMetadata

<p>When creating a refund either the invoice, or invoice payment must be specified.</p><p>Creating a refund by specifying the invoiceID will refund any un-refunded value up to the full value of the payment. When refunding via the invoicePaymentID the same rules apply. Refunds will be processed by the same payment methods that took the payment.</p><p>Refunds can be for a partial amount of the payment. It is possible to create refunds up to the value of the total payment.</p><p>Once a payment or invoice is fully refunded, no more refunds can be created. Errors will be returned if the payment is greater than available refund funds.</p> a new refund","request":"createRefundRequest.html","response":"createRefundResponse.html"

Parameters:

  • refund

    The refund object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/refunds_api.rb', line 39

def create_refund(refund, opts = {})
  data, _status_code, _headers = create_refund_with_http_info(refund, opts)
  return data
end

#create_refund_with_http_info(refund, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

&lt;p&gt;When creating a refund either the invoice, or invoice payment must be specified.&lt;/p&gt;&lt;p&gt;Creating a refund by specifying the invoiceID will refund any un-refunded value up to the full value of the payment. When refunding via the invoicePaymentID the same rules apply. Refunds will be processed by the same payment methods that took the payment.&lt;/p&gt;&lt;p&gt;Refunds can be for a partial amount of the payment. It is possible to create refunds up to the value of the total payment.&lt;/p&gt;&lt;p&gt;Once a payment or invoice is fully refunded, no more refunds can be created. Errors will be returned if the payment is greater than available refund funds.&lt;/p&gt; a new refund&quot;,&quot;request&quot;:&quot;createRefundRequest.html&quot;,&quot;response&quot;:&quot;createRefundResponse.html&quot;

Parameters:

  • refund

    The refund object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/refunds_api.rb', line 49

def create_refund_with_http_info(refund, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.create_refund ..."
  end
  # verify the required parameter 'refund' is set
  fail ArgumentError, "Missing the required parameter 'refund' when calling RefundsApi.create_refund" if refund.nil?
  # resource path
  local_var_path = "/refunds".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(refund)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#create_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_refunds(opts = {}) ⇒ RefundPagedMetadata

Returns a collection of all refunds. By default 10 values are returned. Refunds are returned in natural order all refunds","response":"getRefundsAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first refund to return. (default to 0)

  • :records (Integer)

    The maximum number of refunds to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



100
101
102
103
# File 'lib/bf_ruby2/api/refunds_api.rb', line 100

def get_all_refunds(opts = {})
  data, _status_code, _headers = get_all_refunds_with_http_info(opts)
  return data
end

#get_all_refunds_with_http_info(opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Returns a collection of all refunds. By default 10 values are returned. Refunds are returned in natural order all refunds&quot;,&quot;response&quot;:&quot;getRefundsAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first refund to return.

  • :records (Integer)

    The maximum number of refunds to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/bf_ruby2/api/refunds_api.rb', line 114

def get_all_refunds_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.get_all_refunds ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/refunds".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#get_all_refunds\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_refund_by_id(refund_id, opts = {}) ⇒ RefundPagedMetadata

Returns a single refund, specified by the ID parameter. an existing refund","response":"getRefundByID.html"

Parameters:

  • refund_id

    ID of the Refund.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



168
169
170
171
# File 'lib/bf_ruby2/api/refunds_api.rb', line 168

def get_refund_by_id(refund_id, opts = {})
  data, _status_code, _headers = get_refund_by_id_with_http_info(refund_id, opts)
  return data
end

#get_refund_by_id_with_http_info(refund_id, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Returns a single refund, specified by the ID parameter. an existing refund&quot;,&quot;response&quot;:&quot;getRefundByID.html&quot;

Parameters:

  • refund_id

    ID of the Refund.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/bf_ruby2/api/refunds_api.rb', line 179

def get_refund_by_id_with_http_info(refund_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.get_refund_by_id ..."
  end
  # verify the required parameter 'refund_id' is set
  fail ArgumentError, "Missing the required parameter 'refund_id' when calling RefundsApi.get_refund_by_id" if refund_id.nil?
  # resource path
  local_var_path = "/refunds/{refund-ID}".sub('{format}','json').sub('{' + 'refund-ID' + '}', refund_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#get_refund_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_refund_for_original_payment(payment_id, opts = {}) ⇒ RefundPagedMetadata

Returns a refund for the original payment. by originating payment","response":"getRefundsByPayment.html"

Parameters:

  • payment_id

    ID of the Payment.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



228
229
230
231
# File 'lib/bf_ruby2/api/refunds_api.rb', line 228

def get_refund_for_original_payment(payment_id, opts = {})
  data, _status_code, _headers = get_refund_for_original_payment_with_http_info(payment_id, opts)
  return data
end

#get_refund_for_original_payment_with_http_info(payment_id, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Returns a refund for the original payment. by originating payment&quot;,&quot;response&quot;:&quot;getRefundsByPayment.html&quot;

Parameters:

  • payment_id

    ID of the Payment.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/bf_ruby2/api/refunds_api.rb', line 239

def get_refund_for_original_payment_with_http_info(payment_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.get_refund_for_original_payment ..."
  end
  # verify the required parameter 'payment_id' is set
  fail ArgumentError, "Missing the required parameter 'payment_id' when calling RefundsApi.get_refund_for_original_payment" if payment_id.nil?
  # resource path
  local_var_path = "/refunds/original-payment/{payment-ID}".sub('{format}','json').sub('{' + 'payment-ID' + '}', payment_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#get_refund_for_original_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_refund_for_refund_payment(payment_id, opts = {}) ⇒ RefundPagedMetadata

Returns a refund for the refund payment. by refund payment","response":"getRefundsByPayment.html"

Parameters:

  • payment_id

    ID of the Payment.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



288
289
290
291
# File 'lib/bf_ruby2/api/refunds_api.rb', line 288

def get_refund_for_refund_payment(payment_id, opts = {})
  data, _status_code, _headers = get_refund_for_refund_payment_with_http_info(payment_id, opts)
  return data
end

#get_refund_for_refund_payment_with_http_info(payment_id, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Returns a refund for the refund payment. by refund payment&quot;,&quot;response&quot;:&quot;getRefundsByPayment.html&quot;

Parameters:

  • payment_id

    ID of the Payment.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/bf_ruby2/api/refunds_api.rb', line 299

def get_refund_for_refund_payment_with_http_info(payment_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.get_refund_for_refund_payment ..."
  end
  # verify the required parameter 'payment_id' is set
  fail ArgumentError, "Missing the required parameter 'payment_id' when calling RefundsApi.get_refund_for_refund_payment" if payment_id.nil?
  # resource path
  local_var_path = "/refunds/refund-payment/{payment-ID}".sub('{format}','json').sub('{' + 'payment-ID' + '}', payment_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#get_refund_for_refund_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_refund_for_refunded_invoice(invoice_id, opts = {}) ⇒ RefundPagedMetadata

Returns a refund for the refund payment. by invoice","response":"getRefundsByInvoice.html"

Parameters:

  • invoice_id

    ID of the Invoice.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



348
349
350
351
# File 'lib/bf_ruby2/api/refunds_api.rb', line 348

def get_refund_for_refunded_invoice(invoice_id, opts = {})
  data, _status_code, _headers = get_refund_for_refunded_invoice_with_http_info(invoice_id, opts)
  return data
end

#get_refund_for_refunded_invoice_with_http_info(invoice_id, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Returns a refund for the refund payment. by invoice&quot;,&quot;response&quot;:&quot;getRefundsByInvoice.html&quot;

Parameters:

  • invoice_id

    ID of the Invoice.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/bf_ruby2/api/refunds_api.rb', line 359

def get_refund_for_refunded_invoice_with_http_info(invoice_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.get_refund_for_refunded_invoice ..."
  end
  # verify the required parameter 'invoice_id' is set
  fail ArgumentError, "Missing the required parameter 'invoice_id' when calling RefundsApi.get_refund_for_refunded_invoice" if invoice_id.nil?
  # resource path
  local_var_path = "/refunds/invoice/{invoice-ID}".sub('{format}','json').sub('{' + 'invoice-ID' + '}', invoice_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#get_refund_for_refunded_invoice\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_refunds_as_csv(completed_start, completed_end, opts = {}) ⇒ RefundPagedMetadata

Retrieves refunds in CSV format. { "nickname":"Refunds CSV","response":"refunds.csv"}

Parameters:

  • completed_start

    The UTC DateTime specifying the start of the interval within which refunds were completed.

  • completed_end

    The UTC DateTime specifying the end of the interval within which refunds were completed.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first refund to return.

  • :records (Integer)

    The maximum number of refunds to return.

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    The direction of any ordering, either ASC or DESC. (default to DESC)

Returns:



413
414
415
416
# File 'lib/bf_ruby2/api/refunds_api.rb', line 413

def get_refunds_as_csv(completed_start, completed_end, opts = {})
  data, _status_code, _headers = get_refunds_as_csv_with_http_info(completed_start, completed_end, opts)
  return data
end

#get_refunds_as_csv_with_http_info(completed_start, completed_end, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Retrieves refunds in CSV format. { &quot;nickname&quot;:&quot;Refunds CSV&quot;,&quot;response&quot;:&quot;refunds.csv&quot;}

Parameters:

  • completed_start

    The UTC DateTime specifying the start of the interval within which refunds were completed.

  • completed_end

    The UTC DateTime specifying the end of the interval within which refunds were completed.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first refund to return.

  • :records (Integer)

    The maximum number of refunds to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    The direction of any ordering, either ASC or DESC.

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
# File 'lib/bf_ruby2/api/refunds_api.rb', line 429

def get_refunds_as_csv_with_http_info(completed_start, completed_end, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.get_refunds_as_csv ..."
  end
  # verify the required parameter 'completed_start' is set
  fail ArgumentError, "Missing the required parameter 'completed_start' when calling RefundsApi.get_refunds_as_csv" if completed_start.nil?
  # verify the required parameter 'completed_end' is set
  fail ArgumentError, "Missing the required parameter 'completed_end' when calling RefundsApi.get_refunds_as_csv" if completed_end.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/refunds/csv".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'completed_start'] = completed_start
  query_params[:'completed_end'] = completed_end
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/csv']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#get_refunds_as_csv\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_refund(refund, opts = {}) ⇒ RefundPagedMetadata

Update a refund a refund","request":"updateRefundRequest.html","response":"updateRefundResponse.html"

Parameters:

  • refund

    The refund object to be update.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



488
489
490
491
# File 'lib/bf_ruby2/api/refunds_api.rb', line 488

def update_refund(refund, opts = {})
  data, _status_code, _headers = update_refund_with_http_info(refund, opts)
  return data
end

#update_refund_with_http_info(refund, opts = {}) ⇒ Array<(RefundPagedMetadata, Fixnum, Hash)>

Update a refund a refund&quot;,&quot;request&quot;:&quot;updateRefundRequest.html&quot;,&quot;response&quot;:&quot;updateRefundResponse.html&quot;

Parameters:

  • refund

    The refund object to be update.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RefundPagedMetadata, Fixnum, Hash)>)

    RefundPagedMetadata data, response status code and response headers



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
# File 'lib/bf_ruby2/api/refunds_api.rb', line 498

def update_refund_with_http_info(refund, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RefundsApi.update_refund ..."
  end
  # verify the required parameter 'refund' is set
  fail ArgumentError, "Missing the required parameter 'refund' when calling RefundsApi.update_refund" if refund.nil?
  # resource path
  local_var_path = "/refunds".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(refund)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RefundPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RefundsApi#update_refund\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end