Class: BillForward::RevenueAttribution

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/models/revenue_attribution.rb

Overview

A RevenueAttributions describes a portion of the total cost of an Invoice, that has been attributed to some billable feature.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RevenueAttribution

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 164

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'periodStart')
    self.period_start = attributes[:'periodStart']
  end

  if attributes.has_key?(:'periodEnd')
    self.period_end = attributes[:'periodEnd']
  end

  if attributes.has_key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.has_key?(:'changedBy')
    self.changed_by = attributes[:'changedBy']
  end

  if attributes.has_key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.has_key?(:'organizationID')
    self.organization_id = attributes[:'organizationID']
  end

  if attributes.has_key?(:'invoiceID')
    self.invoice_id = attributes[:'invoiceID']
  end

  if attributes.has_key?(:'invoiceVersionID')
    self.invoice_version_id = attributes[:'invoiceVersionID']
  end

  if attributes.has_key?(:'aggregatedInvoiceID')
    self.aggregated_invoice_id = attributes[:'aggregatedInvoiceID']
  end

  if attributes.has_key?(:'aggregatedInvoiceLineID')
    self.aggregated_invoice_line_id = attributes[:'aggregatedInvoiceLineID']
  end

  if attributes.has_key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.has_key?(:'nominalAmount')
    self.nominal_amount = attributes[:'nominalAmount']
  end

  if attributes.has_key?(:'actualAmount')
    self.actual_amount = attributes[:'actualAmount']
  end

  if attributes.has_key?(:'pricingComponentID')
    self.pricing_component_id = attributes[:'pricingComponentID']
  end

  if attributes.has_key?(:'pricingComponentName')
    self.pricing_component_name = attributes[:'pricingComponentName']
  end

  if attributes.has_key?(:'productRatePlanID')
    self.product_rate_plan_id = attributes[:'productRatePlanID']
  end

  if attributes.has_key?(:'productRatePlanName')
    self.product_rate_plan_name = attributes[:'productRatePlanName']
  end

  if attributes.has_key?(:'productRatePlanNamePublic')
    self.product_rate_plan_name_public = attributes[:'productRatePlanNamePublic']
  end

  if attributes.has_key?(:'productID')
    self.product_id = attributes[:'productID']
  end

  if attributes.has_key?(:'productName')
    self.product_name = attributes[:'productName']
  end

  if attributes.has_key?(:'productNamePublic')
    self.product_name_public = attributes[:'productNamePublic']
  end

  if attributes.has_key?(:'aggregatedSubscriptionID')
    self.aggregated_subscription_id = attributes[:'aggregatedSubscriptionID']
  end

  if attributes.has_key?(:'subscriptionID')
    self.subscription_id = attributes[:'subscriptionID']
  end

  if attributes.has_key?(:'accountID')
    self. = attributes[:'accountID']
  end

end

Instance Attribute Details

#account_idObject

of the Account with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



99
100
101
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 99

def 
  @account_id
end

#actual_amountObject

amount paid — through real money — toward this invoice line.“,”verbs“:



66
67
68
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 66

def actual_amount
  @actual_amount
end

#aggregated_invoice_idObject

of the invoice to which this RevenueAttribution’s invoice line belongs.“,”verbs“:



54
55
56
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 54

def aggregated_invoice_id
  @aggregated_invoice_id
end

#aggregated_invoice_line_idObject

of the invoice line whose debt this RevenueAttribution describes.“,”verbs“:



57
58
59
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 57

def aggregated_invoice_line_id
  @aggregated_invoice_line_id
end

#aggregated_subscription_idObject

of the Subscription with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



93
94
95
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 93

def aggregated_subscription_id
  @aggregated_subscription_id
end

#changed_byObject

{ "description" : "ID of the user who last updated the entity.", "verbs":[] }



39
40
41
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 39

def changed_by
  @changed_by
end

#createdObject

{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }



36
37
38
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 36

def created
  @created
end

#currencyObject

currency of the Invoice from which this RevenueAttribution was raised — specified by a three-character ISO 4217 currency code.“,”verbs“:



60
61
62
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 60

def currency
  @currency
end

#idObject



42
43
44
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 42

def id
  @id
end

#invoice_idObject

ID of the invoice which is expected to be consulted when paying for the billed feature described in this RevenueAttribution. That is: the top parent of that billed feature.“,”verbs“:



48
49
50
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 48

def invoice_id
  @invoice_id
end

#invoice_version_idObject

ID of the invoice which is expected to be consulted when paying for the billed feature described in this RevenueAttribution. That is: the top parent of that billed feature.“,”verbs“:



51
52
53
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 51

def invoice_version_id
  @invoice_version_id
end

#nominal_amountObject

amount paid — through credit or otherwise — toward this invoice line.“,”verbs“:



63
64
65
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 63

def nominal_amount
  @nominal_amount
end

#organization_idObject

of the organization associated with the RevenueAttribution.“,”verbs“:



45
46
47
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 45

def organization_id
  @organization_id
end

#period_endObject

of the charge with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



33
34
35
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 33

def period_end
  @period_end
end

#period_startObject

of the charge with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



30
31
32
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 30

def period_start
  @period_start
end

#pricing_component_idObject

of the PricingComponent with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



69
70
71
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 69

def pricing_component_id
  @pricing_component_id
end

#pricing_component_nameObject

of the PricingComponent with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



72
73
74
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 72

def pricing_component_name
  @pricing_component_name
end

#product_idObject

of the Product with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



84
85
86
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 84

def product_id
  @product_id
end

#product_nameObject

name of the Product with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



87
88
89
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 87

def product_name
  @product_name
end

#product_name_publicObject

name of the Product with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



90
91
92
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 90

def product_name_public
  @product_name_public
end

#product_rate_plan_idObject

of the ProductRatePlan with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



75
76
77
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 75

def product_rate_plan_id
  @product_rate_plan_id
end

#product_rate_plan_nameObject

name of the ProductRatePlan with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



78
79
80
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 78

def product_rate_plan_name
  @product_rate_plan_name
end

#product_rate_plan_name_publicObject

name of the ProductRatePlan with which this RevenueAttribution’s invoice line is associated.“,”verbs“:



81
82
83
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 81

def product_rate_plan_name_public
  @product_rate_plan_name_public
end

#subscription_idObject

ID of the Subscription which pays for this invoice line.“,”verbs“:



96
97
98
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 96

def subscription_id
  @subscription_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 103

def self.attribute_map
  {
    :'period_start' => :'periodStart',
    :'period_end' => :'periodEnd',
    :'created' => :'created',
    :'changed_by' => :'changedBy',
    :'id' => :'id',
    :'organization_id' => :'organizationID',
    :'invoice_id' => :'invoiceID',
    :'invoice_version_id' => :'invoiceVersionID',
    :'aggregated_invoice_id' => :'aggregatedInvoiceID',
    :'aggregated_invoice_line_id' => :'aggregatedInvoiceLineID',
    :'currency' => :'currency',
    :'nominal_amount' => :'nominalAmount',
    :'actual_amount' => :'actualAmount',
    :'pricing_component_id' => :'pricingComponentID',
    :'pricing_component_name' => :'pricingComponentName',
    :'product_rate_plan_id' => :'productRatePlanID',
    :'product_rate_plan_name' => :'productRatePlanName',
    :'product_rate_plan_name_public' => :'productRatePlanNamePublic',
    :'product_id' => :'productID',
    :'product_name' => :'productName',
    :'product_name_public' => :'productNamePublic',
    :'aggregated_subscription_id' => :'aggregatedSubscriptionID',
    :'subscription_id' => :'subscriptionID',
    :'account_id' => :'accountID'
  }
end

.swagger_typesObject

Attribute type mapping.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 133

def self.swagger_types
  {
    :'period_start' => :'DateTime',
    :'period_end' => :'DateTime',
    :'created' => :'DateTime',
    :'changed_by' => :'String',
    :'id' => :'String',
    :'organization_id' => :'String',
    :'invoice_id' => :'String',
    :'invoice_version_id' => :'String',
    :'aggregated_invoice_id' => :'String',
    :'aggregated_invoice_line_id' => :'String',
    :'currency' => :'String',
    :'nominal_amount' => :'Float',
    :'actual_amount' => :'Float',
    :'pricing_component_id' => :'String',
    :'pricing_component_name' => :'String',
    :'product_rate_plan_id' => :'String',
    :'product_rate_plan_name' => :'String',
    :'product_rate_plan_name_public' => :'String',
    :'product_id' => :'String',
    :'product_name' => :'String',
    :'product_name_public' => :'String',
    :'aggregated_subscription_id' => :'String',
    :'subscription_id' => :'String',
    :'account_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 304

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      period_start == o.period_start &&
      period_end == o.period_end &&
      created == o.created &&
      changed_by == o.changed_by &&
      id == o.id &&
      organization_id == o.organization_id &&
      invoice_id == o.invoice_id &&
      invoice_version_id == o.invoice_version_id &&
      aggregated_invoice_id == o.aggregated_invoice_id &&
      aggregated_invoice_line_id == o.aggregated_invoice_line_id &&
      currency == o.currency &&
      nominal_amount == o.nominal_amount &&
      actual_amount == o.actual_amount &&
      pricing_component_id == o.pricing_component_id &&
      pricing_component_name == o.pricing_component_name &&
      product_rate_plan_id == o.product_rate_plan_id &&
      product_rate_plan_name == o.product_rate_plan_name &&
      product_rate_plan_name_public == o.product_rate_plan_name_public &&
      product_id == o.product_id &&
      product_name == o.product_name &&
      product_name_public == o.product_name_public &&
      aggregated_subscription_id == o.aggregated_subscription_id &&
      subscription_id == o.subscription_id &&
       == o.
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 369

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /^(true|t|yes|y|1)$/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = BillForward.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 435

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 348

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /^Array<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


335
336
337
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 335

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



341
342
343
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 341

def hash
  [period_start, period_end, created, changed_by, id, organization_id, invoice_id, invoice_version_id, aggregated_invoice_id, aggregated_invoice_line_id, currency, nominal_amount, actual_amount, pricing_component_id, pricing_component_name, product_rate_plan_id, product_rate_plan_name, product_rate_plan_name_public, product_id, product_name, product_name_public, aggregated_subscription_id, subscription_id, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



270
271
272
273
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 270

def list_invalid_properties
  invalid_properties = Array.new
  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



415
416
417
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 415

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



421
422
423
424
425
426
427
428
429
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 421

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



409
410
411
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 409

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/bf_ruby2/models/revenue_attribution.rb', line 277

def valid?
  return false if @period_start.nil?
  return false if @period_end.nil?
  return false if @organization_id.nil?
  return false if @invoice_id.nil?
  return false if @invoice_version_id.nil?
  return false if @aggregated_invoice_id.nil?
  return false if @aggregated_invoice_line_id.nil?
  return false if @currency.nil?
  return false if @nominal_amount.nil?
  return false if @actual_amount.nil?
  return false if @pricing_component_id.nil?
  return false if @pricing_component_name.nil?
  return false if @product_rate_plan_id.nil?
  return false if @product_rate_plan_name.nil?
  return false if @product_rate_plan_name_public.nil?
  return false if @product_id.nil?
  return false if @product_name.nil?
  return false if @product_name_public.nil?
  return false if @aggregated_subscription_id.nil?
  return false if @subscription_id.nil?
  return false if @account_id.nil?
  return true
end