Class: BillForward::RolesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/roles_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RolesApi

Returns a new instance of RolesApi.



30
31
32
# File 'lib/bf_ruby2/api/roles_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/roles_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_role(role_request, opts = {}) ⇒ RolePagedMetadata

Create a new role. a new role","request":"createRoleRequest.html","response":"createRoleResponse.html"

Parameters:

  • role_request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/roles_api.rb', line 39

def create_role(role_request, opts = {})
  data, _status_code, _headers = create_role_with_http_info(role_request, opts)
  return data
end

#create_role_with_http_info(role_request, opts = {}) ⇒ Array<(RolePagedMetadata, Fixnum, Hash)>

Create a new role. a new role&quot;,&quot;request&quot;:&quot;createRoleRequest.html&quot;,&quot;response&quot;:&quot;createRoleResponse.html&quot;

Parameters:

  • role_request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RolePagedMetadata, Fixnum, Hash)>)

    RolePagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/roles_api.rb', line 49

def create_role_with_http_info(role_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RolesApi.create_role ..."
  end
  # verify the required parameter 'role_request' is set
  fail ArgumentError, "Missing the required parameter 'role_request' when calling RolesApi.create_role" if role_request.nil?
  # resource path
  local_var_path = "/roles".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(role_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RolePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesApi#create_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_roles(opts = {}) ⇒ RolePagedMetadata

Retrieves a collection of all roles. By default 10 values are returned. Records are returned in natural order. all roles","response":"getRoleAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)
  • :offset (Integer)

    The offset from the first subscription to return. (default to 0)

  • :records (Integer)

    The maximum number of subscriptions to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/roles_api.rb', line 101

def get_all_roles(opts = {})
  data, _status_code, _headers = get_all_roles_with_http_info(opts)
  return data
end

#get_all_roles_with_http_info(opts = {}) ⇒ Array<(RolePagedMetadata, Fixnum, Hash)>

Retrieves a collection of all roles. By default 10 values are returned. Records are returned in natural order. all roles&quot;,&quot;response&quot;:&quot;getRoleAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)
  • :offset (Integer)

    The offset from the first subscription to return.

  • :records (Integer)

    The maximum number of subscriptions to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:

  • (Array<(RolePagedMetadata, Fixnum, Hash)>)

    RolePagedMetadata data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/roles_api.rb', line 116

def get_all_roles_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RolesApi.get_all_roles ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/roles".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RolePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesApi#get_all_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_role_by_id(role, opts = {}) ⇒ RolePagedMetadata

Retrieves a single role, specified by the ID parameter. a role","response":"getRoleByID.html"

Parameters:

  • role

    ID or name of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)
  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned. (default to false)

Returns:



172
173
174
175
# File 'lib/bf_ruby2/api/roles_api.rb', line 172

def get_role_by_id(role, opts = {})
  data, _status_code, _headers = get_role_by_id_with_http_info(role, opts)
  return data
end

#get_role_by_id_with_http_info(role, opts = {}) ⇒ Array<(RolePagedMetadata, Fixnum, Hash)>

Retrieves a single role, specified by the ID parameter. a role&quot;,&quot;response&quot;:&quot;getRoleByID.html&quot;

Parameters:

  • role

    ID or name of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)
  • :include_retired (BOOLEAN)

    Whether retired subscriptions should be returned.

Returns:

  • (Array<(RolePagedMetadata, Fixnum, Hash)>)

    RolePagedMetadata data, response status code and response headers



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/bf_ruby2/api/roles_api.rb', line 184

def get_role_by_id_with_http_info(role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RolesApi.get_role_by_id ..."
  end
  # verify the required parameter 'role' is set
  fail ArgumentError, "Missing the required parameter 'role' when calling RolesApi.get_role_by_id" if role.nil?
  # resource path
  local_var_path = "/roles/{role}".sub('{format}','json').sub('{' + 'role' + '}', role.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RolePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesApi#get_role_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_permission_from_role(role, resource, action, opts = {}) ⇒ RolePagedMetadata

Revokes a particular permission Permission from role","response":"removePermissionFromGroup.html","request":"removePermissionFromGroupRequest.html"

Parameters:

  • role

    ID or name of the role.

  • resource
  • action
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

Returns:



236
237
238
239
# File 'lib/bf_ruby2/api/roles_api.rb', line 236

def remove_permission_from_role(role, resource, action, opts = {})
  data, _status_code, _headers = remove_permission_from_role_with_http_info(role, resource, action, opts)
  return data
end

#remove_permission_from_role_with_http_info(role, resource, action, opts = {}) ⇒ Array<(RolePagedMetadata, Fixnum, Hash)>

Revokes a particular permission Permission from role&quot;,&quot;response&quot;:&quot;removePermissionFromGroup.html&quot;,&quot;request&quot;:&quot;removePermissionFromGroupRequest.html&quot;

Parameters:

  • role

    ID or name of the role.

  • resource
  • action
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

Returns:

  • (Array<(RolePagedMetadata, Fixnum, Hash)>)

    RolePagedMetadata data, response status code and response headers



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/bf_ruby2/api/roles_api.rb', line 249

def remove_permission_from_role_with_http_info(role, resource, action, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RolesApi.remove_permission_from_role ..."
  end
  # verify the required parameter 'role' is set
  fail ArgumentError, "Missing the required parameter 'role' when calling RolesApi.remove_permission_from_role" if role.nil?
  # verify the required parameter 'resource' is set
  fail ArgumentError, "Missing the required parameter 'resource' when calling RolesApi.remove_permission_from_role" if resource.nil?
  # verify enum value
  unless ['All', 'Account', 'Address', 'Amendment', 'Analytics', 'Audit', 'BFAdmin', 'BFJS', 'Charge', 'Client', 'Configuration', 'CouponBook', 'CouponBookDefinition', 'CouponDefinition', 'CouponInstance', 'CouponModifier', 'CouponRule', 'Coupon', 'Credit', 'CybersourceToken', 'Dunning', 'Email', 'FixedTerm', 'Gateway', 'Invoice', 'Notification', 'Organization', 'Password', 'PaymentMethod', 'Payment', 'Permission', 'PricingComponent', 'PricingComponentTier', 'PricingComponentValueChange', 'PricingComponentValue', 'ProductRatePlan', 'Product', 'ProductResources', 'Profile', 'Quote', 'Receipt', 'Refund', 'Salesforce', 'Search', 'Subscription', 'Tax', 'UnitOfMeasure', 'Usage', 'Username', 'User', 'UserResources', 'Webhook'].include?(resource)
    fail ArgumentError, "invalid value for 'resource', must be one of All, Account, Address, Amendment, Analytics, Audit, BFAdmin, BFJS, Charge, Client, Configuration, CouponBook, CouponBookDefinition, CouponDefinition, CouponInstance, CouponModifier, CouponRule, Coupon, Credit, CybersourceToken, Dunning, Email, FixedTerm, Gateway, Invoice, Notification, Organization, Password, PaymentMethod, Payment, Permission, PricingComponent, PricingComponentTier, PricingComponentValueChange, PricingComponentValue, ProductRatePlan, Product, ProductResources, Profile, Quote, Receipt, Refund, Salesforce, Search, Subscription, Tax, UnitOfMeasure, Usage, Username, User, UserResources, Webhook"
  end
  # verify the required parameter 'action' is set
  fail ArgumentError, "Missing the required parameter 'action' when calling RolesApi.remove_permission_from_role" if action.nil?
  # verify enum value
  unless ['All', 'AddToInvoice', 'AddToProductRatePlan', 'AddToSubscription', 'Advance', 'Aggregate', 'RemoveFromInvoice', 'RemoveFromProductRatePlan', 'RemoveFromSubscription', 'Cancel', 'Create', 'Delete', 'Edit', 'Execute', 'Freeze', 'Import', 'InvoiceCharges', 'Issue', 'Migrate', 'Read', 'Recalculate', 'Reset', 'Resume', 'Revive', 'Stop', 'Tokenize', 'Void'].include?(action)
    fail ArgumentError, "invalid value for 'action', must be one of All, AddToInvoice, AddToProductRatePlan, AddToSubscription, Advance, Aggregate, RemoveFromInvoice, RemoveFromProductRatePlan, RemoveFromSubscription, Cancel, Create, Delete, Edit, Execute, Freeze, Import, InvoiceCharges, Issue, Migrate, Read, Recalculate, Reset, Resume, Revive, Stop, Tokenize, Void"
  end
  # resource path
  local_var_path = "/roles/{role}/permission/{resource}/{action}".sub('{format}','json').sub('{' + 'role' + '}', role.to_s).sub('{' + 'resource' + '}', resource.to_s).sub('{' + 'action' + '}', action.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RolePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesApi#remove_permission_from_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#revoke_role(role, opts = {}) ⇒ RolePagedMetadata

Revokes a role role","response":"revokeRole.html","request":"revokeRoleRequest.html"

Parameters:

  • role

    ID or name of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

Returns:



310
311
312
313
# File 'lib/bf_ruby2/api/roles_api.rb', line 310

def revoke_role(role, opts = {})
  data, _status_code, _headers = revoke_role_with_http_info(role, opts)
  return data
end

#revoke_role_with_http_info(role, opts = {}) ⇒ Array<(RolePagedMetadata, Fixnum, Hash)>

Revokes a role role&quot;,&quot;response&quot;:&quot;revokeRole.html&quot;,&quot;request&quot;:&quot;revokeRoleRequest.html&quot;

Parameters:

  • role

    ID or name of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

Returns:

  • (Array<(RolePagedMetadata, Fixnum, Hash)>)

    RolePagedMetadata data, response status code and response headers



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/bf_ruby2/api/roles_api.rb', line 321

def revoke_role_with_http_info(role, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RolesApi.revoke_role ..."
  end
  # verify the required parameter 'role' is set
  fail ArgumentError, "Missing the required parameter 'role' when calling RolesApi.revoke_role" if role.nil?
  # resource path
  local_var_path = "/roles/{role}".sub('{format}','json').sub('{' + 'role' + '}', role.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RolePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesApi#revoke_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_role(role_request, opts = {}) ⇒ RolePagedMetadata

Update a role. a role","request":"updateRoleRequest.html","response":"updateRoleResponse.html"

Parameters:

  • role_request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



369
370
371
372
# File 'lib/bf_ruby2/api/roles_api.rb', line 369

def update_role(role_request, opts = {})
  data, _status_code, _headers = update_role_with_http_info(role_request, opts)
  return data
end

#update_role_with_http_info(role_request, opts = {}) ⇒ Array<(RolePagedMetadata, Fixnum, Hash)>

Update a role. a role&quot;,&quot;request&quot;:&quot;updateRoleRequest.html&quot;,&quot;response&quot;:&quot;updateRoleResponse.html&quot;

Parameters:

  • role_request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RolePagedMetadata, Fixnum, Hash)>)

    RolePagedMetadata data, response status code and response headers



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/bf_ruby2/api/roles_api.rb', line 379

def update_role_with_http_info(role_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RolesApi.update_role ..."
  end
  # verify the required parameter 'role_request' is set
  fail ArgumentError, "Missing the required parameter 'role_request' when calling RolesApi.update_role" if role_request.nil?
  # resource path
  local_var_path = "/roles".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(role_request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RolePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesApi#update_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end