Class: BillForward::SynchAppConfigsApi
- Inherits:
-
Object
- Object
- BillForward::SynchAppConfigsApi
- Defined in:
- lib/bf_ruby2/api/synch_app_configs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_sync_app_config(synch_app_config, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Create a synch app configuration.
-
#create_sync_app_config_with_http_info(synch_app_config, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Create a synch app configuration.
-
#get_sync_app_config(synch_app_configs_id, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Returns a single config, specified by the ID parameter.
-
#get_sync_app_config_by_platform(platform, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Returns a collection configurations, specified by the platform parameter.
-
#get_sync_app_config_by_platform_with_http_info(platform, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection configurations, specified by the platform parameter.
-
#get_sync_app_config_with_http_info(synch_app_configs_id, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Returns a single config, specified by the ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ SynchAppConfigsApi
constructor
A new instance of SynchAppConfigsApi.
-
#update_sync_app_config(synch_app_config, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Update a synch app configuration.
-
#update_sync_app_config_with_http_info(synch_app_config, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Update a synch app configuration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SynchAppConfigsApi
Returns a new instance of SynchAppConfigsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_sync_app_config(synch_app_config, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Create a synch app configuration. a new synch app configuration","request":"createSynchAppConfigurationRequest.html","response":"createSynchAppConfigurationResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 39 def create_sync_app_config(synch_app_config, opts = {}) data, _status_code, _headers = create_sync_app_config_with_http_info(synch_app_config, opts) return data end |
#create_sync_app_config_with_http_info(synch_app_config, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Create a synch app configuration. a new synch app configuration","request":"createSynchAppConfigurationRequest.html","response":"createSynchAppConfigurationResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 49 def create_sync_app_config_with_http_info(synch_app_config, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchAppConfigsApi.create_sync_app_config ..." end # verify the required parameter 'synch_app_config' is set fail ArgumentError, "Missing the required parameter 'synch_app_config' when calling SynchAppConfigsApi.create_sync_app_config" if synch_app_config.nil? # resource path local_var_path = "/synchAppConfigs".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(synch_app_config) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationAppConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchAppConfigsApi#create_sync_app_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_app_config(synch_app_configs_id, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Returns a single config, specified by the ID parameter. { "nickname" : "Retrieve an existing synch config","response" : "getSynchAppConfigByID.html"}
97 98 99 100 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 97 def get_sync_app_config(synch_app_configs_id, opts = {}) data, _status_code, _headers = get_sync_app_config_with_http_info(synch_app_configs_id, opts) return data end |
#get_sync_app_config_by_platform(platform, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Returns a collection configurations, specified by the platform parameter. { "nickname" : "Retrieve by platform","response" : "getSynchAppConfigsByPlatform.html"}
157 158 159 160 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 157 def get_sync_app_config_by_platform(platform, opts = {}) data, _status_code, _headers = get_sync_app_config_by_platform_with_http_info(platform, opts) return data end |
#get_sync_app_config_by_platform_with_http_info(platform, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection configurations, specified by the platform parameter. { "nickname" : "Retrieve by platform","response" : "getSynchAppConfigsByPlatform.html"}
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 168 def get_sync_app_config_by_platform_with_http_info(platform, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchAppConfigsApi.get_sync_app_config_by_platform ..." end # verify the required parameter 'platform' is set fail ArgumentError, "Missing the required parameter 'platform' when calling SynchAppConfigsApi.get_sync_app_config_by_platform" if platform.nil? # verify enum value unless ['Salesforce'].include?(platform) fail ArgumentError, "invalid value for 'platform', must be one of Salesforce" end # resource path local_var_path = "/synchAppConfigs/platform/{platform}".sub('{format}','json').sub('{' + 'platform' + '}', platform.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationAppConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchAppConfigsApi#get_sync_app_config_by_platform\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_app_config_with_http_info(synch_app_configs_id, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Returns a single config, specified by the ID parameter. { "nickname" : "Retrieve an existing synch config","response" : "getSynchAppConfigByID.html"}
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 108 def get_sync_app_config_with_http_info(synch_app_configs_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchAppConfigsApi.get_sync_app_config ..." end # verify the required parameter 'synch_app_configs_id' is set fail ArgumentError, "Missing the required parameter 'synch_app_configs_id' when calling SynchAppConfigsApi.get_sync_app_config" if synch_app_configs_id.nil? # resource path local_var_path = "/synchAppConfigs/{synchAppConfigs-ID}".sub('{format}','json').sub('{' + 'synchAppConfigs-ID' + '}', synch_app_configs_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationAppConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchAppConfigsApi#get_sync_app_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_sync_app_config(synch_app_config, opts = {}) ⇒ DataSynchronisationAppConfigurationPagedMetadata
Update a synch app configuration. { "nickname" : "Update a sync app configuration", "request" : "updateSyncAppConfigRequest.html" ,"response" : "updateSyncAppConfigResponse.html" }
220 221 222 223 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 220 def update_sync_app_config(synch_app_config, opts = {}) data, _status_code, _headers = update_sync_app_config_with_http_info(synch_app_config, opts) return data end |
#update_sync_app_config_with_http_info(synch_app_config, opts = {}) ⇒ Array<(DataSynchronisationAppConfigurationPagedMetadata, Fixnum, Hash)>
Update a synch app configuration. { "nickname" : "Update a sync app configuration", "request" : "updateSyncAppConfigRequest.html" ,"response" : "updateSyncAppConfigResponse.html" }
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/bf_ruby2/api/synch_app_configs_api.rb', line 230 def update_sync_app_config_with_http_info(synch_app_config, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchAppConfigsApi.update_sync_app_config ..." end # verify the required parameter 'synch_app_config' is set fail ArgumentError, "Missing the required parameter 'synch_app_config' when calling SynchAppConfigsApi.update_sync_app_config" if synch_app_config.nil? # resource path local_var_path = "/synchAppConfigs".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(synch_app_config) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationAppConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchAppConfigsApi#update_sync_app_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |