Class: BillForward::TaxationlinksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/taxationlinks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ TaxationlinksApi

Returns a new instance of TaxationlinksApi.



30
31
32
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

Create a taxation strategy to a rate-plan","request":"createTaxationLinkRequest.html","response":"createTaxationLinkResponse.html"

Parameters:

  • taxation_link

    The taxation-link object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 39

def create_taxation_link(taxation_link, opts = {})
  data, _status_code, _headers = create_taxation_link_with_http_info(taxation_link, opts)
  return data
end

Create a taxation strategy to a rate-plan","request":"createTaxationLinkRequest.html","response":"createTaxationLinkResponse.html"

Parameters:

  • taxation_link

    The taxation-link object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TaxationLinkPagedMetadata, Fixnum, Hash)>)

    TaxationLinkPagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 49

def create_taxation_link_with_http_info(taxation_link, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TaxationlinksApi.create_taxation_link ..."
  end
  # verify the required parameter 'taxation_link' is set
  fail ArgumentError, "Missing the required parameter 'taxation_link' when calling TaxationlinksApi.create_taxation_link" if taxation_link.nil?
  # resource path
  local_var_path = "/taxation-links".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(taxation_link)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TaxationLinkPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TaxationlinksApi#create_taxation_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Returns a collection of all taxation-links. By default 10 values are returned. Records are returned in natural order. all taxation links","response":"getTaxationLinkAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return. (default to 0)

  • :records (Integer)

    The maximum number of taxation-links to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 101

def get_all_taxation_links(opts = {})
  data, _status_code, _headers = get_all_taxation_links_with_http_info(opts)
  return data
end

Returns a collection of all taxation-links. By default 10 values are returned. Records are returned in natural order. all taxation links&quot;,&quot;response&quot;:&quot;getTaxationLinkAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return.

  • :records (Integer)

    The maximum number of taxation-links to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(TaxationLinkPagedMetadata, Fixnum, Hash)>)

    TaxationLinkPagedMetadata data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 116

def get_all_taxation_links_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TaxationlinksApi.get_all_taxation_links ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/taxation-links".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TaxationLinkPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TaxationlinksApi#get_all_taxation_links\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Returns a single taxation-link, specified by the taxation-link-ID parameter. an existing taxation link","response":"getTaxationLinkByID.html"

Parameters:

  • taxation_link_id

    The unique ID of the Taxation Link.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



171
172
173
174
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 171

def get_taxation_link_by_id(taxation_link_id, opts = {})
  data, _status_code, _headers = get_taxation_link_by_id_with_http_info(taxation_link_id, opts)
  return data
end

Returns a single taxation-link, specified by the taxation-link-ID parameter. an existing taxation link&quot;,&quot;response&quot;:&quot;getTaxationLinkByID.html&quot;

Parameters:

  • taxation_link_id

    The unique ID of the Taxation Link.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(TaxationLinkPagedMetadata, Fixnum, Hash)>)

    TaxationLinkPagedMetadata data, response status code and response headers



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 182

def get_taxation_link_by_id_with_http_info(taxation_link_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TaxationlinksApi.get_taxation_link_by_id ..."
  end
  # verify the required parameter 'taxation_link_id' is set
  fail ArgumentError, "Missing the required parameter 'taxation_link_id' when calling TaxationlinksApi.get_taxation_link_by_id" if taxation_link_id.nil?
  # resource path
  local_var_path = "/taxation-links/{taxation-link-ID}".sub('{format}','json').sub('{' + 'taxation-link-ID' + '}', taxation_link_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TaxationLinkPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TaxationlinksApi#get_taxation_link_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Returns a collection of taxation-links, specified by the product-rate-plan-ID parameter. By default 10 values are returned. Records are returned in natural order. by rate-plan","response":"getTaxationLinkByPRPID.html"

Parameters:

  • product_rate_plan_id

    The ID of the product-rate-plan

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return. (default to 0)

  • :records (Integer)

    The maximum number of taxation-links to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



236
237
238
239
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 236

def get_taxation_link_by_product_rate_plan(product_rate_plan_id, opts = {})
  data, _status_code, _headers = get_taxation_link_by_product_rate_plan_with_http_info(product_rate_plan_id, opts)
  return data
end

Returns a collection of taxation-links, specified by the product-rate-plan-ID parameter. By default 10 values are returned. Records are returned in natural order. by rate-plan&quot;,&quot;response&quot;:&quot;getTaxationLinkByPRPID.html&quot;

Parameters:

  • product_rate_plan_id

    The ID of the product-rate-plan

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return.

  • :records (Integer)

    The maximum number of taxation-links to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(TaxationLinkPagedMetadata, Fixnum, Hash)>)

    TaxationLinkPagedMetadata data, response status code and response headers



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 252

def get_taxation_link_by_product_rate_plan_with_http_info(product_rate_plan_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TaxationlinksApi.get_taxation_link_by_product_rate_plan ..."
  end
  # verify the required parameter 'product_rate_plan_id' is set
  fail ArgumentError, "Missing the required parameter 'product_rate_plan_id' when calling TaxationlinksApi.get_taxation_link_by_product_rate_plan" if product_rate_plan_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/taxation-links/product-rate-plan/{product-rate-plan-ID}".sub('{format}','json').sub('{' + 'product-rate-plan-ID' + '}', product_rate_plan_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TaxationLinkPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TaxationlinksApi#get_taxation_link_by_product_rate_plan\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Returns a collection of taxation-links, specified by the taxation-strategy-ID parameter. By default 10 values are returned. Records are returned in natural order. by taxation strategy","response":"getTaxationLinkByTSID.html"

Parameters:

  • taxation_strategy_id

    The ID of the taxation-strategy

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return. (default to 0)

  • :records (Integer)

    The maximum number of taxation-links to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



314
315
316
317
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 314

def get_taxation_link_by_taxation_strategy(taxation_strategy_id, opts = {})
  data, _status_code, _headers = get_taxation_link_by_taxation_strategy_with_http_info(taxation_strategy_id, opts)
  return data
end

Returns a collection of taxation-links, specified by the taxation-strategy-ID parameter. By default 10 values are returned. Records are returned in natural order. by taxation strategy&quot;,&quot;response&quot;:&quot;getTaxationLinkByTSID.html&quot;

Parameters:

  • taxation_strategy_id

    The ID of the taxation-strategy

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return.

  • :records (Integer)

    The maximum number of taxation-links to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(TaxationLinkPagedMetadata, Fixnum, Hash)>)

    TaxationLinkPagedMetadata data, response status code and response headers



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 330

def get_taxation_link_by_taxation_strategy_with_http_info(taxation_strategy_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TaxationlinksApi.get_taxation_link_by_taxation_strategy ..."
  end
  # verify the required parameter 'taxation_strategy_id' is set
  fail ArgumentError, "Missing the required parameter 'taxation_strategy_id' when calling TaxationlinksApi.get_taxation_link_by_taxation_strategy" if taxation_strategy_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/taxation-links/taxation-strategy/{taxation-strategy-ID}".sub('{format}','json').sub('{' + 'taxation-strategy-ID' + '}', taxation_strategy_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TaxationLinkPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TaxationlinksApi#get_taxation_link_by_taxation_strategy\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

Update taxation linked to rate-plan","request":"updateTaxationLinkRequest.html","response":"updateTaxationLinkResponse.html"

Parameters:

  • taxation_link

    The taxation-link object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



386
387
388
389
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 386

def update_taxation_link(taxation_link, opts = {})
  data, _status_code, _headers = update_taxation_link_with_http_info(taxation_link, opts)
  return data
end

Update taxation linked to rate-plan&quot;,&quot;request&quot;:&quot;updateTaxationLinkRequest.html&quot;,&quot;response&quot;:&quot;updateTaxationLinkResponse.html&quot;

Parameters:

  • taxation_link

    The taxation-link object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(TaxationLinkPagedMetadata, Fixnum, Hash)>)

    TaxationLinkPagedMetadata data, response status code and response headers



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/bf_ruby2/api/taxationlinks_api.rb', line 396

def update_taxation_link_with_http_info(taxation_link, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: TaxationlinksApi.update_taxation_link ..."
  end
  # verify the required parameter 'taxation_link' is set
  fail ArgumentError, "Missing the required parameter 'taxation_link' when calling TaxationlinksApi.update_taxation_link" if taxation_link.nil?
  # resource path
  local_var_path = "/taxation-links".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(taxation_link)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TaxationLinkPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TaxationlinksApi#update_taxation_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end