Class: BillForward::UnitofmeasureApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/unitofmeasure_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UnitofmeasureApi

Returns a new instance of UnitofmeasureApi.



30
31
32
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_unit_of_measure(unit_of_measure, opts = {}) ⇒ UnitOfMeasurePagedMetadata

Create a unit-of-measure. a new unit of measure","request":"createUnitOfMeasureRequest.html","response":"createUnitOfMeasureResponse.html"

Parameters:

  • unit_of_measure

    The unit-of-measure object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 39

def create_unit_of_measure(unit_of_measure, opts = {})
  data, _status_code, _headers = create_unit_of_measure_with_http_info(unit_of_measure, opts)
  return data
end

#create_unit_of_measure_with_http_info(unit_of_measure, opts = {}) ⇒ Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>

Create a unit-of-measure. a new unit of measure&quot;,&quot;request&quot;:&quot;createUnitOfMeasureRequest.html&quot;,&quot;response&quot;:&quot;createUnitOfMeasureResponse.html&quot;

Parameters:

  • unit_of_measure

    The unit-of-measure object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>)

    UnitOfMeasurePagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 49

def create_unit_of_measure_with_http_info(unit_of_measure, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UnitofmeasureApi.create_unit_of_measure ..."
  end
  # verify the required parameter 'unit_of_measure' is set
  fail ArgumentError, "Missing the required parameter 'unit_of_measure' when calling UnitofmeasureApi.create_unit_of_measure" if unit_of_measure.nil?
  # resource path
  local_var_path = "/units-of-measure".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(unit_of_measure)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UnitOfMeasurePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UnitofmeasureApi#create_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_units_of_measure(opts = {}) ⇒ UnitOfMeasurePagedMetadata

Returns a collection of all unit-of-measure objects. By default 10 values are returned. Records are returned in natural order. all units of measure","response":"getUnitOfMeasureAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return. (default to 0)

  • :records (Integer)

    The maximum number of taxation-links to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



101
102
103
104
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 101

def get_all_units_of_measure(opts = {})
  data, _status_code, _headers = get_all_units_of_measure_with_http_info(opts)
  return data
end

#get_all_units_of_measure_with_http_info(opts = {}) ⇒ Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>

Returns a collection of all unit-of-measure objects. By default 10 values are returned. Records are returned in natural order. all units of measure&quot;,&quot;response&quot;:&quot;getUnitOfMeasureAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first taxation-link to return.

  • :records (Integer)

    The maximum number of taxation-links to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>)

    UnitOfMeasurePagedMetadata data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 116

def get_all_units_of_measure_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UnitofmeasureApi.get_all_units_of_measure ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/units-of-measure".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UnitOfMeasurePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UnitofmeasureApi#get_all_units_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_unit_of_measure_by_id(unit_of_measure_identifier, opts = {}) ⇒ UnitOfMeasurePagedMetadata

Returns a single unit-of-measure corresponding to the unique id or name specified. an existing unit of measure","response":"getUnitOfMeasureByID.html"

Parameters:

  • unit_of_measure_identifier

    The unique id or name of the unit-of-measure.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



171
172
173
174
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 171

def get_unit_of_measure_by_id(unit_of_measure_identifier, opts = {})
  data, _status_code, _headers = get_unit_of_measure_by_id_with_http_info(unit_of_measure_identifier, opts)
  return data
end

#get_unit_of_measure_by_id_with_http_info(unit_of_measure_identifier, opts = {}) ⇒ Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>

Returns a single unit-of-measure corresponding to the unique id or name specified. an existing unit of measure&quot;,&quot;response&quot;:&quot;getUnitOfMeasureByID.html&quot;

Parameters:

  • unit_of_measure_identifier

    The unique id or name of the unit-of-measure.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>)

    UnitOfMeasurePagedMetadata data, response status code and response headers



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 182

def get_unit_of_measure_by_id_with_http_info(unit_of_measure_identifier, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UnitofmeasureApi.get_unit_of_measure_by_id ..."
  end
  # verify the required parameter 'unit_of_measure_identifier' is set
  fail ArgumentError, "Missing the required parameter 'unit_of_measure_identifier' when calling UnitofmeasureApi.get_unit_of_measure_by_id" if unit_of_measure_identifier.nil?
  # resource path
  local_var_path = "/units-of-measure/{unit-of-measure-identifier}".sub('{format}','json').sub('{' + 'unit-of-measure-identifier' + '}', unit_of_measure_identifier.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UnitOfMeasurePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UnitofmeasureApi#get_unit_of_measure_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_unit_of_measure(unit_of_measure, opts = {}) ⇒ UnitOfMeasurePagedMetadata

Update a unit-of-measure. a unit of measure","request":"updateUnitOfMeasureRequest.html","response":"updateUnitOfMeasureResponse.html"

Parameters:

  • unit_of_measure

    The unit-of-measure object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



230
231
232
233
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 230

def update_unit_of_measure(unit_of_measure, opts = {})
  data, _status_code, _headers = update_unit_of_measure_with_http_info(unit_of_measure, opts)
  return data
end

#update_unit_of_measure_with_http_info(unit_of_measure, opts = {}) ⇒ Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>

Update a unit-of-measure. a unit of measure&quot;,&quot;request&quot;:&quot;updateUnitOfMeasureRequest.html&quot;,&quot;response&quot;:&quot;updateUnitOfMeasureResponse.html&quot;

Parameters:

  • unit_of_measure

    The unit-of-measure object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UnitOfMeasurePagedMetadata, Fixnum, Hash)>)

    UnitOfMeasurePagedMetadata data, response status code and response headers



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/bf_ruby2/api/unitofmeasure_api.rb', line 240

def update_unit_of_measure_with_http_info(unit_of_measure, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UnitofmeasureApi.update_unit_of_measure ..."
  end
  # verify the required parameter 'unit_of_measure' is set
  fail ArgumentError, "Missing the required parameter 'unit_of_measure' when calling UnitofmeasureApi.update_unit_of_measure" if unit_of_measure.nil?
  # resource path
  local_var_path = "/units-of-measure".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(unit_of_measure)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UnitOfMeasurePagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UnitofmeasureApi#update_unit_of_measure\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end