Class: BillForward::UpdatePricingComponentValueChangeResult
- Inherits:
-
Object
- Object
- BillForward::UpdatePricingComponentValueChangeResult
- Defined in:
- lib/bf_ruby2/models/update_pricing_component_value_change_result.rb
Overview
UpdatePricingComponentValueChangeResult
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amendment ⇒ Object
If an amendment has been created in the prcess (ie. if the update has to be delayed to the ending billing period), this field will contain it.
-
#amount ⇒ Object
The issued amount.
-
#charge ⇒ Object
If a debit or credit charge has been created in the process, this field will contain it.
-
#charge_type ⇒ Object
This field state if the issued amount is a Debit or Credit.
-
#new_value ⇒ Object
The value of the Pricing Component after the update.
-
#old_value ⇒ Object
The Pricing Component Value before the update.
-
#pricing_component_id ⇒ Object
The ID of the updated Pricing Component.
-
#pricing_component_name ⇒ Object
The name of the updated Pricing Component.
-
#pricing_component_public_name ⇒ Object
The public name of the updated Pricing Component.
-
#state ⇒ Object
state of the update. <ul><li>Succeeded: The change has been applied. This state only happens for immediate changes and if the generated invoice has been successfully paid.</li><li>Failed: The change has not been applied. This state only happens for immediate changes and if the generated invoice has not been successfully paid.</li><li>Pending: The changes has not been applied yet. An amendment has been created that will be triggered in the future applying the change. The resulting state can’t be predicted at this time.</li></ul>".
-
#subscription_id ⇒ Object
The ID of the updated Subscription.
-
#type ⇒ Object
The type of the result.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePricingComponentValueChangeResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePricingComponentValueChangeResult
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 125 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'pricingComponentID') self.pricing_component_id = attributes[:'pricingComponentID'] end if attributes.has_key?(:'pricingComponentName') self.pricing_component_name = attributes[:'pricingComponentName'] end if attributes.has_key?(:'pricingComponentPublicName') self.pricing_component_public_name = attributes[:'pricingComponentPublicName'] end if attributes.has_key?(:'newValue') self.new_value = attributes[:'newValue'] end if attributes.has_key?(:'oldValue') self.old_value = attributes[:'oldValue'] end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'subscriptionID') self.subscription_id = attributes[:'subscriptionID'] end if attributes.has_key?(:'amount') self.amount = attributes[:'amount'] end if attributes.has_key?(:'chargeType') self.charge_type = attributes[:'chargeType'] end if attributes.has_key?(:'charge') self.charge = attributes[:'charge'] end if attributes.has_key?(:'amendment') self.amendment = attributes[:'amendment'] end if attributes.has_key?(:'state') self.state = attributes[:'state'] end end |
Instance Attribute Details
#amendment ⇒ Object
If an amendment has been created in the prcess (ie. if the update has to be delayed to the ending billing period), this field will contain it.
60 61 62 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 60 def amendment @amendment end |
#amount ⇒ Object
The issued amount.
51 52 53 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 51 def amount @amount end |
#charge ⇒ Object
If a debit or credit charge has been created in the process, this field will contain it.
57 58 59 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 57 def charge @charge end |
#charge_type ⇒ Object
This field state if the issued amount is a Debit or Credit. This field will be null if the amount is 0 (zero)
54 55 56 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 54 def charge_type @charge_type end |
#new_value ⇒ Object
The value of the Pricing Component after the update.
39 40 41 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 39 def new_value @new_value end |
#old_value ⇒ Object
The Pricing Component Value before the update.
42 43 44 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 42 def old_value @old_value end |
#pricing_component_id ⇒ Object
The ID of the updated Pricing Component.
30 31 32 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 30 def pricing_component_id @pricing_component_id end |
#pricing_component_name ⇒ Object
The name of the updated Pricing Component.
33 34 35 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 33 def pricing_component_name @pricing_component_name end |
#pricing_component_public_name ⇒ Object
The public name of the updated Pricing Component.
36 37 38 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 36 def pricing_component_public_name @pricing_component_public_name end |
#state ⇒ Object
state of the update. <ul><li>Succeeded: The change has been applied. This state only happens for immediate changes and if the generated invoice has been successfully paid.</li><li>Failed: The change has not been applied. This state only happens for immediate changes and if the generated invoice has not been successfully paid.</li><li>Pending: The changes has not been applied yet. An amendment has been created that will be triggered in the future applying the change. The resulting state can’t be predicted at this time.</li></ul>"
63 64 65 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 63 def state @state end |
#subscription_id ⇒ Object
The ID of the updated Subscription.
48 49 50 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 48 def subscription_id @subscription_id end |
#type ⇒ Object
The type of the result.
45 46 47 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 45 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 88 def self.attribute_map { :'pricing_component_id' => :'pricingComponentID', :'pricing_component_name' => :'pricingComponentName', :'pricing_component_public_name' => :'pricingComponentPublicName', :'new_value' => :'newValue', :'old_value' => :'oldValue', :'type' => :'type', :'subscription_id' => :'subscriptionID', :'amount' => :'amount', :'charge_type' => :'chargeType', :'charge' => :'charge', :'amendment' => :'amendment', :'state' => :'state' } end |
.swagger_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 106 def self.swagger_types { :'pricing_component_id' => :'String', :'pricing_component_name' => :'String', :'pricing_component_public_name' => :'String', :'new_value' => :'Integer', :'old_value' => :'Integer', :'type' => :'String', :'subscription_id' => :'String', :'amount' => :'Float', :'charge_type' => :'String', :'charge' => :'SubscriptionCharge', :'amendment' => :'Amendment', :'state' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && pricing_component_id == o.pricing_component_id && pricing_component_name == o.pricing_component_name && pricing_component_public_name == o.pricing_component_public_name && new_value == o.new_value && old_value == o.old_value && type == o.type && subscription_id == o.subscription_id && amount == o.amount && charge_type == o.charge_type && charge == o.charge && amendment == o.amendment && state == o.state end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 285 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 351 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 264 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 257 def hash [pricing_component_id, pricing_component_name, pricing_component_public_name, new_value, old_value, type, subscription_id, amount, charge_type, charge, amendment, state].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
183 184 185 186 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 183 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 194 195 196 197 198 |
# File 'lib/bf_ruby2/models/update_pricing_component_value_change_result.rb', line 190 def valid? type_validator = EnumAttributeValidator.new('String', ["Upgrade", "Downgrade", "NoChange"]) return false unless type_validator.valid?(@type) charge_type_validator = EnumAttributeValidator.new('String', ["Credit", "Debit"]) return false unless charge_type_validator.valid?(@charge_type) state_validator = EnumAttributeValidator.new('String', ["Failed", "Succeeded", "Pending"]) return false unless state_validator.valid?(@state) return true end |