Class: BillForward::UsagesessionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/usagesessions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UsagesessionsApi



30
31
32
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#get_active_sessions_for_subscription(subscription_id, opts = {}) ⇒ UsageSessionPagedMetadata

Get active by subscription active by subscription","response":"getActiveSessions.html"

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first amendment to return. (default to 0)

  • :records (Integer)

    The maximum number of amendments to return. (default to 8766)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    The direction of any ordering, either ASC or DESC. (default to ASC)



44
45
46
47
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 44

def get_active_sessions_for_subscription(subscription_id, opts = {})
  data, _status_code, _headers = get_active_sessions_for_subscription_with_http_info(subscription_id, opts)
  return data
end

#get_active_sessions_for_subscription_with_http_info(subscription_id, opts = {}) ⇒ Array<(UsageSessionPagedMetadata, Fixnum, Hash)>

Get active by subscription active by subscription&quot;,&quot;response&quot;:&quot;getActiveSessions.html&quot;

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first amendment to return.

  • :records (Integer)

    The maximum number of amendments to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    The direction of any ordering, either ASC or DESC.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 59

def get_active_sessions_for_subscription_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UsagesessionsApi.get_active_sessions_for_subscription ..."
  end
  # verify the required parameter 'subscription_id' is set
  fail ArgumentError, "Missing the required parameter 'subscription_id' when calling UsagesessionsApi.get_active_sessions_for_subscription" if subscription_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/usage-sessions/{subscription-id}/active".sub('{format}','json').sub('{' + 'subscription-id' + '}', subscription_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UsageSessionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsagesessionsApi#get_active_sessions_for_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_usage_list_for_usage_session(subscription_id, opts = {}) ⇒ UsageSessionPagedMetadata

Retrieve by subscription by subscription","response":"getAllSessions.html"

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first amendment to return. (default to 0)

  • :records (Integer)

    The maximum number of amendments to return. (default to 8766)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    The direction of any ordering, either ASC or DESC. (default to ASC)



119
120
121
122
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 119

def get_usage_list_for_usage_session(subscription_id, opts = {})
  data, _status_code, _headers = get_usage_list_for_usage_session_with_http_info(subscription_id, opts)
  return data
end

#get_usage_list_for_usage_session_with_http_info(subscription_id, opts = {}) ⇒ Array<(UsageSessionPagedMetadata, Fixnum, Hash)>

Retrieve by subscription by subscription&quot;,&quot;response&quot;:&quot;getAllSessions.html&quot;

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first amendment to return.

  • :records (Integer)

    The maximum number of amendments to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    The direction of any ordering, either ASC or DESC.



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 134

def get_usage_list_for_usage_session_with_http_info(subscription_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UsagesessionsApi.get_usage_list_for_usage_session ..."
  end
  # verify the required parameter 'subscription_id' is set
  fail ArgumentError, "Missing the required parameter 'subscription_id' when calling UsagesessionsApi.get_usage_list_for_usage_session" if subscription_id.nil?
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/usage-sessions/{subscription-id}".sub('{format}','json').sub('{' + 'subscription-id' + '}', subscription_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UsageSessionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsagesessionsApi#get_usage_list_for_usage_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#start_usage_session(usage_sessions, opts = {}) ⇒ UsageSessionPagedMetadata

Start a new session a new session","request":"createStartUsageSessionRequest.html","response":"createStartUsageSessionResponse.html"



189
190
191
192
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 189

def start_usage_session(usage_sessions, opts = {})
  data, _status_code, _headers = start_usage_session_with_http_info(usage_sessions, opts)
  return data
end

#start_usage_session_with_http_info(usage_sessions, opts = {}) ⇒ Array<(UsageSessionPagedMetadata, Fixnum, Hash)>

Start a new session a new session&quot;,&quot;request&quot;:&quot;createStartUsageSessionRequest.html&quot;,&quot;response&quot;:&quot;createStartUsageSessionResponse.html&quot;



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 199

def start_usage_session_with_http_info(usage_sessions, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UsagesessionsApi.start_usage_session ..."
  end
  # verify the required parameter 'usage_sessions' is set
  fail ArgumentError, "Missing the required parameter 'usage_sessions' when calling UsagesessionsApi.start_usage_session" if usage_sessions.nil?
  # resource path
  local_var_path = "/usage-sessions/start".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(usage_sessions)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UsageSessionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsagesessionsApi#start_usage_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#stop_usage_session(usage_sessions, opts = {}) ⇒ UsageSessionPagedMetadata

Stop a specified session a specified session","request":"createStopUsageSessionRequest.html","response":"createStopUsageSessionResponse.html"



246
247
248
249
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 246

def stop_usage_session(usage_sessions, opts = {})
  data, _status_code, _headers = stop_usage_session_with_http_info(usage_sessions, opts)
  return data
end

#stop_usage_session_with_http_info(usage_sessions, opts = {}) ⇒ Array<(UsageSessionPagedMetadata, Fixnum, Hash)>

Stop a specified session a specified session&quot;,&quot;request&quot;:&quot;createStopUsageSessionRequest.html&quot;,&quot;response&quot;:&quot;createStopUsageSessionResponse.html&quot;



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/bf_ruby2/api/usagesessions_api.rb', line 256

def stop_usage_session_with_http_info(usage_sessions, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: UsagesessionsApi.stop_usage_session ..."
  end
  # verify the required parameter 'usage_sessions' is set
  fail ArgumentError, "Missing the required parameter 'usage_sessions' when calling UsagesessionsApi.stop_usage_session" if usage_sessions.nil?
  # resource path
  local_var_path = "/usage-sessions/stop".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(usage_sessions)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'UsageSessionPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsagesessionsApi#stop_usage_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end