Class: BillForward::VaultedgatewaysApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/vaultedgateways_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ VaultedgatewaysApi



30
31
32
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_authorize_net_token(authorize_net_token, opts = {}) ⇒ AuthorizeNetTokenPagedMetadata

Create an authorize-net-token. a authorize-net-token","request":"createAuthorizeNetTokenRequest.html","response":"createAuthorizeNetTokenResponse.html"



39
40
41
42
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 39

def create_authorize_net_token(authorize_net_token, opts = {})
  data, _status_code, _headers = create_authorize_net_token_with_http_info(authorize_net_token, opts)
  return data
end

#create_authorize_net_token_with_http_info(authorize_net_token, opts = {}) ⇒ Array<(AuthorizeNetTokenPagedMetadata, Fixnum, Hash)>

Create an authorize-net-token. a authorize-net-token&quot;,&quot;request&quot;:&quot;createAuthorizeNetTokenRequest.html&quot;,&quot;response&quot;:&quot;createAuthorizeNetTokenResponse.html&quot;



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 49

def create_authorize_net_token_with_http_info(authorize_net_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.create_authorize_net_token ..."
  end
  # verify the required parameter 'authorize_net_token' is set
  fail ArgumentError, "Missing the required parameter 'authorize_net_token' when calling VaultedgatewaysApi.create_authorize_net_token" if authorize_net_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/authorize-net".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(authorize_net_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'AuthorizeNetTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#create_authorize_net_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_braintree_token(braintree_token, opts = {}) ⇒ BraintreeTokenPagedMetadata

Create a braintree-token. a braintree-token","request":"createBraintreeTokenRequest.html","response":"BraintreeTokenResponse.html"



96
97
98
99
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 96

def create_braintree_token(braintree_token, opts = {})
  data, _status_code, _headers = create_braintree_token_with_http_info(braintree_token, opts)
  return data
end

#create_braintree_token_with_http_info(braintree_token, opts = {}) ⇒ Array<(BraintreeTokenPagedMetadata, Fixnum, Hash)>

Create a braintree-token. a braintree-token&quot;,&quot;request&quot;:&quot;createBraintreeTokenRequest.html&quot;,&quot;response&quot;:&quot;BraintreeTokenResponse.html&quot;



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 106

def create_braintree_token_with_http_info(braintree_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.create_braintree_token ..."
  end
  # verify the required parameter 'braintree_token' is set
  fail ArgumentError, "Missing the required parameter 'braintree_token' when calling VaultedgatewaysApi.create_braintree_token" if braintree_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/braintree".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(braintree_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BraintreeTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#create_braintree_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_stripe_ach_token(stripe_ach_token, opts = {}) ⇒ StripeACHTokenPagedMetadata

Create a stripe-ACH-token. a stripe-ACH-token","request":"createstripeACHTokenRequest.html","response":"createstripeACHTokenResponse.html"



153
154
155
156
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 153

def create_stripe_ach_token(stripe_ach_token, opts = {})
  data, _status_code, _headers = create_stripe_ach_token_with_http_info(stripe_ach_token, opts)
  return data
end

#create_stripe_ach_token_with_http_info(stripe_ach_token, opts = {}) ⇒ Array<(StripeACHTokenPagedMetadata, Fixnum, Hash)>

Create a stripe-ACH-token. a stripe-ACH-token&quot;,&quot;request&quot;:&quot;createstripeACHTokenRequest.html&quot;,&quot;response&quot;:&quot;createstripeACHTokenResponse.html&quot;



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 163

def create_stripe_ach_token_with_http_info(stripe_ach_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.create_stripe_ach_token ..."
  end
  # verify the required parameter 'stripe_ach_token' is set
  fail ArgumentError, "Missing the required parameter 'stripe_ach_token' when calling VaultedgatewaysApi.create_stripe_ach_token" if stripe_ach_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe-ACH".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(stripe_ach_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeACHTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#create_stripe_ach_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_stripe_token(stripe_token, opts = {}) ⇒ StripeTokenPagedMetadata

Create a stripe-token. a stripe-token","request":"createstripeTokenRequest.html","response":"createstripeTokenResponse.html"



210
211
212
213
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 210

def create_stripe_token(stripe_token, opts = {})
  data, _status_code, _headers = create_stripe_token_with_http_info(stripe_token, opts)
  return data
end

#create_stripe_token_with_http_info(stripe_token, opts = {}) ⇒ Array<(StripeTokenPagedMetadata, Fixnum, Hash)>

Create a stripe-token. a stripe-token&quot;,&quot;request&quot;:&quot;createstripeTokenRequest.html&quot;,&quot;response&quot;:&quot;createstripeTokenResponse.html&quot;



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 220

def create_stripe_token_with_http_info(stripe_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.create_stripe_token ..."
  end
  # verify the required parameter 'stripe_token' is set
  fail ArgumentError, "Missing the required parameter 'stripe_token' when calling VaultedgatewaysApi.create_stripe_token" if stripe_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(stripe_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#create_stripe_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_trust_commerce_token(trust_commerce_token, opts = {}) ⇒ TrustCommerceTokenPagedMetadata

Create a trust-commerce-token. a trust-commerce-token","request":"createTrustCommerceTokenRequest.html","response":"TrustCommerceTokenResponse.html"



267
268
269
270
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 267

def create_trust_commerce_token(trust_commerce_token, opts = {})
  data, _status_code, _headers = create_trust_commerce_token_with_http_info(trust_commerce_token, opts)
  return data
end

#create_trust_commerce_token_with_http_info(trust_commerce_token, opts = {}) ⇒ Array<(TrustCommerceTokenPagedMetadata, Fixnum, Hash)>

Create a trust-commerce-token. a trust-commerce-token&quot;,&quot;request&quot;:&quot;createTrustCommerceTokenRequest.html&quot;,&quot;response&quot;:&quot;TrustCommerceTokenResponse.html&quot;



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 277

def create_trust_commerce_token_with_http_info(trust_commerce_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.create_trust_commerce_token ..."
  end
  # verify the required parameter 'trust_commerce_token' is set
  fail ArgumentError, "Missing the required parameter 'trust_commerce_token' when calling VaultedgatewaysApi.create_trust_commerce_token" if trust_commerce_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/trustCommerce".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(trust_commerce_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'TrustCommerceTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#create_trust_commerce_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_braintree_by_account_id(account_id, opts = {}) ⇒ BraintreeTokenPagedMetadata

Returns a list of braintree-tokens backing PaymentMethods belonging to the specified account parameter. a list of braintree-token","response":"getBraintreeByAccountID.html"

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.Multiple organization-IDs may be specified by repeated use of the query parameter. Example: …&amp;organizations&#x3D;org1&amp;organizations&#x3D;org2



325
326
327
328
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 325

def (, opts = {})
  data, _status_code, _headers = (, opts)
  return data
end

#get_braintree_by_account_id_with_http_info(account_id, opts = {}) ⇒ Array<(BraintreeTokenPagedMetadata, Fixnum, Hash)>

Returns a list of braintree-tokens backing PaymentMethods belonging to the specified account parameter. a list of braintree-token&quot;,&quot;response&quot;:&quot;getBraintreeByAccountID.html&quot;

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.Multiple organization-IDs may be specified by repeated use of the query parameter. Example: …&amp;organizations&#x3D;org1&amp;organizations&#x3D;org2



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 336

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.get_braintree_by_account_id ..."
  end
  # verify the required parameter 'account_id' is set
  fail ArgumentError, "Missing the required parameter 'account_id' when calling VaultedgatewaysApi.get_braintree_by_account_id" if .nil?
  # resource path
  local_var_path = "/vaulted-gateways/braintree/{accountID}".sub('{format}','json').sub('{' + 'accountID' + '}', .to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BraintreeTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#get_braintree_by_account_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_by_card_details_id(card_details_id, opts = {}) ⇒ StripeTokenPagedMetadata

Returns a single stripe-token, specified by the cardDetailsID parameter. a stripe-token by cardDetailsID","response":"getStripeTokenByCardDetailsID.html"

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.



385
386
387
388
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 385

def get_by_card_details_id(card_details_id, opts = {})
  data, _status_code, _headers = get_by_card_details_id_with_http_info(card_details_id, opts)
  return data
end

#get_by_card_details_id_with_http_info(card_details_id, opts = {}) ⇒ Array<(StripeTokenPagedMetadata, Fixnum, Hash)>

Returns a single stripe-token, specified by the cardDetailsID parameter. a stripe-token by cardDetailsID&quot;,&quot;response&quot;:&quot;getStripeTokenByCardDetailsID.html&quot;

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 396

def get_by_card_details_id_with_http_info(card_details_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.get_by_card_details_id ..."
  end
  # verify the required parameter 'card_details_id' is set
  fail ArgumentError, "Missing the required parameter 'card_details_id' when calling VaultedgatewaysApi.get_by_card_details_id" if card_details_id.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe/card-details-id/{cardDetailsID}".sub('{format}','json').sub('{' + 'cardDetailsID' + '}', card_details_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#get_by_card_details_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_stripe_ach(stripe_ach_token_id, opts = {}) ⇒ StripeACHTokenPagedMetadata

Returns a single stripe-ACH-token, specified by the stripeACHTokenID parameter. a stripe-ACH-token","response":"getStripeACHTokenByID.html"

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.Multiple organization-IDs may be specified by repeated use of the query parameter. Example: …&amp;organizations&#x3D;org1&amp;organizations&#x3D;org2



445
446
447
448
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 445

def get_stripe_ach(stripe_ach_token_id, opts = {})
  data, _status_code, _headers = get_stripe_ach_with_http_info(stripe_ach_token_id, opts)
  return data
end

#get_stripe_ach_with_http_info(stripe_ach_token_id, opts = {}) ⇒ Array<(StripeACHTokenPagedMetadata, Fixnum, Hash)>

Returns a single stripe-ACH-token, specified by the stripeACHTokenID parameter. a stripe-ACH-token&quot;,&quot;response&quot;:&quot;getStripeACHTokenByID.html&quot;

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.Multiple organization-IDs may be specified by repeated use of the query parameter. Example: …&amp;organizations&#x3D;org1&amp;organizations&#x3D;org2



456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 456

def get_stripe_ach_with_http_info(stripe_ach_token_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.get_stripe_ach ..."
  end
  # verify the required parameter 'stripe_ach_token_id' is set
  fail ArgumentError, "Missing the required parameter 'stripe_ach_token_id' when calling VaultedgatewaysApi.get_stripe_ach" if stripe_ach_token_id.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe-ACH/{stripeACHTokenID}".sub('{format}','json').sub('{' + 'stripeACHTokenID' + '}', stripe_ach_token_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeACHTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#get_stripe_ach\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_stripe_token(stripe_token_id, opts = {}) ⇒ StripeTokenPagedMetadata

Returns a single stripe-token, specified by the stripeTokenID parameter. a stripe-token","response":"getStripeTokenByID.html"

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.Multiple organization-IDs may be specified by repeated use of the query parameter. Example: …&amp;organizations&#x3D;org1&amp;organizations&#x3D;org2



505
506
507
508
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 505

def get_stripe_token(stripe_token_id, opts = {})
  data, _status_code, _headers = get_stripe_token_with_http_info(stripe_token_id, opts)
  return data
end

#get_stripe_token_with_http_info(stripe_token_id, opts = {}) ⇒ Array<(StripeTokenPagedMetadata, Fixnum, Hash)>

Returns a single stripe-token, specified by the stripeTokenID parameter. a stripe-token&quot;,&quot;response&quot;:&quot;getStripeTokenByID.html&quot;

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.Multiple organization-IDs may be specified by repeated use of the query parameter. Example: …&amp;organizations&#x3D;org1&amp;organizations&#x3D;org2



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 516

def get_stripe_token_with_http_info(stripe_token_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.get_stripe_token ..."
  end
  # verify the required parameter 'stripe_token_id' is set
  fail ArgumentError, "Missing the required parameter 'stripe_token_id' when calling VaultedgatewaysApi.get_stripe_token" if stripe_token_id.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe/{stripeTokenID}".sub('{format}','json').sub('{' + 'stripeTokenID' + '}', stripe_token_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#get_stripe_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_stripe_ach_token(stripe_token, opts = {}) ⇒ StripeACHTokenPagedMetadata

Update a stripe-ACH-token. a stripe-ACH-token","request":"updatestripeACHTokenRequest.html","response":"updatestripeACHTokenResponse.html"



564
565
566
567
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 564

def update_stripe_ach_token(stripe_token, opts = {})
  data, _status_code, _headers = update_stripe_ach_token_with_http_info(stripe_token, opts)
  return data
end

#update_stripe_ach_token_with_http_info(stripe_token, opts = {}) ⇒ Array<(StripeACHTokenPagedMetadata, Fixnum, Hash)>

Update a stripe-ACH-token. a stripe-ACH-token&quot;,&quot;request&quot;:&quot;updatestripeACHTokenRequest.html&quot;,&quot;response&quot;:&quot;updatestripeACHTokenResponse.html&quot;



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 574

def update_stripe_ach_token_with_http_info(stripe_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.update_stripe_ach_token ..."
  end
  # verify the required parameter 'stripe_token' is set
  fail ArgumentError, "Missing the required parameter 'stripe_token' when calling VaultedgatewaysApi.update_stripe_ach_token" if stripe_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe-ACH".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(stripe_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeACHTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#update_stripe_ach_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_stripe_token(stripe_token, opts = {}) ⇒ StripeTokenPagedMetadata

Update a stripe-token. a stripe-token","request":"updatestripeTokenRequest.html","response":"updatestripeTokenResponse.html"



621
622
623
624
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 621

def update_stripe_token(stripe_token, opts = {})
  data, _status_code, _headers = update_stripe_token_with_http_info(stripe_token, opts)
  return data
end

#update_stripe_token_with_http_info(stripe_token, opts = {}) ⇒ Array<(StripeTokenPagedMetadata, Fixnum, Hash)>

Update a stripe-token. a stripe-token&quot;,&quot;request&quot;:&quot;updatestripeTokenRequest.html&quot;,&quot;response&quot;:&quot;updatestripeTokenResponse.html&quot;



631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 631

def update_stripe_token_with_http_info(stripe_token, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.update_stripe_token ..."
  end
  # verify the required parameter 'stripe_token' is set
  fail ArgumentError, "Missing the required parameter 'stripe_token' when calling VaultedgatewaysApi.update_stripe_token" if stripe_token.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(stripe_token)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'StripeTokenPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#update_stripe_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verify_bank_account(bank_account_verification, opts = {}) ⇒ BankAccountVerificationPagedMetadata

Verify Stripe bank account. Stripe bank account","response":"verifyStripeBankAccount.html"



678
679
680
681
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 678

def (, opts = {})
  data, _status_code, _headers = (, opts)
  return data
end

#verify_bank_account_with_http_info(bank_account_verification, opts = {}) ⇒ Array<(BankAccountVerificationPagedMetadata, Fixnum, Hash)>

Verify Stripe bank account. Stripe bank account&quot;,&quot;response&quot;:&quot;verifyStripeBankAccount.html&quot;



688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 688

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.verify_bank_account ..."
  end
  # verify the required parameter 'bank_account_verification' is set
  fail ArgumentError, "Missing the required parameter 'bank_account_verification' when calling VaultedgatewaysApi.verify_bank_account" if .nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe/verify-bank-account".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body()
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'BankAccountVerificationPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#verify_bank_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#webhook(event, opts = {}) ⇒ String

Receive and handle webhook from Stripe. Stripe webhook","response":"receiveStripeWebhook.html"



735
736
737
738
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 735

def webhook(event, opts = {})
  data, _status_code, _headers = webhook_with_http_info(event, opts)
  return data
end

#webhook_with_http_info(event, opts = {}) ⇒ Array<(String, Fixnum, Hash)>

Receive and handle webhook from Stripe. Stripe webhook&quot;,&quot;response&quot;:&quot;receiveStripeWebhook.html&quot;



745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
# File 'lib/bf_ruby2/api/vaultedgateways_api.rb', line 745

def webhook_with_http_info(event, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: VaultedgatewaysApi.webhook ..."
  end
  # verify the required parameter 'event' is set
  fail ArgumentError, "Missing the required parameter 'event' when calling VaultedgatewaysApi.webhook" if event.nil?
  # resource path
  local_var_path = "/vaulted-gateways/stripe/webhook".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(event)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'String')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: VaultedgatewaysApi#webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end