Class: BillForward::WebhooksApi

Inherits:
Object
  • Object
show all
Defined in:
lib/bf_ruby2/api/webhooks_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ WebhooksApi

Returns a new instance of WebhooksApi.



30
31
32
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 30

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



28
29
30
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 28

def api_client
  @api_client
end

Instance Method Details

#create_webhook(webhook, opts = {}) ⇒ WebhookPagedMetadata

Create a webhook. a new webhook","request":"createWebhookRequest.html","response":"createWebhookResponse.html"

Parameters:

  • webhook

    The webhook object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 39

def create_webhook(webhook, opts = {})
  data, _status_code, _headers = create_webhook_with_http_info(webhook, opts)
  return data
end

#create_webhook_v2(request, opts = {}) ⇒ WebhookPagedMetadata

Create a webhook. a new webhook","request":"createWebhookRequest.html","response":"createWebhookResponse.html"

Parameters:

  • request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



96
97
98
99
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 96

def create_webhook_v2(request, opts = {})
  data, _status_code, _headers = create_webhook_v2_with_http_info(request, opts)
  return data
end

#create_webhook_v2_with_http_info(request, opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

Create a webhook. a new webhook&quot;,&quot;request&quot;:&quot;createWebhookRequest.html&quot;,&quot;response&quot;:&quot;createWebhookResponse.html&quot;

Parameters:

  • request
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 106

def create_webhook_v2_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.create_webhook_v2 ..."
  end
  # verify the required parameter 'request' is set
  fail ArgumentError, "Missing the required parameter 'request' when calling WebhooksApi.create_webhook_v2" if request.nil?
  # resource path
  local_var_path = "/webhooks/create".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(request)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#create_webhook_v2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_webhook_with_http_info(webhook, opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

Create a webhook. a new webhook&quot;,&quot;request&quot;:&quot;createWebhookRequest.html&quot;,&quot;response&quot;:&quot;createWebhookResponse.html&quot;

Parameters:

  • webhook

    The webhook object to be created.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 49

def create_webhook_with_http_info(webhook, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.create_webhook ..."
  end
  # verify the required parameter 'webhook' is set
  fail ArgumentError, "Missing the required parameter 'webhook' when calling WebhooksApi.create_webhook" if webhook.nil?
  # resource path
  local_var_path = "/webhooks".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(webhook)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#create_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_webhooks(opts = {}) ⇒ WebhookPagedMetadata

Returns a collection of Webhooks, specified by the accountID parameter. By default 10 values are returned. Records are returned in natural order. all webhooks","response":"getWebhookAll.html"

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first webhook to return. (default to 0)

  • :records (Integer)

    The maximum number of webhooks to return. (default to 10)

  • :order_by (String)

    Specify a field used to order the result set. (default to created)

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC. (default to DESC)

  • :include_retired (BOOLEAN)

    Whether retired products should be returned. (default to true)

Returns:



158
159
160
161
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 158

def get_all_webhooks(opts = {})
  data, _status_code, _headers = get_all_webhooks_with_http_info(opts)
  return data
end

#get_all_webhooks_with_http_info(opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

Returns a collection of Webhooks, specified by the accountID parameter. By default 10 values are returned. Records are returned in natural order. all webhooks&quot;,&quot;response&quot;:&quot;getWebhookAll.html&quot;

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

  • :offset (Integer)

    The offset from the first webhook to return.

  • :records (Integer)

    The maximum number of webhooks to return.

  • :order_by (String)

    Specify a field used to order the result set.

  • :order (String)

    Ihe direction of any ordering, either ASC or DESC.

  • :include_retired (BOOLEAN)

    Whether retired products should be returned.

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 173

def get_all_webhooks_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.get_all_webhooks ..."
  end
  if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order'])
    fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC'
  end
  # resource path
  local_var_path = "/webhooks".sub('{format}','json')

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil?
  query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil?
  query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#get_all_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_webhook_by_id(webhook_id, opts = {}) ⇒ WebhookPagedMetadata

Returns a single webhook, specified by the webhook-ID parameter. an existing webhook","response":"getWebhookByID.html"

Parameters:

  • webhook_id

    ID of the webhook.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



228
229
230
231
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 228

def get_webhook_by_id(webhook_id, opts = {})
  data, _status_code, _headers = get_webhook_by_id_with_http_info(webhook_id, opts)
  return data
end

#get_webhook_by_id_with_http_info(webhook_id, opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

Returns a single webhook, specified by the webhook-ID parameter. an existing webhook&quot;,&quot;response&quot;:&quot;getWebhookByID.html&quot;

Parameters:

  • webhook_id

    ID of the webhook.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 239

def get_webhook_by_id_with_http_info(webhook_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.get_webhook_by_id ..."
  end
  # verify the required parameter 'webhook_id' is set
  fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.get_webhook_by_id" if webhook_id.nil?
  # resource path
  local_var_path = "/webhooks/{webhook-ID}".sub('{format}','json').sub('{' + 'webhook-ID' + '}', webhook_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#get_webhook_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retire_webhook(webhook_id, organizations, opts = {}) ⇒ WebhookPagedMetadata

Retires the specified webhook. a webhook","response":"deleteWebhook.html"

Parameters:

  • webhook_id

    ID of the webhook.

  • organizations

    A list of organization-IDs used to restrict the scope of API calls.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



288
289
290
291
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 288

def retire_webhook(webhook_id, organizations, opts = {})
  data, _status_code, _headers = retire_webhook_with_http_info(webhook_id, organizations, opts)
  return data
end

#retire_webhook_with_http_info(webhook_id, organizations, opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

Retires the specified webhook. a webhook&quot;,&quot;response&quot;:&quot;deleteWebhook.html&quot;

Parameters:

  • webhook_id

    ID of the webhook.

  • organizations

    A list of organization-IDs used to restrict the scope of API calls.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 299

def retire_webhook_with_http_info(webhook_id, organizations, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.retire_webhook ..."
  end
  # verify the required parameter 'webhook_id' is set
  fail ArgumentError, "Missing the required parameter 'webhook_id' when calling WebhooksApi.retire_webhook" if webhook_id.nil?
  # verify the required parameter 'organizations' is set
  fail ArgumentError, "Missing the required parameter 'organizations' when calling WebhooksApi.retire_webhook" if organizations.nil?
  # resource path
  local_var_path = "/webhooks/{webhook-ID}".sub('{format}','json').sub('{' + 'webhook-ID' + '}', webhook_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(organizations, :multi)

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#retire_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_webhook(webhook, opts = {}) ⇒ WebhookPagedMetadata

Update a webhook. a webhook","request":"updateWebhookRequest.html","response":"updateWebhookResponse.html"

Parameters:

  • webhook

    The webhook object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



349
350
351
352
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 349

def update_webhook(webhook, opts = {})
  data, _status_code, _headers = update_webhook_with_http_info(webhook, opts)
  return data
end

#update_webhook_with_http_info(webhook, opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

Update a webhook. a webhook&quot;,&quot;request&quot;:&quot;updateWebhookRequest.html&quot;,&quot;response&quot;:&quot;updateWebhookResponse.html&quot;

Parameters:

  • webhook

    The webhook object to be updated.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 359

def update_webhook_with_http_info(webhook, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.update_webhook ..."
  end
  # verify the required parameter 'webhook' is set
  fail ArgumentError, "Missing the required parameter 'webhook' when calling WebhooksApi.update_webhook" if webhook.nil?
  # resource path
  local_var_path = "/webhooks".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['application/json; charset=utf-8']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(webhook)
  auth_names = []
  data, status_code, headers = @api_client.call_api(:PUT, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#update_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#verify_webhook(verification_id, opts = {}) ⇒ WebhookPagedMetadata

New webhooks must be verified before use, use the verificationID of the webhook to perform verification. a webhook","response":"verifyWebhook.html"

Parameters:

  • verification_id

    verificationID of the webhook.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:



407
408
409
410
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 407

def verify_webhook(verification_id, opts = {})
  data, _status_code, _headers = verify_webhook_with_http_info(verification_id, opts)
  return data
end

#verify_webhook_with_http_info(verification_id, opts = {}) ⇒ Array<(WebhookPagedMetadata, Fixnum, Hash)>

New webhooks must be verified before use, use the verificationID of the webhook to perform verification. a webhook&quot;,&quot;response&quot;:&quot;verifyWebhook.html&quot;

Parameters:

  • verification_id

    verificationID of the webhook.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :organizations (Array<String>)

    A list of organization-IDs used to restrict the scope of API calls.

Returns:

  • (Array<(WebhookPagedMetadata, Fixnum, Hash)>)

    WebhookPagedMetadata data, response status code and response headers



418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/bf_ruby2/api/webhooks_api.rb', line 418

def verify_webhook_with_http_info(verification_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: WebhooksApi.verify_webhook ..."
  end
  # verify the required parameter 'verification_id' is set
  fail ArgumentError, "Missing the required parameter 'verification_id' when calling WebhooksApi.verify_webhook" if verification_id.nil?
  # resource path
  local_var_path = "/webhooks/verify/{verification-ID}".sub('{format}','json').sub('{' + 'verification-ID' + '}', verification_id.to_s)

  # query parameters
  query_params = {}
  query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil?

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  local_header_accept = ['application/json; charset=utf-8']
  local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result

  # HTTP header 'Content-Type'
  local_header_content_type = ['text/plain']
  header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = []
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'WebhookPagedMetadata')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhooksApi#verify_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end