Class: Bfwd::EmailsubscriptionsApi
- Inherits:
-
Object
- Object
- Bfwd::EmailsubscriptionsApi
- Defined in:
- lib/bf_ruby2/api/emailsubscriptions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_email_subscription(request, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Create an email subscription.
-
#create_email_subscription_with_http_info(request, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Create an email subscription.
-
#delete_email_subscription_by_type(type, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Unsubscribe from the email specified by the type parameter.
-
#delete_email_subscription_by_type_with_http_info(type, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Unsubscribe from the email specified by the type parameter.
-
#get_all_email_subscriptions(state, type, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Returns a collection of all email-subscriptions.
-
#get_all_email_subscriptions_with_http_info(state, type, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Returns a collection of all email-subscriptions.
-
#get_email_subscription_by_id(email_subscription_id, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Retrieves a single email subscription, specified by ID.
-
#get_email_subscription_by_id_with_http_info(email_subscription_id, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Retrieves a single email subscription, specified by ID.
-
#initialize(api_client = ApiClient.default) ⇒ EmailsubscriptionsApi
constructor
A new instance of EmailsubscriptionsApi.
-
#update_email_subscription(request, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Update an email subscription.
-
#update_email_subscription_with_http_info(request, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Update an email subscription.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EmailsubscriptionsApi
Returns a new instance of EmailsubscriptionsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_email_subscription(request, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Create an email subscription. an email subscription","request":"createEmailSubscriptionRequest.html","response":"creatEmailSubscriptionResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 39 def create_email_subscription(request, opts = {}) data, _status_code, _headers = create_email_subscription_with_http_info(request, opts) return data end |
#create_email_subscription_with_http_info(request, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Create an email subscription. an email subscription","request":"createEmailSubscriptionRequest.html","response":"creatEmailSubscriptionResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 49 def create_email_subscription_with_http_info(request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailsubscriptionsApi.create_email_subscription ..." end # verify the required parameter 'request' is set fail ArgumentError, "Missing the required parameter 'request' when calling EmailsubscriptionsApi.create_email_subscription" if request.nil? # resource path local_var_path = "/email-subscriptions".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailSubscriptionPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsubscriptionsApi#create_email_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_email_subscription_by_type(type, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Unsubscribe from the email specified by the type parameter. { "nickname" : "Unsubscribe","response" : "unsubscribeEmail.html"}
97 98 99 100 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 97 def delete_email_subscription_by_type(type, opts = {}) data, _status_code, _headers = delete_email_subscription_by_type_with_http_info(type, opts) return data end |
#delete_email_subscription_by_type_with_http_info(type, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Unsubscribe from the email specified by the type parameter. { "nickname" : "Unsubscribe","response" : "unsubscribeEmail.html"}
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 108 def delete_email_subscription_by_type_with_http_info(type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailsubscriptionsApi.delete_email_subscription_by_type ..." end # verify the required parameter 'type' is set fail ArgumentError, "Missing the required parameter 'type' when calling EmailsubscriptionsApi.delete_email_subscription_by_type" if type.nil? # verify enum value unless ['FailedPayment', 'InvoicePaid', 'SubscriptionCancellation', 'SubscriptionCancelled', 'SubscriptionPlanMigrated', 'SubscriptionPlanMigrating', 'CardExpired', 'CardExpiring'].include?(type) fail ArgumentError, "invalid value for 'type', must be one of FailedPayment, InvoicePaid, SubscriptionCancellation, SubscriptionCancelled, SubscriptionPlanMigrated, SubscriptionPlanMigrating, CardExpired, CardExpiring" end # resource path local_var_path = "/email-subscriptions/type={type}".sub('{format}','json').sub('{' + 'type' + '}', type.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8', 'text/xml'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailSubscriptionPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsubscriptionsApi#delete_email_subscription_by_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_email_subscriptions(state, type, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Returns a collection of all email-subscriptions. By default 10 values are returned. Records are returned in natural order. all email subscriptions","response":"getEmailSubscriptionsAll.html"
166 167 168 169 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 166 def get_all_email_subscriptions(state, type, opts = {}) data, _status_code, _headers = get_all_email_subscriptions_with_http_info(state, type, opts) return data end |
#get_all_email_subscriptions_with_http_info(state, type, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Returns a collection of all email-subscriptions. By default 10 values are returned. Records are returned in natural order. all email subscriptions","response":"getEmailSubscriptionsAll.html"
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 182 def get_all_email_subscriptions_with_http_info(state, type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailsubscriptionsApi.get_all_email_subscriptions ..." end # verify the required parameter 'state' is set fail ArgumentError, "Missing the required parameter 'state' when calling EmailsubscriptionsApi.get_all_email_subscriptions" if state.nil? # verify enum value unless ['Active', 'Disabled'].include?(state) fail ArgumentError, "invalid value for 'state', must be one of Active, Disabled" end # verify the required parameter 'type' is set fail ArgumentError, "Missing the required parameter 'type' when calling EmailsubscriptionsApi.get_all_email_subscriptions" if type.nil? # verify enum value unless ['FailedPayment', 'InvoicePaid', 'SubscriptionCancellation', 'SubscriptionCancelled', 'SubscriptionPlanMigrated', 'SubscriptionPlanMigrating', 'CardExpired', 'CardExpiring'].include?(type) fail ArgumentError, "invalid value for 'type', must be one of FailedPayment, InvoicePaid, SubscriptionCancellation, SubscriptionCancelled, SubscriptionPlanMigrated, SubscriptionPlanMigrating, CardExpired, CardExpiring" end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/email-subscriptions".sub('{format}','json') # query parameters query_params = {} query_params[:'state'] = state query_params[:'type'] = type query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailSubscriptionPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsubscriptionsApi#get_all_email_subscriptions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_email_subscription_by_id(email_subscription_id, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Retrieves a single email subscription, specified by ID. { "nickname" : "Retrieve by ID","response" : "getEmailSubscriptionByID.html"}
251 252 253 254 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 251 def get_email_subscription_by_id(email_subscription_id, opts = {}) data, _status_code, _headers = get_email_subscription_by_id_with_http_info(email_subscription_id, opts) return data end |
#get_email_subscription_by_id_with_http_info(email_subscription_id, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Retrieves a single email subscription, specified by ID. { "nickname" : "Retrieve by ID","response" : "getEmailSubscriptionByID.html"}
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 263 def get_email_subscription_by_id_with_http_info(email_subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailsubscriptionsApi.get_email_subscription_by_id ..." end # verify the required parameter 'email_subscription_id' is set fail ArgumentError, "Missing the required parameter 'email_subscription_id' when calling EmailsubscriptionsApi.get_email_subscription_by_id" if email_subscription_id.nil? # resource path local_var_path = "/email-subscriptions/{email-subscription-id}".sub('{format}','json').sub('{' + 'email-subscription-id' + '}', email_subscription_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailSubscriptionPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsubscriptionsApi#get_email_subscription_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_email_subscription(request, opts = {}) ⇒ EmailSubscriptionPagedMetadata
Update an email subscription. EmailSubscription","request":"updateEmailSubscriptionRequest.html","response":"updateEmailSubscriptionResponse.html"
312 313 314 315 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 312 def update_email_subscription(request, opts = {}) data, _status_code, _headers = update_email_subscription_with_http_info(request, opts) return data end |
#update_email_subscription_with_http_info(request, opts = {}) ⇒ Array<(EmailSubscriptionPagedMetadata, Fixnum, Hash)>
Update an email subscription. EmailSubscription","request":"updateEmailSubscriptionRequest.html","response":"updateEmailSubscriptionResponse.html"
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/bf_ruby2/api/emailsubscriptions_api.rb', line 322 def update_email_subscription_with_http_info(request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailsubscriptionsApi.update_email_subscription ..." end # verify the required parameter 'request' is set fail ArgumentError, "Missing the required parameter 'request' when calling EmailsubscriptionsApi.update_email_subscription" if request.nil? # resource path local_var_path = "/email-subscriptions".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(request) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailSubscriptionPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailsubscriptionsApi#update_email_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |