Class: Bfwd::InvoicePayment
- Inherits:
-
Object
- Object
- Bfwd::InvoicePayment
- Defined in:
- lib/bf_ruby2/models/invoice_payment.rb
Overview
An invoice-payment specifies the amount of a particular payment used to pay part or entirety of the outstanding balance of the associated invoice.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#actual_amount ⇒ Object
{ "description" : "The value of the payment used by payment-line.", "verbs“: }.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#crm_id ⇒ Object
{ "description" : "CRM ID of the invoice.", "verbs“: }.
-
#currency ⇒ Object
{ "description" : "The currency of the payment specified by a three character ISO 4217 currency code.", "verbs“: }.
-
#gateway ⇒ Object
Payment gateway associated with the payment.
-
#id ⇒ Object
{ "description" : "ID of the payment-line.", "verbs“: }.
-
#invoice_id ⇒ Object
{ "description" : "ID of the invoice associated with the payment-line.", "verbs“: }.
-
#nominal_amount ⇒ Object
{ "description" : "The value that this payment-line represents.", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "ID of the organization associated with the invoice-payment.", "verbs“: }.
-
#payment_id ⇒ Object
{ "description" : "ID of the payment used.", "verbs“: }.
-
#payment_received ⇒ Object
date when the associated payment was received.“,”verbs“:.
-
#refund_received ⇒ Object
date when the associated payment was refunded.“,”verbs“:.
-
#refunded_amount ⇒ Object
{ "description" : "The refunded amount of the invoice-payment.", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvoicePayment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ InvoicePayment
Initializes the object
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 140 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'paymentReceived') self.payment_received = attributes[:'paymentReceived'] end if attributes.has_key?(:'refundReceived') self.refund_received = attributes[:'refundReceived'] end if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'crmID') self.crm_id = attributes[:'crmID'] end if attributes.has_key?(:'paymentID') self.payment_id = attributes[:'paymentID'] end if attributes.has_key?(:'invoiceID') self.invoice_id = attributes[:'invoiceID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'currency') self.currency = attributes[:'currency'] end if attributes.has_key?(:'gateway') self.gateway = attributes[:'gateway'] end if attributes.has_key?(:'nominalAmount') self.nominal_amount = attributes[:'nominalAmount'] end if attributes.has_key?(:'actualAmount') self.actual_amount = attributes[:'actualAmount'] end if attributes.has_key?(:'refundedAmount') self.refunded_amount = attributes[:'refundedAmount'] end end |
Instance Attribute Details
#actual_amount ⇒ Object
{ "description" : "The value of the payment used by payment-line.", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 69 def actual_amount @actual_amount end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
39 40 41 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 39 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 36 def created @created end |
#crm_id ⇒ Object
{ "description" : "CRM ID of the invoice.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 48 def crm_id @crm_id end |
#currency ⇒ Object
{ "description" : "The currency of the payment specified by a three character ISO 4217 currency code.", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 60 def currency @currency end |
#gateway ⇒ Object
Payment gateway associated with the payment
63 64 65 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 63 def gateway @gateway end |
#id ⇒ Object
{ "description" : "ID of the payment-line.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 45 def id @id end |
#invoice_id ⇒ Object
{ "description" : "ID of the invoice associated with the payment-line.", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 54 def invoice_id @invoice_id end |
#nominal_amount ⇒ Object
{ "description" : "The value that this payment-line represents.", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 66 def nominal_amount @nominal_amount end |
#organization_id ⇒ Object
{ "description" : "ID of the organization associated with the invoice-payment.", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 57 def organization_id @organization_id end |
#payment_id ⇒ Object
{ "description" : "ID of the payment used.", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 51 def payment_id @payment_id end |
#payment_received ⇒ Object
date when the associated payment was received.“,”verbs“:
30 31 32 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 30 def payment_received @payment_received end |
#refund_received ⇒ Object
date when the associated payment was refunded.“,”verbs“:
33 34 35 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 33 def refund_received @refund_received end |
#refunded_amount ⇒ Object
{ "description" : "The refunded amount of the invoice-payment.", "verbs“: }
72 73 74 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 72 def refunded_amount @refunded_amount end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
42 43 44 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 42 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 97 def self.attribute_map { :'payment_received' => :'paymentReceived', :'refund_received' => :'refundReceived', :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'crm_id' => :'crmID', :'payment_id' => :'paymentID', :'invoice_id' => :'invoiceID', :'organization_id' => :'organizationID', :'currency' => :'currency', :'gateway' => :'gateway', :'nominal_amount' => :'nominalAmount', :'actual_amount' => :'actualAmount', :'refunded_amount' => :'refundedAmount' } end |
.swagger_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 118 def self.swagger_types { :'payment_received' => :'DateTime', :'refund_received' => :'DateTime', :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'crm_id' => :'String', :'payment_id' => :'String', :'invoice_id' => :'String', :'organization_id' => :'String', :'currency' => :'String', :'gateway' => :'String', :'nominal_amount' => :'Float', :'actual_amount' => :'Float', :'refunded_amount' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 246 def ==(o) return true if self.equal?(o) self.class == o.class && payment_received == o.payment_received && refund_received == o.refund_received && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && crm_id == o.crm_id && payment_id == o.payment_id && invoice_id == o.invoice_id && organization_id == o.organization_id && currency == o.currency && gateway == o.gateway && nominal_amount == o.nominal_amount && actual_amount == o.actual_amount && refunded_amount == o.refunded_amount end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 302 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 368 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 281 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 274 def hash [payment_received, refund_received, created, changed_by, updated, id, crm_id, payment_id, invoice_id, organization_id, currency, gateway, nominal_amount, actual_amount, refunded_amount].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
210 211 212 213 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 210 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/bf_ruby2/models/invoice_payment.rb', line 217 def valid? return false if @payment_received.nil? return false if @refund_received.nil? return false if @crm_id.nil? return false if @payment_id.nil? return false if @invoice_id.nil? return false if @organization_id.nil? return false if @currency.nil? return false if @gateway.nil? gateway_validator = EnumAttributeValidator.new('String', ["cybersource_token", "card_vault", "paypal_simple", "locustworld", "free", "coupon", "credit_note", "stripe", "braintree", "balanced", "paypal", "billforward_test", "offline", "trial", "stripeACH", "authorizeNet", "spreedly", "sagePay", "trustCommerce", "payvision", "kash"]) return false unless gateway_validator.valid?(@gateway) return false if @nominal_amount.nil? return false if @actual_amount.nil? return false if @refunded_amount.nil? return true end |