Class: Bfwd::StripeAuthCaptureRequest
- Inherits:
-
Object
- Object
- Bfwd::StripeAuthCaptureRequest
- Defined in:
- lib/bf_ruby2/models/stripe_auth_capture_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
of the BillForward Account with which you would like to associate the created payment method.
If omitted, BillForward will associate the created PaymentMethod with a newly-created Account, whose Profile details will be populated using billing information from the funding instrument.“,”verbs“:. -
#card_id ⇒ Object
of the captured Card in Stripe. This can be provided as well as — or instead of — the one-use
stripeToken, to lead BillForward to the card tokenized within the Stripe vault.“,”verbs“:. -
#company_name ⇒ Object
name of the company of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#default_payment_method ⇒ Object
the PaymentMethod produced by this request should be elected as the ‘default’ payment method for the concerned BillForward Account. Whichever PaymentMethod is elected as an Account’s default payment method, will be consulted whenever payment is demanded of that Account (i.e. upon the execution of any of the Account’s invoices).“,”verbs“:.
-
#email ⇒ Object
email address of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#first_name ⇒ Object
first name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#gateway ⇒ Object
gateway with which your funding instrument has been vaulted.“,”verbs“:.
-
#last_name ⇒ Object
last name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#mobile ⇒ Object
mobile phone number of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:.
-
#organization_id ⇒ Object
of the BillForward Organization within which the requested PaymentMethod should be created. If omitted, this will be auto-populated using your authentication credentials.“,”verbs“:.
-
#stripe_token ⇒ Object
token <a href=\"stripe.com/docs/stripe.js\">provided by Stripe’s client-side card capture SDK</a>, in response to your capturing a card into the Stripe vault. This token will be used by BillForward to find the tokenized card within the Stripe vault — precursory to linking a BillForward PaymentMethod to that tokenized card.“,”verbs“:.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StripeAuthCaptureRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StripeAuthCaptureRequest
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 128 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'@type') self.type = attributes[:'@type'] end if attributes.has_key?(:'accountID') self.account_id = attributes[:'accountID'] end if attributes.has_key?(:'gateway') self.gateway = attributes[:'gateway'] end if attributes.has_key?(:'companyName') self.company_name = attributes[:'companyName'] end if attributes.has_key?(:'email') self.email = attributes[:'email'] end if attributes.has_key?(:'firstName') self.first_name = attributes[:'firstName'] end if attributes.has_key?(:'lastName') self.last_name = attributes[:'lastName'] end if attributes.has_key?(:'mobile') self.mobile = attributes[:'mobile'] end if attributes.has_key?(:'defaultPaymentMethod') self.default_payment_method = attributes[:'defaultPaymentMethod'] else self.default_payment_method = false end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'stripeToken') self.stripe_token = attributes[:'stripeToken'] end if attributes.has_key?(:'cardID') self.card_id = attributes[:'cardID'] end if attributes.has_key?(:'customerID') self.customer_id = attributes[:'customerID'] end end |
Instance Attribute Details
#account_id ⇒ Object
of the BillForward Account with which you would like to associate the created payment method.
If omitted, BillForward will associate the created PaymentMethod with a newly-created Account, whose Profile details will be populated using billing information from the funding instrument.“,”verbs“:
32 33 34 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 32 def account_id @account_id end |
#card_id ⇒ Object
of the captured Card in Stripe. This can be provided as well as — or instead of — the one-use stripeToken, to lead BillForward to the card tokenized within the Stripe vault.“,”verbs“:
62 63 64 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 62 def card_id @card_id end |
#company_name ⇒ Object
name of the company of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
38 39 40 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 38 def company_name @company_name end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
64 65 66 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 64 def customer_id @customer_id end |
#default_payment_method ⇒ Object
the PaymentMethod produced by this request should be elected as the ‘default’ payment method for the concerned BillForward Account. Whichever PaymentMethod is elected as an Account’s default payment method, will be consulted whenever payment is demanded of that Account (i.e. upon the execution of any of the Account’s invoices).“,”verbs“:
53 54 55 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 53 def default_payment_method @default_payment_method end |
#email ⇒ Object
email address of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
41 42 43 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 41 def email @email end |
#first_name ⇒ Object
first name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
44 45 46 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 44 def first_name @first_name end |
#gateway ⇒ Object
gateway with which your funding instrument has been vaulted.“,”verbs“:
35 36 37 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 35 def gateway @gateway end |
#last_name ⇒ Object
last name of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
47 48 49 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 47 def last_name @last_name end |
#mobile ⇒ Object
mobile phone number of the customer from whose card a PaymentMethod is being produced. If provided: this metadata will be used to populate a Profile — should a BillForward Account be created by this request.“,”verbs“:
50 51 52 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 50 def mobile @mobile end |
#organization_id ⇒ Object
of the BillForward Organization within which the requested PaymentMethod should be created. If omitted, this will be auto-populated using your authentication credentials.“,”verbs“:
56 57 58 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 56 def organization_id @organization_id end |
#stripe_token ⇒ Object
token <a href=\"stripe.com/docs/stripe.js\">provided by Stripe’s client-side card capture SDK</a>, in response to your capturing a card into the Stripe vault. This token will be used by BillForward to find the tokenized card within the Stripe vault — precursory to linking a BillForward PaymentMethod to that tokenized card.“,”verbs“:
59 60 61 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 59 def stripe_token @stripe_token end |
#type ⇒ Object
Returns the value of attribute type.
29 30 31 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 29 def type @type end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 89 def self.attribute_map { :'type' => :'@type', :'account_id' => :'accountID', :'gateway' => :'gateway', :'company_name' => :'companyName', :'email' => :'email', :'first_name' => :'firstName', :'last_name' => :'lastName', :'mobile' => :'mobile', :'default_payment_method' => :'defaultPaymentMethod', :'organization_id' => :'organizationID', :'stripe_token' => :'stripeToken', :'card_id' => :'cardID', :'customer_id' => :'customerID' } end |
.swagger_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 108 def self.swagger_types { :'type' => :'String', :'account_id' => :'String', :'gateway' => :'String', :'company_name' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'mobile' => :'String', :'default_payment_method' => :'BOOLEAN', :'organization_id' => :'String', :'stripe_token' => :'String', :'card_id' => :'String', :'customer_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && account_id == o.account_id && gateway == o.gateway && company_name == o.company_name && email == o.email && first_name == o.first_name && last_name == o.last_name && mobile == o.mobile && default_payment_method == o.default_payment_method && organization_id == o.organization_id && stripe_token == o.stripe_token && card_id == o.card_id && customer_id == o.customer_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 285 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 351 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 264 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 257 def hash [type, account_id, gateway, company_name, email, first_name, last_name, mobile, default_payment_method, organization_id, stripe_token, card_id, customer_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 192 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 |
# File 'lib/bf_ruby2/models/stripe_auth_capture_request.rb', line 199 def valid? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["StripeAuthCaptureRequest"]) return false unless type_validator.valid?(@type) gateway_validator = EnumAttributeValidator.new('String', ["Balanced", "Braintree", "Cybersource", "Paypal", "Stripe", "AuthorizeNet", "Spreedly", "SagePay", "TrustCommerce", "Payvision", "Kash"]) return false unless gateway_validator.valid?(@gateway) return false if @stripe_token.nil? return true end |