Class: Bfwd::TokenizationApi
- Inherits:
-
Object
- Object
- Bfwd::TokenizationApi
- Defined in:
- lib/bf_ruby2/api/tokenization_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#auth_capture(auth_capture_request, opts = {}) ⇒ PaymentMethodPagedMetadata
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSAuthCapture.html","request":"BFJSAuthCapture.request.html".
-
#auth_capture_with_http_info(auth_capture_request, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSAuthCapture.html","request":"BFJSAuthCapture.request.html".
-
#braintree_card_capture(opts = {}) ⇒ PaymentMethodPagedMetadata
- Warning: for use only in PCI-compliant environments; for more information, <a href="[email protected]">contact us</a> regarding provisioning of your own on-premise BillForward instance
-
Captures raw credit card details into Braintree’s vault.
-
#braintree_card_capture_with_http_info(opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>
- Warning: for use only in PCI-compliant environments; for more information, <a href="[email protected]">contact us</a> regarding provisioning of your own on-premise BillForward instance
-
Captures raw credit card details into Braintree's vault.
-
#initialize(api_client = ApiClient.default) ⇒ TokenizationApi
constructor
A new instance of TokenizationApi.
-
#pay_vision_shout_v1(opts = {}) ⇒ String
- Note: this API is intended to be invoked by the PayVision servers – they are BillForward’s way of informing client-side of the result of card-capture from within an iframe
-
Generates iframe to which customer will be directed upon success or failure.
-
#pay_vision_shout_v1_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>
- Note: this API is intended to be invoked by the PayVision servers – they are BillForward's way of informing client-side of the result of card-capture from within an iframe
-
Generates iframe to which customer will be directed upon success or failure.
-
#pre_auth(pre_auth_request, opts = {}) ⇒ TokenizationPreAuthPagedMetadata
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSPreAuth.html","request":"BFJSPreAuth.request.html".
-
#pre_auth_with_http_info(pre_auth_request, opts = {}) ⇒ Array<(TokenizationPreAuthPagedMetadata, Fixnum, Hash)>
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSPreAuth.html","request":"BFJSPreAuth.request.html".
-
#sage_pay_notify_v300(opts = {}) ⇒ String
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward’s way of receiving a callback from a SagePay card capture operation, using SagePay’s FORM Protocol, v3.0
-
Handles SagePay Notification.
-
#sage_pay_notify_v300_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward's way of receiving a callback from a SagePay card capture operation, using SagePay's FORM Protocol, v3.0
-
Handles SagePay Notification.
-
#sage_pay_shout_v300(opts = {}) ⇒ String
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward’s way of informing client-side of the result of card-capture from within an iframe, using SagePay’s FORM Protocol, v3.0
-
Generates iframe to which customer will be directed upon success or failure.
-
#sage_pay_shout_v300_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward's way of informing client-side of the result of card-capture from within an iframe, using SagePay's FORM Protocol, v3.0
-
Generates iframe to which customer will be directed upon success or failure.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TokenizationApi
Returns a new instance of TokenizationApi.
30 31 32 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#auth_capture(auth_capture_request, opts = {}) ⇒ PaymentMethodPagedMetadata
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSAuthCapture.html","request":"BFJSAuthCapture.request.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 39 def auth_capture(auth_capture_request, opts = {}) data, _status_code, _headers = auth_capture_with_http_info(auth_capture_request, opts) return data end |
#auth_capture_with_http_info(auth_capture_request, opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSAuthCapture.html","request":"BFJSAuthCapture.request.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 49 def auth_capture_with_http_info(auth_capture_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TokenizationApi.auth_capture ..." end # verify the required parameter 'auth_capture_request' is set fail ArgumentError, "Missing the required parameter 'auth_capture_request' when calling TokenizationApi.auth_capture" if auth_capture_request.nil? # resource path local_var_path = "/tokenization/auth-capture".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(auth_capture_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentMethodPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenizationApi#auth_capture\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#braintree_card_capture(opts = {}) ⇒ PaymentMethodPagedMetadata
- Warning: for use only in PCI-compliant environments; for more information, <a href="[email protected]">contact us</a> regarding provisioning of your own on-premise BillForward instance
-
Captures raw credit card details into Braintree’s vault.
Tokenization","response":"braintreeDirectTokenization.html","request":"braintreeDirectTokenization.request.html"
96 97 98 99 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 96 def braintree_card_capture(opts = {}) data, _status_code, _headers = braintree_card_capture_with_http_info(opts) return data end |
#braintree_card_capture_with_http_info(opts = {}) ⇒ Array<(PaymentMethodPagedMetadata, Fixnum, Hash)>
- Warning: for use only in PCI-compliant environments; for more information, <a href="[email protected]">contact us</a> regarding provisioning of your own on-premise BillForward instance
-
Captures raw credit card details into Braintree's vault.
Tokenization","response":"braintreeDirectTokenization.html","request":"braintreeDirectTokenization.request.html"
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 106 def braintree_card_capture_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TokenizationApi.braintree_card_capture ..." end # resource path local_var_path = "/tokenization/braintree".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(opts[:'body']) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentMethodPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenizationApi#braintree_card_capture\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pay_vision_shout_v1(opts = {}) ⇒ String
- Note: this API is intended to be invoked by the PayVision servers – they are BillForward’s way of informing client-side of the result of card-capture from within an iframe
-
Generates iframe to which customer will be directed upon success or failure. The iframe contains JavaScript which attempts to send a message to BillForward.js on the client-side, which will handle the result.
PayVision iframe redirect","response":"payVisionShoutV1.html","request":"payVisionShoutV1.request.html"
152 153 154 155 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 152 def pay_vision_shout_v1(opts = {}) data, _status_code, _headers = pay_vision_shout_v1_with_http_info(opts) return data end |
#pay_vision_shout_v1_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>
- Note: this API is intended to be invoked by the PayVision servers – they are BillForward's way of informing client-side of the result of card-capture from within an iframe
-
Generates iframe to which customer will be directed upon success or failure. The iframe contains JavaScript which attempts to send a message to BillForward.js on the client-side, which will handle the result.
PayVision iframe redirect","response":"payVisionShoutV1.html","request":"payVisionShoutV1.request.html"
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 163 def pay_vision_shout_v1_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TokenizationApi.pay_vision_shout_v1 ..." end # resource path local_var_path = "/tokenization/payvision-shout-v1".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/html'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/x-www-form-urlencoded'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} form_params["resourcePath"] = opts[:'resource_path'] if !opts[:'resource_path'].nil? form_params["id"] = opts[:'id'] if !opts[:'id'].nil? # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenizationApi#pay_vision_shout_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pre_auth(pre_auth_request, opts = {}) ⇒ TokenizationPreAuthPagedMetadata
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSPreAuth.html","request":"BFJSPreAuth.request.html"
210 211 212 213 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 210 def pre_auth(pre_auth_request, opts = {}) data, _status_code, _headers = pre_auth_with_http_info(pre_auth_request, opts) return data end |
#pre_auth_with_http_info(pre_auth_request, opts = {}) ⇒ Array<(TokenizationPreAuthPagedMetadata, Fixnum, Hash)>
- Note: this API can be invoked more simply by our client-side card capture library, <a href="github.com/billforward/billforward-js">BillForward.js</a>; you should not need to interact with this API manually unless you have particularly bespoke requirements
-
card capture","response":"BFJSPreAuth.html","request":"BFJSPreAuth.request.html"
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 220 def pre_auth_with_http_info(pre_auth_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TokenizationApi.pre_auth ..." end # verify the required parameter 'pre_auth_request' is set fail ArgumentError, "Missing the required parameter 'pre_auth_request' when calling TokenizationApi.pre_auth" if pre_auth_request.nil? # resource path local_var_path = "/tokenization/pre-auth".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(pre_auth_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'TokenizationPreAuthPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenizationApi#pre_auth\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sage_pay_notify_v300(opts = {}) ⇒ String
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward’s way of receiving a callback from a SagePay card capture operation, using SagePay’s FORM Protocol, v3.0
-
Handles SagePay Notification.
SagePay Notification","response":"sagePayNotifyV3_00.html","request":"sagePayNotifyV3_00.request.html"
280 281 282 283 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 280 def sage_pay_notify_v300(opts = {}) data, _status_code, _headers = sage_pay_notify_v300_with_http_info(opts) return data end |
#sage_pay_notify_v300_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward's way of receiving a callback from a SagePay card capture operation, using SagePay's FORM Protocol, v3.0
-
Handles SagePay Notification.
SagePay Notification","response":"sagePayNotifyV3_00.html","request":"sagePayNotifyV3_00.request.html"
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 303 def sage_pay_notify_v300_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TokenizationApi.sage_pay_notify_v300 ..." end # resource path local_var_path = "/tokenization/sagepay-notify-v3-00".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'billForwardURLRoot'] = opts[:'bill_forward_url_root'] if !opts[:'bill_forward_url_root'].nil? query_params[:'access_token'] = opts[:'access_token'] if !opts[:'access_token'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/plain'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/x-www-form-urlencoded'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} form_params["VPSProtocol"] = opts[:'vps_protocol'] if !opts[:'vps_protocol'].nil? form_params["TxType"] = opts[:'tx_type'] if !opts[:'tx_type'].nil? form_params["VendorTxCode"] = opts[:'vendor_tx_code'] if !opts[:'vendor_tx_code'].nil? form_params["Status"] = opts[:'status'] if !opts[:'status'].nil? form_params["VPSTxId"] = opts[:'vps_tx_id'] if !opts[:'vps_tx_id'].nil? form_params["CardType"] = opts[:'card_type'] if !opts[:'card_type'].nil? form_params["Token"] = opts[:'token'] if !opts[:'token'].nil? form_params["StatusDetail"] = opts[:'status_detail'] if !opts[:'status_detail'].nil? form_params["Last4Digits"] = opts[:'last4_digits'] if !opts[:'last4_digits'].nil? form_params["VPSSignature"] = opts[:'vps_signature'] if !opts[:'vps_signature'].nil? form_params["ExpiryDate"] = opts[:'expiry_date'] if !opts[:'expiry_date'].nil? # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenizationApi#sage_pay_notify_v300\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sage_pay_shout_v300(opts = {}) ⇒ String
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward’s way of informing client-side of the result of card-capture from within an iframe, using SagePay’s FORM Protocol, v3.0
-
Generates iframe to which customer will be directed upon success or failure. The iframe contains JavaScript which attempts to send a message to BillForward.js on the client-side, which will handle the result.
SagePay iframe redirect","response":"sagePayShoutV3_00.html","request":"sagePayShoutV3_00.request.html"
368 369 370 371 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 368 def sage_pay_shout_v300(opts = {}) data, _status_code, _headers = sage_pay_shout_v300_with_http_info(opts) return data end |
#sage_pay_shout_v300_with_http_info(opts = {}) ⇒ Array<(String, Fixnum, Hash)>
- Note: this API is intended to be invoked by the SagePay servers – they are BillForward's way of informing client-side of the result of card-capture from within an iframe, using SagePay's FORM Protocol, v3.0
-
Generates iframe to which customer will be directed upon success or failure. The iframe contains JavaScript which attempts to send a message to BillForward.js on the client-side, which will handle the result.
SagePay iframe redirect","response":"sagePayShoutV3_00.html","request":"sagePayShoutV3_00.request.html"
384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/bf_ruby2/api/tokenization_api.rb', line 384 def sage_pay_shout_v300_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: TokenizationApi.sage_pay_shout_v300 ..." end # resource path local_var_path = "/tokenization/sagepay-shout-v3-00".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'s'] = opts[:'s'] if !opts[:'s'].nil? query_params[:'t'] = opts[:'t'] if !opts[:'t'].nil? query_params[:'c'] = opts[:'c'] if !opts[:'c'].nil? query_params[:'e'] = opts[:'e'] if !opts[:'e'].nil? query_params[:'l'] = opts[:'l'] if !opts[:'l'].nil? query_params[:'d'] = opts[:'d'] if !opts[:'d'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/html'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'String') if @api_client.config.debugging @api_client.config.logger.debug "API called: TokenizationApi#sage_pay_shout_v300\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |