Class: Bfwd::Usage
- Inherits:
-
Object
- Object
- Bfwd::Usage
- Defined in:
- lib/bf_ruby2/models/usage.rb
Overview
An instance of usage
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#billing_date ⇒ Object
{ "description" : "The UTC DateTime when the usage is to be billed.", "verbs“: }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs“: }.
-
#created_by ⇒ Object
{ "description" : "Some identifying information about who created this object.", "verbs“: }.
-
#detailed ⇒ Object
{ "description" : "Is this usage a detailed entry?", "verbs“: }.
-
#occurred_on ⇒ Object
{ "description" : "The UTC DateTime when the usage occurred.", "verbs“: }.
-
#organization_id ⇒ Object
{ "description" : "The organization associated with this usage instance.", "verbs“: }.
-
#pricing_component_id ⇒ Object
{ "description" : "The ID of the pricing component this usage is for.", "verbs“: }.
-
#pricing_component_name ⇒ Object
{ "description" : "The name of the pricing component this usage is for.", "verbs“: }.
-
#session_id ⇒ Object
{ "description" : "A (not guaranteed unique) identifier for the session from which this usage was generated.", "verbs“: }.
-
#start ⇒ Object
{ "description" : "The start date of this usage instance, UTC DateTime", "verbs“: }.
-
#stop ⇒ Object
{ "description" : "The end date of this usage instance, UTC DateTime", "verbs“: }.
-
#subscription_id ⇒ Object
{ "description" : "ID of the subscription to which this usage instance pertains.", "verbs“: }.
-
#uom ⇒ Object
{ "description" : "The unit-of-measure that this usage is for.", "verbs“: }.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was updated.", "verbs“: }.
-
#updated_by ⇒ Object
{ "description" : "Some identifying information about who updated this object.", "verbs“: }.
-
#usage_duration ⇒ Object
{ "description" : "The amount of time over which usage occurred (in milliseconds?). Relevant for ‘temporal’ usage only.", "verbs“: }.
-
#usage_period ⇒ Object
{ "description" : "The usage period during which this usage occurred.", "verbs“: }.
-
#usage_type ⇒ Object
{ "description" : "The type of usage (‘Temporal’ or ‘Itemized’).", "verbs“: }.
-
#usage_value ⇒ Object
{ "description" : "The quantity of product consumed by this usage. Relevant for ‘itemized’ usage only.", "verbs“: }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Usage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Usage
Initializes the object
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/bf_ruby2/models/usage.rb', line 160 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'sessionID') self.session_id = attributes[:'sessionID'] end if attributes.has_key?(:'subscriptionID') self.subscription_id = attributes[:'subscriptionID'] end if attributes.has_key?(:'pricingComponentID') self.pricing_component_id = attributes[:'pricingComponentID'] end if attributes.has_key?(:'pricingComponentName') self.pricing_component_name = attributes[:'pricingComponentName'] end if attributes.has_key?(:'uom') self.uom = attributes[:'uom'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'usagePeriod') self.usage_period = attributes[:'usagePeriod'] end if attributes.has_key?(:'usageDuration') self.usage_duration = attributes[:'usageDuration'] end if attributes.has_key?(:'usageType') self.usage_type = attributes[:'usageType'] end if attributes.has_key?(:'usageValue') self.usage_value = attributes[:'usageValue'] end if attributes.has_key?(:'detailed') self.detailed = attributes[:'detailed'] else self.detailed = false end if attributes.has_key?(:'createdBy') self.created_by = attributes[:'createdBy'] end if attributes.has_key?(:'updatedBy') self.updated_by = attributes[:'updatedBy'] end if attributes.has_key?(:'start') self.start = attributes[:'start'] end if attributes.has_key?(:'stop') self.stop = attributes[:'stop'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'occurred_on') self.occurred_on = attributes[:'occurred_on'] end if attributes.has_key?(:'billing_date') self.billing_date = attributes[:'billing_date'] end end |
Instance Attribute Details
#billing_date ⇒ Object
{ "description" : "The UTC DateTime when the usage is to be billed.", "verbs“: }
84 85 86 |
# File 'lib/bf_ruby2/models/usage.rb', line 84 def billing_date @billing_date end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs“: }
30 31 32 |
# File 'lib/bf_ruby2/models/usage.rb', line 30 def created @created end |
#created_by ⇒ Object
{ "description" : "Some identifying information about who created this object.", "verbs“: }
66 67 68 |
# File 'lib/bf_ruby2/models/usage.rb', line 66 def created_by @created_by end |
#detailed ⇒ Object
{ "description" : "Is this usage a detailed entry?", "verbs“: }
63 64 65 |
# File 'lib/bf_ruby2/models/usage.rb', line 63 def detailed @detailed end |
#occurred_on ⇒ Object
{ "description" : "The UTC DateTime when the usage occurred.", "verbs“: }
81 82 83 |
# File 'lib/bf_ruby2/models/usage.rb', line 81 def occurred_on @occurred_on end |
#organization_id ⇒ Object
{ "description" : "The organization associated with this usage instance.", "verbs“: }
48 49 50 |
# File 'lib/bf_ruby2/models/usage.rb', line 48 def organization_id @organization_id end |
#pricing_component_id ⇒ Object
{ "description" : "The ID of the pricing component this usage is for.", "verbs“: }
39 40 41 |
# File 'lib/bf_ruby2/models/usage.rb', line 39 def pricing_component_id @pricing_component_id end |
#pricing_component_name ⇒ Object
{ "description" : "The name of the pricing component this usage is for.", "verbs“: }
42 43 44 |
# File 'lib/bf_ruby2/models/usage.rb', line 42 def pricing_component_name @pricing_component_name end |
#session_id ⇒ Object
{ "description" : "A (not guaranteed unique) identifier for the session from which this usage was generated.", "verbs“: }
33 34 35 |
# File 'lib/bf_ruby2/models/usage.rb', line 33 def session_id @session_id end |
#start ⇒ Object
{ "description" : "The start date of this usage instance, UTC DateTime", "verbs“: }
72 73 74 |
# File 'lib/bf_ruby2/models/usage.rb', line 72 def start @start end |
#stop ⇒ Object
{ "description" : "The end date of this usage instance, UTC DateTime", "verbs“: }
75 76 77 |
# File 'lib/bf_ruby2/models/usage.rb', line 75 def stop @stop end |
#subscription_id ⇒ Object
{ "description" : "ID of the subscription to which this usage instance pertains.", "verbs“: }
36 37 38 |
# File 'lib/bf_ruby2/models/usage.rb', line 36 def subscription_id @subscription_id end |
#uom ⇒ Object
{ "description" : "The unit-of-measure that this usage is for.", "verbs“: }
45 46 47 |
# File 'lib/bf_ruby2/models/usage.rb', line 45 def uom @uom end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was updated.", "verbs“: }
78 79 80 |
# File 'lib/bf_ruby2/models/usage.rb', line 78 def updated @updated end |
#updated_by ⇒ Object
{ "description" : "Some identifying information about who updated this object.", "verbs“: }
69 70 71 |
# File 'lib/bf_ruby2/models/usage.rb', line 69 def updated_by @updated_by end |
#usage_duration ⇒ Object
{ "description" : "The amount of time over which usage occurred (in milliseconds?). Relevant for ‘temporal’ usage only.", "verbs“: }
54 55 56 |
# File 'lib/bf_ruby2/models/usage.rb', line 54 def usage_duration @usage_duration end |
#usage_period ⇒ Object
{ "description" : "The usage period during which this usage occurred.", "verbs“: }
51 52 53 |
# File 'lib/bf_ruby2/models/usage.rb', line 51 def usage_period @usage_period end |
#usage_type ⇒ Object
{ "description" : "The type of usage (‘Temporal’ or ‘Itemized’).", "verbs“: }
57 58 59 |
# File 'lib/bf_ruby2/models/usage.rb', line 57 def usage_type @usage_type end |
#usage_value ⇒ Object
{ "description" : "The quantity of product consumed by this usage. Relevant for ‘itemized’ usage only.", "verbs“: }
60 61 62 |
# File 'lib/bf_ruby2/models/usage.rb', line 60 def usage_value @usage_value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/bf_ruby2/models/usage.rb', line 109 def self.attribute_map { :'created' => :'created', :'session_id' => :'sessionID', :'subscription_id' => :'subscriptionID', :'pricing_component_id' => :'pricingComponentID', :'pricing_component_name' => :'pricingComponentName', :'uom' => :'uom', :'organization_id' => :'organizationID', :'usage_period' => :'usagePeriod', :'usage_duration' => :'usageDuration', :'usage_type' => :'usageType', :'usage_value' => :'usageValue', :'detailed' => :'detailed', :'created_by' => :'createdBy', :'updated_by' => :'updatedBy', :'start' => :'start', :'stop' => :'stop', :'updated' => :'updated', :'occurred_on' => :'occurred_on', :'billing_date' => :'billing_date' } end |
.swagger_types ⇒ Object
Attribute type mapping.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/bf_ruby2/models/usage.rb', line 134 def self.swagger_types { :'created' => :'DateTime', :'session_id' => :'String', :'subscription_id' => :'String', :'pricing_component_id' => :'String', :'pricing_component_name' => :'String', :'uom' => :'String', :'organization_id' => :'String', :'usage_period' => :'Integer', :'usage_duration' => :'Integer', :'usage_type' => :'String', :'usage_value' => :'Integer', :'detailed' => :'BOOLEAN', :'created_by' => :'String', :'updated_by' => :'String', :'start' => :'DateTime', :'stop' => :'DateTime', :'updated' => :'DateTime', :'occurred_on' => :'DateTime', :'billing_date' => :'DateTime' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/bf_ruby2/models/usage.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && session_id == o.session_id && subscription_id == o.subscription_id && pricing_component_id == o.pricing_component_id && pricing_component_name == o.pricing_component_name && uom == o.uom && organization_id == o.organization_id && usage_period == o.usage_period && usage_duration == o.usage_duration && usage_type == o.usage_type && usage_value == o.usage_value && detailed == o.detailed && created_by == o.created_by && updated_by == o.updated_by && start == o.start && stop == o.stop && updated == o.updated && occurred_on == o.occurred_on && billing_date == o.billing_date end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/bf_ruby2/models/usage.rb', line 341 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = Bfwd.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/bf_ruby2/models/usage.rb', line 407 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/bf_ruby2/models/usage.rb', line 320 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
307 308 309 |
# File 'lib/bf_ruby2/models/usage.rb', line 307 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/bf_ruby2/models/usage.rb', line 313 def hash [created, session_id, subscription_id, pricing_component_id, pricing_component_name, uom, organization_id, usage_period, usage_duration, usage_type, usage_value, detailed, created_by, updated_by, start, stop, updated, occurred_on, billing_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
248 249 250 251 |
# File 'lib/bf_ruby2/models/usage.rb', line 248 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
387 388 389 |
# File 'lib/bf_ruby2/models/usage.rb', line 387 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
393 394 395 396 397 398 399 400 401 |
# File 'lib/bf_ruby2/models/usage.rb', line 393 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
381 382 383 |
# File 'lib/bf_ruby2/models/usage.rb', line 381 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/bf_ruby2/models/usage.rb', line 255 def valid? return false if @session_id.nil? return false if @subscription_id.nil? return false if @pricing_component_id.nil? return false if @pricing_component_name.nil? return false if @uom.nil? return false if @organization_id.nil? return false if @usage_type.nil? usage_type_validator = EnumAttributeValidator.new('String', ["Temporal", "Itemized"]) return false unless usage_type_validator.valid?(@usage_type) return false if @start.nil? return true end |