Class: BillForward::CouponbookApi
- Inherits:
-
Object
- Object
- BillForward::CouponbookApi
- Defined in:
- lib/bf_ruby2/api/couponbook_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_coupon_book(coupon_book, opts = {}) ⇒ CouponBookPagedMetadata
Create a coupon-book.
-
#create_coupon_book_with_http_info(coupon_book, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Create a coupon-book.
-
#delete_coupon_book(coupon_book_id, opts = {}) ⇒ CouponBookPagedMetadata
Retire a coupon-book, specified by the coupon-book-ID parameter.
-
#delete_coupon_book_with_http_info(coupon_book_id, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Retire a coupon-book, specified by the coupon-book-ID parameter.
-
#get_all_attachable_coupon_books(attachableness, has_code, opts = {}) ⇒ CouponBookPagedMetadata
Returns a collection of attachable coupon-books.
-
#get_all_attachable_coupon_books_with_http_info(attachableness, has_code, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a collection of attachable coupon-books.
-
#get_all_coupon_books(opts = {}) ⇒ CouponBookPagedMetadata
Returns a collection of coupon-books.
-
#get_all_coupon_books_with_http_info(opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a collection of coupon-books.
-
#get_coupon_book_by_book_code(book_code, opts = {}) ⇒ CouponBookPagedMetadata
Returns a single coupon-book, specified by the book-code parameter.
-
#get_coupon_book_by_book_code_with_http_info(book_code, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a single coupon-book, specified by the book-code parameter.
-
#get_coupon_book_by_coupon_book_definition_id(coupon_book_definition_id, opts = {}) ⇒ CouponBookPagedMetadata
Returns a collection of coupon-books, specified by coupon-book-definition-ID parameter.
-
#get_coupon_book_by_coupon_book_definition_id_with_http_info(coupon_book_definition_id, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a collection of coupon-books, specified by coupon-book-definition-ID parameter.
-
#get_coupon_book_by_coupon_code(coupon_code, opts = {}) ⇒ CouponBookPagedMetadata
Returns a single coupon-book, specified by the coupon-code parameter.
-
#get_coupon_book_by_coupon_code_with_http_info(coupon_code, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a single coupon-book, specified by the coupon-code parameter.
-
#get_coupon_book_by_id(coupon_book_id, opts = {}) ⇒ CouponBookPagedMetadata
Returns a single coupon-book, specified by the coupon-book-ID parameter.
-
#get_coupon_book_by_id_with_http_info(coupon_book_id, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a single coupon-book, specified by the coupon-book-ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ CouponbookApi
constructor
A new instance of CouponbookApi.
-
#update_coupon_book(coupon_book, opts = {}) ⇒ CouponBookPagedMetadata
Update a coupon-book.
-
#update_coupon_book_with_http_info(coupon_book, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Update a coupon-book.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ CouponbookApi
Returns a new instance of CouponbookApi.
30 31 32 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_coupon_book(coupon_book, opts = {}) ⇒ CouponBookPagedMetadata
Create a coupon-book. a new coupon book","request":"createCouponBookRequest.html","response":"createCouponBookResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 39 def create_coupon_book(coupon_book, opts = {}) data, _status_code, _headers = create_coupon_book_with_http_info(coupon_book, opts) return data end |
#create_coupon_book_with_http_info(coupon_book, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Create a coupon-book. a new coupon book","request":"createCouponBookRequest.html","response":"createCouponBookResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 49 def create_coupon_book_with_http_info(coupon_book, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.create_coupon_book ..." end # verify the required parameter 'coupon_book' is set fail ArgumentError, "Missing the required parameter 'coupon_book' when calling CouponbookApi.create_coupon_book" if coupon_book.nil? # resource path local_var_path = "/coupon-books".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(coupon_book) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#create_coupon_book\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_coupon_book(coupon_book_id, opts = {}) ⇒ CouponBookPagedMetadata
Retire a coupon-book, specified by the coupon-book-ID parameter. coupon book","response":"deleteCouponBookByID.html"
97 98 99 100 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 97 def delete_coupon_book(coupon_book_id, opts = {}) data, _status_code, _headers = delete_coupon_book_with_http_info(coupon_book_id, opts) return data end |
#delete_coupon_book_with_http_info(coupon_book_id, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Retire a coupon-book, specified by the coupon-book-ID parameter. coupon book","response":"deleteCouponBookByID.html"
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 108 def delete_coupon_book_with_http_info(coupon_book_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.delete_coupon_book ..." end # verify the required parameter 'coupon_book_id' is set fail ArgumentError, "Missing the required parameter 'coupon_book_id' when calling CouponbookApi.delete_coupon_book" if coupon_book_id.nil? # resource path local_var_path = "/coupon-books/{coupon-book-ID}".sub('{format}','json').sub('{' + 'coupon-book-ID' + '}', coupon_book_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#delete_coupon_book\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_attachable_coupon_books(attachableness, has_code, opts = {}) ⇒ CouponBookPagedMetadata
Returns a collection of attachable coupon-books. An attachable coupon-book has at least one remaining use, and is not deleted. By default 10 values are returned. Records are returned in natural order. all attachable coupon books","response":"getCouponBookAllAttachable.html"
162 163 164 165 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 162 def get_all_attachable_coupon_books(attachableness, has_code, opts = {}) data, _status_code, _headers = get_all_attachable_coupon_books_with_http_info(attachableness, has_code, opts) return data end |
#get_all_attachable_coupon_books_with_http_info(attachableness, has_code, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a collection of attachable coupon-books. An attachable coupon-book has at least one remaining use, and is not deleted. By default 10 values are returned. Records are returned in natural order. all attachable coupon books","response":"getCouponBookAllAttachable.html"
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 178 def get_all_attachable_coupon_books_with_http_info(attachableness, has_code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.get_all_attachable_coupon_books ..." end # verify the required parameter 'attachableness' is set fail ArgumentError, "Missing the required parameter 'attachableness' when calling CouponbookApi.get_all_attachable_coupon_books" if attachableness.nil? # verify the required parameter 'has_code' is set fail ArgumentError, "Missing the required parameter 'has_code' when calling CouponbookApi.get_all_attachable_coupon_books" if has_code.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/coupon-books/attachable/{attachableness}/{has_code}".sub('{format}','json').sub('{' + 'attachableness' + '}', attachableness.to_s).sub('{' + 'has_code' + '}', has_code.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#get_all_attachable_coupon_books\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_coupon_books(opts = {}) ⇒ CouponBookPagedMetadata
Returns a collection of coupon-books. By default 10 values are returned. Records are returned in natural order. all coupon books","response":"getCouponBookAll.html"
240 241 242 243 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 240 def get_all_coupon_books(opts = {}) data, _status_code, _headers = get_all_coupon_books_with_http_info(opts) return data end |
#get_all_coupon_books_with_http_info(opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a collection of coupon-books. By default 10 values are returned. Records are returned in natural order. all coupon books","response":"getCouponBookAll.html"
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 255 def get_all_coupon_books_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.get_all_coupon_books ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/coupon-books".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#get_all_coupon_books\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_coupon_book_by_book_code(book_code, opts = {}) ⇒ CouponBookPagedMetadata
Returns a single coupon-book, specified by the book-code parameter. by book code","response":"getCouponBookByBookCode.html"
310 311 312 313 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 310 def get_coupon_book_by_book_code(book_code, opts = {}) data, _status_code, _headers = get_coupon_book_by_book_code_with_http_info(book_code, opts) return data end |
#get_coupon_book_by_book_code_with_http_info(book_code, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a single coupon-book, specified by the book-code parameter. by book code","response":"getCouponBookByBookCode.html"
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 321 def get_coupon_book_by_book_code_with_http_info(book_code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.get_coupon_book_by_book_code ..." end # verify the required parameter 'book_code' is set fail ArgumentError, "Missing the required parameter 'book_code' when calling CouponbookApi.get_coupon_book_by_book_code" if book_code.nil? # resource path local_var_path = "/coupon-books/book-code/{book-code}".sub('{format}','json').sub('{' + 'book-code' + '}', book_code.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#get_coupon_book_by_book_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_coupon_book_by_coupon_book_definition_id(coupon_book_definition_id, opts = {}) ⇒ CouponBookPagedMetadata
Returns a collection of coupon-books, specified by coupon-book-definition-ID parameter. By default 10 coupon-books are returned. Records are returned in natural order. by coupon book definition","response":"getCouponBookByCouponBookDefinitionID.html"
375 376 377 378 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 375 def get_coupon_book_by_coupon_book_definition_id(coupon_book_definition_id, opts = {}) data, _status_code, _headers = get_coupon_book_by_coupon_book_definition_id_with_http_info(coupon_book_definition_id, opts) return data end |
#get_coupon_book_by_coupon_book_definition_id_with_http_info(coupon_book_definition_id, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a collection of coupon-books, specified by coupon-book-definition-ID parameter. By default 10 coupon-books are returned. Records are returned in natural order. by coupon book definition","response":"getCouponBookByCouponBookDefinitionID.html"
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 391 def get_coupon_book_by_coupon_book_definition_id_with_http_info(coupon_book_definition_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.get_coupon_book_by_coupon_book_definition_id ..." end # verify the required parameter 'coupon_book_definition_id' is set fail ArgumentError, "Missing the required parameter 'coupon_book_definition_id' when calling CouponbookApi.get_coupon_book_by_coupon_book_definition_id" if coupon_book_definition_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/coupon-books/coupon-book-definition/{coupon-book-definition-ID}".sub('{format}','json').sub('{' + 'coupon-book-definition-ID' + '}', coupon_book_definition_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#get_coupon_book_by_coupon_book_definition_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_coupon_book_by_coupon_code(coupon_code, opts = {}) ⇒ CouponBookPagedMetadata
Returns a single coupon-book, specified by the coupon-code parameter. by coupon code","response":"getCouponBookByBookCode.html"
448 449 450 451 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 448 def get_coupon_book_by_coupon_code(coupon_code, opts = {}) data, _status_code, _headers = get_coupon_book_by_coupon_code_with_http_info(coupon_code, opts) return data end |
#get_coupon_book_by_coupon_code_with_http_info(coupon_code, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a single coupon-book, specified by the coupon-code parameter. by coupon code","response":"getCouponBookByBookCode.html"
459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 459 def get_coupon_book_by_coupon_code_with_http_info(coupon_code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.get_coupon_book_by_coupon_code ..." end # verify the required parameter 'coupon_code' is set fail ArgumentError, "Missing the required parameter 'coupon_code' when calling CouponbookApi.get_coupon_book_by_coupon_code" if coupon_code.nil? # resource path local_var_path = "/coupon-books/coupon/{coupon-code}".sub('{format}','json').sub('{' + 'coupon-code' + '}', coupon_code.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#get_coupon_book_by_coupon_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_coupon_book_by_id(coupon_book_id, opts = {}) ⇒ CouponBookPagedMetadata
Returns a single coupon-book, specified by the coupon-book-ID parameter. an existing coupon book","response":"getCouponBookByID.html"
508 509 510 511 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 508 def get_coupon_book_by_id(coupon_book_id, opts = {}) data, _status_code, _headers = get_coupon_book_by_id_with_http_info(coupon_book_id, opts) return data end |
#get_coupon_book_by_id_with_http_info(coupon_book_id, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Returns a single coupon-book, specified by the coupon-book-ID parameter. an existing coupon book","response":"getCouponBookByID.html"
519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 519 def get_coupon_book_by_id_with_http_info(coupon_book_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.get_coupon_book_by_id ..." end # verify the required parameter 'coupon_book_id' is set fail ArgumentError, "Missing the required parameter 'coupon_book_id' when calling CouponbookApi.get_coupon_book_by_id" if coupon_book_id.nil? # resource path local_var_path = "/coupon-books/{coupon-book-ID}".sub('{format}','json').sub('{' + 'coupon-book-ID' + '}', coupon_book_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#get_coupon_book_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_coupon_book(coupon_book, opts = {}) ⇒ CouponBookPagedMetadata
Update a coupon-book. a coupon book","request":"updateCouponBookRequest.html","response":"updateCouponBookResponse.html"
567 568 569 570 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 567 def update_coupon_book(coupon_book, opts = {}) data, _status_code, _headers = update_coupon_book_with_http_info(coupon_book, opts) return data end |
#update_coupon_book_with_http_info(coupon_book, opts = {}) ⇒ Array<(CouponBookPagedMetadata, Fixnum, Hash)>
Update a coupon-book. a coupon book","request":"updateCouponBookRequest.html","response":"updateCouponBookResponse.html"
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/bf_ruby2/api/couponbook_api.rb', line 577 def update_coupon_book_with_http_info(coupon_book, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: CouponbookApi.update_coupon_book ..." end # verify the required parameter 'coupon_book' is set fail ArgumentError, "Missing the required parameter 'coupon_book' when calling CouponbookApi.update_coupon_book" if coupon_book.nil? # resource path local_var_path = "/coupon-books".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(coupon_book) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'CouponBookPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: CouponbookApi#update_coupon_book\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |