Class: BillForward::EmailprovidersApi
- Inherits:
-
Object
- Object
- BillForward::EmailprovidersApi
- Defined in:
- lib/bf_ruby2/api/emailproviders_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_email_provider(request, opts = {}) ⇒ EmailProviderPagedMetadata
Create an email provider.
-
#create_email_provider_with_http_info(request, opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Create an email provider.
-
#delete(email_provider_id, opts = {}) ⇒ EmailProviderPagedMetadata
Deletes a single email provider, specified by id or name parameter.
-
#delete_with_http_info(email_provider_id, opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Deletes a single email provider, specified by id or name parameter.
-
#get_all_email_providers(opts = {}) ⇒ EmailProviderPagedMetadata
Returns a collection of all email-providers.
-
#get_all_email_providers_with_http_info(opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Returns a collection of all email-providers.
-
#get_email_by_provider_id(email_provider_id, opts = {}) ⇒ EmailProviderPagedMetadata
Retrieves a single email provider, specified by the version-ID parameter.
-
#get_email_by_provider_id_with_http_info(email_provider_id, opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Retrieves a single email provider, specified by the version-ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ EmailprovidersApi
constructor
A new instance of EmailprovidersApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EmailprovidersApi
Returns a new instance of EmailprovidersApi.
30 31 32 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_email_provider(request, opts = {}) ⇒ EmailProviderPagedMetadata
Create an email provider. an email provider","request":"createEmailProviderRequest.html","response":"creatEmailProviderResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 39 def create_email_provider(request, opts = {}) data, _status_code, _headers = create_email_provider_with_http_info(request, opts) return data end |
#create_email_provider_with_http_info(request, opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Create an email provider. an email provider","request":"createEmailProviderRequest.html","response":"creatEmailProviderResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 49 def create_email_provider_with_http_info(request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailprovidersApi.create_email_provider ..." end # verify the required parameter 'request' is set fail ArgumentError, "Missing the required parameter 'request' when calling EmailprovidersApi.create_email_provider" if request.nil? # resource path local_var_path = "/email-providers".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailProviderPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailprovidersApi#create_email_provider\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(email_provider_id, opts = {}) ⇒ EmailProviderPagedMetadata
Deletes a single email provider, specified by id or name parameter. { "nickname" : "delete","response" : "deleteEmailProvider.html"}
97 98 99 100 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 97 def delete(email_provider_id, opts = {}) data, _status_code, _headers = delete_with_http_info(email_provider_id, opts) return data end |
#delete_with_http_info(email_provider_id, opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Deletes a single email provider, specified by id or name parameter. { "nickname" : "delete","response" : "deleteEmailProvider.html"}
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 108 def delete_with_http_info(email_provider_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailprovidersApi.delete ..." end # verify the required parameter 'email_provider_id' is set fail ArgumentError, "Missing the required parameter 'email_provider_id' when calling EmailprovidersApi.delete" if email_provider_id.nil? # resource path local_var_path = "/email-providers/{email-provider-ID}".sub('{format}','json').sub('{' + 'email-provider-ID' + '}', email_provider_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailProviderPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailprovidersApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_email_providers(opts = {}) ⇒ EmailProviderPagedMetadata
Returns a collection of all email-providers. By default 10 values are returned. Records are returned in natural order. all email providers","response":"getEmailProvidersAll.html"
161 162 163 164 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 161 def get_all_email_providers(opts = {}) data, _status_code, _headers = get_all_email_providers_with_http_info(opts) return data end |
#get_all_email_providers_with_http_info(opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Returns a collection of all email-providers. By default 10 values are returned. Records are returned in natural order. all email providers","response":"getEmailProvidersAll.html"
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 176 def get_all_email_providers_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailprovidersApi.get_all_email_providers ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/email-providers".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailProviderPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailprovidersApi#get_all_email_providers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_email_by_provider_id(email_provider_id, opts = {}) ⇒ EmailProviderPagedMetadata
Retrieves a single email provider, specified by the version-ID parameter. { "nickname" : "Retrieve by version","response" : "getEmailProviderByID.html"}
232 233 234 235 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 232 def get_email_by_provider_id(email_provider_id, opts = {}) data, _status_code, _headers = get_email_by_provider_id_with_http_info(email_provider_id, opts) return data end |
#get_email_by_provider_id_with_http_info(email_provider_id, opts = {}) ⇒ Array<(EmailProviderPagedMetadata, Fixnum, Hash)>
Retrieves a single email provider, specified by the version-ID parameter. { "nickname" : "Retrieve by version","response" : "getEmailProviderByID.html"}
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/bf_ruby2/api/emailproviders_api.rb', line 244 def get_email_by_provider_id_with_http_info(email_provider_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: EmailprovidersApi.get_email_by_provider_id ..." end # verify the required parameter 'email_provider_id' is set fail ArgumentError, "Missing the required parameter 'email_provider_id' when calling EmailprovidersApi.get_email_by_provider_id" if email_provider_id.nil? # resource path local_var_path = "/email-providers/{email-provider-ID}".sub('{format}','json').sub('{' + 'email-provider-ID' + '}', email_provider_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'EmailProviderPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailprovidersApi#get_email_by_provider_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |