Class: BillForward::OrganizationsApi
- Inherits:
-
Object
- Object
- BillForward::OrganizationsApi
- Defined in:
- lib/bf_ruby2/api/organizations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_organization(organization, opts = {}) ⇒ OrganizationPagedMetadata
Create an organization.
-
#create_organization_with_http_info(organization, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Create an organization.
-
#get_all_my_organizations(opts = {}) ⇒ OrganizationPagedMetadata
Returns a collection of all my asociated organizations.
-
#get_all_my_organizations_with_http_info(opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a collection of all my asociated organizations.
-
#get_all_organizations(opts = {}) ⇒ OrganizationPagedMetadata
Returns a collection of all organizations.
-
#get_all_organizations_with_http_info(opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a collection of all organizations.
-
#get_organization_by_customer_code(customer_code, opts = {}) ⇒ OrganizationPagedMetadata
Returns a single organization, specified by the customer-code parameter.
-
#get_organization_by_customer_code_with_http_info(customer_code, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a single organization, specified by the customer-code parameter.
-
#get_organization_by_id(organization_id, opts = {}) ⇒ OrganizationPagedMetadata
Returns a single Organization, specified by the organization-ID parameter.
-
#get_organization_by_id_with_http_info(organization_id, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a single Organization, specified by the organization-ID parameter.
-
#get_organization_by_name(name, opts = {}) ⇒ OrganizationPagedMetadata
Returns a single Organization, specified by the name parameter.
-
#get_organization_by_name_with_http_info(name, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a single Organization, specified by the name parameter.
-
#initialize(api_client = ApiClient.default) ⇒ OrganizationsApi
constructor
A new instance of OrganizationsApi.
-
#update_organization(organization, opts = {}) ⇒ OrganizationPagedMetadata
Update an organization.
-
#update_organization_with_http_info(organization, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Update an organization.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OrganizationsApi
Returns a new instance of OrganizationsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_organization(organization, opts = {}) ⇒ OrganizationPagedMetadata
Create an organization. BillForward::OrganizationsApi."nickname":"Create","request":"createOrganizationRequest.html","response":"createOrganizationResponse"nickname":"Create","request":"createOrganizationRequest.html","response":"createOrganizationResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 39 def create_organization(organization, opts = {}) data, _status_code, _headers = create_organization_with_http_info(organization, opts) return data end |
#create_organization_with_http_info(organization, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Create an organization. BillForward::OrganizationsApi."nickname":"Create","request":"createOrganizationRequest.html","response":"createOrganizationResponse"nickname":"Create","request":"createOrganizationRequest.html","response":"createOrganizationResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 49 def create_organization_with_http_info(organization, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.create_organization ..." end # verify the required parameter 'organization' is set fail ArgumentError, "Missing the required parameter 'organization' when calling OrganizationsApi.create_organization" if organization.nil? # resource path local_var_path = "/organizations".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(organization) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#create_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_my_organizations(opts = {}) ⇒ OrganizationPagedMetadata
Returns a collection of all my asociated organizations. By default 10 values are returned. Records are returned in natural order. Mine","response":"getOrganizationAll.html"
101 102 103 104 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 101 def get_all_my_organizations(opts = {}) data, _status_code, _headers = get_all_my_organizations_with_http_info(opts) return data end |
#get_all_my_organizations_with_http_info(opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a collection of all my asociated organizations. By default 10 values are returned. Records are returned in natural order. Mine","response":"getOrganizationAll.html"
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 116 def get_all_my_organizations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.get_all_my_organizations ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/organizations/mine".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#get_all_my_organizations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_organizations(opts = {}) ⇒ OrganizationPagedMetadata
Returns a collection of all organizations. By default 10 values are returned. Records are returned in natural order. All","response":"getOrganizationAll.html"
175 176 177 178 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 175 def get_all_organizations(opts = {}) data, _status_code, _headers = get_all_organizations_with_http_info(opts) return data end |
#get_all_organizations_with_http_info(opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a collection of all organizations. By default 10 values are returned. Records are returned in natural order. All","response":"getOrganizationAll.html"
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 190 def get_all_organizations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.get_all_organizations ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/organizations".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#get_all_organizations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_organization_by_customer_code(customer_code, opts = {}) ⇒ OrganizationPagedMetadata
Returns a single organization, specified by the customer-code parameter. by Customer-Code","response":"getOrganizationByCustomer.html"
245 246 247 248 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 245 def get_organization_by_customer_code(customer_code, opts = {}) data, _status_code, _headers = get_organization_by_customer_code_with_http_info(customer_code, opts) return data end |
#get_organization_by_customer_code_with_http_info(customer_code, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a single organization, specified by the customer-code parameter. by Customer-Code","response":"getOrganizationByCustomer.html"
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 256 def get_organization_by_customer_code_with_http_info(customer_code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.get_organization_by_customer_code ..." end # verify the required parameter 'customer_code' is set fail ArgumentError, "Missing the required parameter 'customer_code' when calling OrganizationsApi.get_organization_by_customer_code" if customer_code.nil? # resource path local_var_path = "/organizations/customer-code/{customer-code}".sub('{format}','json').sub('{' + 'customer-code' + '}', customer_code.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#get_organization_by_customer_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_organization_by_id(organization_id, opts = {}) ⇒ OrganizationPagedMetadata
Returns a single Organization, specified by the organization-ID parameter. by id","response":"getOrganizationByID.html"
305 306 307 308 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 305 def get_organization_by_id(organization_id, opts = {}) data, _status_code, _headers = get_organization_by_id_with_http_info(organization_id, opts) return data end |
#get_organization_by_id_with_http_info(organization_id, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a single Organization, specified by the organization-ID parameter. by id","response":"getOrganizationByID.html"
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 316 def get_organization_by_id_with_http_info(organization_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.get_organization_by_id ..." end # verify the required parameter 'organization_id' is set fail ArgumentError, "Missing the required parameter 'organization_id' when calling OrganizationsApi.get_organization_by_id" if organization_id.nil? # resource path local_var_path = "/organizations/{organization-ID}".sub('{format}','json').sub('{' + 'organization-ID' + '}', organization_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#get_organization_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_organization_by_name(name, opts = {}) ⇒ OrganizationPagedMetadata
Returns a single Organization, specified by the name parameter. by Name","response":"getOrganizationByName.html"
365 366 367 368 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 365 def get_organization_by_name(name, opts = {}) data, _status_code, _headers = get_organization_by_name_with_http_info(name, opts) return data end |
#get_organization_by_name_with_http_info(name, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Returns a single Organization, specified by the name parameter. by Name","response":"getOrganizationByName.html"
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 376 def get_organization_by_name_with_http_info(name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.get_organization_by_name ..." end # verify the required parameter 'name' is set fail ArgumentError, "Missing the required parameter 'name' when calling OrganizationsApi.get_organization_by_name" if name.nil? # resource path local_var_path = "/organizations/name/{name}".sub('{format}','json').sub('{' + 'name' + '}', name.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#get_organization_by_name\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_organization(organization, opts = {}) ⇒ OrganizationPagedMetadata
Update an organization. BillForward::OrganizationsApi."nickname":"Updated","request":"updateOrganizationRequest.html","response":"updateOrganizationResponse"nickname":"Updated","request":"updateOrganizationRequest.html","response":"updateOrganizationResponse.html"
424 425 426 427 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 424 def update_organization(organization, opts = {}) data, _status_code, _headers = update_organization_with_http_info(organization, opts) return data end |
#update_organization_with_http_info(organization, opts = {}) ⇒ Array<(OrganizationPagedMetadata, Fixnum, Hash)>
Update an organization. BillForward::OrganizationsApi."nickname":"Updated","request":"updateOrganizationRequest.html","response":"updateOrganizationResponse"nickname":"Updated","request":"updateOrganizationRequest.html","response":"updateOrganizationResponse.html"
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/bf_ruby2/api/organizations_api.rb', line 434 def update_organization_with_http_info(organization, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: OrganizationsApi.update_organization ..." end # verify the required parameter 'organization' is set fail ArgumentError, "Missing the required parameter 'organization' when calling OrganizationsApi.update_organization" if organization.nil? # resource path local_var_path = "/organizations".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(organization) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'OrganizationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsApi#update_organization\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |