Class: BillForward::PaymentsApi
- Inherits:
-
Object
- Object
- BillForward::PaymentsApi
- Defined in:
- lib/bf_ruby2/api/payments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_payment(payment, opts = {}) ⇒ PaymentPagedMetadata
Create a payment.
-
#create_payment_with_http_info(payment, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Create a payment.
-
#get_all_payments(opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of all payments.
-
#get_all_payments_with_http_info(opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of all payments.
-
#get_payment_as_csv(received_start, received_end, opts = {}) ⇒ PaymentPagedMetadata
Retrieves payments in CSV format.
-
#get_payment_as_csv_with_http_info(received_start, received_end, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Retrieves payments in CSV format.
-
#get_payment_by_id(payment_id, opts = {}) ⇒ PaymentPagedMetadata
Returns a single payment, specified by the payment-ID parameter.
-
#get_payment_by_id_with_http_info(payment_id, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a single payment, specified by the payment-ID parameter.
-
#get_payment_by_invoice_id(invoice_id, opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of payments, specified by the invoice-ID parameter.
-
#get_payment_by_invoice_id_with_http_info(invoice_id, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of payments, specified by the invoice-ID parameter.
-
#get_payment_by_payment_gateway(gateway, opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of payments, specified by the gateway parameter.
-
#get_payment_by_payment_gateway_with_http_info(gateway, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of payments, specified by the gateway parameter.
-
#get_payment_by_payment_method_id(payment_method_id, opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of payments, specified by the payment-method-ID parameter.
-
#get_payment_by_payment_method_id_with_http_info(payment_method_id, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of payments, specified by the payment-method-ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ PaymentsApi
constructor
A new instance of PaymentsApi.
-
#update_payment(payment, opts = {}) ⇒ PaymentPagedMetadata
Update a payment.
-
#update_payment_with_http_info(payment, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Update a payment.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PaymentsApi
Returns a new instance of PaymentsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_payment(payment, opts = {}) ⇒ PaymentPagedMetadata
Create a payment. a new payment","request":"createPaymentRequest.html","response":"createPaymentResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 39 def create_payment(payment, opts = {}) data, _status_code, _headers = create_payment_with_http_info(payment, opts) return data end |
#create_payment_with_http_info(payment, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Create a payment. a new payment","request":"createPaymentRequest.html","response":"createPaymentResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 49 def create_payment_with_http_info(payment, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.create_payment ..." end # verify the required parameter 'payment' is set fail ArgumentError, "Missing the required parameter 'payment' when calling PaymentsApi.create_payment" if payment.nil? # resource path local_var_path = "/payments".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(payment) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#create_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_payments(opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of all payments. By default 10 values are returned. Records are returned in natural order. all payments","response":"getPaymentAll.html"
101 102 103 104 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 101 def get_all_payments(opts = {}) data, _status_code, _headers = get_all_payments_with_http_info(opts) return data end |
#get_all_payments_with_http_info(opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of all payments. By default 10 values are returned. Records are returned in natural order. all payments","response":"getPaymentAll.html"
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 116 def get_all_payments_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.get_all_payments ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/payments".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#get_all_payments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_as_csv(received_start, received_end, opts = {}) ⇒ PaymentPagedMetadata
Retrieves payments in CSV format. { "nickname":"Payments CSV","response":"payments.csv"}
176 177 178 179 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 176 def get_payment_as_csv(received_start, received_end, opts = {}) data, _status_code, _headers = get_payment_as_csv_with_http_info(received_start, received_end, opts) return data end |
#get_payment_as_csv_with_http_info(received_start, received_end, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Retrieves payments in CSV format. { "nickname":"Payments CSV","response":"payments.csv"}
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 192 def get_payment_as_csv_with_http_info(received_start, received_end, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.get_payment_as_csv ..." end # verify the required parameter 'received_start' is set fail ArgumentError, "Missing the required parameter 'received_start' when calling PaymentsApi.get_payment_as_csv" if received_start.nil? # verify the required parameter 'received_end' is set fail ArgumentError, "Missing the required parameter 'received_end' when calling PaymentsApi.get_payment_as_csv" if received_end.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/payments/csv".sub('{format}','json') # query parameters query_params = {} query_params[:'received_start'] = received_start query_params[:'received_end'] = received_end query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/csv'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#get_payment_as_csv\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_by_id(payment_id, opts = {}) ⇒ PaymentPagedMetadata
Returns a single payment, specified by the payment-ID parameter. an existing payment","response":"getPaymentByID.html"
252 253 254 255 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 252 def get_payment_by_id(payment_id, opts = {}) data, _status_code, _headers = get_payment_by_id_with_http_info(payment_id, opts) return data end |
#get_payment_by_id_with_http_info(payment_id, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a single payment, specified by the payment-ID parameter. an existing payment","response":"getPaymentByID.html"
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 263 def get_payment_by_id_with_http_info(payment_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.get_payment_by_id ..." end # verify the required parameter 'payment_id' is set fail ArgumentError, "Missing the required parameter 'payment_id' when calling PaymentsApi.get_payment_by_id" if payment_id.nil? # resource path local_var_path = "/payments/{payment-ID}".sub('{format}','json').sub('{' + 'payment-ID' + '}', payment_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#get_payment_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_by_invoice_id(invoice_id, opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of payments, specified by the invoice-ID parameter. By default 10 values are returned. Records are returned in natural order. for invoice","response":"getPaymentByInvoice.html"
317 318 319 320 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 317 def get_payment_by_invoice_id(invoice_id, opts = {}) data, _status_code, _headers = get_payment_by_invoice_id_with_http_info(invoice_id, opts) return data end |
#get_payment_by_invoice_id_with_http_info(invoice_id, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of payments, specified by the invoice-ID parameter. By default 10 values are returned. Records are returned in natural order. for invoice","response":"getPaymentByInvoice.html"
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 333 def get_payment_by_invoice_id_with_http_info(invoice_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.get_payment_by_invoice_id ..." end # verify the required parameter 'invoice_id' is set fail ArgumentError, "Missing the required parameter 'invoice_id' when calling PaymentsApi.get_payment_by_invoice_id" if invoice_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/payments/invoice/{invoice-ID}".sub('{format}','json').sub('{' + 'invoice-ID' + '}', invoice_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#get_payment_by_invoice_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_by_payment_gateway(gateway, opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of payments, specified by the gateway parameter. By default 10 values are returned. Records are returned in natural order. by gateway","response":"getPaymentByGateway.html"
395 396 397 398 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 395 def get_payment_by_payment_gateway(gateway, opts = {}) data, _status_code, _headers = get_payment_by_payment_gateway_with_http_info(gateway, opts) return data end |
#get_payment_by_payment_gateway_with_http_info(gateway, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of payments, specified by the gateway parameter. By default 10 values are returned. Records are returned in natural order. by gateway","response":"getPaymentByGateway.html"
411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 411 def get_payment_by_payment_gateway_with_http_info(gateway, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.get_payment_by_payment_gateway ..." end # verify the required parameter 'gateway' is set fail ArgumentError, "Missing the required parameter 'gateway' when calling PaymentsApi.get_payment_by_payment_gateway" if gateway.nil? # verify enum value unless ['cybersource_token', 'card_vault', 'paypal_simple', 'locustworld', 'free', 'coupon', 'credit_note', 'stripe', 'braintree', 'balanced', 'paypal', 'billforward_test', 'offline', 'trial', 'stripeACH', 'authorizeNet', 'spreedly', 'sagePay', 'trustCommerce', 'payvision', 'kash'].include?(gateway) fail ArgumentError, "invalid value for 'gateway', must be one of cybersource_token, card_vault, paypal_simple, locustworld, free, coupon, credit_note, stripe, braintree, balanced, paypal, billforward_test, offline, trial, stripeACH, authorizeNet, spreedly, sagePay, trustCommerce, payvision, kash" end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/payments/gateway/{gateway}".sub('{format}','json').sub('{' + 'gateway' + '}', gateway.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#get_payment_by_payment_gateway\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_by_payment_method_id(payment_method_id, opts = {}) ⇒ PaymentPagedMetadata
Returns a collection of payments, specified by the payment-method-ID parameter. By default 10 values are returned. Records are returned in natural order. by payment method","response":"getPaymentByPaymentMethod.html"
477 478 479 480 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 477 def get_payment_by_payment_method_id(payment_method_id, opts = {}) data, _status_code, _headers = get_payment_by_payment_method_id_with_http_info(payment_method_id, opts) return data end |
#get_payment_by_payment_method_id_with_http_info(payment_method_id, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Returns a collection of payments, specified by the payment-method-ID parameter. By default 10 values are returned. Records are returned in natural order. by payment method","response":"getPaymentByPaymentMethod.html"
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 493 def get_payment_by_payment_method_id_with_http_info(payment_method_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.get_payment_by_payment_method_id ..." end # verify the required parameter 'payment_method_id' is set fail ArgumentError, "Missing the required parameter 'payment_method_id' when calling PaymentsApi.get_payment_by_payment_method_id" if payment_method_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/payments/payment-method/{payment-method-ID}".sub('{format}','json').sub('{' + 'payment-method-ID' + '}', payment_method_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#get_payment_by_payment_method_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_payment(payment, opts = {}) ⇒ PaymentPagedMetadata
Update a payment. a payment","request":"updatePaymentRequest.html","response":"updatePaymentResponse.html"
549 550 551 552 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 549 def update_payment(payment, opts = {}) data, _status_code, _headers = update_payment_with_http_info(payment, opts) return data end |
#update_payment_with_http_info(payment, opts = {}) ⇒ Array<(PaymentPagedMetadata, Fixnum, Hash)>
Update a payment. a payment","request":"updatePaymentRequest.html","response":"updatePaymentResponse.html"
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 |
# File 'lib/bf_ruby2/api/payments_api.rb', line 559 def update_payment_with_http_info(payment, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: PaymentsApi.update_payment ..." end # verify the required parameter 'payment' is set fail ArgumentError, "Missing the required parameter 'payment' when calling PaymentsApi.update_payment" if payment.nil? # resource path local_var_path = "/payments".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(payment) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'PaymentPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: PaymentsApi#update_payment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |