Class: BillForward::Product
- Inherits:
-
Object
- Object
- BillForward::Product
- Defined in:
- lib/bf_ruby2/models/product.rb
Overview
Product
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
"description":"","verbs":[].
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#crm_id ⇒ Object
ID of the product.“,”verbs“:.
-
#deleted ⇒ Object
href="\"GET\"">description“:”“,”verbs“:.
-
#description ⇒ Object
description — for your benefit — of the product. For example: you could explain what service this product entitles a customer to.“,”verbs“:.
-
#duration ⇒ Object
of length-measures which constitute the product’s period.“,”verbs“:.
-
#duration_period ⇒ Object
describing the magnitude of the product’s period.“,”verbs“:.
-
#id ⇒ Object
uniquely identifying this product.“,”verbs“:.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
unique name — for your benefit — used to identify this product within BillForward. It should reflect the fact that this product confers some service to a customer (e.g. \"Gold membership\").
The product can also be defined by the frequency with which it recurs (e.g. \"Monthly Gold membership\").
Remember also that rate plans can override the timing prescribed by their product. If you intend to override that timing, you may consider the product’s period duration to be an unimportant factor when it comes to naming it.“,”verbs“:. -
#payment_terms ⇒ Object
Returns the value of attribute payment_terms.
-
#product_type ⇒ Object
frequency of the product — either recurring or non-recurring.“,”verbs“:.
-
#public_name ⇒ Object
friendly non-unique name used to identify this product“,”verbs“:.
-
#start_date ⇒ Object
"description":"","verbs":[].
-
#trial ⇒ Object
of trial-length-measures which constitute the product’s trial period“,”verbs“:.
-
#trial_period ⇒ Object
describing the magnitude of the product’s trial period.“,”verbs“:.
-
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Product
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Product
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/bf_ruby2/models/product.rb', line 153 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'updated') self.updated = attributes[:'updated'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'crmID') self.crm_id = attributes[:'crmID'] end if attributes.has_key?(:'accountID') self.account_id = attributes[:'accountID'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'publicName') self.public_name = attributes[:'publicName'] end if attributes.has_key?(:'description') self.description = attributes[:'description'] end if attributes.has_key?(:'duration') self.duration = attributes[:'duration'] end if attributes.has_key?(:'durationPeriod') self.duration_period = attributes[:'durationPeriod'] end if attributes.has_key?(:'metadata') self. = attributes[:'metadata'] end if attributes.has_key?(:'trial') self.trial = attributes[:'trial'] end if attributes.has_key?(:'trialPeriod') self.trial_period = attributes[:'trialPeriod'] end if attributes.has_key?(:'productType') self.product_type = attributes[:'productType'] end if attributes.has_key?(:'deleted') self.deleted = attributes[:'deleted'] else self.deleted = false end if attributes.has_key?(:'startDate') self.start_date = attributes[:'startDate'] end if attributes.has_key?(:'paymentTerms') self.payment_terms = attributes[:'paymentTerms'] end end |
Instance Attribute Details
#account_id ⇒ Object
"description":"","verbs":[]
45 46 47 |
# File 'lib/bf_ruby2/models/product.rb', line 45 def account_id @account_id end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
33 34 35 |
# File 'lib/bf_ruby2/models/product.rb', line 33 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
30 31 32 |
# File 'lib/bf_ruby2/models/product.rb', line 30 def created @created end |
#crm_id ⇒ Object
ID of the product.“,”verbs“:
42 43 44 |
# File 'lib/bf_ruby2/models/product.rb', line 42 def crm_id @crm_id end |
#deleted ⇒ Object
href="\"GET\"">description“:”“,”verbs“:
74 75 76 |
# File 'lib/bf_ruby2/models/product.rb', line 74 def deleted @deleted end |
#description ⇒ Object
description — for your benefit — of the product. For example: you could explain what service this product entitles a customer to.“,”verbs“:
54 55 56 |
# File 'lib/bf_ruby2/models/product.rb', line 54 def description @description end |
#duration ⇒ Object
of length-measures which constitute the product’s period.“,”verbs“:
57 58 59 |
# File 'lib/bf_ruby2/models/product.rb', line 57 def duration @duration end |
#duration_period ⇒ Object
describing the magnitude of the product’s period.“,”verbs“:
60 61 62 |
# File 'lib/bf_ruby2/models/product.rb', line 60 def duration_period @duration_period end |
#id ⇒ Object
uniquely identifying this product.“,”verbs“:
39 40 41 |
# File 'lib/bf_ruby2/models/product.rb', line 39 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
62 63 64 |
# File 'lib/bf_ruby2/models/product.rb', line 62 def @metadata end |
#name ⇒ Object
unique name — for your benefit — used to identify this product within BillForward. It should reflect the fact that this product confers some service to a customer (e.g. \"Gold membership\").
The product can also be defined by the frequency with which it recurs (e.g. \"Monthly Gold membership\").
Remember also that rate plans can override the timing prescribed by their product. If you intend to override that timing, you may consider the product’s period duration to be an unimportant factor when it comes to naming it.“,”verbs“:
48 49 50 |
# File 'lib/bf_ruby2/models/product.rb', line 48 def name @name end |
#payment_terms ⇒ Object
Returns the value of attribute payment_terms.
79 80 81 |
# File 'lib/bf_ruby2/models/product.rb', line 79 def payment_terms @payment_terms end |
#product_type ⇒ Object
frequency of the product — either recurring or non-recurring.“,”verbs“:
71 72 73 |
# File 'lib/bf_ruby2/models/product.rb', line 71 def product_type @product_type end |
#public_name ⇒ Object
friendly non-unique name used to identify this product“,”verbs“:
51 52 53 |
# File 'lib/bf_ruby2/models/product.rb', line 51 def public_name @public_name end |
#start_date ⇒ Object
"description":"","verbs":[]
77 78 79 |
# File 'lib/bf_ruby2/models/product.rb', line 77 def start_date @start_date end |
#trial ⇒ Object
of trial-length-measures which constitute the product’s trial period“,”verbs“:
65 66 67 |
# File 'lib/bf_ruby2/models/product.rb', line 65 def trial @trial end |
#trial_period ⇒ Object
describing the magnitude of the product’s trial period.“,”verbs“:
68 69 70 |
# File 'lib/bf_ruby2/models/product.rb', line 68 def trial_period @trial_period end |
#updated ⇒ Object
{ "description" : "The UTC DateTime when the object was last updated.", "verbs":[] }
36 37 38 |
# File 'lib/bf_ruby2/models/product.rb', line 36 def updated @updated end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/bf_ruby2/models/product.rb', line 104 def self.attribute_map { :'created' => :'created', :'changed_by' => :'changedBy', :'updated' => :'updated', :'id' => :'id', :'crm_id' => :'crmID', :'account_id' => :'accountID', :'name' => :'name', :'public_name' => :'publicName', :'description' => :'description', :'duration' => :'duration', :'duration_period' => :'durationPeriod', :'metadata' => :'metadata', :'trial' => :'trial', :'trial_period' => :'trialPeriod', :'product_type' => :'productType', :'deleted' => :'deleted', :'start_date' => :'startDate', :'payment_terms' => :'paymentTerms' } end |
.swagger_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/bf_ruby2/models/product.rb', line 128 def self.swagger_types { :'created' => :'DateTime', :'changed_by' => :'String', :'updated' => :'DateTime', :'id' => :'String', :'crm_id' => :'String', :'account_id' => :'String', :'name' => :'String', :'public_name' => :'String', :'description' => :'String', :'duration' => :'Integer', :'duration_period' => :'String', :'metadata' => :'DynamicMetadata', :'trial' => :'Integer', :'trial_period' => :'String', :'product_type' => :'String', :'deleted' => :'BOOLEAN', :'start_date' => :'DateTime', :'payment_terms' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/bf_ruby2/models/product.rb', line 294 def ==(o) return true if self.equal?(o) self.class == o.class && created == o.created && changed_by == o.changed_by && updated == o.updated && id == o.id && crm_id == o.crm_id && account_id == o.account_id && name == o.name && public_name == o.public_name && description == o.description && duration == o.duration && duration_period == o.duration_period && == o. && trial == o.trial && trial_period == o.trial_period && product_type == o.product_type && deleted == o.deleted && start_date == o.start_date && payment_terms == o.payment_terms end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/bf_ruby2/models/product.rb', line 353 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/bf_ruby2/models/product.rb', line 419 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/bf_ruby2/models/product.rb', line 332 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
319 320 321 |
# File 'lib/bf_ruby2/models/product.rb', line 319 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
325 326 327 |
# File 'lib/bf_ruby2/models/product.rb', line 325 def hash [created, changed_by, updated, id, crm_id, account_id, name, public_name, description, duration, duration_period, , trial, trial_period, product_type, deleted, start_date, payment_terms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
237 238 239 240 |
# File 'lib/bf_ruby2/models/product.rb', line 237 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
399 400 401 |
# File 'lib/bf_ruby2/models/product.rb', line 399 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
405 406 407 408 409 410 411 412 413 |
# File 'lib/bf_ruby2/models/product.rb', line 405 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
393 394 395 |
# File 'lib/bf_ruby2/models/product.rb', line 393 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/bf_ruby2/models/product.rb', line 244 def valid? return false if @name.nil? return false if @description.nil? return false if @duration.nil? return false if @duration_period.nil? duration_period_validator = EnumAttributeValidator.new('String', ["minutes", "days", "months", "years"]) return false unless duration_period_validator.valid?(@duration_period) return false if @trial.nil? return false if @trial_period.nil? trial_period_validator = EnumAttributeValidator.new('String', ["none", "minutes", "days", "months"]) return false unless trial_period_validator.valid?(@trial_period) return false if @product_type.nil? product_type_validator = EnumAttributeValidator.new('String', ["nonrecurring", "recurring"]) return false unless product_type_validator.valid?(@product_type) return false if @deleted.nil? return true end |