Class: BillForward::ProfilesApi
- Inherits:
-
Object
- Object
- BillForward::ProfilesApi
- Defined in:
- lib/bf_ruby2/api/profiles_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_all_profiles(opts = {}) ⇒ ProfilePagedMetadata
Returns a collection of all profiles.
-
#get_all_profiles_with_http_info(opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a collection of all profiles.
-
#get_profile(profile_id, opts = {}) ⇒ ProfilePagedMetadata
Returns a single profile, specified by the ID parameter.
-
#get_profile_by_account_id(account_id, opts = {}) ⇒ ProfilePagedMetadata
Returns a collection of profiles, specified by the account-ID parameter.
-
#get_profile_by_account_id_with_http_info(account_id, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a collection of profiles, specified by the account-ID parameter.
-
#get_profile_by_email_address(email, opts = {}) ⇒ ProfilePagedMetadata
Returns a single profile, specified by the email parameter.
-
#get_profile_by_email_address_with_http_info(email, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a single profile, specified by the email parameter.
-
#get_profile_with_http_info(profile_id, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a single profile, specified by the ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ ProfilesApi
constructor
A new instance of ProfilesApi.
-
#update_profile(request, opts = {}) ⇒ ProfilePagedMetadata
Update a profile a profile","request":"updateProfileRequest.html","response":"updateProfileResponse.html".
-
#update_profile_with_http_info(request, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Update a profile a profile","request":"updateProfileRequest.html","response":"updateProfileResponse.html".
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProfilesApi
Returns a new instance of ProfilesApi.
30 31 32 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#get_all_profiles(opts = {}) ⇒ ProfilePagedMetadata
Returns a collection of all profiles. By default 10 values are returned. Records are returned in natural order all profiles","response":"getProfileAll.html"
43 44 45 46 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 43 def get_all_profiles(opts = {}) data, _status_code, _headers = get_all_profiles_with_http_info(opts) return data end |
#get_all_profiles_with_http_info(opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a collection of all profiles. By default 10 values are returned. Records are returned in natural order all profiles","response":"getProfileAll.html"
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 57 def get_all_profiles_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ProfilesApi.get_all_profiles ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/profiles".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ProfilePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#get_all_profiles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_profile(profile_id, opts = {}) ⇒ ProfilePagedMetadata
Returns a single profile, specified by the ID parameter. an existing profile","response":"getProfileByID.html"
111 112 113 114 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 111 def get_profile(profile_id, opts = {}) data, _status_code, _headers = get_profile_with_http_info(profile_id, opts) return data end |
#get_profile_by_account_id(account_id, opts = {}) ⇒ ProfilePagedMetadata
Returns a collection of profiles, specified by the account-ID parameter. By default 10 values are returned. Records are returned in natural order by account","response":"getProfileByAccountID.html"
175 176 177 178 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 175 def get_profile_by_account_id(account_id, opts = {}) data, _status_code, _headers = get_profile_by_account_id_with_http_info(account_id, opts) return data end |
#get_profile_by_account_id_with_http_info(account_id, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a collection of profiles, specified by the account-ID parameter. By default 10 values are returned. Records are returned in natural order by account","response":"getProfileByAccountID.html"
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 190 def get_profile_by_account_id_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ProfilesApi.get_profile_by_account_id ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling ProfilesApi.get_profile_by_account_id" if account_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/profiles/account/{account-ID}".sub('{format}','json').sub('{' + 'account-ID' + '}', account_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ProfilePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#get_profile_by_account_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_profile_by_email_address(email, opts = {}) ⇒ ProfilePagedMetadata
Returns a single profile, specified by the email parameter. by e-mail","response":"getProfileByEmail.html"
251 252 253 254 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 251 def get_profile_by_email_address(email, opts = {}) data, _status_code, _headers = get_profile_by_email_address_with_http_info(email, opts) return data end |
#get_profile_by_email_address_with_http_info(email, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a single profile, specified by the email parameter. by e-mail","response":"getProfileByEmail.html"
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 267 def get_profile_by_email_address_with_http_info(email, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ProfilesApi.get_profile_by_email_address ..." end # verify the required parameter 'email' is set fail ArgumentError, "Missing the required parameter 'email' when calling ProfilesApi.get_profile_by_email_address" if email.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/profiles/email/{email}".sub('{format}','json').sub('{' + 'email' + '}', email.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? query_params[:'include_retired'] = opts[:'include_retired'] if !opts[:'include_retired'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ProfilePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#get_profile_by_email_address\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_profile_with_http_info(profile_id, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Returns a single profile, specified by the ID parameter. an existing profile","response":"getProfileByID.html"
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 122 def get_profile_with_http_info(profile_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ProfilesApi.get_profile ..." end # verify the required parameter 'profile_id' is set fail ArgumentError, "Missing the required parameter 'profile_id' when calling ProfilesApi.get_profile" if profile_id.nil? # resource path local_var_path = "/profiles/{profile-ID}".sub('{format}','json').sub('{' + 'profile-ID' + '}', profile_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ProfilePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#get_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_profile(request, opts = {}) ⇒ ProfilePagedMetadata
Update a profile a profile","request":"updateProfileRequest.html","response":"updateProfileResponse.html"
323 324 325 326 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 323 def update_profile(request, opts = {}) data, _status_code, _headers = update_profile_with_http_info(request, opts) return data end |
#update_profile_with_http_info(request, opts = {}) ⇒ Array<(ProfilePagedMetadata, Fixnum, Hash)>
Update a profile a profile","request":"updateProfileRequest.html","response":"updateProfileResponse.html"
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/bf_ruby2/api/profiles_api.rb', line 333 def update_profile_with_http_info(request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: ProfilesApi.update_profile ..." end # verify the required parameter 'request' is set fail ArgumentError, "Missing the required parameter 'request' when calling ProfilesApi.update_profile" if request.nil? # resource path local_var_path = "/profiles".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(request) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ProfilePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#update_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |