Class: BillForward::Receipt
- Inherits:
-
Object
- Object
- BillForward::Receipt
- Defined in:
- lib/bf_ruby2/models/receipt.rb
Overview
Receipt
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#card_country ⇒ Object
Returns the value of attribute card_country.
-
#card_description ⇒ Object
Returns the value of attribute card_description.
-
#card_last_four ⇒ Object
Returns the value of attribute card_last_four.
-
#card_province ⇒ Object
Returns the value of attribute card_province.
-
#card_type ⇒ Object
Returns the value of attribute card_type.
-
#cardholder_name ⇒ Object
Returns the value of attribute cardholder_name.
-
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }.
-
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }.
-
#crm_id ⇒ Object
{ "description" : "CRM ID of the subscription.", "verbs“: }.
-
#currency ⇒ Object
{ "description" : "Currency of the invoice specified by a three character ISO 4217 currency code.", "verbs“: }.
-
#decision ⇒ Object
Returns the value of attribute decision.
-
#execution_attempt ⇒ Object
Returns the value of attribute execution_attempt.
-
#gateway_reference_id ⇒ Object
Returns the value of attribute gateway_reference_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#invoice_id ⇒ Object
Returns the value of attribute invoice_id.
-
#invoice_type ⇒ Object
{ "description" : "The type of the invoice. A subscription invoice is raised every time a subscription recurs. An amendment is created for intra-contract changes. An Adhoc invoice is created for payment that is taken out-of-band of a subscription. Finally the invoice generated for a trial period is marked as Trial.", "verbs“: }.
-
#ip_address ⇒ Object
address associated with this payment method.“,”verbs“:.
-
#ip_address_country ⇒ Object
of the IP address associated with this payment method.“,”verbs“:.
-
#organization_id ⇒ Object
Returns the value of attribute organization_id.
-
#payment_gateway ⇒ Object
Returns the value of attribute payment_gateway.
-
#payment_id ⇒ Object
Returns the value of attribute payment_id.
-
#payment_method_id ⇒ Object
Returns the value of attribute payment_method_id.
-
#raw_data ⇒ Object
Returns the value of attribute raw_data.
-
#raw_reason_code ⇒ Object
Returns the value of attribute raw_reason_code.
-
#reason_code ⇒ Object
Returns the value of attribute reason_code.
-
#refund_id ⇒ Object
Returns the value of attribute refund_id.
-
#type ⇒ Object
{ "description" : "Type of transaction.", "verbs“: }.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Receipt
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Receipt
Initializes the object
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/bf_ruby2/models/receipt.rb', line 189 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v} if attributes.has_key?(:'refundID') self.refund_id = attributes[:'refundID'] end if attributes.has_key?(:'created') self.created = attributes[:'created'] end if attributes.has_key?(:'changedBy') self.changed_by = attributes[:'changedBy'] end if attributes.has_key?(:'id') self.id = attributes[:'id'] end if attributes.has_key?(:'crmID') self.crm_id = attributes[:'crmID'] end if attributes.has_key?(:'invoiceID') self.invoice_id = attributes[:'invoiceID'] end if attributes.has_key?(:'gatewayReferenceID') self.gateway_reference_id = attributes[:'gatewayReferenceID'] end if attributes.has_key?(:'accountID') self.account_id = attributes[:'accountID'] end if attributes.has_key?(:'paymentID') self.payment_id = attributes[:'paymentID'] end if attributes.has_key?(:'paymentMethodID') self.payment_method_id = attributes[:'paymentMethodID'] end if attributes.has_key?(:'organizationID') self.organization_id = attributes[:'organizationID'] end if attributes.has_key?(:'cardholderName') self.cardholder_name = attributes[:'cardholderName'] end if attributes.has_key?(:'cardLastFour') self.card_last_four = attributes[:'cardLastFour'] end if attributes.has_key?(:'cardDescription') self.card_description = attributes[:'cardDescription'] end if attributes.has_key?(:'cardCountry') self.card_country = attributes[:'cardCountry'] end if attributes.has_key?(:'cardProvince') self.card_province = attributes[:'cardProvince'] end if attributes.has_key?(:'cardType') self.card_type = attributes[:'cardType'] end if attributes.has_key?(:'ipAddress') self.ip_address = attributes[:'ipAddress'] end if attributes.has_key?(:'ipAddressCountry') self.ip_address_country = attributes[:'ipAddressCountry'] end if attributes.has_key?(:'type') self.type = attributes[:'type'] end if attributes.has_key?(:'currency') self.currency = attributes[:'currency'] end if attributes.has_key?(:'value') self.value = attributes[:'value'] end if attributes.has_key?(:'paymentGateway') self.payment_gateway = attributes[:'paymentGateway'] end if attributes.has_key?(:'invoiceType') self.invoice_type = attributes[:'invoiceType'] end if attributes.has_key?(:'executionAttempt') self.execution_attempt = attributes[:'executionAttempt'] end if attributes.has_key?(:'decision') self.decision = attributes[:'decision'] end if attributes.has_key?(:'reasonCode') self.reason_code = attributes[:'reasonCode'] end if attributes.has_key?(:'rawReasonCode') self.raw_reason_code = attributes[:'rawReasonCode'] end if attributes.has_key?(:'rawData') if (value = attributes[:'rawData']).is_a?(Array) self.raw_data = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
46 47 48 |
# File 'lib/bf_ruby2/models/receipt.rb', line 46 def account_id @account_id end |
#card_country ⇒ Object
Returns the value of attribute card_country.
60 61 62 |
# File 'lib/bf_ruby2/models/receipt.rb', line 60 def card_country @card_country end |
#card_description ⇒ Object
Returns the value of attribute card_description.
58 59 60 |
# File 'lib/bf_ruby2/models/receipt.rb', line 58 def card_description @card_description end |
#card_last_four ⇒ Object
Returns the value of attribute card_last_four.
56 57 58 |
# File 'lib/bf_ruby2/models/receipt.rb', line 56 def card_last_four @card_last_four end |
#card_province ⇒ Object
Returns the value of attribute card_province.
62 63 64 |
# File 'lib/bf_ruby2/models/receipt.rb', line 62 def card_province @card_province end |
#card_type ⇒ Object
Returns the value of attribute card_type.
64 65 66 |
# File 'lib/bf_ruby2/models/receipt.rb', line 64 def card_type @card_type end |
#cardholder_name ⇒ Object
Returns the value of attribute cardholder_name.
54 55 56 |
# File 'lib/bf_ruby2/models/receipt.rb', line 54 def cardholder_name @cardholder_name end |
#changed_by ⇒ Object
{ "description" : "ID of the user who last updated the entity.", "verbs":[] }
35 36 37 |
# File 'lib/bf_ruby2/models/receipt.rb', line 35 def changed_by @changed_by end |
#created ⇒ Object
{ "description" : "The UTC DateTime when the object was created.", "verbs":[] }
32 33 34 |
# File 'lib/bf_ruby2/models/receipt.rb', line 32 def created @created end |
#crm_id ⇒ Object
{ "description" : "CRM ID of the subscription.", "verbs“: }
40 41 42 |
# File 'lib/bf_ruby2/models/receipt.rb', line 40 def crm_id @crm_id end |
#currency ⇒ Object
{ "description" : "Currency of the invoice specified by a three character ISO 4217 currency code.", "verbs“: }
76 77 78 |
# File 'lib/bf_ruby2/models/receipt.rb', line 76 def currency @currency end |
#decision ⇒ Object
Returns the value of attribute decision.
87 88 89 |
# File 'lib/bf_ruby2/models/receipt.rb', line 87 def decision @decision end |
#execution_attempt ⇒ Object
Returns the value of attribute execution_attempt.
85 86 87 |
# File 'lib/bf_ruby2/models/receipt.rb', line 85 def execution_attempt @execution_attempt end |
#gateway_reference_id ⇒ Object
Returns the value of attribute gateway_reference_id.
44 45 46 |
# File 'lib/bf_ruby2/models/receipt.rb', line 44 def gateway_reference_id @gateway_reference_id end |
#id ⇒ Object
Returns the value of attribute id.
37 38 39 |
# File 'lib/bf_ruby2/models/receipt.rb', line 37 def id @id end |
#invoice_id ⇒ Object
Returns the value of attribute invoice_id.
42 43 44 |
# File 'lib/bf_ruby2/models/receipt.rb', line 42 def invoice_id @invoice_id end |
#invoice_type ⇒ Object
{ "description" : "The type of the invoice. A subscription invoice is raised every time a subscription recurs. An amendment is created for intra-contract changes. An Adhoc invoice is created for payment that is taken out-of-band of a subscription. Finally the invoice generated for a trial period is marked as Trial.", "verbs“: }
83 84 85 |
# File 'lib/bf_ruby2/models/receipt.rb', line 83 def invoice_type @invoice_type end |
#ip_address ⇒ Object
address associated with this payment method.“,”verbs“:
67 68 69 |
# File 'lib/bf_ruby2/models/receipt.rb', line 67 def ip_address @ip_address end |
#ip_address_country ⇒ Object
of the IP address associated with this payment method.“,”verbs“:
70 71 72 |
# File 'lib/bf_ruby2/models/receipt.rb', line 70 def ip_address_country @ip_address_country end |
#organization_id ⇒ Object
Returns the value of attribute organization_id.
52 53 54 |
# File 'lib/bf_ruby2/models/receipt.rb', line 52 def organization_id @organization_id end |
#payment_gateway ⇒ Object
Returns the value of attribute payment_gateway.
80 81 82 |
# File 'lib/bf_ruby2/models/receipt.rb', line 80 def payment_gateway @payment_gateway end |
#payment_id ⇒ Object
Returns the value of attribute payment_id.
48 49 50 |
# File 'lib/bf_ruby2/models/receipt.rb', line 48 def payment_id @payment_id end |
#payment_method_id ⇒ Object
Returns the value of attribute payment_method_id.
50 51 52 |
# File 'lib/bf_ruby2/models/receipt.rb', line 50 def payment_method_id @payment_method_id end |
#raw_data ⇒ Object
Returns the value of attribute raw_data.
93 94 95 |
# File 'lib/bf_ruby2/models/receipt.rb', line 93 def raw_data @raw_data end |
#raw_reason_code ⇒ Object
Returns the value of attribute raw_reason_code.
91 92 93 |
# File 'lib/bf_ruby2/models/receipt.rb', line 91 def raw_reason_code @raw_reason_code end |
#reason_code ⇒ Object
Returns the value of attribute reason_code.
89 90 91 |
# File 'lib/bf_ruby2/models/receipt.rb', line 89 def reason_code @reason_code end |
#refund_id ⇒ Object
Returns the value of attribute refund_id.
29 30 31 |
# File 'lib/bf_ruby2/models/receipt.rb', line 29 def refund_id @refund_id end |
#type ⇒ Object
{ "description" : "Type of transaction.", "verbs“: }
73 74 75 |
# File 'lib/bf_ruby2/models/receipt.rb', line 73 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
78 79 80 |
# File 'lib/bf_ruby2/models/receipt.rb', line 78 def value @value end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/bf_ruby2/models/receipt.rb', line 118 def self.attribute_map { :'refund_id' => :'refundID', :'created' => :'created', :'changed_by' => :'changedBy', :'id' => :'id', :'crm_id' => :'crmID', :'invoice_id' => :'invoiceID', :'gateway_reference_id' => :'gatewayReferenceID', :'account_id' => :'accountID', :'payment_id' => :'paymentID', :'payment_method_id' => :'paymentMethodID', :'organization_id' => :'organizationID', :'cardholder_name' => :'cardholderName', :'card_last_four' => :'cardLastFour', :'card_description' => :'cardDescription', :'card_country' => :'cardCountry', :'card_province' => :'cardProvince', :'card_type' => :'cardType', :'ip_address' => :'ipAddress', :'ip_address_country' => :'ipAddressCountry', :'type' => :'type', :'currency' => :'currency', :'value' => :'value', :'payment_gateway' => :'paymentGateway', :'invoice_type' => :'invoiceType', :'execution_attempt' => :'executionAttempt', :'decision' => :'decision', :'reason_code' => :'reasonCode', :'raw_reason_code' => :'rawReasonCode', :'raw_data' => :'rawData' } end |
.swagger_types ⇒ Object
Attribute type mapping.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/bf_ruby2/models/receipt.rb', line 153 def self.swagger_types { :'refund_id' => :'String', :'created' => :'DateTime', :'changed_by' => :'String', :'id' => :'String', :'crm_id' => :'String', :'invoice_id' => :'String', :'gateway_reference_id' => :'String', :'account_id' => :'String', :'payment_id' => :'String', :'payment_method_id' => :'String', :'organization_id' => :'String', :'cardholder_name' => :'String', :'card_last_four' => :'String', :'card_description' => :'String', :'card_country' => :'String', :'card_province' => :'String', :'card_type' => :'String', :'ip_address' => :'String', :'ip_address_country' => :'String', :'type' => :'String', :'currency' => :'String', :'value' => :'Float', :'payment_gateway' => :'String', :'invoice_type' => :'String', :'execution_attempt' => :'Integer', :'decision' => :'String', :'reason_code' => :'Integer', :'raw_reason_code' => :'String', :'raw_data' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/bf_ruby2/models/receipt.rb', line 383 def ==(o) return true if self.equal?(o) self.class == o.class && refund_id == o.refund_id && created == o.created && changed_by == o.changed_by && id == o.id && crm_id == o.crm_id && invoice_id == o.invoice_id && gateway_reference_id == o.gateway_reference_id && account_id == o.account_id && payment_id == o.payment_id && payment_method_id == o.payment_method_id && organization_id == o.organization_id && cardholder_name == o.cardholder_name && card_last_four == o.card_last_four && card_description == o.card_description && card_country == o.card_country && card_province == o.card_province && card_type == o.card_type && ip_address == o.ip_address && ip_address_country == o.ip_address_country && type == o.type && currency == o.currency && value == o.value && payment_gateway == o.payment_gateway && invoice_type == o.invoice_type && execution_attempt == o.execution_attempt && decision == o.decision && reason_code == o.reason_code && raw_reason_code == o.raw_reason_code && raw_data == o.raw_data end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/bf_ruby2/models/receipt.rb', line 453 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /^(true|t|yes|y|1)$/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = BillForward.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
519 520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/bf_ruby2/models/receipt.rb', line 519 def _to_hash(value) if value.is_a?(Array) value.compact.map{ |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/bf_ruby2/models/receipt.rb', line 432 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /^Array<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } ) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
419 420 421 |
# File 'lib/bf_ruby2/models/receipt.rb', line 419 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
425 426 427 |
# File 'lib/bf_ruby2/models/receipt.rb', line 425 def hash [refund_id, created, changed_by, id, crm_id, invoice_id, gateway_reference_id, account_id, payment_id, payment_method_id, organization_id, cardholder_name, card_last_four, card_description, card_country, card_province, card_type, ip_address, ip_address_country, type, currency, value, payment_gateway, invoice_type, execution_attempt, decision, reason_code, raw_reason_code, raw_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
317 318 319 320 |
# File 'lib/bf_ruby2/models/receipt.rb', line 317 def list_invalid_properties invalid_properties = Array.new return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
499 500 501 |
# File 'lib/bf_ruby2/models/receipt.rb', line 499 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
505 506 507 508 509 510 511 512 513 |
# File 'lib/bf_ruby2/models/receipt.rb', line 505 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
493 494 495 |
# File 'lib/bf_ruby2/models/receipt.rb', line 493 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/bf_ruby2/models/receipt.rb', line 324 def valid? return false if @refund_id.nil? return false if @crm_id.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["credit", "debit"]) return false unless type_validator.valid?(@type) return false if @currency.nil? payment_gateway_validator = EnumAttributeValidator.new('String', ["cybersource_token", "card_vault", "paypal_simple", "locustworld", "free", "coupon", "credit_note", "stripe", "braintree", "balanced", "paypal", "billforward_test", "offline", "trial", "stripeACH", "authorizeNet", "spreedly", "sagePay", "trustCommerce", "payvision", "kash"]) return false unless payment_gateway_validator.valid?(@payment_gateway) return false if @invoice_type.nil? invoice_type_validator = EnumAttributeValidator.new('String', ["Subscription", "Trial", "Charge", "FinalArrears", "Amendment", "Aggregated"]) return false unless invoice_type_validator.valid?(@invoice_type) decision_validator = EnumAttributeValidator.new('String', ["Accept", "Reject", "Error"]) return false unless decision_validator.valid?(@decision) return true end |