Class: BillForward::SynchConfigsApi
- Inherits:
-
Object
- Object
- BillForward::SynchConfigsApi
- Defined in:
- lib/bf_ruby2/api/synch_configs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_sync_config(synch_config, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Create a synch configuration.
-
#create_sync_config_with_http_info(synch_config, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Create a synch configuration.
-
#get_all_sync_configs(opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a collection of Users.
-
#get_all_sync_configs_with_http_info(opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection of Users.
-
#get_sync_config(synch_configs_id, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a single config, specified by the ID parameter.
-
#get_sync_config_by_platform(platform, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a collection configurations, specified by the platform parameter.
-
#get_sync_config_by_platform_with_http_info(platform, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection configurations, specified by the platform parameter.
-
#get_sync_config_by_username(username, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a collection configurations, specified by the username parameter.
-
#get_sync_config_by_username_with_http_info(username, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection configurations, specified by the username parameter.
-
#get_sync_config_with_http_info(synch_configs_id, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a single config, specified by the ID parameter.
-
#initialize(api_client = ApiClient.default) ⇒ SynchConfigsApi
constructor
A new instance of SynchConfigsApi.
-
#update_sync_config(synch_config, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Update a synch configuration.
-
#update_sync_config_with_http_info(synch_config, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Update a synch configuration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SynchConfigsApi
Returns a new instance of SynchConfigsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_sync_config(synch_config, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Create a synch configuration. a new synch configuration","request":"createSynchConfigRequest.html","response":"createSynchConfigResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 39 def create_sync_config(synch_config, opts = {}) data, _status_code, _headers = create_sync_config_with_http_info(synch_config, opts) return data end |
#create_sync_config_with_http_info(synch_config, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Create a synch configuration. a new synch configuration","request":"createSynchConfigRequest.html","response":"createSynchConfigResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 49 def create_sync_config_with_http_info(synch_config, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchConfigsApi.create_sync_config ..." end # verify the required parameter 'synch_config' is set fail ArgumentError, "Missing the required parameter 'synch_config' when calling SynchConfigsApi.create_sync_config" if synch_config.nil? # resource path local_var_path = "/synchConfigs".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(synch_config) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchConfigsApi#create_sync_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_sync_configs(opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a collection of Users. By default 10 values are returned. Records are returned in natural order. { "nickname" : "Get all synch configs","response" : "getSynchConfigsAll.html"}
100 101 102 103 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 100 def get_all_sync_configs(opts = {}) data, _status_code, _headers = get_all_sync_configs_with_http_info(opts) return data end |
#get_all_sync_configs_with_http_info(opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection of Users. By default 10 values are returned. Records are returned in natural order. { "nickname" : "Get all synch configs","response" : "getSynchConfigsAll.html"}
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 114 def get_all_sync_configs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchConfigsApi.get_all_sync_configs ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/synchConfigs".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchConfigsApi#get_all_sync_configs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_config(synch_configs_id, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a single config, specified by the ID parameter. { "nickname" : "Retrieve an existing synch config","response" : "getSynchConfigByID.html"}
168 169 170 171 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 168 def get_sync_config(synch_configs_id, opts = {}) data, _status_code, _headers = get_sync_config_with_http_info(synch_configs_id, opts) return data end |
#get_sync_config_by_platform(platform, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a collection configurations, specified by the platform parameter. { "nickname" : "Retrieve by platform","response" : "getSynchConfigsByPlatform.html"}
228 229 230 231 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 228 def get_sync_config_by_platform(platform, opts = {}) data, _status_code, _headers = get_sync_config_by_platform_with_http_info(platform, opts) return data end |
#get_sync_config_by_platform_with_http_info(platform, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection configurations, specified by the platform parameter. { "nickname" : "Retrieve by platform","response" : "getSynchConfigsByPlatform.html"}
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 239 def get_sync_config_by_platform_with_http_info(platform, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchConfigsApi.get_sync_config_by_platform ..." end # verify the required parameter 'platform' is set fail ArgumentError, "Missing the required parameter 'platform' when calling SynchConfigsApi.get_sync_config_by_platform" if platform.nil? # verify enum value unless ['Salesforce'].include?(platform) fail ArgumentError, "invalid value for 'platform', must be one of Salesforce" end # resource path local_var_path = "/synchConfigs/platform/{platform}".sub('{format}','json').sub('{' + 'platform' + '}', platform.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchConfigsApi#get_sync_config_by_platform\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_config_by_username(username, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Returns a collection configurations, specified by the username parameter. { "nickname" : "Retrieve by username","response" : "getSynchConfigByUsername.html"}
292 293 294 295 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 292 def get_sync_config_by_username(username, opts = {}) data, _status_code, _headers = get_sync_config_by_username_with_http_info(username, opts) return data end |
#get_sync_config_by_username_with_http_info(username, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a collection configurations, specified by the username parameter. { "nickname" : "Retrieve by username","response" : "getSynchConfigByUsername.html"}
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 303 def get_sync_config_by_username_with_http_info(username, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchConfigsApi.get_sync_config_by_username ..." end # verify the required parameter 'username' is set fail ArgumentError, "Missing the required parameter 'username' when calling SynchConfigsApi.get_sync_config_by_username" if username.nil? # resource path local_var_path = "/synchConfigs/username/{username}".sub('{format}','json').sub('{' + 'username' + '}', username.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchConfigsApi#get_sync_config_by_username\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_config_with_http_info(synch_configs_id, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Returns a single config, specified by the ID parameter. { "nickname" : "Retrieve an existing synch config","response" : "getSynchConfigByID.html"}
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 179 def get_sync_config_with_http_info(synch_configs_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchConfigsApi.get_sync_config ..." end # verify the required parameter 'synch_configs_id' is set fail ArgumentError, "Missing the required parameter 'synch_configs_id' when calling SynchConfigsApi.get_sync_config" if synch_configs_id.nil? # resource path local_var_path = "/synchConfigs/{synchConfigs-ID}".sub('{format}','json').sub('{' + 'synchConfigs-ID' + '}', synch_configs_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchConfigsApi#get_sync_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_sync_config(synch_config, opts = {}) ⇒ DataSynchronisationConfigurationPagedMetadata
Update a synch configuration. { "nickname" : "Update a synch config", "request" : "updateSyncConfigRequest.html" ,"response" : "updateSyncConfigResponse.html" }
351 352 353 354 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 351 def update_sync_config(synch_config, opts = {}) data, _status_code, _headers = update_sync_config_with_http_info(synch_config, opts) return data end |
#update_sync_config_with_http_info(synch_config, opts = {}) ⇒ Array<(DataSynchronisationConfigurationPagedMetadata, Fixnum, Hash)>
Update a synch configuration. { "nickname" : "Update a synch config", "request" : "updateSyncConfigRequest.html" ,"response" : "updateSyncConfigResponse.html" }
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/bf_ruby2/api/synch_configs_api.rb', line 361 def update_sync_config_with_http_info(synch_config, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchConfigsApi.update_sync_config ..." end # verify the required parameter 'synch_config' is set fail ArgumentError, "Missing the required parameter 'synch_config' when calling SynchConfigsApi.update_sync_config" if synch_config.nil? # resource path local_var_path = "/synchConfigs".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(synch_config) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronisationConfigurationPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchConfigsApi#update_sync_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |