Class: BillForward::SynchJobsApi
- Inherits:
-
Object
- Object
- BillForward::SynchJobsApi
- Defined in:
- lib/bf_ruby2/api/synch_jobs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_sync_job(synch_job, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Create a synch job.
-
#create_sync_job_with_http_info(synch_job, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Create a synch job.
-
#get_all_sync_jobs(opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection of Users.
-
#get_all_sync_jobs_with_http_info(opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection of Users.
-
#get_sync_job_by_id(synch_job_id, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a single job, specified by the ID parameter.
-
#get_sync_job_by_id_with_http_info(synch_job_id, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a single job, specified by the ID parameter.
-
#get_sync_job_by_scope(scope, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the scope parameter.
-
#get_sync_job_by_scope_with_http_info(scope, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the scope parameter.
-
#get_sync_job_by_state(state, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the state parameter.
-
#get_sync_job_by_state_with_http_info(state, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the state parameter.
-
#get_sync_job_by_target(target, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the target parameter.
-
#get_sync_job_by_target_with_http_info(target, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the target parameter.
-
#get_sync_job_by_type(type, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the type parameter.
-
#get_sync_job_by_type_with_http_info(type, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the type parameter.
-
#initialize(api_client = ApiClient.default) ⇒ SynchJobsApi
constructor
A new instance of SynchJobsApi.
-
#update_sync_job(synch_job, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Update a synch job.
-
#update_sync_job_with_http_info(synch_job, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Update a synch job.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SynchJobsApi
Returns a new instance of SynchJobsApi.
30 31 32 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_sync_job(synch_job, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Create a synch job. a new sync job","request":"createSynchJobRequest.html","response":"createSynchJobResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 39 def create_sync_job(synch_job, opts = {}) data, _status_code, _headers = create_sync_job_with_http_info(synch_job, opts) return data end |
#create_sync_job_with_http_info(synch_job, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Create a synch job. a new sync job","request":"createSynchJobRequest.html","response":"createSynchJobResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 49 def create_sync_job_with_http_info(synch_job, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.create_sync_job ..." end # verify the required parameter 'synch_job' is set fail ArgumentError, "Missing the required parameter 'synch_job' when calling SynchJobsApi.create_sync_job" if synch_job.nil? # resource path local_var_path = "/synchJobs".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(synch_job) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#create_sync_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_all_sync_jobs(opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection of Users. By default 10 values are returned. Records are returned in natural order. all synch jobs","response":"getSynchJobsAll.html"
100 101 102 103 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 100 def get_all_sync_jobs(opts = {}) data, _status_code, _headers = get_all_sync_jobs_with_http_info(opts) return data end |
#get_all_sync_jobs_with_http_info(opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection of Users. By default 10 values are returned. Records are returned in natural order. all synch jobs","response":"getSynchJobsAll.html"
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 114 def get_all_sync_jobs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.get_all_sync_jobs ..." end if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/synchJobs".sub('{format}','json') # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#get_all_sync_jobs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_job_by_id(synch_job_id, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a single job, specified by the ID parameter. an existing synch job","response":"getSyncJobByID.html"
168 169 170 171 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 168 def get_sync_job_by_id(synch_job_id, opts = {}) data, _status_code, _headers = get_sync_job_by_id_with_http_info(synch_job_id, opts) return data end |
#get_sync_job_by_id_with_http_info(synch_job_id, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a single job, specified by the ID parameter. an existing synch job","response":"getSyncJobByID.html"
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 179 def get_sync_job_by_id_with_http_info(synch_job_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.get_sync_job_by_id ..." end # verify the required parameter 'synch_job_id' is set fail ArgumentError, "Missing the required parameter 'synch_job_id' when calling SynchJobsApi.get_sync_job_by_id" if synch_job_id.nil? # resource path local_var_path = "/synchJobs/{synchJob-ID}".sub('{format}','json').sub('{' + 'synchJob-ID' + '}', synch_job_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#get_sync_job_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_job_by_scope(scope, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the scope parameter. by scope","response":"getSyncJobByScope.html"
228 229 230 231 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 228 def get_sync_job_by_scope(scope, opts = {}) data, _status_code, _headers = get_sync_job_by_scope_with_http_info(scope, opts) return data end |
#get_sync_job_by_scope_with_http_info(scope, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the scope parameter. by scope","response":"getSyncJobByScope.html"
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 239 def get_sync_job_by_scope_with_http_info(scope, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.get_sync_job_by_scope ..." end # verify the required parameter 'scope' is set fail ArgumentError, "Missing the required parameter 'scope' when calling SynchJobsApi.get_sync_job_by_scope" if scope.nil? # verify enum value unless ['Manual', 'Scheduled'].include?(scope) fail ArgumentError, "invalid value for 'scope', must be one of Manual, Scheduled" end # resource path local_var_path = "/synchJobs/scope/{scope}".sub('{format}','json').sub('{' + 'scope' + '}', scope.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#get_sync_job_by_scope\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_job_by_state(state, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the state parameter. by state","response":"getSyncJobByState.html"
292 293 294 295 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 292 def get_sync_job_by_state(state, opts = {}) data, _status_code, _headers = get_sync_job_by_state_with_http_info(state, opts) return data end |
#get_sync_job_by_state_with_http_info(state, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the state parameter. by state","response":"getSyncJobByState.html"
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 303 def get_sync_job_by_state_with_http_info(state, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.get_sync_job_by_state ..." end # verify the required parameter 'state' is set fail ArgumentError, "Missing the required parameter 'state' when calling SynchJobsApi.get_sync_job_by_state" if state.nil? # verify enum value unless ['Pending', 'Complete', 'Failed', 'Cancelled', 'Processing'].include?(state) fail ArgumentError, "invalid value for 'state', must be one of Pending, Complete, Failed, Cancelled, Processing" end # resource path local_var_path = "/synchJobs/state/{state}".sub('{format}','json').sub('{' + 'state' + '}', state.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#get_sync_job_by_state\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_job_by_target(target, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the target parameter. by target","response":"getSyncJobByTarget.html"
356 357 358 359 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 356 def get_sync_job_by_target(target, opts = {}) data, _status_code, _headers = get_sync_job_by_target_with_http_info(target, opts) return data end |
#get_sync_job_by_target_with_http_info(target, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the target parameter. by target","response":"getSyncJobByTarget.html"
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 367 def get_sync_job_by_target_with_http_info(target, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.get_sync_job_by_target ..." end # verify the required parameter 'target' is set fail ArgumentError, "Missing the required parameter 'target' when calling SynchJobsApi.get_sync_job_by_target" if target.nil? # verify enum value unless ['Salesforce'].include?(target) fail ArgumentError, "invalid value for 'target', must be one of Salesforce" end # resource path local_var_path = "/synchJobs/target/{target}".sub('{format}','json').sub('{' + 'target' + '}', target.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#get_sync_job_by_target\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sync_job_by_type(type, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Returns a collection jobs, specified by the type parameter. by type","response":"getSyncJobByType.html"
420 421 422 423 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 420 def get_sync_job_by_type(type, opts = {}) data, _status_code, _headers = get_sync_job_by_type_with_http_info(type, opts) return data end |
#get_sync_job_by_type_with_http_info(type, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Returns a collection jobs, specified by the type parameter. by type","response":"getSyncJobByType.html"
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 431 def get_sync_job_by_type_with_http_info(type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.get_sync_job_by_type ..." end # verify the required parameter 'type' is set fail ArgumentError, "Missing the required parameter 'type' when calling SynchJobsApi.get_sync_job_by_type" if type.nil? # verify enum value unless ['Incremental', 'Full'].include?(type) fail ArgumentError, "invalid value for 'type', must be one of Incremental, Full" end # resource path local_var_path = "/synchJobs/type/{type}".sub('{format}','json').sub('{' + 'type' + '}', type.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['text/plain'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#get_sync_job_by_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_sync_job(synch_job, opts = {}) ⇒ DataSynchronizationJobPagedMetadata
Update a synch job. a synch job","request":"updateSyncJobRequest.html","response":"updateSyncJobResponse.html"
483 484 485 486 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 483 def update_sync_job(synch_job, opts = {}) data, _status_code, _headers = update_sync_job_with_http_info(synch_job, opts) return data end |
#update_sync_job_with_http_info(synch_job, opts = {}) ⇒ Array<(DataSynchronizationJobPagedMetadata, Fixnum, Hash)>
Update a synch job. a synch job","request":"updateSyncJobRequest.html","response":"updateSyncJobResponse.html"
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/bf_ruby2/api/synch_jobs_api.rb', line 493 def update_sync_job_with_http_info(synch_job, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: SynchJobsApi.update_sync_job ..." end # verify the required parameter 'synch_job' is set fail ArgumentError, "Missing the required parameter 'synch_job' when calling SynchJobsApi.update_sync_job" if synch_job.nil? # resource path local_var_path = "/synchJobs".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(synch_job) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'DataSynchronizationJobPagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: SynchJobsApi#update_sync_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |