Class: BillForward::UsageApi
- Inherits:
-
Object
- Object
- BillForward::UsageApi
- Defined in:
- lib/bf_ruby2/api/usage_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_usage_instance(usage, opts = {}) ⇒ UsagePagedMetadata
Add usage usage","request":"createUsageRequest.html","response":"createUsageResponse.html".
-
#create_usage_instance_with_http_info(usage, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Add usage usage","request":"createUsageRequest.html","response":"createUsageResponse.html".
-
#get_usage_by_id(subscription_id, period_id, opts = {}) ⇒ UsagePagedMetadata
Retrieve by subscription and period by subscription and period","response":"getUsageForPeriod.html".
-
#get_usage_by_id_with_http_info(subscription_id, period_id, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Retrieve by subscription and period by subscription and period","response":"getUsageForPeriod.html".
-
#get_usage_by_subscription_id(subscription_id, opts = {}) ⇒ UsagePagedMetadata
Retrieve by subscription by subscription","response":"getUsage.html".
-
#get_usage_by_subscription_id_uo_m_period_and_usage_type(subscription_id, uom, period_id, usage_type, opts = {}) ⇒ UsagePagedMetadata
Retrieve by subscription, period and type by subscription, period and type","response":"getDetailedUsageForPeriod.html".
-
#get_usage_by_subscription_id_uo_m_period_and_usage_type_with_http_info(subscription_id, uom, period_id, usage_type, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Retrieve by subscription, period and type by subscription, period and type","response":"getDetailedUsageForPeriod.html".
-
#get_usage_by_subscription_id_with_http_info(subscription_id, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Retrieve by subscription by subscription","response":"getUsage.html".
-
#initialize(api_client = ApiClient.default) ⇒ UsageApi
constructor
A new instance of UsageApi.
-
#update_usage_instance(usage, opts = {}) ⇒ UsagePagedMetadata
Update usage usage","request":"updateUsageRequest.html","response":"updateUsageResponse.html".
-
#update_usage_instance_with_http_info(usage, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Update usage usage","request":"updateUsageRequest.html","response":"updateUsageResponse.html".
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UsageApi
Returns a new instance of UsageApi.
30 31 32 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 30 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
28 29 30 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 28 def api_client @api_client end |
Instance Method Details
#create_usage_instance(usage, opts = {}) ⇒ UsagePagedMetadata
Add usage usage","request":"createUsageRequest.html","response":"createUsageResponse.html"
39 40 41 42 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 39 def create_usage_instance(usage, opts = {}) data, _status_code, _headers = create_usage_instance_with_http_info(usage, opts) return data end |
#create_usage_instance_with_http_info(usage, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Add usage usage","request":"createUsageRequest.html","response":"createUsageResponse.html"
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 49 def create_usage_instance_with_http_info(usage, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: UsageApi.create_usage_instance ..." end # verify the required parameter 'usage' is set fail ArgumentError, "Missing the required parameter 'usage' when calling UsageApi.create_usage_instance" if usage.nil? # resource path local_var_path = "/usage".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(usage) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UsagePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: UsageApi#create_usage_instance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_usage_by_id(subscription_id, period_id, opts = {}) ⇒ UsagePagedMetadata
Retrieve by subscription and period by subscription and period","response":"getUsageForPeriod.html"
102 103 104 105 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 102 def get_usage_by_id(subscription_id, period_id, opts = {}) data, _status_code, _headers = get_usage_by_id_with_http_info(subscription_id, period_id, opts) return data end |
#get_usage_by_id_with_http_info(subscription_id, period_id, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Retrieve by subscription and period by subscription and period","response":"getUsageForPeriod.html"
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 118 def get_usage_by_id_with_http_info(subscription_id, period_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: UsageApi.get_usage_by_id ..." end # verify the required parameter 'subscription_id' is set fail ArgumentError, "Missing the required parameter 'subscription_id' when calling UsageApi.get_usage_by_id" if subscription_id.nil? # verify the required parameter 'period_id' is set fail ArgumentError, "Missing the required parameter 'period_id' when calling UsageApi.get_usage_by_id" if period_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/usage/{subscription-id}/{period-id}".sub('{format}','json').sub('{' + 'subscription-id' + '}', subscription_id.to_s).sub('{' + 'period-id' + '}', period_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UsagePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: UsageApi#get_usage_by_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_usage_by_subscription_id(subscription_id, opts = {}) ⇒ UsagePagedMetadata
Retrieve by subscription by subscription","response":"getUsage.html"
180 181 182 183 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 180 def get_usage_by_subscription_id(subscription_id, opts = {}) data, _status_code, _headers = get_usage_by_subscription_id_with_http_info(subscription_id, opts) return data end |
#get_usage_by_subscription_id_uo_m_period_and_usage_type(subscription_id, uom, period_id, usage_type, opts = {}) ⇒ UsagePagedMetadata
Retrieve by subscription, period and type by subscription, period and type","response":"getDetailedUsageForPeriod.html"
258 259 260 261 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 258 def get_usage_by_subscription_id_uo_m_period_and_usage_type(subscription_id, uom, period_id, usage_type, opts = {}) data, _status_code, _headers = get_usage_by_subscription_id_uo_m_period_and_usage_type_with_http_info(subscription_id, uom, period_id, usage_type, opts) return data end |
#get_usage_by_subscription_id_uo_m_period_and_usage_type_with_http_info(subscription_id, uom, period_id, usage_type, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Retrieve by subscription, period and type by subscription, period and type","response":"getDetailedUsageForPeriod.html"
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 276 def get_usage_by_subscription_id_uo_m_period_and_usage_type_with_http_info(subscription_id, uom, period_id, usage_type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: UsageApi.get_usage_by_subscription_id_uo_m_period_and_usage_type ..." end # verify the required parameter 'subscription_id' is set fail ArgumentError, "Missing the required parameter 'subscription_id' when calling UsageApi.get_usage_by_subscription_id_uo_m_period_and_usage_type" if subscription_id.nil? # verify the required parameter 'uom' is set fail ArgumentError, "Missing the required parameter 'uom' when calling UsageApi.get_usage_by_subscription_id_uo_m_period_and_usage_type" if uom.nil? # verify the required parameter 'period_id' is set fail ArgumentError, "Missing the required parameter 'period_id' when calling UsageApi.get_usage_by_subscription_id_uo_m_period_and_usage_type" if period_id.nil? # verify the required parameter 'usage_type' is set fail ArgumentError, "Missing the required parameter 'usage_type' when calling UsageApi.get_usage_by_subscription_id_uo_m_period_and_usage_type" if usage_type.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/usage/{subscription-id}/{uom}/{period-id}/{usage-type}".sub('{format}','json').sub('{' + 'subscription-id' + '}', subscription_id.to_s).sub('{' + 'uom' + '}', uom.to_s).sub('{' + 'period-id' + '}', period_id.to_s).sub('{' + 'usage-type' + '}', usage_type.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UsagePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: UsageApi#get_usage_by_subscription_id_uo_m_period_and_usage_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_usage_by_subscription_id_with_http_info(subscription_id, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Retrieve by subscription by subscription","response":"getUsage.html"
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 195 def get_usage_by_subscription_id_with_http_info(subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: UsageApi.get_usage_by_subscription_id ..." end # verify the required parameter 'subscription_id' is set fail ArgumentError, "Missing the required parameter 'subscription_id' when calling UsageApi.get_usage_by_subscription_id" if subscription_id.nil? if opts[:'order'] && !['ASC', 'DESC'].include?(opts[:'order']) fail ArgumentError, 'invalid value for "order", must be one of ASC, DESC' end # resource path local_var_path = "/usage/{subscription-id}".sub('{format}','json').sub('{' + 'subscription-id' + '}', subscription_id.to_s) # query parameters query_params = {} query_params[:'organizations'] = @api_client.build_collection_param(opts[:'organizations'], :multi) if !opts[:'organizations'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'records'] = opts[:'records'] if !opts[:'records'].nil? query_params[:'order_by'] = opts[:'order_by'] if !opts[:'order_by'].nil? query_params[:'order'] = opts[:'order'] if !opts[:'order'].nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = [] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UsagePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: UsageApi#get_usage_by_subscription_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_usage_instance(usage, opts = {}) ⇒ UsagePagedMetadata
Update usage usage","request":"updateUsageRequest.html","response":"updateUsageResponse.html"
337 338 339 340 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 337 def update_usage_instance(usage, opts = {}) data, _status_code, _headers = update_usage_instance_with_http_info(usage, opts) return data end |
#update_usage_instance_with_http_info(usage, opts = {}) ⇒ Array<(UsagePagedMetadata, Fixnum, Hash)>
Update usage usage","request":"updateUsageRequest.html","response":"updateUsageResponse.html"
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/bf_ruby2/api/usage_api.rb', line 347 def update_usage_instance_with_http_info(usage, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: UsageApi.update_usage_instance ..." end # verify the required parameter 'usage' is set fail ArgumentError, "Missing the required parameter 'usage' when calling UsageApi.update_usage_instance" if usage.nil? # resource path local_var_path = "/usage".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) local_header_accept = ['text/xml', 'application/xml', 'application/json; charset=utf-8'] local_header_accept_result = @api_client.select_header_accept(local_header_accept) and header_params['Accept'] = local_header_accept_result # HTTP header 'Content-Type' local_header_content_type = ['application/json; charset=utf-8'] header_params['Content-Type'] = @api_client.select_header_content_type(local_header_content_type) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(usage) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UsagePagedMetadata') if @api_client.config.debugging @api_client.config.logger.debug "API called: UsageApi#update_usage_instance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |